@@ -1,30 +1,21 @@
 var globals_dup =
 [
-    [ "!", "globals.html", null ],
-    [ "_", "globals__.html", null ],
+    [ "_", "globals.html", null ],
     [ "a", "globals_a.html", null ],
-    [ "b", "globals_b.html", null ],
     [ "c", "globals_c.html", null ],
     [ "d", "globals_d.html", null ],
-    [ "e", "globals_e.html", null ],
     [ "f", "globals_f.html", null ],
     [ "g", "globals_g.html", null ],
     [ "h", "globals_h.html", null ],
     [ "i", "globals_i.html", null ],
-    [ "j", "globals_j.html", null ],
-    [ "k", "globals_k.html", null ],
     [ "l", "globals_l.html", null ],
     [ "m", "globals_m.html", null ],
     [ "n", "globals_n.html", null ],
-    [ "o", "globals_o.html", null ],
     [ "p", "globals_p.html", null ],
     [ "r", "globals_r.html", null ],
     [ "s", "globals_s.html", null ],
     [ "t", "globals_t.html", null ],
     [ "u", "globals_u.html", null ],
-    [ "v", "globals_v.html", null ],
-    [ "w", "globals_w.html", null ],
     [ "x", "globals_x.html", null ],
-    [ "y", "globals_y.html", null ],
     [ "z", "globals_z.html", null ]
 ];
\ No newline at end of file
