@@ -1,11 +1,49 @@
 var NAVTREEINDEX110 =
 {
-"df/d12/sblat3_8f_ab4eaef13c778812c29d5fc176aca492f.html#ab4eaef13c778812c29d5fc176aca492f":[2,0,0,1,8,12],
+"df/d06/lapacke__ctrcon__work_8c_ad3c21df643c23b07cf4e6e4ac5cf0181.html#ad3c21df643c23b07cf4e6e4ac5cf0181":[2,0,3,3,559,0],
+"df/d06/lapacke__ctrcon__work_8c_source.html":[2,0,3,3,559],
+"df/d07/lapacke__ctgsyl__work_8c.html":[2,0,3,3,537],
+"df/d07/lapacke__ctgsyl__work_8c_a418510cd551e456919a2e580f31b12e4.html#a418510cd551e456919a2e580f31b12e4":[2,0,3,3,537,0],
+"df/d07/lapacke__ctgsyl__work_8c_source.html":[2,0,3,3,537],
+"df/d0b/dsytrf__aa_8f.html":[2,0,4,906],
+"df/d0b/dsytrf__aa_8f_source.html":[2,0,4,906],
+"df/d0c/lapacke__dlasrt__work_8c.html":[2,0,3,3,849],
+"df/d0c/lapacke__dlasrt__work_8c_a0a1ed2b92e5086a4507ac1cbacdace4f.html#a0a1ed2b92e5086a4507ac1cbacdace4f":[2,0,3,3,849,0],
+"df/d0c/lapacke__dlasrt__work_8c_source.html":[2,0,3,3,849],
+"df/d0c/sdrvst2stg_8f.html":[2,0,5,0,218],
+"df/d0c/sdrvst2stg_8f_source.html":[2,0,5,0,218],
+"df/d0f/dzasum_8f.html":[2,0,0,0,70],
+"df/d0f/dzasum_8f_source.html":[2,0,0,0,70],
+"df/d0f/lapacke__stgexc_8c.html":[2,0,3,3,1733],
+"df/d0f/lapacke__stgexc_8c_aff49cfe1afe2620ccb96cb25290029d6.html#aff49cfe1afe2620ccb96cb25290029d6":[2,0,3,3,1733,0],
+"df/d0f/lapacke__stgexc_8c_source.html":[2,0,3,3,1733],
+"df/d10/zungqr_8f.html":[2,0,4,1923],
+"df/d10/zungqr_8f_source.html":[2,0,4,1923],
+"df/d11/lapacke__ctrevc__work_8c.html":[2,0,3,3,561],
+"df/d11/lapacke__ctrevc__work_8c_a38f7ad1fb82a6f7b8df11e3499400fe6.html#a38f7ad1fb82a6f7b8df11e3499400fe6":[2,0,3,3,561,0],
+"df/d11/lapacke__ctrevc__work_8c_source.html":[2,0,3,3,561],
+"df/d11/slapll_8f.html":[2,0,4,1156],
+"df/d11/slapll_8f_source.html":[2,0,4,1156],
+"df/d12/cerrbd_8f.html":[2,0,5,0,45],
+"df/d12/cerrbd_8f_source.html":[2,0,5,0,45],
+"df/d12/lapacke__chbevx__2stage__work_8c.html":[2,0,3,3,180],
+"df/d12/lapacke__chbevx__2stage__work_8c_a3fe8510dd6efcb6d670d3a7ced0993f5.html#a3fe8510dd6efcb6d670d3a7ced0993f5":[2,0,3,3,180,0],
+"df/d12/lapacke__chbevx__2stage__work_8c_source.html":[2,0,3,3,180],
+"df/d12/sblat3_8f.html":[2,0,0,1,8],
+"df/d12/sblat3_8f_a1c298334ebbca6a82c3c32bc24fa9286.html#a1c298334ebbca6a82c3c32bc24fa9286":[2,0,0,1,8,1],
+"df/d12/sblat3_8f_a1e23a9d74d4acf6f0a0c0944d653b213.html#a1e23a9d74d4acf6f0a0c0944d653b213":[2,0,0,1,8,10],
+"df/d12/sblat3_8f_a30a4ceda48eefff13734aeae8a451140.html#a30a4ceda48eefff13734aeae8a451140":[2,0,0,1,8,5],
+"df/d12/sblat3_8f_a338dd593080b76432c2540c9c4837ff9.html#a338dd593080b76432c2540c9c4837ff9":[2,0,0,1,8,2],
+"df/d12/sblat3_8f_a3597737138b45ecc8c7cbb2bee691334.html#a3597737138b45ecc8c7cbb2bee691334":[2,0,0,1,8,6],
+"df/d12/sblat3_8f_a377ee61015baf8dea7770b3a404b1c07.html#a377ee61015baf8dea7770b3a404b1c07":[2,0,0,1,8,14],
+"df/d12/sblat3_8f_a57343063350f870a00e61c74d426e7d9.html#a57343063350f870a00e61c74d426e7d9":[2,0,0,1,8,8],
+"df/d12/sblat3_8f_a63e51b74e6acd8c154c4b580350b9840.html#a63e51b74e6acd8c154c4b580350b9840":[2,0,0,1,8,3],
+"df/d12/sblat3_8f_a811bf0c7768bfc6cbd7ebe565f6f42a1.html#a811bf0c7768bfc6cbd7ebe565f6f42a1":[2,0,0,1,8,9],
+"df/d12/sblat3_8f_a8b530541d1d90ba10621058fbabcf4e4.html#a8b530541d1d90ba10621058fbabcf4e4":[2,0,0,1,8,13],
+"df/d12/sblat3_8f_aa9175f36775378b28d6c23e177f5bac3.html#aa9175f36775378b28d6c23e177f5bac3":[2,0,0,1,8,7],
 "df/d12/sblat3_8f_ac38ebedb093eaa221fa9c708c2c9b34c.html#ac38ebedb093eaa221fa9c708c2c9b34c":[2,0,0,1,8,11],
-"df/d12/sblat3_8f_ae2c02963dd2f871b072fe1c859375042.html#ae2c02963dd2f871b072fe1c859375042":[2,0,0,1,8,6],
-"df/d12/sblat3_8f_ae2e7ab6a0c23c01a8c47760147fa111a.html#ae2e7ab6a0c23c01a8c47760147fa111a":[2,0,0,1,8,9],
-"df/d12/sblat3_8f_ae8b3965ff18b75f0fe0170096a9712ec.html#ae8b3965ff18b75f0fe0170096a9712ec":[2,0,0,1,8,8],
 "df/d12/sblat3_8f_af0279384c87f94223fdf27a4d97f4f7d.html#af0279384c87f94223fdf27a4d97f4f7d":[2,0,0,1,8,0],
+"df/d12/sblat3_8f_af6989f98e6d5db4084fdbf5b2a153d3d.html#af6989f98e6d5db4084fdbf5b2a153d3d":[2,0,0,1,8,12],
 "df/d12/sblat3_8f_source.html":[2,0,0,1,8],
 "df/d13/derrhs_8f.html":[2,0,5,0,130],
 "df/d13/derrhs_8f_source.html":[2,0,5,0,130],
@@ -17,25 +55,25 @@ var NAVTREEINDEX110 =
 "df/d14/lapacke__cgeqr2_8c.html":[2,0,3,3,77],
 "df/d14/lapacke__cgeqr2_8c_aff8d767232b5d9598ed30e541bc2d065.html#aff8d767232b5d9598ed30e541bc2d065":[2,0,3,3,77,0],
 "df/d14/lapacke__cgeqr2_8c_source.html":[2,0,3,3,77],
-"df/d14/lapacke__cuncsd_8c.html":[2,0,3,3,582],
-"df/d14/lapacke__cuncsd_8c_a0d8bba2ce527b3bd6c82a3f6bd31320b.html#a0d8bba2ce527b3bd6c82a3f6bd31320b":[2,0,3,3,582,0],
-"df/d14/lapacke__cuncsd_8c_source.html":[2,0,3,3,582],
+"df/d14/lapacke__cuncsd_8c.html":[2,0,3,3,584],
+"df/d14/lapacke__cuncsd_8c_a0d8bba2ce527b3bd6c82a3f6bd31320b.html#a0d8bba2ce527b3bd6c82a3f6bd31320b":[2,0,3,3,584,0],
+"df/d14/lapacke__cuncsd_8c_source.html":[2,0,3,3,584],
 "df/d15/lapacke__ssy__nancheck_8c.html":[2,0,3,4,99],
 "df/d15/lapacke__ssy__nancheck_8c_ae64b4197793e4ad4b1a210aa277ac0dd.html#ae64b4197793e4ad4b1a210aa277ac0dd":[2,0,3,4,99,0],
 "df/d15/lapacke__ssy__nancheck_8c_source.html":[2,0,3,4,99],
-"df/d16/lapacke__cstein__work_8c.html":[2,0,3,3,451],
-"df/d16/lapacke__cstein__work_8c_a4a3edc89975fb5b676e6aeb80158ae2a.html#a4a3edc89975fb5b676e6aeb80158ae2a":[2,0,3,3,451,0],
-"df/d16/lapacke__cstein__work_8c_source.html":[2,0,3,3,451],
-"df/d16/lapacke__dgtrfs_8c.html":[2,0,3,3,786],
-"df/d16/lapacke__dgtrfs_8c_a0c6ee6b5db49f01f1a94945c8df3cd8d.html#a0c6ee6b5db49f01f1a94945c8df3cd8d":[2,0,3,3,786,0],
-"df/d16/lapacke__dgtrfs_8c_source.html":[2,0,3,3,786],
-"df/d16/zspr_8f.html":[2,0,4,1818],
-"df/d16/zspr_8f_source.html":[2,0,4,1818],
+"df/d16/lapacke__cstein__work_8c.html":[2,0,3,3,453],
+"df/d16/lapacke__cstein__work_8c_a4a3edc89975fb5b676e6aeb80158ae2a.html#a4a3edc89975fb5b676e6aeb80158ae2a":[2,0,3,3,453,0],
+"df/d16/lapacke__cstein__work_8c_source.html":[2,0,3,3,453],
+"df/d16/lapacke__dgtrfs_8c.html":[2,0,3,3,788],
+"df/d16/lapacke__dgtrfs_8c_a0c6ee6b5db49f01f1a94945c8df3cd8d.html#a0c6ee6b5db49f01f1a94945c8df3cd8d":[2,0,3,3,788,0],
+"df/d16/lapacke__dgtrfs_8c_source.html":[2,0,3,3,788],
+"df/d16/zspr_8f.html":[2,0,4,1817],
+"df/d16/zspr_8f_source.html":[2,0,4,1817],
 "df/d17/cchkbl_8f.html":[2,0,5,0,13],
 "df/d17/cchkbl_8f_source.html":[2,0,5,0,13],
-"df/d18/lapacke__dggbak_8c.html":[2,0,3,3,748],
-"df/d18/lapacke__dggbak_8c_a7dba8b074ae0077a60748b6acd39b745.html#a7dba8b074ae0077a60748b6acd39b745":[2,0,3,3,748,0],
-"df/d18/lapacke__dggbak_8c_source.html":[2,0,3,3,748],
+"df/d18/lapacke__dggbak_8c.html":[2,0,3,3,750],
+"df/d18/lapacke__dggbak_8c_a7dba8b074ae0077a60748b6acd39b745.html#a7dba8b074ae0077a60748b6acd39b745":[2,0,3,3,750,0],
+"df/d18/lapacke__dggbak_8c_source.html":[2,0,3,3,750],
 "df/d18/zdrvbd_8f.html":[2,0,5,0,307],
 "df/d18/zdrvbd_8f_source.html":[2,0,5,0,307],
 "df/d19/zchkps_8f.html":[2,0,5,1,569],
@@ -43,22 +81,22 @@ var NAVTREEINDEX110 =
 "df/d1a/lapacke__chpev_8c.html":[2,0,3,3,274],
 "df/d1a/lapacke__chpev_8c_ab4aabd24a7c8aeda805d6ce4a53d1251.html#ab4aabd24a7c8aeda805d6ce4a53d1251":[2,0,3,3,274,0],
 "df/d1a/lapacke__chpev_8c_source.html":[2,0,3,3,274],
-"df/d1a/lapacke__zheev__work_8c.html":[2,0,3,3,1986],
-"df/d1a/lapacke__zheev__work_8c_a36e02d4e1ef418164cbca63e0c13e55e.html#a36e02d4e1ef418164cbca63e0c13e55e":[2,0,3,3,1986,0],
-"df/d1a/lapacke__zheev__work_8c_source.html":[2,0,3,3,1986],
+"df/d1a/lapacke__zheev__work_8c.html":[2,0,3,3,1992],
+"df/d1a/lapacke__zheev__work_8c_a36e02d4e1ef418164cbca63e0c13e55e.html#a36e02d4e1ef418164cbca63e0c13e55e":[2,0,3,3,1992,0],
+"df/d1a/lapacke__zheev__work_8c_source.html":[2,0,3,3,1992],
 "df/d1b/ctpt02_8f.html":[2,0,5,1,193],
 "df/d1b/ctpt02_8f_source.html":[2,0,5,1,193],
 "df/d1c/lapacke__clarft__work_8c.html":[2,0,3,3,339],
 "df/d1c/lapacke__clarft__work_8c_a22cf35772040bebbcd98aad331984945.html#a22cf35772040bebbcd98aad331984945":[2,0,3,3,339,0],
 "df/d1c/lapacke__clarft__work_8c_source.html":[2,0,3,3,339],
-"df/d1c/lapacke__zpbrfs_8c.html":[2,0,3,3,2143],
-"df/d1c/lapacke__zpbrfs_8c_a283915cde35c45428a10914eb039c732.html#a283915cde35c45428a10914eb039c732":[2,0,3,3,2143,0],
-"df/d1c/lapacke__zpbrfs_8c_source.html":[2,0,3,3,2143],
-"df/d1c/sstevr_8f.html":[2,0,4,1365],
-"df/d1c/sstevr_8f_source.html":[2,0,4,1365],
-"df/d1d/lapacke__ssytrs2_8c.html":[2,0,3,3,1702],
-"df/d1d/lapacke__ssytrs2_8c_afaf6cc20f7c90e462b5ed86e6f79499e.html#afaf6cc20f7c90e462b5ed86e6f79499e":[2,0,3,3,1702,0],
-"df/d1d/lapacke__ssytrs2_8c_source.html":[2,0,3,3,1702],
+"df/d1c/lapacke__zpbrfs_8c.html":[2,0,3,3,2151],
+"df/d1c/lapacke__zpbrfs_8c_a283915cde35c45428a10914eb039c732.html#a283915cde35c45428a10914eb039c732":[2,0,3,3,2151,0],
+"df/d1c/lapacke__zpbrfs_8c_source.html":[2,0,3,3,2151],
+"df/d1c/sstevr_8f.html":[2,0,4,1364],
+"df/d1c/sstevr_8f_source.html":[2,0,4,1364],
+"df/d1d/lapacke__ssytrs2_8c.html":[2,0,3,3,1708],
+"df/d1d/lapacke__ssytrs2_8c_afaf6cc20f7c90e462b5ed86e6f79499e.html#afaf6cc20f7c90e462b5ed86e6f79499e":[2,0,3,3,1708,0],
+"df/d1d/lapacke__ssytrs2_8c_source.html":[2,0,3,3,1708],
 "df/d1e/lapacke__clapmt_8c.html":[2,0,3,3,332],
 "df/d1e/lapacke__clapmt_8c_a5d50f6a83a2b20e6bef1e8fcb27bb52c.html#a5d50f6a83a2b20e6bef1e8fcb27bb52c":[2,0,3,3,332,0],
 "df/d1e/lapacke__clapmt_8c_source.html":[2,0,3,3,332],
@@ -66,42 +104,42 @@ var NAVTREEINDEX110 =
 "df/d1f/dlar1v_8f_source.html":[2,0,4,674],
 "df/d1f/sasum_8f.html":[2,0,0,0,77],
 "df/d1f/sasum_8f_source.html":[2,0,0,0,77],
-"df/d20/_s_r_c_2zlarfy_8f.html":[2,0,4,1741],
-"df/d20/_s_r_c_2zlarfy_8f_source.html":[2,0,4,1741],
+"df/d20/_s_r_c_2zlarfy_8f.html":[2,0,4,1740],
+"df/d20/_s_r_c_2zlarfy_8f_source.html":[2,0,4,1740],
 "df/d20/zsyr2k_8f.html":[2,0,0,0,141],
 "df/d20/zsyr2k_8f_source.html":[2,0,0,0,141],
-"df/d21/lapacke__dgetsls__work_8c.html":[2,0,3,3,747],
-"df/d21/lapacke__dgetsls__work_8c_aefb2d33db3f6cce4bd29a1a61e77e5ca.html#aefb2d33db3f6cce4bd29a1a61e77e5ca":[2,0,3,3,747,0],
-"df/d21/lapacke__dgetsls__work_8c_source.html":[2,0,3,3,747],
-"df/d22/lapacke__zgeqrt__work_8c.html":[2,0,3,3,1874],
-"df/d22/lapacke__zgeqrt__work_8c_a5e2f1d694f74c0b81a9ad4d3d30e91a6.html#a5e2f1d694f74c0b81a9ad4d3d30e91a6":[2,0,3,3,1874,0],
-"df/d22/lapacke__zgeqrt__work_8c_source.html":[2,0,3,3,1874],
-"df/d23/lapacke__dsbgvx_8c.html":[2,0,3,3,990],
-"df/d23/lapacke__dsbgvx_8c_a10cdbe816693e1943f93c74917e955e8.html#a10cdbe816693e1943f93c74917e955e8":[2,0,3,3,990,0],
-"df/d23/lapacke__dsbgvx_8c_source.html":[2,0,3,3,990],
-"df/d25/lapacke__sgecon__work_8c.html":[2,0,3,3,1242],
-"df/d25/lapacke__sgecon__work_8c_a9e3cb56f75c18c7b856b572ac04106db.html#a9e3cb56f75c18c7b856b572ac04106db":[2,0,3,3,1242,0],
-"df/d25/lapacke__sgecon__work_8c_source.html":[2,0,3,3,1242],
-"df/d25/ssysv__rk_8f.html":[2,0,4,1392],
-"df/d25/ssysv__rk_8f_a13c1b8d6927e742ba14816baf193c7b5.html#a13c1b8d6927e742ba14816baf193c7b5":[2,0,4,1392,0],
-"df/d25/ssysv__rk_8f_source.html":[2,0,4,1392],
-"df/d25/zsteqr_8f.html":[2,0,4,1829],
-"df/d25/zsteqr_8f_source.html":[2,0,4,1829],
+"df/d21/lapacke__dgetsls__work_8c.html":[2,0,3,3,749],
+"df/d21/lapacke__dgetsls__work_8c_aefb2d33db3f6cce4bd29a1a61e77e5ca.html#aefb2d33db3f6cce4bd29a1a61e77e5ca":[2,0,3,3,749,0],
+"df/d21/lapacke__dgetsls__work_8c_source.html":[2,0,3,3,749],
+"df/d22/lapacke__zgeqrt__work_8c.html":[2,0,3,3,1880],
+"df/d22/lapacke__zgeqrt__work_8c_a5e2f1d694f74c0b81a9ad4d3d30e91a6.html#a5e2f1d694f74c0b81a9ad4d3d30e91a6":[2,0,3,3,1880,0],
+"df/d22/lapacke__zgeqrt__work_8c_source.html":[2,0,3,3,1880],
+"df/d23/lapacke__dsbgvx_8c.html":[2,0,3,3,994],
+"df/d23/lapacke__dsbgvx_8c_a10cdbe816693e1943f93c74917e955e8.html#a10cdbe816693e1943f93c74917e955e8":[2,0,3,3,994,0],
+"df/d23/lapacke__dsbgvx_8c_source.html":[2,0,3,3,994],
+"df/d25/lapacke__sgecon__work_8c.html":[2,0,3,3,1246],
+"df/d25/lapacke__sgecon__work_8c_a9e3cb56f75c18c7b856b572ac04106db.html#a9e3cb56f75c18c7b856b572ac04106db":[2,0,3,3,1246,0],
+"df/d25/lapacke__sgecon__work_8c_source.html":[2,0,3,3,1246],
+"df/d25/ssysv__rk_8f.html":[2,0,4,1391],
+"df/d25/ssysv__rk_8f_aeb68410e46703ed4079117e14f67a653.html#aeb68410e46703ed4079117e14f67a653":[2,0,4,1391,0],
+"df/d25/ssysv__rk_8f_source.html":[2,0,4,1391],
+"df/d25/zsteqr_8f.html":[2,0,4,1828],
+"df/d25/zsteqr_8f_source.html":[2,0,4,1828],
 "df/d28/group__single__blas__level1.html":[0,2,0,0],
-"df/d28/group__single__blas__level1_ga0a2eaca94b4941dbc351157126cbb0f6.html#ga0a2eaca94b4941dbc351157126cbb0f6":[0,2,0,0,14],
 "df/d28/group__single__blas__level1_ga0a2eaca94b4941dbc351157126cbb0f6.html#ga0a2eaca94b4941dbc351157126cbb0f6":[2,0,0,0,99,0],
+"df/d28/group__single__blas__level1_ga0a2eaca94b4941dbc351157126cbb0f6.html#ga0a2eaca94b4941dbc351157126cbb0f6":[0,2,0,0,14],
 "df/d28/group__single__blas__level1_ga0ce1ab4726eb7ad925cbd89f100d5ce0.html#ga0ce1ab4726eb7ad925cbd89f100d5ce0":[2,0,0,0,90,0],
 "df/d28/group__single__blas__level1_ga0ce1ab4726eb7ad925cbd89f100d5ce0.html#ga0ce1ab4726eb7ad925cbd89f100d5ce0":[0,2,0,0,9],
-"df/d28/group__single__blas__level1_ga24785e467bd921df5a2b7300da57c469.html#ga24785e467bd921df5a2b7300da57c469":[2,0,0,0,82,0],
 "df/d28/group__single__blas__level1_ga24785e467bd921df5a2b7300da57c469.html#ga24785e467bd921df5a2b7300da57c469":[0,2,0,0,5],
-"df/d28/group__single__blas__level1_ga2f65d66137ddaeb7ae93fcc4902de3fc.html#ga2f65d66137ddaeb7ae93fcc4902de3fc":[0,2,0,0,10],
+"df/d28/group__single__blas__level1_ga24785e467bd921df5a2b7300da57c469.html#ga24785e467bd921df5a2b7300da57c469":[2,0,0,0,82,0],
 "df/d28/group__single__blas__level1_ga2f65d66137ddaeb7ae93fcc4902de3fc.html#ga2f65d66137ddaeb7ae93fcc4902de3fc":[2,0,0,0,91,0],
+"df/d28/group__single__blas__level1_ga2f65d66137ddaeb7ae93fcc4902de3fc.html#ga2f65d66137ddaeb7ae93fcc4902de3fc":[0,2,0,0,10],
 "df/d28/group__single__blas__level1_ga3252f1f70b29d59941e9bc65a6aefc0a.html#ga3252f1f70b29d59941e9bc65a6aefc0a":[0,2,0,0,13],
 "df/d28/group__single__blas__level1_ga3252f1f70b29d59941e9bc65a6aefc0a.html#ga3252f1f70b29d59941e9bc65a6aefc0a":[2,0,0,0,95,0],
-"df/d28/group__single__blas__level1_ga351f01fdf3baa8e6a71d56ded46b126d.html#ga351f01fdf3baa8e6a71d56ded46b126d":[2,0,0,0,79,0],
 "df/d28/group__single__blas__level1_ga351f01fdf3baa8e6a71d56ded46b126d.html#ga351f01fdf3baa8e6a71d56ded46b126d":[0,2,0,0,2],
-"df/d28/group__single__blas__level1_ga35c2ec0e9bfdaa545320c2a134fcc471.html#ga35c2ec0e9bfdaa545320c2a134fcc471":[2,0,0,0,89,0],
+"df/d28/group__single__blas__level1_ga351f01fdf3baa8e6a71d56ded46b126d.html#ga351f01fdf3baa8e6a71d56ded46b126d":[2,0,0,0,79,0],
 "df/d28/group__single__blas__level1_ga35c2ec0e9bfdaa545320c2a134fcc471.html#ga35c2ec0e9bfdaa545320c2a134fcc471":[0,2,0,0,8],
+"df/d28/group__single__blas__level1_ga35c2ec0e9bfdaa545320c2a134fcc471.html#ga35c2ec0e9bfdaa545320c2a134fcc471":[2,0,0,0,89,0],
 "df/d28/group__single__blas__level1_ga37a14d8598319955b711af0d64a6f56e.html#ga37a14d8598319955b711af0d64a6f56e":[0,2,0,0,6],
 "df/d28/group__single__blas__level1_ga37a14d8598319955b711af0d64a6f56e.html#ga37a14d8598319955b711af0d64a6f56e":[2,0,0,0,83,0],
 "df/d28/group__single__blas__level1_ga5633344a5729b4f0167aa441dcf95a9c.html#ga5633344a5729b4f0167aa441dcf95a9c":[0,2,0,0,11],
@@ -110,40 +148,40 @@ var NAVTREEINDEX110 =
 "df/d28/group__single__blas__level1_ga97ce4e31b77723a3b60fb3f479f61316.html#ga97ce4e31b77723a3b60fb3f479f61316":[0,2,0,0,12],
 "df/d28/group__single__blas__level1_gab0d23a73e9fd79e8a9c304fd282ab03d.html#gab0d23a73e9fd79e8a9c304fd282ab03d":[0,2,0,0,4],
 "df/d28/group__single__blas__level1_gab0d23a73e9fd79e8a9c304fd282ab03d.html#gab0d23a73e9fd79e8a9c304fd282ab03d":[2,0,0,0,81,0],
-"df/d28/group__single__blas__level1_gad2a52de0e32a6fc111931ece9b39726c.html#gad2a52de0e32a6fc111931ece9b39726c":[0,2,0,0,1],
 "df/d28/group__single__blas__level1_gad2a52de0e32a6fc111931ece9b39726c.html#gad2a52de0e32a6fc111931ece9b39726c":[2,0,0,0,78,0],
-"df/d28/group__single__blas__level1_gadd7d12f994e4868ca9998b054707d934.html#gadd7d12f994e4868ca9998b054707d934":[0,2,0,0,3],
+"df/d28/group__single__blas__level1_gad2a52de0e32a6fc111931ece9b39726c.html#gad2a52de0e32a6fc111931ece9b39726c":[0,2,0,0,1],
 "df/d28/group__single__blas__level1_gadd7d12f994e4868ca9998b054707d934.html#gadd7d12f994e4868ca9998b054707d934":[2,0,0,0,80,0],
+"df/d28/group__single__blas__level1_gadd7d12f994e4868ca9998b054707d934.html#gadd7d12f994e4868ca9998b054707d934":[0,2,0,0,3],
 "df/d28/group__single__blas__level1_gaddc89585ced76065053abffb322c5a22.html#gaddc89585ced76065053abffb322c5a22":[2,0,0,0,84,0],
 "df/d28/group__single__blas__level1_gaddc89585ced76065053abffb322c5a22.html#gaddc89585ced76065053abffb322c5a22":[0,2,0,0,7],
-"df/d28/group__single__blas__level1_gafc5e1e8d9f26907c0a7cf878107f08cf.html#gafc5e1e8d9f26907c0a7cf878107f08cf":[0,2,0,0,0],
 "df/d28/group__single__blas__level1_gafc5e1e8d9f26907c0a7cf878107f08cf.html#gafc5e1e8d9f26907c0a7cf878107f08cf":[2,0,0,0,77,0],
+"df/d28/group__single__blas__level1_gafc5e1e8d9f26907c0a7cf878107f08cf.html#gafc5e1e8d9f26907c0a7cf878107f08cf":[0,2,0,0,0],
 "df/d29/dtbmv_8f.html":[2,0,0,0,62],
 "df/d29/dtbmv_8f_source.html":[2,0,0,0,62],
-"df/d29/lapacke__spbtrs__work_8c.html":[2,0,3,3,1492],
-"df/d29/lapacke__spbtrs__work_8c_ad642e5badf974cb156e58e12c6c2277a.html#ad642e5badf974cb156e58e12c6c2277a":[2,0,3,3,1492,0],
-"df/d29/lapacke__spbtrs__work_8c_source.html":[2,0,3,3,1492],
+"df/d29/lapacke__spbtrs__work_8c.html":[2,0,3,3,1498],
+"df/d29/lapacke__spbtrs__work_8c_ad642e5badf974cb156e58e12c6c2277a.html#ad642e5badf974cb156e58e12c6c2277a":[2,0,3,3,1498,0],
+"df/d29/lapacke__spbtrs__work_8c_source.html":[2,0,3,3,1498],
 "df/d2b/csyt01__rook_8f.html":[2,0,5,1,185],
 "df/d2b/csyt01__rook_8f_source.html":[2,0,5,1,185],
 "df/d2c/chpgv_8f.html":[2,0,4,167],
 "df/d2c/chpgv_8f_source.html":[2,0,4,167],
 "df/d2c/dlasum_8f.html":[2,0,5,0,159],
 "df/d2c/dlasum_8f_source.html":[2,0,5,0,159],
-"df/d2d/lapacke__ctrttp__work_8c.html":[2,0,3,3,577],
-"df/d2d/lapacke__ctrttp__work_8c_a2b7b4526818140eceed4104482a87cac.html#a2b7b4526818140eceed4104482a87cac":[2,0,3,3,577,0],
-"df/d2d/lapacke__ctrttp__work_8c_source.html":[2,0,3,3,577],
+"df/d2d/lapacke__ctrttp__work_8c.html":[2,0,3,3,579],
+"df/d2d/lapacke__ctrttp__work_8c_a2b7b4526818140eceed4104482a87cac.html#a2b7b4526818140eceed4104482a87cac":[2,0,3,3,579,0],
+"df/d2d/lapacke__ctrttp__work_8c_source.html":[2,0,3,3,579],
 "df/d2e/group__complex16_p_tcomputational.html":[0,0,6,1,3],
-"df/d2e/group__complex16_p_tcomputational_ga08d07a22ba5f50a14d9caf644723b5c3.html#ga08d07a22ba5f50a14d9caf644723b5c3":[2,0,4,1808,0],
 "df/d2e/group__complex16_p_tcomputational_ga08d07a22ba5f50a14d9caf644723b5c3.html#ga08d07a22ba5f50a14d9caf644723b5c3":[0,0,6,1,3,1],
-"df/d2e/group__complex16_p_tcomputational_ga216beeac0fe239f03d9b37f51e96d7c7.html#ga216beeac0fe239f03d9b37f51e96d7c7":[2,0,4,1814,0],
+"df/d2e/group__complex16_p_tcomputational_ga08d07a22ba5f50a14d9caf644723b5c3.html#ga08d07a22ba5f50a14d9caf644723b5c3":[2,0,4,1807,0],
 "df/d2e/group__complex16_p_tcomputational_ga216beeac0fe239f03d9b37f51e96d7c7.html#ga216beeac0fe239f03d9b37f51e96d7c7":[0,0,6,1,3,5],
+"df/d2e/group__complex16_p_tcomputational_ga216beeac0fe239f03d9b37f51e96d7c7.html#ga216beeac0fe239f03d9b37f51e96d7c7":[2,0,4,1813,0],
 "df/d2e/group__complex16_p_tcomputational_ga7a91b8a69883b74c20c26aee3c537c55.html#ga7a91b8a69883b74c20c26aee3c537c55":[0,0,6,1,3,4],
-"df/d2e/group__complex16_p_tcomputational_ga7a91b8a69883b74c20c26aee3c537c55.html#ga7a91b8a69883b74c20c26aee3c537c55":[2,0,4,1813,0],
-"df/d2e/group__complex16_p_tcomputational_ga81b328b4e6b06f848d8d9a316990e321.html#ga81b328b4e6b06f848d8d9a316990e321":[0,0,6,1,3,2],
-"df/d2e/group__complex16_p_tcomputational_ga81b328b4e6b06f848d8d9a316990e321.html#ga81b328b4e6b06f848d8d9a316990e321":[2,0,4,1809,0],
-"df/d2e/group__complex16_p_tcomputational_gac66038080132a6b116df577c91e3a39d.html#gac66038080132a6b116df577c91e3a39d":[2,0,4,1812,0],
+"df/d2e/group__complex16_p_tcomputational_ga7a91b8a69883b74c20c26aee3c537c55.html#ga7a91b8a69883b74c20c26aee3c537c55":[2,0,4,1812,0],
+"df/d2e/group__complex16_p_tcomputational_ga93372dc1bb896550f56db40a44b3f202.html#ga93372dc1bb896550f56db40a44b3f202":[0,0,6,1,3,2],
+"df/d2e/group__complex16_p_tcomputational_ga93372dc1bb896550f56db40a44b3f202.html#ga93372dc1bb896550f56db40a44b3f202":[2,0,4,1808,0],
 "df/d2e/group__complex16_p_tcomputational_gac66038080132a6b116df577c91e3a39d.html#gac66038080132a6b116df577c91e3a39d":[0,0,6,1,3,3],
-"df/d2e/group__complex16_p_tcomputational_gae93ce2977fc454e3b4362e894d8b54df.html#gae93ce2977fc454e3b4362e894d8b54df":[2,0,4,1807,0],
+"df/d2e/group__complex16_p_tcomputational_gac66038080132a6b116df577c91e3a39d.html#gac66038080132a6b116df577c91e3a39d":[2,0,4,1811,0],
+"df/d2e/group__complex16_p_tcomputational_gae93ce2977fc454e3b4362e894d8b54df.html#gae93ce2977fc454e3b4362e894d8b54df":[2,0,4,1806,0],
 "df/d2e/group__complex16_p_tcomputational_gae93ce2977fc454e3b4362e894d8b54df.html#gae93ce2977fc454e3b4362e894d8b54df":[0,0,6,1,3,0],
 "df/d2f/cblas__zsymm_8c.html":[2,0,1,2,133],
 "df/d2f/cblas__zsymm_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[2,0,1,2,133,2],
@@ -155,27 +193,27 @@ var NAVTREEINDEX110 =
 "df/d2f/cblas__zsymm_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[2,0,1,2,133,6],
 "df/d2f/cblas__zsymm_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[2,0,1,2,133,3],
 "df/d2f/cblas__zsymm_8c_source.html":[2,0,1,2,133],
-"df/d30/lapacke__stpcon__work_8c.html":[2,0,3,3,1738],
-"df/d30/lapacke__stpcon__work_8c_a840caa323001d102ea876c177c422237.html#a840caa323001d102ea876c177c422237":[2,0,3,3,1738,0],
-"df/d30/lapacke__stpcon__work_8c_source.html":[2,0,3,3,1738],
-"df/d30/lapacke__zpbcon_8c.html":[2,0,3,3,2139],
-"df/d30/lapacke__zpbcon_8c_a7ea4ec67c15fc9caa88a62fbcfd41be1.html#a7ea4ec67c15fc9caa88a62fbcfd41be1":[2,0,3,3,2139,0],
-"df/d30/lapacke__zpbcon_8c_source.html":[2,0,3,3,2139],
-"df/d31/lapacke__slapmr_8c.html":[2,0,3,3,1403],
-"df/d31/lapacke__slapmr_8c_a49640e48b022914d07112eba6fd7d5d1.html#a49640e48b022914d07112eba6fd7d5d1":[2,0,3,3,1403,0],
-"df/d31/lapacke__slapmr_8c_source.html":[2,0,3,3,1403],
-"df/d31/lapacke__ztpttf_8c.html":[2,0,3,3,2337],
-"df/d31/lapacke__ztpttf_8c_a5a78ed3f7d9d31b864b2b419315fb8c2.html#a5a78ed3f7d9d31b864b2b419315fb8c2":[2,0,3,3,2337,0],
-"df/d31/lapacke__ztpttf_8c_source.html":[2,0,3,3,2337],
+"df/d30/lapacke__stpcon__work_8c.html":[2,0,3,3,1744],
+"df/d30/lapacke__stpcon__work_8c_a840caa323001d102ea876c177c422237.html#a840caa323001d102ea876c177c422237":[2,0,3,3,1744,0],
+"df/d30/lapacke__stpcon__work_8c_source.html":[2,0,3,3,1744],
+"df/d30/lapacke__zpbcon_8c.html":[2,0,3,3,2147],
+"df/d30/lapacke__zpbcon_8c_a7ea4ec67c15fc9caa88a62fbcfd41be1.html#a7ea4ec67c15fc9caa88a62fbcfd41be1":[2,0,3,3,2147,0],
+"df/d30/lapacke__zpbcon_8c_source.html":[2,0,3,3,2147],
+"df/d31/lapacke__slapmr_8c.html":[2,0,3,3,1407],
+"df/d31/lapacke__slapmr_8c_a49640e48b022914d07112eba6fd7d5d1.html#a49640e48b022914d07112eba6fd7d5d1":[2,0,3,3,1407,0],
+"df/d31/lapacke__slapmr_8c_source.html":[2,0,3,3,1407],
+"df/d31/lapacke__ztpttf_8c.html":[2,0,3,3,2345],
+"df/d31/lapacke__ztpttf_8c_a5a78ed3f7d9d31b864b2b419315fb8c2.html#a5a78ed3f7d9d31b864b2b419315fb8c2":[2,0,3,3,2345,0],
+"df/d31/lapacke__ztpttf_8c_source.html":[2,0,3,3,2345],
 "df/d32/dgerfs_8f.html":[2,0,4,536],
 "df/d32/dgerfs_8f_source.html":[2,0,4,536],
 "df/d32/serrec_8f.html":[2,0,5,0,222],
 "df/d32/serrec_8f_source.html":[2,0,5,0,222],
 "df/d32/serrlqt_8f.html":[2,0,5,1,438],
 "df/d32/serrlqt_8f_source.html":[2,0,5,1,438],
-"df/d34/lapacke__zpocon_8c.html":[2,0,3,3,2161],
-"df/d34/lapacke__zpocon_8c_afd6c8c4113aee74ae08e61cbf1c71a73.html#afd6c8c4113aee74ae08e61cbf1c71a73":[2,0,3,3,2161,0],
-"df/d34/lapacke__zpocon_8c_source.html":[2,0,3,3,2161],
+"df/d34/lapacke__zpocon_8c.html":[2,0,3,3,2169],
+"df/d34/lapacke__zpocon_8c_afd6c8c4113aee74ae08e61cbf1c71a73.html#afd6c8c4113aee74ae08e61cbf1c71a73":[2,0,3,3,2169,0],
+"df/d34/lapacke__zpocon_8c_source.html":[2,0,3,3,2169],
 "df/d37/slamchf77_8f.html":[2,0,2,20],
 "df/d37/slamchf77_8f_a0259f906df485fc6fba360cb3ebef320.html#a0259f906df485fc6fba360cb3ebef320":[2,0,2,20,0],
 "df/d37/slamchf77_8f_a063f886475dbe005f58b9c37ced98b65.html#a063f886475dbe005f58b9c37ced98b65":[2,0,2,20,2],
@@ -187,22 +225,22 @@ var NAVTREEINDEX110 =
 "df/d38/lapacke__chesvx_8c.html":[2,0,3,3,234],
 "df/d38/lapacke__chesvx_8c_aeb98840f6598288dcefceeda45a6228f.html#aeb98840f6598288dcefceeda45a6228f":[2,0,3,3,234,0],
 "df/d38/lapacke__chesvx_8c_source.html":[2,0,3,3,234],
-"df/d38/lapacke__dptsvx_8c.html":[2,0,3,3,966],
-"df/d38/lapacke__dptsvx_8c_a9005d071f2dd6a9d23ef51750928f14e.html#a9005d071f2dd6a9d23ef51750928f14e":[2,0,3,3,966,0],
-"df/d38/lapacke__dptsvx_8c_source.html":[2,0,3,3,966],
-"df/d38/lapacke__zbdsqr_8c.html":[2,0,3,3,1783],
-"df/d38/lapacke__zbdsqr_8c_a1123bcc2b031aeb35fe899bc443f15ab.html#a1123bcc2b031aeb35fe899bc443f15ab":[2,0,3,3,1783,0],
-"df/d38/lapacke__zbdsqr_8c_source.html":[2,0,3,3,1783],
+"df/d38/lapacke__dptsvx_8c.html":[2,0,3,3,970],
+"df/d38/lapacke__dptsvx_8c_a9005d071f2dd6a9d23ef51750928f14e.html#a9005d071f2dd6a9d23ef51750928f14e":[2,0,3,3,970,0],
+"df/d38/lapacke__dptsvx_8c_source.html":[2,0,3,3,970],
+"df/d38/lapacke__zbdsqr_8c.html":[2,0,3,3,1789],
+"df/d38/lapacke__zbdsqr_8c_a1123bcc2b031aeb35fe899bc443f15ab.html#a1123bcc2b031aeb35fe899bc443f15ab":[2,0,3,3,1789,0],
+"df/d38/lapacke__zbdsqr_8c_source.html":[2,0,3,3,1789],
 "df/d38/lapacke__zhs__nancheck_8c.html":[2,0,3,4,124],
 "df/d38/lapacke__zhs__nancheck_8c_a8baccfd32360d2c8ab62232a23b2e80b.html#a8baccfd32360d2c8ab62232a23b2e80b":[2,0,3,4,124,0],
 "df/d38/lapacke__zhs__nancheck_8c_source.html":[2,0,3,4,124],
-"df/d38/zlahef__rook_8f.html":[2,0,4,1689],
-"df/d38/zlahef__rook_8f_source.html":[2,0,4,1689],
+"df/d38/zlahef__rook_8f.html":[2,0,4,1688],
+"df/d38/zlahef__rook_8f_source.html":[2,0,4,1688],
 "df/d3a/derrsyx_8f.html":[2,0,5,1,279],
 "df/d3a/derrsyx_8f_source.html":[2,0,5,1,279],
-"df/d3a/lapacke__claswp_8c.html":[2,0,3,3,348],
-"df/d3a/lapacke__claswp_8c_ab1a3893307d6c36eb53dbbaa176b4549.html#ab1a3893307d6c36eb53dbbaa176b4549":[2,0,3,3,348,0],
-"df/d3a/lapacke__claswp_8c_source.html":[2,0,3,3,348],
+"df/d3a/lapacke__claswp_8c.html":[2,0,3,3,350],
+"df/d3a/lapacke__claswp_8c_ab1a3893307d6c36eb53dbbaa176b4549.html#ab1a3893307d6c36eb53dbbaa176b4549":[2,0,3,3,350,0],
+"df/d3a/lapacke__claswp_8c_source.html":[2,0,3,3,350],
 "df/d3b/dsyevr_8f.html":[2,0,4,879],
 "df/d3b/dsyevr_8f_source.html":[2,0,4,879],
 "df/d3b/lapacke__cgemqrt_8c.html":[2,0,3,3,68],
@@ -210,44 +248,6 @@ var NAVTREEINDEX110 =
 "df/d3b/lapacke__cgemqrt_8c_source.html":[2,0,3,3,68],
 "df/d3d/ssyr2k_8f.html":[2,0,0,0,104],
 "df/d3d/ssyr2k_8f_source.html":[2,0,0,0,104],
-"df/d3e/lapacke__dtbcon_8c.html":[2,0,3,3,1132],
-"df/d3e/lapacke__dtbcon_8c_a23ad689f8a402288053205537b51fea8.html#a23ad689f8a402288053205537b51fea8":[2,0,3,3,1132,0],
-"df/d3e/lapacke__dtbcon_8c_source.html":[2,0,3,3,1132],
-"df/d3e/slasq3_8f.html":[2,0,4,1224],
-"df/d3e/slasq3_8f_source.html":[2,0,4,1224],
-"df/d3e/zlarscl2_8f.html":[2,0,4,1745],
-"df/d3e/zlarscl2_8f_source.html":[2,0,4,1745],
-"df/d3f/cblas__zaxpy_8c.html":[2,0,1,2,111],
-"df/d3f/cblas__zaxpy_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[2,0,1,2,111,0],
-"df/d3f/cblas__zaxpy_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[2,0,1,2,111,1],
-"df/d3f/cblas__zaxpy_8c_a2b7b182b84c3f44f68adcf6b4fb12336.html#a2b7b182b84c3f44f68adcf6b4fb12336":[2,0,1,2,111,3],
-"df/d3f/cblas__zaxpy_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[2,0,1,2,111,2],
-"df/d3f/cblas__zaxpy_8c_source.html":[2,0,1,2,111],
-"df/d40/ctgevc_8f.html":[2,0,4,410],
-"df/d40/ctgevc_8f_source.html":[2,0,4,410],
-"df/d41/dlags2_8f.html":[2,0,4,625],
-"df/d41/dlags2_8f_source.html":[2,0,4,625],
-"df/d42/zblat1_8f.html":[2,0,0,1,9],
-"df/d42/zblat1_8f_a077aa8449e1055cdecdebf7cb41738a5.html#a077aa8449e1055cdecdebf7cb41738a5":[2,0,0,1,9,6],
-"df/d42/zblat1_8f_a094d00ddd2399699d62da4f0f6f83834.html#a094d00ddd2399699d62da4f0f6f83834":[2,0,0,1,9,5],
-"df/d42/zblat1_8f_a410931b600854e6dd3e253731606117e.html#a410931b600854e6dd3e253731606117e":[2,0,0,1,9,3],
-"df/d42/zblat1_8f_a87cda69493417357e26ad280bc547317.html#a87cda69493417357e26ad280bc547317":[2,0,0,1,9,0],
-"df/d42/zblat1_8f_a9ff9298afee60deb7ffaea43a6d1b668.html#a9ff9298afee60deb7ffaea43a6d1b668":[2,0,0,1,9,1],
-"df/d42/zblat1_8f_ab395702962b4ce31a8b18ae8c74d7f97.html#ab395702962b4ce31a8b18ae8c74d7f97":[2,0,0,1,9,7],
-"df/d42/zblat1_8f_aefe3dd8c590960cceacbe19f55ff769c.html#aefe3dd8c590960cceacbe19f55ff769c":[2,0,0,1,9,2],
-"df/d42/zblat1_8f_af82694537a350a6cb3615ece843dcede.html#af82694537a350a6cb3615ece843dcede":[2,0,0,1,9,4],
-"df/d42/zblat1_8f_source.html":[2,0,0,1,9],
-"df/d43/lapacke__chbevd_8c.html":[2,0,3,3,174],
-"df/d43/lapacke__chbevd_8c_afe5a235c8ba5c0e58a6510ac1051477e.html#afe5a235c8ba5c0e58a6510ac1051477e":[2,0,3,3,174,0],
-"df/d43/lapacke__chbevd_8c_source.html":[2,0,3,3,174],
-"df/d43/lapacke__zgetsls__work_8c.html":[2,0,3,3,1906],
-"df/d43/lapacke__zgetsls__work_8c_aa2dcddab2fa70c9c2ae31af3c1db0533.html#aa2dcddab2fa70c9c2ae31af3c1db0533":[2,0,3,3,1906,0],
-"df/d43/lapacke__zgetsls__work_8c_source.html":[2,0,3,3,1906],
-"df/d43/zlacpy_8f.html":[2,0,4,1673],
-"df/d43/zlacpy_8f_source.html":[2,0,4,1673],
-"df/d44/lapacke__sgetrf2__work_8c.html":[2,0,3,3,1323],
-"df/d44/lapacke__sgetrf2__work_8c_ae34fbd55fc8549409d279e6cf1e3df38.html#ae34fbd55fc8549409d279e6cf1e3df38":[2,0,3,3,1323,0],
-"df/d44/lapacke__sgetrf2__work_8c_source.html":[2,0,3,3,1323],
-"df/d45/spocon_8f.html":[2,0,4,1296],
-"df/d45/spocon_8f_source.html":[2,0,4,1296]
+"df/d3e/lapacke__dtbcon_8c.html":[2,0,3,3,1136],
+"df/d3e/lapacke__dtbcon_8c_a23ad689f8a402288053205537b51fea8.html#a23ad689f8a402288053205537b51fea8":[2,0,3,3,1136,0]
 };
