@@ -1,19 +1,37 @@
 var NAVTREEINDEX43 =
 {
+"d6/de4/lapacke__chptrf_8c.html":[2,0,3,3,296],
+"d6/de4/lapacke__chptrf_8c_a79a452c2b11bdc862ee3e307a360a487.html#a79a452c2b11bdc862ee3e307a360a487":[2,0,3,3,296,0],
+"d6/de4/lapacke__chptrf_8c_source.html":[2,0,3,3,296],
+"d6/de5/lapacke__dlauum__work_8c.html":[2,0,3,3,857],
+"d6/de5/lapacke__dlauum__work_8c_a94924e920ceb68f3be9876d801365ba0.html#a94924e920ceb68f3be9876d801365ba0":[2,0,3,3,857,0],
+"d6/de5/lapacke__dlauum__work_8c_source.html":[2,0,3,3,857],
+"d6/de6/ddrvsg2stg_8f.html":[2,0,5,0,121],
+"d6/de6/ddrvsg2stg_8f_source.html":[2,0,5,0,121],
+"d6/de6/sgetrf2_8f.html":[2,0,4,1052],
+"d6/de6/sgetrf2_8f_source.html":[2,0,4,1052],
+"d6/de6/sgglse_8f.html":[2,0,4,1067],
+"d6/de6/sgglse_8f_source.html":[2,0,4,1067],
+"d6/de8/lapacke__dgesv_8c.html":[2,0,3,3,726],
+"d6/de8/lapacke__dgesv_8c_a3ff136210c1293cb1b015979b9a57d96.html#a3ff136210c1293cb1b015979b9a57d96":[2,0,3,3,726,0],
+"d6/de8/lapacke__dgesv_8c_source.html":[2,0,3,3,726],
+"d6/de8/sormr3_8f.html":[2,0,4,1279],
+"d6/de8/sormr3_8f_source.html":[2,0,4,1279],
+"d6/dea/ctsqr01_8f.html":[2,0,5,1,202],
 "d6/dea/ctsqr01_8f_a5d746df5d34ef26583788a536a988d28.html#a5d746df5d34ef26583788a536a988d28":[2,0,5,1,202,0],
 "d6/dea/ctsqr01_8f_source.html":[2,0,5,1,202],
-"d6/dea/lapacke__zheev_8c.html":[2,0,3,3,1983],
-"d6/dea/lapacke__zheev_8c_a7bcf427fdae62e4c27abf90ffcc43800.html#a7bcf427fdae62e4c27abf90ffcc43800":[2,0,3,3,1983,0],
-"d6/dea/lapacke__zheev_8c_source.html":[2,0,3,3,1983],
+"d6/dea/lapacke__zheev_8c.html":[2,0,3,3,1989],
+"d6/dea/lapacke__zheev_8c_a7bcf427fdae62e4c27abf90ffcc43800.html#a7bcf427fdae62e4c27abf90ffcc43800":[2,0,3,3,1989,0],
+"d6/dea/lapacke__zheev_8c_source.html":[2,0,3,3,1989],
 "d6/dea/zchkpo_8f.html":[2,0,5,1,567],
 "d6/dea/zchkpo_8f_source.html":[2,0,5,1,567],
 "d6/deb/group__auxiliary_g_e.html":[0,0,0,5],
-"d6/deb/lapacke__cpftrs_8c.html":[2,0,3,3,374],
-"d6/deb/lapacke__cpftrs_8c_add041ca547d02655f4a1d1374eddffd9.html#add041ca547d02655f4a1d1374eddffd9":[2,0,3,3,374,0],
-"d6/deb/lapacke__cpftrs_8c_source.html":[2,0,3,3,374],
-"d6/dec/lapacke__ctpcon_8c.html":[2,0,3,3,536],
-"d6/dec/lapacke__ctpcon_8c_a84661d0f1ce95adbb79a3f1755446dd8.html#a84661d0f1ce95adbb79a3f1755446dd8":[2,0,3,3,536,0],
-"d6/dec/lapacke__ctpcon_8c_source.html":[2,0,3,3,536],
+"d6/deb/lapacke__cpftrs_8c.html":[2,0,3,3,376],
+"d6/deb/lapacke__cpftrs_8c_add041ca547d02655f4a1d1374eddffd9.html#add041ca547d02655f4a1d1374eddffd9":[2,0,3,3,376,0],
+"d6/deb/lapacke__cpftrs_8c_source.html":[2,0,3,3,376],
+"d6/dec/lapacke__ctpcon_8c.html":[2,0,3,3,538],
+"d6/dec/lapacke__ctpcon_8c_a84661d0f1ce95adbb79a3f1755446dd8.html#a84661d0f1ce95adbb79a3f1755446dd8":[2,0,3,3,538,0],
+"d6/dec/lapacke__ctpcon_8c_source.html":[2,0,3,3,538],
 "d6/ded/lapacke__cgeqrfp_8c.html":[2,0,3,3,82],
 "d6/ded/lapacke__cgeqrfp_8c_a7e3683ddebb3313ebd6aa98a779dce35.html#a7e3683ddebb3313ebd6aa98a779dce35":[2,0,3,3,82,0],
 "d6/ded/lapacke__cgeqrfp_8c_source.html":[2,0,3,3,82],
@@ -21,18 +39,18 @@ var NAVTREEINDEX43 =
 "d6/ded/second___e_x_t___e_t_i_m_e___8f_ae9f971a8b343bd2fcb85c3b16da97f10.html#ae9f971a8b343bd2fcb85c3b16da97f10":[2,0,2,14,0],
 "d6/ded/second___e_x_t___e_t_i_m_e___8f_source.html":[2,0,2,14],
 "d6/dee/group__complex__blas__level2.html":[0,2,1,2],
-"d6/dee/group__complex__blas__level2_ga0983da08821bec7701e90fb1e65c8cd7.html#ga0983da08821bec7701e90fb1e65c8cd7":[0,2,1,2,1],
 "d6/dee/group__complex__blas__level2_ga0983da08821bec7701e90fb1e65c8cd7.html#ga0983da08821bec7701e90fb1e65c8cd7":[2,0,0,0,6,0],
+"d6/dee/group__complex__blas__level2_ga0983da08821bec7701e90fb1e65c8cd7.html#ga0983da08821bec7701e90fb1e65c8cd7":[0,2,1,2,1],
 "d6/dee/group__complex__blas__level2_ga1afdec04246cf2d0cb650ec237296ef3.html#ga1afdec04246cf2d0cb650ec237296ef3":[0,2,1,2,14],
 "d6/dee/group__complex__blas__level2_ga1afdec04246cf2d0cb650ec237296ef3.html#ga1afdec04246cf2d0cb650ec237296ef3":[2,0,0,0,30,0],
 "d6/dee/group__complex__blas__level2_ga2483c6533c8a24ff715137629f939074.html#ga2483c6533c8a24ff715137629f939074":[0,2,1,2,11],
 "d6/dee/group__complex__blas__level2_ga2483c6533c8a24ff715137629f939074.html#ga2483c6533c8a24ff715137629f939074":[2,0,0,0,27,0],
-"d6/dee/group__complex__blas__level2_ga35e2f0f20e014b9f0ec090a6eb3def22.html#ga35e2f0f20e014b9f0ec090a6eb3def22":[0,2,1,2,2],
 "d6/dee/group__complex__blas__level2_ga35e2f0f20e014b9f0ec090a6eb3def22.html#ga35e2f0f20e014b9f0ec090a6eb3def22":[2,0,0,0,7,0],
-"d6/dee/group__complex__blas__level2_ga38ae7f5a40e16fd315011faddf4412cc.html#ga38ae7f5a40e16fd315011faddf4412cc":[0,2,1,2,16],
+"d6/dee/group__complex__blas__level2_ga35e2f0f20e014b9f0ec090a6eb3def22.html#ga35e2f0f20e014b9f0ec090a6eb3def22":[0,2,1,2,2],
 "d6/dee/group__complex__blas__level2_ga38ae7f5a40e16fd315011faddf4412cc.html#ga38ae7f5a40e16fd315011faddf4412cc":[2,0,0,0,34,0],
-"d6/dee/group__complex__blas__level2_ga426c198e1c8863d9ecbdbe16efa0f6cf.html#ga426c198e1c8863d9ecbdbe16efa0f6cf":[2,0,0,0,9,0],
+"d6/dee/group__complex__blas__level2_ga38ae7f5a40e16fd315011faddf4412cc.html#ga38ae7f5a40e16fd315011faddf4412cc":[0,2,1,2,16],
 "d6/dee/group__complex__blas__level2_ga426c198e1c8863d9ecbdbe16efa0f6cf.html#ga426c198e1c8863d9ecbdbe16efa0f6cf":[0,2,1,2,4],
+"d6/dee/group__complex__blas__level2_ga426c198e1c8863d9ecbdbe16efa0f6cf.html#ga426c198e1c8863d9ecbdbe16efa0f6cf":[2,0,0,0,9,0],
 "d6/dee/group__complex__blas__level2_ga47f0128bb830b67b37b285af34eaad5f.html#ga47f0128bb830b67b37b285af34eaad5f":[0,2,1,2,12],
 "d6/dee/group__complex__blas__level2_ga47f0128bb830b67b37b285af34eaad5f.html#ga47f0128bb830b67b37b285af34eaad5f":[2,0,0,0,28,0],
 "d6/dee/group__complex__blas__level2_ga50fe7a70e7ae8f9ede50acd6747510d7.html#ga50fe7a70e7ae8f9ede50acd6747510d7":[0,2,1,2,0],
@@ -41,36 +59,36 @@ var NAVTREEINDEX43 =
 "d6/dee/group__complex__blas__level2_ga537b8bcd05cbe626ebce0fbc8d66a2d6.html#ga537b8bcd05cbe626ebce0fbc8d66a2d6":[2,0,0,0,18,0],
 "d6/dee/group__complex__blas__level2_ga62930e76219d094e424db1712a5356cb.html#ga62930e76219d094e424db1712a5356cb":[0,2,1,2,15],
 "d6/dee/group__complex__blas__level2_ga62930e76219d094e424db1712a5356cb.html#ga62930e76219d094e424db1712a5356cb":[2,0,0,0,32,0],
-"d6/dee/group__complex__blas__level2_gaa59d93fbbd8d0b1be4a51634cb437cc1.html#gaa59d93fbbd8d0b1be4a51634cb437cc1":[2,0,0,0,13,0],
 "d6/dee/group__complex__blas__level2_gaa59d93fbbd8d0b1be4a51634cb437cc1.html#gaa59d93fbbd8d0b1be4a51634cb437cc1":[0,2,1,2,7],
-"d6/dee/group__complex__blas__level2_gab21c402efadfa2023cfbc06911506e42.html#gab21c402efadfa2023cfbc06911506e42":[0,2,1,2,3],
+"d6/dee/group__complex__blas__level2_gaa59d93fbbd8d0b1be4a51634cb437cc1.html#gaa59d93fbbd8d0b1be4a51634cb437cc1":[2,0,0,0,13,0],
 "d6/dee/group__complex__blas__level2_gab21c402efadfa2023cfbc06911506e42.html#gab21c402efadfa2023cfbc06911506e42":[2,0,0,0,8,0],
-"d6/dee/group__complex__blas__level2_gac23d51cad7f51484371119bb6e3fb1f3.html#gac23d51cad7f51484371119bb6e3fb1f3":[0,2,1,2,5],
+"d6/dee/group__complex__blas__level2_gab21c402efadfa2023cfbc06911506e42.html#gab21c402efadfa2023cfbc06911506e42":[0,2,1,2,3],
 "d6/dee/group__complex__blas__level2_gac23d51cad7f51484371119bb6e3fb1f3.html#gac23d51cad7f51484371119bb6e3fb1f3":[2,0,0,0,11,0],
+"d6/dee/group__complex__blas__level2_gac23d51cad7f51484371119bb6e3fb1f3.html#gac23d51cad7f51484371119bb6e3fb1f3":[0,2,1,2,5],
 "d6/dee/group__complex__blas__level2_gac98100eee08124fb7a5d55effbb85a65.html#gac98100eee08124fb7a5d55effbb85a65":[0,2,1,2,9],
 "d6/dee/group__complex__blas__level2_gac98100eee08124fb7a5d55effbb85a65.html#gac98100eee08124fb7a5d55effbb85a65":[2,0,0,0,17,0],
 "d6/dee/group__complex__blas__level2_gad1dc14308bf0c1c8d9ba6ee068ac4d60.html#gad1dc14308bf0c1c8d9ba6ee068ac4d60":[0,2,1,2,8],
 "d6/dee/group__complex__blas__level2_gad1dc14308bf0c1c8d9ba6ee068ac4d60.html#gad1dc14308bf0c1c8d9ba6ee068ac4d60":[2,0,0,0,16,0],
 "d6/dee/group__complex__blas__level2_gafa73370c613ec8f157771992010809ac.html#gafa73370c613ec8f157771992010809ac":[0,2,1,2,6],
 "d6/dee/group__complex__blas__level2_gafa73370c613ec8f157771992010809ac.html#gafa73370c613ec8f157771992010809ac":[2,0,0,0,12,0],
-"d6/dee/group__complex__blas__level2_gafb7324ce48931e58b392dd6eef9a286c.html#gafb7324ce48931e58b392dd6eef9a286c":[0,2,1,2,13],
 "d6/dee/group__complex__blas__level2_gafb7324ce48931e58b392dd6eef9a286c.html#gafb7324ce48931e58b392dd6eef9a286c":[2,0,0,0,29,0],
-"d6/dee/zheev_8f.html":[2,0,4,1578],
-"d6/dee/zheev_8f_source.html":[2,0,4,1578],
-"d6/def/lapacke__dpstrf_8c.html":[2,0,3,3,956],
-"d6/def/lapacke__dpstrf_8c_a2b650cddf82818423fe53c664392a6c9.html#a2b650cddf82818423fe53c664392a6c9":[2,0,3,3,956,0],
-"d6/def/lapacke__dpstrf_8c_source.html":[2,0,3,3,956],
+"d6/dee/group__complex__blas__level2_gafb7324ce48931e58b392dd6eef9a286c.html#gafb7324ce48931e58b392dd6eef9a286c":[0,2,1,2,13],
+"d6/dee/zheev_8f.html":[2,0,4,1577],
+"d6/dee/zheev_8f_source.html":[2,0,4,1577],
+"d6/def/lapacke__dpstrf_8c.html":[2,0,3,3,960],
+"d6/def/lapacke__dpstrf_8c_a2b650cddf82818423fe53c664392a6c9.html#a2b650cddf82818423fe53c664392a6c9":[2,0,3,3,960,0],
+"d6/def/lapacke__dpstrf_8c_source.html":[2,0,3,3,960],
 "d6/df0/dlaqr1_8f.html":[2,0,4,665],
 "d6/df0/dlaqr1_8f_source.html":[2,0,4,665],
-"d6/df0/ssygv_8f.html":[2,0,4,1384],
-"d6/df0/ssygv_8f_source.html":[2,0,4,1384],
+"d6/df0/ssygv_8f.html":[2,0,4,1383],
+"d6/df0/ssygv_8f_source.html":[2,0,4,1383],
 "d6/df1/cdrgvx_8f.html":[2,0,5,0,35],
 "d6/df1/cdrgvx_8f_source.html":[2,0,5,0,35],
 "d6/df1/lapacke__cgbcon_8c.html":[2,0,3,3,6],
 "d6/df1/lapacke__cgbcon_8c_a005993b6d9cf5510f6267820a48a7e32.html#a005993b6d9cf5510f6267820a48a7e32":[2,0,3,3,6,0],
 "d6/df1/lapacke__cgbcon_8c_source.html":[2,0,3,3,6],
-"d6/df1/zlanhs_8f.html":[2,0,4,1705],
-"d6/df1/zlanhs_8f_source.html":[2,0,4,1705],
+"d6/df1/zlanhs_8f.html":[2,0,4,1704],
+"d6/df1/zlanhs_8f_source.html":[2,0,4,1704],
 "d6/df2/cblas__ztpsv_8c.html":[2,0,1,2,139],
 "d6/df2/cblas__ztpsv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[2,0,1,2,139,0],
 "d6/df2/cblas__ztpsv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[2,0,1,2,139,1],
@@ -82,15 +100,15 @@ var NAVTREEINDEX43 =
 "d6/df2/lapacke__cherfsx__work_8c.html":[2,0,3,3,227],
 "d6/df2/lapacke__cherfsx__work_8c_a174f49f86c82930fcdfe1d52041ba28e.html#a174f49f86c82930fcdfe1d52041ba28e":[2,0,3,3,227,0],
 "d6/df2/lapacke__cherfsx__work_8c_source.html":[2,0,3,3,227],
-"d6/df2/lapacke__dgeqrfp__work_8c.html":[2,0,3,3,709],
-"d6/df2/lapacke__dgeqrfp__work_8c_a146f2c599b0bda43981468a615050f9c.html#a146f2c599b0bda43981468a615050f9c":[2,0,3,3,709,0],
-"d6/df2/lapacke__dgeqrfp__work_8c_source.html":[2,0,3,3,709],
-"d6/df3/lapacke__dlacpy_8c.html":[2,0,3,3,804],
-"d6/df3/lapacke__dlacpy_8c_a199e5c646edf25bdbad687cd62727c86.html#a199e5c646edf25bdbad687cd62727c86":[2,0,3,3,804,0],
-"d6/df3/lapacke__dlacpy_8c_source.html":[2,0,3,3,804],
-"d6/df5/lapacke__zupgtr__work_8c.html":[2,0,3,3,2402],
-"d6/df5/lapacke__zupgtr__work_8c_a1085ff4261cb8b6854163f382d0ad9c2.html#a1085ff4261cb8b6854163f382d0ad9c2":[2,0,3,3,2402,0],
-"d6/df5/lapacke__zupgtr__work_8c_source.html":[2,0,3,3,2402],
+"d6/df2/lapacke__dgeqrfp__work_8c.html":[2,0,3,3,711],
+"d6/df2/lapacke__dgeqrfp__work_8c_a146f2c599b0bda43981468a615050f9c.html#a146f2c599b0bda43981468a615050f9c":[2,0,3,3,711,0],
+"d6/df2/lapacke__dgeqrfp__work_8c_source.html":[2,0,3,3,711],
+"d6/df3/lapacke__dlacpy_8c.html":[2,0,3,3,806],
+"d6/df3/lapacke__dlacpy_8c_a199e5c646edf25bdbad687cd62727c86.html#a199e5c646edf25bdbad687cd62727c86":[2,0,3,3,806,0],
+"d6/df3/lapacke__dlacpy_8c_source.html":[2,0,3,3,806],
+"d6/df5/lapacke__zupgtr__work_8c.html":[2,0,3,3,2410],
+"d6/df5/lapacke__zupgtr__work_8c_a1085ff4261cb8b6854163f382d0ad9c2.html#a1085ff4261cb8b6854163f382d0ad9c2":[2,0,3,3,2410,0],
+"d6/df5/lapacke__zupgtr__work_8c_source.html":[2,0,3,3,2410],
 "d6/df5/ssvdct_8f.html":[2,0,5,0,271],
 "d6/df5/ssvdct_8f_source.html":[2,0,5,0,271],
 "d6/df6/group__complex_p_ocomputational.html":[0,0,4,1,2],
@@ -98,30 +116,30 @@ var NAVTREEINDEX43 =
 "d6/df6/group__complex_p_ocomputational_ga02421020615f3c0fe23637cbad9dea9e.html#ga02421020615f3c0fe23637cbad9dea9e":[0,0,4,1,2,6],
 "d6/df6/group__complex_p_ocomputational_ga175bba20a3b3ca013531900779876573.html#ga175bba20a3b3ca013531900779876573":[2,0,4,321,0],
 "d6/df6/group__complex_p_ocomputational_ga175bba20a3b3ca013531900779876573.html#ga175bba20a3b3ca013531900779876573":[0,0,4,1,2,5],
-"d6/df6/group__complex_p_ocomputational_ga2e2e4c01cbb78f7da3b6fd25c7c07ab7.html#ga2e2e4c01cbb78f7da3b6fd25c7c07ab7":[2,0,4,323,0],
-"d6/df6/group__complex_p_ocomputational_ga2e2e4c01cbb78f7da3b6fd25c7c07ab7.html#ga2e2e4c01cbb78f7da3b6fd25c7c07ab7":[0,0,4,1,2,7],
-"d6/df6/group__complex_p_ocomputational_ga3ffd4f911ac716b03017691cf300ff8b.html#ga3ffd4f911ac716b03017691cf300ff8b":[2,0,4,324,0],
-"d6/df6/group__complex_p_ocomputational_ga3ffd4f911ac716b03017691cf300ff8b.html#ga3ffd4f911ac716b03017691cf300ff8b":[0,0,4,1,2,8],
-"d6/df6/group__complex_p_ocomputational_ga469fc500ac223c4c6baa923afe218627.html#ga469fc500ac223c4c6baa923afe218627":[0,0,4,1,2,11],
+"d6/df6/group__complex_p_ocomputational_ga29f47972e18ce3bc44ca5d8ee0cf7f28.html#ga29f47972e18ce3bc44ca5d8ee0cf7f28":[2,0,4,323,0],
+"d6/df6/group__complex_p_ocomputational_ga29f47972e18ce3bc44ca5d8ee0cf7f28.html#ga29f47972e18ce3bc44ca5d8ee0cf7f28":[0,0,4,1,2,7],
+"d6/df6/group__complex_p_ocomputational_ga2ddc05543f7ed596609cdce0478ca8a3.html#ga2ddc05543f7ed596609cdce0478ca8a3":[2,0,4,320,0],
+"d6/df6/group__complex_p_ocomputational_ga2ddc05543f7ed596609cdce0478ca8a3.html#ga2ddc05543f7ed596609cdce0478ca8a3":[0,0,4,1,2,4],
 "d6/df6/group__complex_p_ocomputational_ga469fc500ac223c4c6baa923afe218627.html#ga469fc500ac223c4c6baa923afe218627":[2,0,4,330,0],
+"d6/df6/group__complex_p_ocomputational_ga469fc500ac223c4c6baa923afe218627.html#ga469fc500ac223c4c6baa923afe218627":[0,0,4,1,2,11],
 "d6/df6/group__complex_p_ocomputational_ga4e85f48dbd837ccbbf76aa077f33de19.html#ga4e85f48dbd837ccbbf76aa077f33de19":[2,0,4,329,0],
 "d6/df6/group__complex_p_ocomputational_ga4e85f48dbd837ccbbf76aa077f33de19.html#ga4e85f48dbd837ccbbf76aa077f33de19":[0,0,4,1,2,10],
 "d6/df6/group__complex_p_ocomputational_ga52b8da4d314abefaee93dd5c1ed7739e.html#ga52b8da4d314abefaee93dd5c1ed7739e":[2,0,4,331,0],
 "d6/df6/group__complex_p_ocomputational_ga52b8da4d314abefaee93dd5c1ed7739e.html#ga52b8da4d314abefaee93dd5c1ed7739e":[0,0,4,1,2,12],
 "d6/df6/group__complex_p_ocomputational_ga56e13fb822ec7474402943652d7c93c6.html#ga56e13fb822ec7474402943652d7c93c6":[2,0,4,328,0],
 "d6/df6/group__complex_p_ocomputational_ga56e13fb822ec7474402943652d7c93c6.html#ga56e13fb822ec7474402943652d7c93c6":[0,0,4,1,2,9],
-"d6/df6/group__complex_p_ocomputational_ga76e40c178d99397625d69e0e0f2f51e1.html#ga76e40c178d99397625d69e0e0f2f51e1":[2,0,4,195,0],
-"d6/df6/group__complex_p_ocomputational_ga76e40c178d99397625d69e0e0f2f51e1.html#ga76e40c178d99397625d69e0e0f2f51e1":[0,0,4,1,2,0],
+"d6/df6/group__complex_p_ocomputational_gaa3a60feb87c68a34e9ef409d288af65c.html#gaa3a60feb87c68a34e9ef409d288af65c":[2,0,4,195,0],
+"d6/df6/group__complex_p_ocomputational_gaa3a60feb87c68a34e9ef409d288af65c.html#gaa3a60feb87c68a34e9ef409d288af65c":[0,0,4,1,2,0],
+"d6/df6/group__complex_p_ocomputational_gaae09867c151f12f346831c649a0c8e14.html#gaae09867c151f12f346831c649a0c8e14":[2,0,4,196,0],
+"d6/df6/group__complex_p_ocomputational_gaae09867c151f12f346831c649a0c8e14.html#gaae09867c151f12f346831c649a0c8e14":[0,0,4,1,2,1],
 "d6/df6/group__complex_p_ocomputational_gac233b27b7668956a58100cbb8e9ee392.html#gac233b27b7668956a58100cbb8e9ee392":[2,0,4,198,0],
 "d6/df6/group__complex_p_ocomputational_gac233b27b7668956a58100cbb8e9ee392.html#gac233b27b7668956a58100cbb8e9ee392":[0,0,4,1,2,3],
-"d6/df6/group__complex_p_ocomputational_gac8ee3018d804f6dbf603947b14b9fdc8.html#gac8ee3018d804f6dbf603947b14b9fdc8":[2,0,4,197,0],
-"d6/df6/group__complex_p_ocomputational_gac8ee3018d804f6dbf603947b14b9fdc8.html#gac8ee3018d804f6dbf603947b14b9fdc8":[0,0,4,1,2,2],
-"d6/df6/group__complex_p_ocomputational_gad527ff1b5ab568e46aa5fcf0d9ecd2d7.html#gad527ff1b5ab568e46aa5fcf0d9ecd2d7":[2,0,4,196,0],
-"d6/df6/group__complex_p_ocomputational_gad527ff1b5ab568e46aa5fcf0d9ecd2d7.html#gad527ff1b5ab568e46aa5fcf0d9ecd2d7":[0,0,4,1,2,1],
+"d6/df6/group__complex_p_ocomputational_gad3d34aea85ff135afe5692ec73649249.html#gad3d34aea85ff135afe5692ec73649249":[2,0,4,324,0],
+"d6/df6/group__complex_p_ocomputational_gad3d34aea85ff135afe5692ec73649249.html#gad3d34aea85ff135afe5692ec73649249":[0,0,4,1,2,8],
 "d6/df6/group__complex_p_ocomputational_gad9052b4b70569dfd6e8943971c9b38b2.html#gad9052b4b70569dfd6e8943971c9b38b2":[2,0,4,332,0],
 "d6/df6/group__complex_p_ocomputational_gad9052b4b70569dfd6e8943971c9b38b2.html#gad9052b4b70569dfd6e8943971c9b38b2":[0,0,4,1,2,13],
-"d6/df6/group__complex_p_ocomputational_gafeb7f0390cb5bd81a3e7a432af121f47.html#gafeb7f0390cb5bd81a3e7a432af121f47":[2,0,4,320,0],
-"d6/df6/group__complex_p_ocomputational_gafeb7f0390cb5bd81a3e7a432af121f47.html#gafeb7f0390cb5bd81a3e7a432af121f47":[0,0,4,1,2,4],
+"d6/df6/group__complex_p_ocomputational_gae3d6f3635d5674e86148d50639cf2675.html#gae3d6f3635d5674e86148d50639cf2675":[2,0,4,197,0],
+"d6/df6/group__complex_p_ocomputational_gae3d6f3635d5674e86148d50639cf2675.html#gae3d6f3635d5674e86148d50639cf2675":[0,0,4,1,2,2],
 "d6/df7/cblas__ctrsv_8c.html":[2,0,1,2,32],
 "d6/df7/cblas__ctrsv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[2,0,1,2,32,0],
 "d6/df7/cblas__ctrsv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[2,0,1,2,32,1],
@@ -131,19 +149,19 @@ var NAVTREEINDEX43 =
 "d6/df7/cblas__ctrsv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[2,0,1,2,32,5],
 "d6/df7/cblas__ctrsv_8c_ad70a0f29c3b7015b2b8811d807e6bfb1.html#ad70a0f29c3b7015b2b8811d807e6bfb1":[2,0,1,2,32,6],
 "d6/df7/cblas__ctrsv_8c_source.html":[2,0,1,2,32],
-"d6/df7/lapacke__cunmrz_8c.html":[2,0,3,3,612],
-"d6/df7/lapacke__cunmrz_8c_aadf0dd9df89e13af85512db8a4aa1c59.html#aadf0dd9df89e13af85512db8a4aa1c59":[2,0,3,3,612,0],
-"d6/df7/lapacke__cunmrz_8c_source.html":[2,0,3,3,612],
-"d6/df8/ssytrs__rook_8f.html":[2,0,4,1418],
-"d6/df8/ssytrs__rook_8f_source.html":[2,0,4,1418],
+"d6/df7/lapacke__cunmrz_8c.html":[2,0,3,3,614],
+"d6/df7/lapacke__cunmrz_8c_aadf0dd9df89e13af85512db8a4aa1c59.html#aadf0dd9df89e13af85512db8a4aa1c59":[2,0,3,3,614,0],
+"d6/df7/lapacke__cunmrz_8c_source.html":[2,0,3,3,614],
+"d6/df8/ssytrs__rook_8f.html":[2,0,4,1417],
+"d6/df8/ssytrs__rook_8f_source.html":[2,0,4,1417],
 "d6/df9/group__complex_s_yeigen.html":[0,0,2,1,2],
-"d6/df9/lapacke__csycon_8c.html":[2,0,3,3,456],
-"d6/df9/lapacke__csycon_8c_a205e6f48f7849ecb44683f6c2de3c8cb.html#a205e6f48f7849ecb44683f6c2de3c8cb":[2,0,3,3,456,0],
-"d6/df9/lapacke__csycon_8c_source.html":[2,0,3,3,456],
-"d6/df9/zgesvxx_8f.html":[2,0,4,1529],
-"d6/df9/zgesvxx_8f_source.html":[2,0,4,1529],
-"d6/dfa/zspcon_8f.html":[2,0,4,1816],
-"d6/dfa/zspcon_8f_source.html":[2,0,4,1816],
+"d6/df9/lapacke__csycon_8c.html":[2,0,3,3,458],
+"d6/df9/lapacke__csycon_8c_a205e6f48f7849ecb44683f6c2de3c8cb.html#a205e6f48f7849ecb44683f6c2de3c8cb":[2,0,3,3,458,0],
+"d6/df9/lapacke__csycon_8c_source.html":[2,0,3,3,458],
+"d6/df9/zgesvxx_8f.html":[2,0,4,1528],
+"d6/df9/zgesvxx_8f_source.html":[2,0,4,1528],
+"d6/dfa/zspcon_8f.html":[2,0,4,1815],
+"d6/dfa/zspcon_8f_source.html":[2,0,4,1815],
 "d6/dfb/dgehd2_8f.html":[2,0,4,509],
 "d6/dfb/dgehd2_8f_source.html":[2,0,4,509],
 "d6/dfc/clatrz_8f.html":[2,0,4,304],
@@ -152,8 +170,8 @@ var NAVTREEINDEX43 =
 "d6/dfd/dgges3_8f_source.html":[2,0,4,558],
 "d6/dfd/dlasdq_8f.html":[2,0,4,717],
 "d6/dfd/dlasdq_8f_source.html":[2,0,4,717],
-"d6/dfd/sgeqr2_8f.html":[2,0,4,1031],
-"d6/dfd/sgeqr2_8f_source.html":[2,0,4,1031],
+"d6/dfd/sgeqr2_8f.html":[2,0,4,1030],
+"d6/dfd/sgeqr2_8f_source.html":[2,0,4,1030],
 "d6/dff/c__sblas1_8c.html":[2,0,1,3,19],
 "d6/dff/c__sblas1_8c_a25178981ec0049866cca30fae0a16680.html#a25178981ec0049866cca30fae0a16680":[2,0,1,3,19,4],
 "d6/dff/c__sblas1_8c_a562a35c8d9ab27742e28409b3a2b404d.html#a562a35c8d9ab27742e28409b3a2b404d":[2,0,1,3,19,6],
@@ -168,58 +186,58 @@ var NAVTREEINDEX43 =
 "d6/dff/c__sblas1_8c_ac872e13c7b9436e66fc8ba9b0e881465.html#ac872e13c7b9436e66fc8ba9b0e881465":[2,0,1,3,19,9],
 "d6/dff/c__sblas1_8c_aee03268abc78dfcaf897c9b30473dbf2.html#aee03268abc78dfcaf897c9b30473dbf2":[2,0,1,3,19,0],
 "d6/dff/c__sblas1_8c_source.html":[2,0,1,3,19],
-"d6/dff/zlat2c_8f.html":[2,0,4,1762],
-"d6/dff/zlat2c_8f_source.html":[2,0,4,1762],
-"d7/d01/lapacke__csytri_8c.html":[2,0,3,3,492],
-"d7/d01/lapacke__csytri_8c_a5ff73ed90aa4e4f131703543c727e549.html#a5ff73ed90aa4e4f131703543c727e549":[2,0,3,3,492,0],
-"d7/d01/lapacke__csytri_8c_source.html":[2,0,3,3,492],
-"d7/d01/lapacke__dtptri__work_8c.html":[2,0,3,3,1171],
-"d7/d01/lapacke__dtptri__work_8c_a75d07190075412124e1a6cf054ad4b44.html#a75d07190075412124e1a6cf054ad4b44":[2,0,3,3,1171,0],
-"d7/d01/lapacke__dtptri__work_8c_source.html":[2,0,3,3,1171],
+"d6/dff/zlat2c_8f.html":[2,0,4,1761],
+"d6/dff/zlat2c_8f_source.html":[2,0,4,1761],
+"d7/d01/lapacke__csytri_8c.html":[2,0,3,3,494],
+"d7/d01/lapacke__csytri_8c_a5ff73ed90aa4e4f131703543c727e549.html#a5ff73ed90aa4e4f131703543c727e549":[2,0,3,3,494,0],
+"d7/d01/lapacke__csytri_8c_source.html":[2,0,3,3,494],
+"d7/d01/lapacke__dtptri__work_8c.html":[2,0,3,3,1175],
+"d7/d01/lapacke__dtptri__work_8c_a75d07190075412124e1a6cf054ad4b44.html#a75d07190075412124e1a6cf054ad4b44":[2,0,3,3,1175,0],
+"d7/d01/lapacke__dtptri__work_8c_source.html":[2,0,3,3,1175],
 "d7/d01/zdrvgbx_8f.html":[2,0,5,1,591],
 "d7/d01/zdrvgbx_8f_source.html":[2,0,5,1,591],
-"d7/d01/zpbtrs_8f.html":[2,0,4,1780],
-"d7/d01/zpbtrs_8f_source.html":[2,0,4,1780],
-"d7/d02/lapacke__sgetf2__work_8c.html":[2,0,3,3,1320],
-"d7/d02/lapacke__sgetf2__work_8c_ad724233980145ef9378380229e348f76.html#ad724233980145ef9378380229e348f76":[2,0,3,3,1320,0],
-"d7/d02/lapacke__sgetf2__work_8c_source.html":[2,0,3,3,1320],
-"d7/d02/zhprfs_8f.html":[2,0,4,1633],
-"d7/d02/zhprfs_8f_source.html":[2,0,4,1633],
+"d7/d01/zpbtrs_8f.html":[2,0,4,1779],
+"d7/d01/zpbtrs_8f_source.html":[2,0,4,1779],
+"d7/d02/lapacke__sgetf2__work_8c.html":[2,0,3,3,1324],
+"d7/d02/lapacke__sgetf2__work_8c_ad724233980145ef9378380229e348f76.html#ad724233980145ef9378380229e348f76":[2,0,3,3,1324,0],
+"d7/d02/lapacke__sgetf2__work_8c_source.html":[2,0,3,3,1324],
+"d7/d02/zhprfs_8f.html":[2,0,4,1632],
+"d7/d02/zhprfs_8f_source.html":[2,0,4,1632],
 "d7/d03/dpptrs_8f.html":[2,0,4,815],
 "d7/d03/dpptrs_8f_source.html":[2,0,4,815],
-"d7/d03/lapacke__zhesvx__work_8c.html":[2,0,3,3,2020],
-"d7/d03/lapacke__zhesvx__work_8c_aa67c39a2429a86b3422b38e554ea8fbc.html#aa67c39a2429a86b3422b38e554ea8fbc":[2,0,3,3,2020,0],
-"d7/d03/lapacke__zhesvx__work_8c_source.html":[2,0,3,3,2020],
-"d7/d04/lapacke__ctgevc_8c.html":[2,0,3,3,524],
-"d7/d04/lapacke__ctgevc_8c_abf5b8901c64d23c1ab27b40d7b5ca0bd.html#abf5b8901c64d23c1ab27b40d7b5ca0bd":[2,0,3,3,524,0],
-"d7/d04/lapacke__ctgevc_8c_source.html":[2,0,3,3,524],
-"d7/d04/lapacke__dsyev__2stage__work_8c.html":[2,0,3,3,1062],
-"d7/d04/lapacke__dsyev__2stage__work_8c_a54ba77411a1a874874c60583a1ff0945.html#a54ba77411a1a874874c60583a1ff0945":[2,0,3,3,1062,0],
-"d7/d04/lapacke__dsyev__2stage__work_8c_source.html":[2,0,3,3,1062],
-"d7/d04/lapacke__zgemlq_8c.html":[2,0,3,3,1849],
-"d7/d04/lapacke__zgemlq_8c_abf70de05ffc87b723a3a734e3d589983.html#abf70de05ffc87b723a3a734e3d589983":[2,0,3,3,1849,0],
-"d7/d04/lapacke__zgemlq_8c_source.html":[2,0,3,3,1849],
-"d7/d0a/lapacke__zpoequ_8c.html":[2,0,3,3,2163],
-"d7/d0a/lapacke__zpoequ_8c_ad7f06791d2b1b8431fde6f948af8c66b.html#ad7f06791d2b1b8431fde6f948af8c66b":[2,0,3,3,2163,0],
-"d7/d0a/lapacke__zpoequ_8c_source.html":[2,0,3,3,2163],
+"d7/d03/lapacke__zhesvx__work_8c.html":[2,0,3,3,2026],
+"d7/d03/lapacke__zhesvx__work_8c_aa67c39a2429a86b3422b38e554ea8fbc.html#aa67c39a2429a86b3422b38e554ea8fbc":[2,0,3,3,2026,0],
+"d7/d03/lapacke__zhesvx__work_8c_source.html":[2,0,3,3,2026],
+"d7/d04/lapacke__ctgevc_8c.html":[2,0,3,3,526],
+"d7/d04/lapacke__ctgevc_8c_abf5b8901c64d23c1ab27b40d7b5ca0bd.html#abf5b8901c64d23c1ab27b40d7b5ca0bd":[2,0,3,3,526,0],
+"d7/d04/lapacke__ctgevc_8c_source.html":[2,0,3,3,526],
+"d7/d04/lapacke__dsyev__2stage__work_8c.html":[2,0,3,3,1066],
+"d7/d04/lapacke__dsyev__2stage__work_8c_a54ba77411a1a874874c60583a1ff0945.html#a54ba77411a1a874874c60583a1ff0945":[2,0,3,3,1066,0],
+"d7/d04/lapacke__dsyev__2stage__work_8c_source.html":[2,0,3,3,1066],
+"d7/d04/lapacke__zgemlq_8c.html":[2,0,3,3,1855],
+"d7/d04/lapacke__zgemlq_8c_abf70de05ffc87b723a3a734e3d589983.html#abf70de05ffc87b723a3a734e3d589983":[2,0,3,3,1855,0],
+"d7/d04/lapacke__zgemlq_8c_source.html":[2,0,3,3,1855],
+"d7/d0a/lapacke__zpoequ_8c.html":[2,0,3,3,2171],
+"d7/d0a/lapacke__zpoequ_8c_ad7f06791d2b1b8431fde6f948af8c66b.html#ad7f06791d2b1b8431fde6f948af8c66b":[2,0,3,3,2171,0],
+"d7/d0a/lapacke__zpoequ_8c_source.html":[2,0,3,3,2171],
 "d7/d0b/_l_i_n_2alasum_8f.html":[2,0,5,1,5],
 "d7/d0b/_l_i_n_2alasum_8f_source.html":[2,0,5,1,5],
-"d7/d0b/lapacke__dgelq2__work_8c.html":[2,0,3,3,678],
-"d7/d0b/lapacke__dgelq2__work_8c_ae774663e6f525de36122414f1bab1e1c.html#ae774663e6f525de36122414f1bab1e1c":[2,0,3,3,678,0],
-"d7/d0b/lapacke__dgelq2__work_8c_source.html":[2,0,3,3,678],
-"d7/d0b/lapacke__spftri_8c.html":[2,0,3,3,1495],
-"d7/d0b/lapacke__spftri_8c_aee59bcc5d92662b977afb3d0a5e37b05.html#aee59bcc5d92662b977afb3d0a5e37b05":[2,0,3,3,1495,0],
-"d7/d0b/lapacke__spftri_8c_source.html":[2,0,3,3,1495],
-"d7/d0d/lapacke__spoequ__work_8c.html":[2,0,3,3,1502],
-"d7/d0d/lapacke__spoequ__work_8c_a8253547205f1b6b147ffe18ac78281c5.html#a8253547205f1b6b147ffe18ac78281c5":[2,0,3,3,1502,0],
-"d7/d0d/lapacke__spoequ__work_8c_source.html":[2,0,3,3,1502],
-"d7/d0d/zhptrf_8f.html":[2,0,4,1637],
-"d7/d0d/zhptrf_8f_source.html":[2,0,4,1637],
+"d7/d0b/lapacke__dgelq2__work_8c.html":[2,0,3,3,680],
+"d7/d0b/lapacke__dgelq2__work_8c_ae774663e6f525de36122414f1bab1e1c.html#ae774663e6f525de36122414f1bab1e1c":[2,0,3,3,680,0],
+"d7/d0b/lapacke__dgelq2__work_8c_source.html":[2,0,3,3,680],
+"d7/d0b/lapacke__spftri_8c.html":[2,0,3,3,1501],
+"d7/d0b/lapacke__spftri_8c_aee59bcc5d92662b977afb3d0a5e37b05.html#aee59bcc5d92662b977afb3d0a5e37b05":[2,0,3,3,1501,0],
+"d7/d0b/lapacke__spftri_8c_source.html":[2,0,3,3,1501],
+"d7/d0d/lapacke__spoequ__work_8c.html":[2,0,3,3,1508],
+"d7/d0d/lapacke__spoequ__work_8c_a8253547205f1b6b147ffe18ac78281c5.html#a8253547205f1b6b147ffe18ac78281c5":[2,0,3,3,1508,0],
+"d7/d0d/lapacke__spoequ__work_8c_source.html":[2,0,3,3,1508],
+"d7/d0d/zhptrf_8f.html":[2,0,4,1636],
+"d7/d0d/zhptrf_8f_source.html":[2,0,4,1636],
 "d7/d0f/scklse_8f.html":[2,0,5,0,204],
 "d7/d0f/scklse_8f_source.html":[2,0,5,0,204],
-"d7/d10/lapacke__sgbtrs_8c.html":[2,0,3,3,1233],
-"d7/d10/lapacke__sgbtrs_8c_af21de9c6632243e3684bfb0b746967b9.html#af21de9c6632243e3684bfb0b746967b9":[2,0,3,3,1233,0],
-"d7/d10/lapacke__sgbtrs_8c_source.html":[2,0,3,3,1233],
+"d7/d10/lapacke__sgbtrs_8c.html":[2,0,3,3,1237],
+"d7/d10/lapacke__sgbtrs_8c_af21de9c6632243e3684bfb0b746967b9.html#af21de9c6632243e3684bfb0b746967b9":[2,0,3,3,1237,0],
+"d7/d10/lapacke__sgbtrs_8c_source.html":[2,0,3,3,1237],
 "d7/d12/zgeru_8f.html":[2,0,0,0,126],
 "d7/d12/zgeru_8f_source.html":[2,0,0,0,126],
 "d7/d14/_l_i_n_2cget02_8f.html":[2,0,5,1,106],
@@ -231,23 +249,5 @@ var NAVTREEINDEX43 =
 "d7/d15/cblas__zgemm_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[2,0,1,2,117,3],
 "d7/d15/cblas__zgemm_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[2,0,1,2,117,0],
 "d7/d15/cblas__zgemm_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[2,0,1,2,117,2],
-"d7/d15/cblas__zgemm_8c_a5e21023e217bd5a6db0984f3164ba6fc.html#a5e21023e217bd5a6db0984f3164ba6fc":[2,0,1,2,117,7],
-"d7/d15/cblas__zgemm_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[2,0,1,2,117,6],
-"d7/d15/cblas__zgemm_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[2,0,1,2,117,5],
-"d7/d15/cblas__zgemm_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[2,0,1,2,117,1],
-"d7/d15/cblas__zgemm_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[2,0,1,2,117,4],
-"d7/d15/cblas__zgemm_8c_source.html":[2,0,1,2,117],
-"d7/d15/dgelqs_8f.html":[2,0,5,1,288],
-"d7/d15/dgelqs_8f_source.html":[2,0,5,1,288],
-"d7/d15/dlatps_8f.html":[2,0,4,740],
-"d7/d15/dlatps_8f_source.html":[2,0,4,740],
-"d7/d15/group__double__blas__level2.html":[0,2,1,1],
-"d7/d15/group__double__blas__level2_ga0dc187c15a47772440defe879d034888.html#ga0dc187c15a47772440defe879d034888":[0,2,1,1,0],
-"d7/d15/group__double__blas__level2_ga0dc187c15a47772440defe879d034888.html#ga0dc187c15a47772440defe879d034888":[2,0,0,0,40,0],
-"d7/d15/group__double__blas__level2_ga0fff73e765a7655a67da779c898863f1.html#ga0fff73e765a7655a67da779c898863f1":[0,2,1,1,13],
-"d7/d15/group__double__blas__level2_ga0fff73e765a7655a67da779c898863f1.html#ga0fff73e765a7655a67da779c898863f1":[2,0,0,0,65,0],
-"d7/d15/group__double__blas__level2_ga16318e7e16083b395bd959b0cc93e803.html#ga16318e7e16083b395bd959b0cc93e803":[0,2,1,1,6],
-"d7/d15/group__double__blas__level2_ga16318e7e16083b395bd959b0cc93e803.html#ga16318e7e16083b395bd959b0cc93e803":[2,0,0,0,54,0],
-"d7/d15/group__double__blas__level2_ga1d9a8ecfddfea2c84e73e28e1ebb74cf.html#ga1d9a8ecfddfea2c84e73e28e1ebb74cf":[0,2,1,1,12],
-"d7/d15/group__double__blas__level2_ga1d9a8ecfddfea2c84e73e28e1ebb74cf.html#ga1d9a8ecfddfea2c84e73e28e1ebb74cf":[2,0,0,0,64,0]
+"d7/d15/cblas__zgemm_8c_a5e21023e217bd5a6db0984f3164ba6fc.html#a5e21023e217bd5a6db0984f3164ba6fc":[2,0,1,2,117,7]
 };
