@@ -1,26 +1,44 @@
 var NAVTREEINDEX45 =
 {
-"d7/d49/lapacke__cunglq__work_8c.html":[2,0,3,3,591],
-"d7/d49/lapacke__cunglq__work_8c_ac30e408f4fb532a6226437d293ab9163.html#ac30e408f4fb532a6226437d293ab9163":[2,0,3,3,591,0],
-"d7/d49/lapacke__cunglq__work_8c_source.html":[2,0,3,3,591],
+"d7/d45/lapacke__strsyl_8c.html":[2,0,3,3,1775],
+"d7/d45/lapacke__strsyl_8c_a60cb57b10de1873b2a4f61f1c03d59fa.html#a60cb57b10de1873b2a4f61f1c03d59fa":[2,0,3,3,1775,0],
+"d7/d45/lapacke__strsyl_8c_source.html":[2,0,3,3,1775],
+"d7/d46/dsb2st__kernels_8f.html":[2,0,4,827],
+"d7/d46/dsb2st__kernels_8f_a05cb49c56dfeae0cf40aea85a33c8195.html#a05cb49c56dfeae0cf40aea85a33c8195":[2,0,4,827,0],
+"d7/d46/dsb2st__kernels_8f_source.html":[2,0,4,827],
+"d7/d46/lapacke__cungql__work_8c.html":[2,0,3,3,595],
+"d7/d46/lapacke__cungql__work_8c_a453140411207d731be7f92651f56cc5c.html#a453140411207d731be7f92651f56cc5c":[2,0,3,3,595,0],
+"d7/d46/lapacke__cungql__work_8c_source.html":[2,0,3,3,595],
+"d7/d46/lapacke__ztrsna__work_8c.html":[2,0,3,3,2360],
+"d7/d46/lapacke__ztrsna__work_8c_a1cb3dbd0b72841c7f4717dcf34b8bd3d.html#a1cb3dbd0b72841c7f4717dcf34b8bd3d":[2,0,3,3,2360,0],
+"d7/d46/lapacke__ztrsna__work_8c_source.html":[2,0,3,3,2360],
+"d7/d48/claqgb_8f.html":[2,0,4,253],
+"d7/d48/claqgb_8f_source.html":[2,0,4,253],
+"d7/d48/dstev_8f.html":[2,0,4,864],
+"d7/d48/dstev_8f_source.html":[2,0,4,864],
+"d7/d48/sdrgvx_8f.html":[2,0,5,0,211],
+"d7/d48/sdrgvx_8f_source.html":[2,0,5,0,211],
+"d7/d49/lapacke__cunglq__work_8c.html":[2,0,3,3,593],
+"d7/d49/lapacke__cunglq__work_8c_ac30e408f4fb532a6226437d293ab9163.html#ac30e408f4fb532a6226437d293ab9163":[2,0,3,3,593,0],
+"d7/d49/lapacke__cunglq__work_8c_source.html":[2,0,3,3,593],
 "d7/d49/sqrt01p_8f.html":[2,0,5,1,512],
 "d7/d49/sqrt01p_8f_source.html":[2,0,5,1,512],
-"d7/d49/ssytrd_8f.html":[2,0,4,1401],
-"d7/d49/ssytrd_8f_source.html":[2,0,4,1401],
-"d7/d4a/sgtrfs_8f.html":[2,0,4,1076],
-"d7/d4a/sgtrfs_8f_source.html":[2,0,4,1076],
+"d7/d49/ssytrd_8f.html":[2,0,4,1400],
+"d7/d49/ssytrd_8f_source.html":[2,0,4,1400],
+"d7/d4a/sgtrfs_8f.html":[2,0,4,1075],
+"d7/d4a/sgtrfs_8f_source.html":[2,0,4,1075],
 "d7/d4b/zchkqrt_8f.html":[2,0,5,1,574],
 "d7/d4b/zchkqrt_8f_source.html":[2,0,5,1,574],
 "d7/d4c/clacgv_8f.html":[2,0,4,206],
 "d7/d4c/clacgv_8f_source.html":[2,0,4,206],
 "d7/d4c/clarcm_8f.html":[2,0,4,271],
 "d7/d4c/clarcm_8f_source.html":[2,0,4,271],
-"d7/d4d/slagtf_8f.html":[2,0,4,1128],
-"d7/d4d/slagtf_8f_source.html":[2,0,4,1128],
+"d7/d4d/slagtf_8f.html":[2,0,4,1127],
+"d7/d4d/slagtf_8f_source.html":[2,0,4,1127],
 "d7/d4e/cchktz_8f.html":[2,0,5,1,41],
 "d7/d4e/cchktz_8f_source.html":[2,0,5,1,41],
-"d7/d50/zlaqps_8f.html":[2,0,4,1722],
-"d7/d50/zlaqps_8f_source.html":[2,0,4,1722],
+"d7/d50/zlaqps_8f.html":[2,0,4,1721],
+"d7/d50/zlaqps_8f_source.html":[2,0,4,1721],
 "d7/d51/c__c3chke_8c.html":[2,0,1,3,2],
 "d7/d51/c__c3chke_8c_a0daba2de2c41dae3fbb8b6cadfce3b2d.html#a0daba2de2c41dae3fbb8b6cadfce3b2d":[2,0,1,3,2,1],
 "d7/d51/c__c3chke_8c_a3a4311d32529babd1371d46ac838fec8.html#a3a4311d32529babd1371d46ac838fec8":[2,0,1,3,2,7],
@@ -33,62 +51,62 @@ var NAVTREEINDEX45 =
 "d7/d51/c__c3chke_8c_source.html":[2,0,1,3,2],
 "d7/d51/chemv_8f.html":[2,0,0,0,11],
 "d7/d51/chemv_8f_source.html":[2,0,0,0,11],
-"d7/d51/zlangt_8f.html":[2,0,4,1700],
-"d7/d51/zlangt_8f_source.html":[2,0,4,1700],
-"d7/d52/lapacke__slapy3__work_8c.html":[2,0,3,3,1410],
-"d7/d52/lapacke__slapy3__work_8c_a11a81600e21a856773e3f44298f3d890.html#a11a81600e21a856773e3f44298f3d890":[2,0,3,3,1410,0],
-"d7/d52/lapacke__slapy3__work_8c_source.html":[2,0,3,3,1410],
+"d7/d51/zlangt_8f.html":[2,0,4,1699],
+"d7/d51/zlangt_8f_source.html":[2,0,4,1699],
+"d7/d52/lapacke__slapy3__work_8c.html":[2,0,3,3,1414],
+"d7/d52/lapacke__slapy3__work_8c_a11a81600e21a856773e3f44298f3d890.html#a11a81600e21a856773e3f44298f3d890":[2,0,3,3,1414,0],
+"d7/d52/lapacke__slapy3__work_8c_source.html":[2,0,3,3,1414],
 "d7/d53/zchktb_8f.html":[2,0,5,1,583],
 "d7/d53/zchktb_8f_source.html":[2,0,5,1,583],
-"d7/d55/lapacke__ztfsm_8c.html":[2,0,3,3,2301],
-"d7/d55/lapacke__ztfsm_8c_a95c7bf5b791c3531c3be8b2325e43119.html#a95c7bf5b791c3531c3be8b2325e43119":[2,0,3,3,2301,0],
-"d7/d55/lapacke__ztfsm_8c_source.html":[2,0,3,3,2301],
+"d7/d55/lapacke__ztfsm_8c.html":[2,0,3,3,2309],
+"d7/d55/lapacke__ztfsm_8c_a95c7bf5b791c3531c3be8b2325e43119.html#a95c7bf5b791c3531c3be8b2325e43119":[2,0,3,3,2309,0],
+"d7/d55/lapacke__ztfsm_8c_source.html":[2,0,3,3,2309],
 "d7/d56/cdrvsy__aa_8f.html":[2,0,5,1,66],
 "d7/d56/cdrvsy__aa_8f_source.html":[2,0,5,1,66],
 "d7/d56/ctrttp_8f.html":[2,0,4,443],
 "d7/d56/ctrttp_8f_source.html":[2,0,4,443],
-"d7/d56/lapacke__csyr__work_8c.html":[2,0,3,3,465],
-"d7/d56/lapacke__csyr__work_8c_a45b243299ecb76160936c9ee866dcbb4.html#a45b243299ecb76160936c9ee866dcbb4":[2,0,3,3,465,0],
-"d7/d56/lapacke__csyr__work_8c_source.html":[2,0,3,3,465],
+"d7/d56/lapacke__csyr__work_8c.html":[2,0,3,3,467],
+"d7/d56/lapacke__csyr__work_8c_a45b243299ecb76160936c9ee866dcbb4.html#a45b243299ecb76160936c9ee866dcbb4":[2,0,3,3,467,0],
+"d7/d56/lapacke__csyr__work_8c_source.html":[2,0,3,3,467],
 "d7/d57/cpftri_8f.html":[2,0,4,318],
 "d7/d57/cpftri_8f_source.html":[2,0,4,318],
-"d7/d57/lapacke__ssyrfsx__work_8c.html":[2,0,3,3,1668],
-"d7/d57/lapacke__ssyrfsx__work_8c_a41a7f01d92b55b20c3549f1eccbda73b.html#a41a7f01d92b55b20c3549f1eccbda73b":[2,0,3,3,1668,0],
-"d7/d57/lapacke__ssyrfsx__work_8c_source.html":[2,0,3,3,1668],
-"d7/d57/zungtr_8f.html":[2,0,4,1927],
-"d7/d57/zungtr_8f_source.html":[2,0,4,1927],
+"d7/d57/lapacke__ssyrfsx__work_8c.html":[2,0,3,3,1674],
+"d7/d57/lapacke__ssyrfsx__work_8c_a41a7f01d92b55b20c3549f1eccbda73b.html#a41a7f01d92b55b20c3549f1eccbda73b":[2,0,3,3,1674,0],
+"d7/d57/lapacke__ssyrfsx__work_8c_source.html":[2,0,3,3,1674],
+"d7/d57/zungtr_8f.html":[2,0,4,1926],
+"d7/d57/zungtr_8f_source.html":[2,0,4,1926],
 "d7/d58/_l_i_n_2slarhs_8f.html":[2,0,5,1,478],
 "d7/d58/_l_i_n_2slarhs_8f_source.html":[2,0,5,1,478],
 "d7/d5b/dchksp_8f.html":[2,0,5,1,224],
 "d7/d5b/dchksp_8f_source.html":[2,0,5,1,224],
-"d7/d5b/lapacke__ctpqrt2_8c.html":[2,0,3,3,541],
-"d7/d5b/lapacke__ctpqrt2_8c_a6fced1354627de15612e59329e9d6aea.html#a6fced1354627de15612e59329e9d6aea":[2,0,3,3,541,0],
-"d7/d5b/lapacke__ctpqrt2_8c_source.html":[2,0,3,3,541],
-"d7/d5b/lapacke__zhetrf__rk_8c.html":[2,0,3,3,2030],
-"d7/d5b/lapacke__zhetrf__rk_8c_a154e816548bbd20d3de3b74f1e26d870.html#a154e816548bbd20d3de3b74f1e26d870":[2,0,3,3,2030,0],
-"d7/d5b/lapacke__zhetrf__rk_8c_source.html":[2,0,3,3,2030],
+"d7/d5b/lapacke__ctpqrt2_8c.html":[2,0,3,3,543],
+"d7/d5b/lapacke__ctpqrt2_8c_a6fced1354627de15612e59329e9d6aea.html#a6fced1354627de15612e59329e9d6aea":[2,0,3,3,543,0],
+"d7/d5b/lapacke__ctpqrt2_8c_source.html":[2,0,3,3,543],
+"d7/d5b/lapacke__zhetrf__rk_8c.html":[2,0,3,3,2036],
+"d7/d5b/lapacke__zhetrf__rk_8c_a154e816548bbd20d3de3b74f1e26d870.html#a154e816548bbd20d3de3b74f1e26d870":[2,0,3,3,2036,0],
+"d7/d5b/lapacke__zhetrf__rk_8c_source.html":[2,0,3,3,2036],
 "d7/d5b/schkst2stg_8f.html":[2,0,5,0,199],
 "d7/d5b/schkst2stg_8f_source.html":[2,0,5,0,199],
-"d7/d5c/lapacke__zsyswapr_8c.html":[2,0,3,3,2267],
-"d7/d5c/lapacke__zsyswapr_8c_a7b3cc82427ba44b455c51f6626946243.html#a7b3cc82427ba44b455c51f6626946243":[2,0,3,3,2267,0],
-"d7/d5c/lapacke__zsyswapr_8c_source.html":[2,0,3,3,2267],
-"d7/d5c/spbcon_8f.html":[2,0,4,1284],
-"d7/d5c/spbcon_8f_source.html":[2,0,4,1284],
+"d7/d5c/lapacke__zsyswapr_8c.html":[2,0,3,3,2275],
+"d7/d5c/lapacke__zsyswapr_8c_a7b3cc82427ba44b455c51f6626946243.html#a7b3cc82427ba44b455c51f6626946243":[2,0,3,3,2275,0],
+"d7/d5c/lapacke__zsyswapr_8c_source.html":[2,0,3,3,2275],
+"d7/d5c/spbcon_8f.html":[2,0,4,1283],
+"d7/d5c/spbcon_8f_source.html":[2,0,4,1283],
 "d7/d5d/lapacke__chetri_8c.html":[2,0,3,3,250],
 "d7/d5d/lapacke__chetri_8c_a1d8722df71b6f6b76db3f860541bc2fb.html#a1d8722df71b6f6b76db3f860541bc2fb":[2,0,3,3,250,0],
 "d7/d5d/lapacke__chetri_8c_source.html":[2,0,3,3,250],
-"d7/d5d/lapacke__zsprfs_8c.html":[2,0,3,3,2219],
-"d7/d5d/lapacke__zsprfs_8c_a953e792b92643cb57fb884625373fd66.html#a953e792b92643cb57fb884625373fd66":[2,0,3,3,2219,0],
-"d7/d5d/lapacke__zsprfs_8c_source.html":[2,0,3,3,2219],
-"d7/d5d/zlarfgp_8f.html":[2,0,4,1738],
-"d7/d5d/zlarfgp_8f_source.html":[2,0,4,1738],
+"d7/d5d/lapacke__zsprfs_8c.html":[2,0,3,3,2227],
+"d7/d5d/lapacke__zsprfs_8c_a953e792b92643cb57fb884625373fd66.html#a953e792b92643cb57fb884625373fd66":[2,0,3,3,2227,0],
+"d7/d5d/lapacke__zsprfs_8c_source.html":[2,0,3,3,2227],
+"d7/d5d/zlarfgp_8f.html":[2,0,4,1737],
+"d7/d5d/zlarfgp_8f_source.html":[2,0,4,1737],
 "d7/d5e/dchkbl_8f.html":[2,0,5,0,94],
 "d7/d5e/dchkbl_8f_source.html":[2,0,5,0,94],
-"d7/d5e/lapacke__zgelqf_8c.html":[2,0,3,3,1839],
-"d7/d5e/lapacke__zgelqf_8c_a2b75888c00494844ef611506267c006d.html#a2b75888c00494844ef611506267c006d":[2,0,3,3,1839,0],
-"d7/d5e/lapacke__zgelqf_8c_source.html":[2,0,3,3,1839],
-"d7/d5e/zposvxx_8f.html":[2,0,4,1791],
-"d7/d5e/zposvxx_8f_source.html":[2,0,4,1791],
+"d7/d5e/lapacke__zgelqf_8c.html":[2,0,3,3,1845],
+"d7/d5e/lapacke__zgelqf_8c_a2b75888c00494844ef611506267c006d.html#a2b75888c00494844ef611506267c006d":[2,0,3,3,1845,0],
+"d7/d5e/lapacke__zgelqf_8c_source.html":[2,0,3,3,1845],
+"d7/d5e/zposvxx_8f.html":[2,0,4,1790],
+"d7/d5e/zposvxx_8f_source.html":[2,0,4,1790],
 "d7/d60/cgelq2_8f.html":[2,0,4,31],
 "d7/d60/cgelq2_8f_source.html":[2,0,4,31],
 "d7/d60/lapacke__chetri2x__work_8c.html":[2,0,3,3,254],
@@ -105,9 +123,9 @@ var NAVTREEINDEX45 =
 "d7/d66/lapacke__cgesvx_8c.html":[2,0,3,3,106],
 "d7/d66/lapacke__cgesvx_8c_ae18e78f38990f25aaac6272575df18c1.html#ae18e78f38990f25aaac6272575df18c1":[2,0,3,3,106,0],
 "d7/d66/lapacke__cgesvx_8c_source.html":[2,0,3,3,106],
-"d7/d66/lapacke__ssyequb_8c.html":[2,0,3,3,1637],
-"d7/d66/lapacke__ssyequb_8c_a9a44b20a6a90a29125f27d6f5ec41a52.html#a9a44b20a6a90a29125f27d6f5ec41a52":[2,0,3,3,1637,0],
-"d7/d66/lapacke__ssyequb_8c_source.html":[2,0,3,3,1637],
+"d7/d66/lapacke__ssyequb_8c.html":[2,0,3,3,1643],
+"d7/d66/lapacke__ssyequb_8c_a9a44b20a6a90a29125f27d6f5ec41a52.html#a9a44b20a6a90a29125f27d6f5ec41a52":[2,0,3,3,1643,0],
+"d7/d66/lapacke__ssyequb_8c_source.html":[2,0,3,3,1643],
 "d7/d66/sqrt05_8f.html":[2,0,5,1,516],
 "d7/d66/sqrt05_8f_source.html":[2,0,5,1,516],
 "d7/d67/cblas__ssyr_8c.html":[2,0,1,2,98],
@@ -119,9 +137,9 @@ var NAVTREEINDEX45 =
 "d7/d67/cblas__ssyr_8c_source.html":[2,0,1,2,98],
 "d7/d67/zqlt03_8f.html":[2,0,5,1,709],
 "d7/d67/zqlt03_8f_source.html":[2,0,5,1,709],
-"d7/d69/lapacke__sgbtrs__work_8c.html":[2,0,3,3,1234],
-"d7/d69/lapacke__sgbtrs__work_8c_a4b2878834211b7cc90933d101e6e5acb.html#a4b2878834211b7cc90933d101e6e5acb":[2,0,3,3,1234,0],
-"d7/d69/lapacke__sgbtrs__work_8c_source.html":[2,0,3,3,1234],
+"d7/d69/lapacke__sgbtrs__work_8c.html":[2,0,3,3,1238],
+"d7/d69/lapacke__sgbtrs__work_8c_a4b2878834211b7cc90933d101e6e5acb.html#a4b2878834211b7cc90933d101e6e5acb":[2,0,3,3,1238,0],
+"d7/d69/lapacke__sgbtrs__work_8c_source.html":[2,0,3,3,1238],
 "d7/d6a/_e_i_g_2clarhs_8f.html":[2,0,5,0,74],
 "d7/d6a/_e_i_g_2clarhs_8f_source.html":[2,0,5,0,74],
 "d7/d6a/cunglq_8f.html":[2,0,4,459],
@@ -130,9 +148,9 @@ var NAVTREEINDEX45 =
 "d7/d6b/dlaswp_8f_source.html":[2,0,4,731],
 "d7/d6c/cqrt15_8f.html":[2,0,5,1,170],
 "d7/d6c/cqrt15_8f_source.html":[2,0,5,1,170],
-"d7/d6c/lapacke__ssptrs_8c.html":[2,0,3,3,1607],
-"d7/d6c/lapacke__ssptrs_8c_ad38ad65dd374ae03d09280196b2aa364.html#ad38ad65dd374ae03d09280196b2aa364":[2,0,3,3,1607,0],
-"d7/d6c/lapacke__ssptrs_8c_source.html":[2,0,3,3,1607],
+"d7/d6c/lapacke__ssptrs_8c.html":[2,0,3,3,1613],
+"d7/d6c/lapacke__ssptrs_8c_ad38ad65dd374ae03d09280196b2aa364.html#ad38ad65dd374ae03d09280196b2aa364":[2,0,3,3,1613,0],
+"d7/d6c/lapacke__ssptrs_8c_source.html":[2,0,3,3,1613],
 "d7/d6c/schklq_8f.html":[2,0,5,1,386],
 "d7/d6c/schklq_8f_source.html":[2,0,5,1,386],
 "d7/d6d/cblas__dtrmv_8c.html":[2,0,1,2,64],
@@ -146,8 +164,8 @@ var NAVTREEINDEX45 =
 "d7/d6d/cblas__dtrmv_8c_source.html":[2,0,1,2,64],
 "d7/d6d/dsytf2__rook_8f.html":[2,0,4,901],
 "d7/d6d/dsytf2__rook_8f_source.html":[2,0,4,901],
-"d7/d6d/zheevx__2stage_8f.html":[2,0,4,1585],
-"d7/d6d/zheevx__2stage_8f_source.html":[2,0,4,1585],
+"d7/d6d/zheevx__2stage_8f.html":[2,0,4,1584],
+"d7/d6d/zheevx__2stage_8f_source.html":[2,0,4,1584],
 "d7/d6f/c__cblas3_8c.html":[2,0,1,3,5],
 "d7/d6f/c__cblas3_8c_a2b013059e149dfa76fd29028e0fdcde1.html#a2b013059e149dfa76fd29028e0fdcde1":[2,0,1,3,5,10],
 "d7/d6f/c__cblas3_8c_a2dc3870be25a19efa2940150507aaf71.html#a2dc3870be25a19efa2940150507aaf71":[2,0,1,3,5,2],
@@ -162,20 +180,20 @@ var NAVTREEINDEX45 =
 "d7/d6f/c__cblas3_8c_af7fdfcf4057129f22773d552eb0c476d.html#af7fdfcf4057129f22773d552eb0c476d":[2,0,1,3,5,9],
 "d7/d6f/c__cblas3_8c_af99c52010352e31aee9d7876c8d718a7.html#af99c52010352e31aee9d7876c8d718a7":[2,0,1,3,5,6],
 "d7/d6f/c__cblas3_8c_source.html":[2,0,1,3,5],
-"d7/d70/lapacke__zunghr__work_8c.html":[2,0,3,3,2374],
-"d7/d70/lapacke__zunghr__work_8c_aa9cfac6c12995aa71dfead3116aba866.html#aa9cfac6c12995aa71dfead3116aba866":[2,0,3,3,2374,0],
-"d7/d70/lapacke__zunghr__work_8c_source.html":[2,0,3,3,2374],
-"d7/d70/stpttr_8f.html":[2,0,4,1446],
-"d7/d70/stpttr_8f_source.html":[2,0,4,1446],
-"d7/d71/lapacke__spbcon__work_8c.html":[2,0,3,3,1478],
-"d7/d71/lapacke__spbcon__work_8c_aad8354384fd4101fe58485aa82d1197c.html#aad8354384fd4101fe58485aa82d1197c":[2,0,3,3,1478,0],
-"d7/d71/lapacke__spbcon__work_8c_source.html":[2,0,3,3,1478],
-"d7/d72/lapacke__stgsja_8c.html":[2,0,3,3,1731],
-"d7/d72/lapacke__stgsja_8c_ace5a5def5c3a7e1b48b0a8dc9068eca9.html#ace5a5def5c3a7e1b48b0a8dc9068eca9":[2,0,3,3,1731,0],
-"d7/d72/lapacke__stgsja_8c_source.html":[2,0,3,3,1731],
-"d7/d72/lapacke__ztftri_8c.html":[2,0,3,3,2303],
-"d7/d72/lapacke__ztftri_8c_acb818cfc5146520e123f91c434b4f941.html#acb818cfc5146520e123f91c434b4f941":[2,0,3,3,2303,0],
-"d7/d72/lapacke__ztftri_8c_source.html":[2,0,3,3,2303],
+"d7/d70/lapacke__zunghr__work_8c.html":[2,0,3,3,2382],
+"d7/d70/lapacke__zunghr__work_8c_aa9cfac6c12995aa71dfead3116aba866.html#aa9cfac6c12995aa71dfead3116aba866":[2,0,3,3,2382,0],
+"d7/d70/lapacke__zunghr__work_8c_source.html":[2,0,3,3,2382],
+"d7/d70/stpttr_8f.html":[2,0,4,1445],
+"d7/d70/stpttr_8f_source.html":[2,0,4,1445],
+"d7/d71/lapacke__spbcon__work_8c.html":[2,0,3,3,1484],
+"d7/d71/lapacke__spbcon__work_8c_aad8354384fd4101fe58485aa82d1197c.html#aad8354384fd4101fe58485aa82d1197c":[2,0,3,3,1484,0],
+"d7/d71/lapacke__spbcon__work_8c_source.html":[2,0,3,3,1484],
+"d7/d72/lapacke__stgsja_8c.html":[2,0,3,3,1737],
+"d7/d72/lapacke__stgsja_8c_ace5a5def5c3a7e1b48b0a8dc9068eca9.html#ace5a5def5c3a7e1b48b0a8dc9068eca9":[2,0,3,3,1737,0],
+"d7/d72/lapacke__stgsja_8c_source.html":[2,0,3,3,1737],
+"d7/d72/lapacke__ztftri_8c.html":[2,0,3,3,2311],
+"d7/d72/lapacke__ztftri_8c_acb818cfc5146520e123f91c434b4f941.html#acb818cfc5146520e123f91c434b4f941":[2,0,3,3,2311,0],
+"d7/d72/lapacke__ztftri_8c_source.html":[2,0,3,3,2311],
 "d7/d73/cblas__ctpsv_8c.html":[2,0,1,2,28],
 "d7/d73/cblas__ctpsv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[2,0,1,2,28,0],
 "d7/d73/cblas__ctpsv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[2,0,1,2,28,1],
@@ -190,31 +208,31 @@ var NAVTREEINDEX45 =
 "d7/d75/cbdt01_8f_source.html":[2,0,5,0,6],
 "d7/d75/dopgtr_8f.html":[2,0,4,747],
 "d7/d75/dopgtr_8f_source.html":[2,0,4,747],
-"d7/d75/lapacke__slartgp__work_8c.html":[2,0,3,3,1422],
-"d7/d75/lapacke__slartgp__work_8c_ae692f0f914d5656916a9f63db688fae9.html#ae692f0f914d5656916a9f63db688fae9":[2,0,3,3,1422,0],
-"d7/d75/lapacke__slartgp__work_8c_source.html":[2,0,3,3,1422],
-"d7/d75/lapacke__ssyevr_8c.html":[2,0,3,3,1647],
-"d7/d75/lapacke__ssyevr_8c_a57aa02c0efb60bcb686c4d5e341c833b.html#a57aa02c0efb60bcb686c4d5e341c833b":[2,0,3,3,1647,0],
-"d7/d75/lapacke__ssyevr_8c_source.html":[2,0,3,3,1647],
+"d7/d75/lapacke__slartgp__work_8c.html":[2,0,3,3,1426],
+"d7/d75/lapacke__slartgp__work_8c_ae692f0f914d5656916a9f63db688fae9.html#ae692f0f914d5656916a9f63db688fae9":[2,0,3,3,1426,0],
+"d7/d75/lapacke__slartgp__work_8c_source.html":[2,0,3,3,1426],
+"d7/d75/lapacke__ssyevr_8c.html":[2,0,3,3,1653],
+"d7/d75/lapacke__ssyevr_8c_a57aa02c0efb60bcb686c4d5e341c833b.html#a57aa02c0efb60bcb686c4d5e341c833b":[2,0,3,3,1653,0],
+"d7/d75/lapacke__ssyevr_8c_source.html":[2,0,3,3,1653],
 "d7/d75/strt01_8f.html":[2,0,5,1,544],
 "d7/d75/strt01_8f_source.html":[2,0,5,1,544],
-"d7/d76/sorm22_8f.html":[2,0,4,1270],
-"d7/d76/sorm22_8f_source.html":[2,0,4,1270],
+"d7/d76/sorm22_8f.html":[2,0,4,1269],
+"d7/d76/sorm22_8f_source.html":[2,0,4,1269],
 "d7/d76/zgemm_8f.html":[2,0,0,0,123],
 "d7/d76/zgemm_8f_source.html":[2,0,0,0,123],
 "d7/d77/dpttrs_8f.html":[2,0,4,824],
 "d7/d77/dpttrs_8f_source.html":[2,0,4,824],
-"d7/d77/lapacke__dorcsd2by1__work_8c.html":[2,0,3,3,862],
-"d7/d77/lapacke__dorcsd2by1__work_8c_a6fed1ef0054fd7ffa7cda6967e014ccc.html#a6fed1ef0054fd7ffa7cda6967e014ccc":[2,0,3,3,862,0],
-"d7/d77/lapacke__dorcsd2by1__work_8c_source.html":[2,0,3,3,862],
-"d7/d77/lapacke__ztrtrs__work_8c.html":[2,0,3,3,2358],
-"d7/d77/lapacke__ztrtrs__work_8c_a8aee03f5f46607648f1f492827bac009.html#a8aee03f5f46607648f1f492827bac009":[2,0,3,3,2358,0],
-"d7/d77/lapacke__ztrtrs__work_8c_source.html":[2,0,3,3,2358],
+"d7/d77/lapacke__dorcsd2by1__work_8c.html":[2,0,3,3,866],
+"d7/d77/lapacke__dorcsd2by1__work_8c_a6fed1ef0054fd7ffa7cda6967e014ccc.html#a6fed1ef0054fd7ffa7cda6967e014ccc":[2,0,3,3,866,0],
+"d7/d77/lapacke__dorcsd2by1__work_8c_source.html":[2,0,3,3,866],
+"d7/d77/lapacke__ztrtrs__work_8c.html":[2,0,3,3,2366],
+"d7/d77/lapacke__ztrtrs__work_8c_a8aee03f5f46607648f1f492827bac009.html#a8aee03f5f46607648f1f492827bac009":[2,0,3,3,2366,0],
+"d7/d77/lapacke__ztrtrs__work_8c_source.html":[2,0,3,3,2366],
 "d7/d79/cdrgev3_8f.html":[2,0,5,0,33],
 "d7/d79/cdrgev3_8f_source.html":[2,0,5,0,33],
-"d7/d79/lapacke__sormrz_8c.html":[2,0,3,3,1473],
-"d7/d79/lapacke__sormrz_8c_a72e12ecec38ebb86133d930f3ad3ca33.html#a72e12ecec38ebb86133d930f3ad3ca33":[2,0,3,3,1473,0],
-"d7/d79/lapacke__sormrz_8c_source.html":[2,0,3,3,1473],
+"d7/d79/lapacke__sormrz_8c.html":[2,0,3,3,1479],
+"d7/d79/lapacke__sormrz_8c_a72e12ecec38ebb86133d930f3ad3ca33.html#a72e12ecec38ebb86133d930f3ad3ca33":[2,0,3,3,1479,0],
+"d7/d79/lapacke__sormrz_8c_source.html":[2,0,3,3,1479],
 "d7/d7b/cdotu_8f.html":[2,0,0,0,3],
 "d7/d7b/cdotu_8f_source.html":[2,0,0,0,3],
 "d7/d7b/dorcsd2by1_8f.html":[2,0,4,757],
@@ -231,23 +249,5 @@ var NAVTREEINDEX45 =
 "d7/d7c/example__user_8c_a0240ac851181b84ac374872dc5434ee4.html#a0240ac851181b84ac374872dc5434ee4":[2,0,3,0,4,2],
 "d7/d7c/example__user_8c_a2a30cbe1245f6fab285b4d71354cf2c6.html#a2a30cbe1245f6fab285b4d71354cf2c6":[2,0,3,0,4,5],
 "d7/d7c/example__user_8c_a50e90a7104df172b5a89a06c47fcca04.html#a50e90a7104df172b5a89a06c47fcca04":[2,0,3,0,4,1],
-"d7/d7c/example__user_8c_a940f2bf73166fe75212e1b43e9ea9521.html#a940f2bf73166fe75212e1b43e9ea9521":[2,0,3,0,4,6],
-"d7/d7c/example__user_8c_aa0138da002ce2a90360df2f521eb3198.html#aa0138da002ce2a90360df2f521eb3198":[2,0,3,0,4,3],
-"d7/d7c/example__user_8c_ae66f6b31b5ad750f1fe042a706a4e3d4.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[2,0,3,0,4,4],
-"d7/d7c/example__user_8c_ae946da542ce0db94dced19b2ecefd1aa.html#ae946da542ce0db94dced19b2ecefd1aa":[2,0,3,0,4,0],
-"d7/d7c/example__user_8c_source.html":[2,0,3,0,4],
-"d7/d7d/lapacke__slange_8c.html":[2,0,3,3,1397],
-"d7/d7d/lapacke__slange_8c_ae7df0e6be1babf8a3412fc87e3245cbb.html#ae7df0e6be1babf8a3412fc87e3245cbb":[2,0,3,3,1397,0],
-"d7/d7d/lapacke__slange_8c_source.html":[2,0,3,3,1397],
-"d7/d7f/_v_a_r_i_a_n_t_s_2lu_2_c_r_2dgetrf_8f.html":[2,0,4,1,1,0,1],
-"d7/d7f/_v_a_r_i_a_n_t_s_2lu_2_c_r_2dgetrf_8f_source.html":[2,0,4,1,1,0,1],
-"d7/d7f/dpot06_8f.html":[2,0,5,1,327],
-"d7/d7f/dpot06_8f_source.html":[2,0,5,1,327],
-"d7/d80/cqrt05_8f.html":[2,0,5,1,165],
-"d7/d80/cqrt05_8f_source.html":[2,0,5,1,165],
-"d7/d80/lapacke__dsy__trans_8c.html":[2,0,3,4,63],
-"d7/d80/lapacke__dsy__trans_8c_aef8c308a8f1bcce98598849dc06bccff.html#aef8c308a8f1bcce98598849dc06bccff":[2,0,3,4,63,0],
-"d7/d80/lapacke__dsy__trans_8c_source.html":[2,0,3,4,63],
-"d7/d82/dstedc_8f.html":[2,0,4,858],
-"d7/d82/dstedc_8f_source.html":[2,0,4,858]
+"d7/d7c/example__user_8c_a940f2bf73166fe75212e1b43e9ea9521.html#a940f2bf73166fe75212e1b43e9ea9521":[2,0,3,0,4,6]
 };
