@@ -1,7 +1,25 @@
 var NAVTREEINDEX49 =
 {
-"d7/dcb/sla__porfsx__extended_8f.html":[2,0,4,1096],
-"d7/dcb/sla__porfsx__extended_8f_source.html":[2,0,4,1096],
+"d7/dc4/zhecon__3_8f_source.html":[2,0,4,1574],
+"d7/dc4/zsytri__3x_8f.html":[2,0,4,1858],
+"d7/dc4/zsytri__3x_8f_source.html":[2,0,4,1858],
+"d7/dc5/dget10_8f.html":[2,0,5,0,133],
+"d7/dc5/dget10_8f_source.html":[2,0,5,0,133],
+"d7/dc9/lapacke__dsytrs_8c.html":[2,0,3,3,1126],
+"d7/dc9/lapacke__dsytrs_8c_a738baba9e7bc295b08a8d02b9f5e8fc4.html#a738baba9e7bc295b08a8d02b9f5e8fc4":[2,0,3,3,1126,0],
+"d7/dc9/lapacke__dsytrs_8c_source.html":[2,0,3,3,1126],
+"d7/dc9/lapacke__zpptrf_8c.html":[2,0,3,3,2203],
+"d7/dc9/lapacke__zpptrf_8c_a1bd0809496e08794da33ebd201455971.html#a1bd0809496e08794da33ebd201455971":[2,0,3,3,2203,0],
+"d7/dc9/lapacke__zpptrf_8c_source.html":[2,0,3,3,2203],
+"d7/dca/cpocon_8f.html":[2,0,4,320],
+"d7/dca/cpocon_8f_source.html":[2,0,4,320],
+"d7/dca/lapacke__zgeqrt2_8c.html":[2,0,3,3,1876],
+"d7/dca/lapacke__zgeqrt2_8c_a206baad277920a2d6f592f4e1a1c0641.html#a206baad277920a2d6f592f4e1a1c0641":[2,0,3,3,1876,0],
+"d7/dca/lapacke__zgeqrt2_8c_source.html":[2,0,3,3,1876],
+"d7/dcb/dtrt03_8f.html":[2,0,5,1,375],
+"d7/dcb/dtrt03_8f_source.html":[2,0,5,1,375],
+"d7/dcb/sla__porfsx__extended_8f.html":[2,0,4,1095],
+"d7/dcb/sla__porfsx__extended_8f_source.html":[2,0,4,1095],
 "d7/dcc/cblas__stpsv_8c.html":[2,0,1,2,105],
 "d7/dcc/cblas__stpsv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[2,0,1,2,105,0],
 "d7/dcc/cblas__stpsv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[2,0,1,2,105,1],
@@ -26,101 +44,101 @@ var NAVTREEINDEX49 =
 "d7/dcf/cblas__ssyr2_8c_source.html":[2,0,1,2,99],
 "d7/dd0/dlatm1_8f.html":[2,0,5,2,27],
 "d7/dd0/dlatm1_8f_source.html":[2,0,5,2,27],
-"d7/dd0/lapacke__zgges3_8c.html":[2,0,3,3,1912],
-"d7/dd0/lapacke__zgges3_8c_a966552ea05b5505bbf9acbc2efcf582b.html#a966552ea05b5505bbf9acbc2efcf582b":[2,0,3,3,1912,0],
-"d7/dd0/lapacke__zgges3_8c_source.html":[2,0,3,3,1912],
-"d7/dd1/slarrk_8f.html":[2,0,4,1194],
-"d7/dd1/slarrk_8f_source.html":[2,0,4,1194],
-"d7/dd1/slasdq_8f.html":[2,0,4,1219],
-"d7/dd1/slasdq_8f_source.html":[2,0,4,1219],
-"d7/dd1/zhpgvd_8f.html":[2,0,4,1631],
-"d7/dd1/zhpgvd_8f_source.html":[2,0,4,1631],
+"d7/dd0/lapacke__zgges3_8c.html":[2,0,3,3,1918],
+"d7/dd0/lapacke__zgges3_8c_a966552ea05b5505bbf9acbc2efcf582b.html#a966552ea05b5505bbf9acbc2efcf582b":[2,0,3,3,1918,0],
+"d7/dd0/lapacke__zgges3_8c_source.html":[2,0,3,3,1918],
+"d7/dd1/slarrk_8f.html":[2,0,4,1193],
+"d7/dd1/slarrk_8f_source.html":[2,0,4,1193],
+"d7/dd1/slasdq_8f.html":[2,0,4,1218],
+"d7/dd1/slasdq_8f_source.html":[2,0,4,1218],
+"d7/dd1/zhpgvd_8f.html":[2,0,4,1630],
+"d7/dd1/zhpgvd_8f_source.html":[2,0,4,1630],
 "d7/dd2/clagsy_8f.html":[2,0,5,2,2],
 "d7/dd2/clagsy_8f_source.html":[2,0,5,2,2],
-"d7/dd2/lapacke__ztptrs__work_8c.html":[2,0,3,3,2336],
-"d7/dd2/lapacke__ztptrs__work_8c_a379338bf5421013dbf01eb0b9321accc.html#a379338bf5421013dbf01eb0b9321accc":[2,0,3,3,2336,0],
-"d7/dd2/lapacke__ztptrs__work_8c_source.html":[2,0,3,3,2336],
-"d7/dd3/lapacke__dsygst_8c.html":[2,0,3,3,1076],
-"d7/dd3/lapacke__dsygst_8c_a03d0b7dc294cacfd03d837d20fcd8a9c.html#a03d0b7dc294cacfd03d837d20fcd8a9c":[2,0,3,3,1076,0],
-"d7/dd3/lapacke__dsygst_8c_source.html":[2,0,3,3,1076],
-"d7/dd3/lapacke__zgbsvx_8c.html":[2,0,3,3,1803],
-"d7/dd3/lapacke__zgbsvx_8c_a4ee222b53a4eaf5a14084cb90adb2428.html#a4ee222b53a4eaf5a14084cb90adb2428":[2,0,3,3,1803,0],
-"d7/dd3/lapacke__zgbsvx_8c_source.html":[2,0,3,3,1803],
+"d7/dd2/lapacke__ztptrs__work_8c.html":[2,0,3,3,2344],
+"d7/dd2/lapacke__ztptrs__work_8c_a379338bf5421013dbf01eb0b9321accc.html#a379338bf5421013dbf01eb0b9321accc":[2,0,3,3,2344,0],
+"d7/dd2/lapacke__ztptrs__work_8c_source.html":[2,0,3,3,2344],
+"d7/dd3/lapacke__dsygst_8c.html":[2,0,3,3,1080],
+"d7/dd3/lapacke__dsygst_8c_a03d0b7dc294cacfd03d837d20fcd8a9c.html#a03d0b7dc294cacfd03d837d20fcd8a9c":[2,0,3,3,1080,0],
+"d7/dd3/lapacke__dsygst_8c_source.html":[2,0,3,3,1080],
+"d7/dd3/lapacke__zgbsvx_8c.html":[2,0,3,3,1809],
+"d7/dd3/lapacke__zgbsvx_8c_a4ee222b53a4eaf5a14084cb90adb2428.html#a4ee222b53a4eaf5a14084cb90adb2428":[2,0,3,3,1809,0],
+"d7/dd3/lapacke__zgbsvx_8c_source.html":[2,0,3,3,1809],
 "d7/dd3/zstt22_8f.html":[2,0,5,0,353],
 "d7/dd3/zstt22_8f_source.html":[2,0,5,0,353],
-"d7/dd4/lapacke__dtptrs__work_8c.html":[2,0,3,3,1173],
-"d7/dd4/lapacke__dtptrs__work_8c_a463ff7c889e74a66e849d5797a9fd5b8.html#a463ff7c889e74a66e849d5797a9fd5b8":[2,0,3,3,1173,0],
-"d7/dd4/lapacke__dtptrs__work_8c_source.html":[2,0,3,3,1173],
+"d7/dd4/lapacke__dtptrs__work_8c.html":[2,0,3,3,1177],
+"d7/dd4/lapacke__dtptrs__work_8c_a463ff7c889e74a66e849d5797a9fd5b8.html#a463ff7c889e74a66e849d5797a9fd5b8":[2,0,3,3,1177,0],
+"d7/dd4/lapacke__dtptrs__work_8c_source.html":[2,0,3,3,1177],
 "d7/dd6/lapacke__chbev_8c.html":[2,0,3,3,170],
 "d7/dd6/lapacke__chbev_8c_a61cde4965d9ad88dcf77b5853c6328c5.html#a61cde4965d9ad88dcf77b5853c6328c5":[2,0,3,3,170,0],
 "d7/dd6/lapacke__chbev_8c_source.html":[2,0,3,3,170],
-"d7/dd6/lapacke__zgtcon__work_8c.html":[2,0,3,3,1944],
-"d7/dd6/lapacke__zgtcon__work_8c_a9ca3de4726802a1a6a582ccc1756c601.html#a9ca3de4726802a1a6a582ccc1756c601":[2,0,3,3,1944,0],
-"d7/dd6/lapacke__zgtcon__work_8c_source.html":[2,0,3,3,1944],
+"d7/dd6/lapacke__zgtcon__work_8c.html":[2,0,3,3,1950],
+"d7/dd6/lapacke__zgtcon__work_8c_a9ca3de4726802a1a6a582ccc1756c601.html#a9ca3de4726802a1a6a582ccc1756c601":[2,0,3,3,1950,0],
+"d7/dd6/lapacke__zgtcon__work_8c_source.html":[2,0,3,3,1950],
 "d7/dd7/group__complex__matgen.html":[0,1,0,2],
 "d7/dd7/group__complex__matgen_ga01a45e71da04e1130918ab95dbcd08c7.html#ga01a45e71da04e1130918ab95dbcd08c7":[0,1,0,2,0],
 "d7/dd7/group__complex__matgen_ga01a45e71da04e1130918ab95dbcd08c7.html#ga01a45e71da04e1130918ab95dbcd08c7":[2,0,5,2,0,0],
-"d7/dd7/group__complex__matgen_ga03442e4155cbb7b5bcbe29542d73ef05.html#ga03442e4155cbb7b5bcbe29542d73ef05":[0,1,0,2,13],
-"d7/dd7/group__complex__matgen_ga03442e4155cbb7b5bcbe29542d73ef05.html#ga03442e4155cbb7b5bcbe29542d73ef05":[2,0,5,2,13,0],
-"d7/dd7/group__complex__matgen_ga34c7f3d8c3c55af2b597996dab2b3d8f.html#ga34c7f3d8c3c55af2b597996dab2b3d8f":[0,1,0,2,11],
-"d7/dd7/group__complex__matgen_ga34c7f3d8c3c55af2b597996dab2b3d8f.html#ga34c7f3d8c3c55af2b597996dab2b3d8f":[2,0,5,2,11,0],
-"d7/dd7/group__complex__matgen_ga38ffd95f4e862ca535574a89233e28e7.html#ga38ffd95f4e862ca535574a89233e28e7":[0,1,0,2,3],
-"d7/dd7/group__complex__matgen_ga38ffd95f4e862ca535574a89233e28e7.html#ga38ffd95f4e862ca535574a89233e28e7":[2,0,5,2,3,0],
+"d7/dd7/group__complex__matgen_ga2689df757dd5958a8c2911a648577d56.html#ga2689df757dd5958a8c2911a648577d56":[0,1,0,2,10],
+"d7/dd7/group__complex__matgen_ga2689df757dd5958a8c2911a648577d56.html#ga2689df757dd5958a8c2911a648577d56":[2,0,5,2,10,0],
+"d7/dd7/group__complex__matgen_ga411f64e8d8b980e985c6b0189139dc49.html#ga411f64e8d8b980e985c6b0189139dc49":[0,1,0,2,16],
+"d7/dd7/group__complex__matgen_ga411f64e8d8b980e985c6b0189139dc49.html#ga411f64e8d8b980e985c6b0189139dc49":[2,0,5,2,16,0],
 "d7/dd7/group__complex__matgen_ga463c7fe8bfbf095b0c8703935e2b619a.html#ga463c7fe8bfbf095b0c8703935e2b619a":[0,1,0,2,7],
 "d7/dd7/group__complex__matgen_ga463c7fe8bfbf095b0c8703935e2b619a.html#ga463c7fe8bfbf095b0c8703935e2b619a":[2,0,5,2,7,0],
-"d7/dd7/group__complex__matgen_ga46cb87c6ebc50180ed050f1efecb3c1c.html#ga46cb87c6ebc50180ed050f1efecb3c1c":[0,1,0,2,14],
-"d7/dd7/group__complex__matgen_ga46cb87c6ebc50180ed050f1efecb3c1c.html#ga46cb87c6ebc50180ed050f1efecb3c1c":[2,0,5,2,14,0],
-"d7/dd7/group__complex__matgen_ga4c894dde6c97869a6c21009877c6ca83.html#ga4c894dde6c97869a6c21009877c6ca83":[0,1,0,2,17],
-"d7/dd7/group__complex__matgen_ga4c894dde6c97869a6c21009877c6ca83.html#ga4c894dde6c97869a6c21009877c6ca83":[2,0,5,2,17,0],
 "d7/dd7/group__complex__matgen_ga591e57991ad92ea8cc4ffd534c682bf9.html#ga591e57991ad92ea8cc4ffd534c682bf9":[0,1,0,2,5],
 "d7/dd7/group__complex__matgen_ga591e57991ad92ea8cc4ffd534c682bf9.html#ga591e57991ad92ea8cc4ffd534c682bf9":[2,0,5,2,5,0],
+"d7/dd7/group__complex__matgen_ga6b05f57659c673fb19b320ad9737810b.html#ga6b05f57659c673fb19b320ad9737810b":[0,1,0,2,12],
+"d7/dd7/group__complex__matgen_ga6b05f57659c673fb19b320ad9737810b.html#ga6b05f57659c673fb19b320ad9737810b":[2,0,5,2,12,0],
+"d7/dd7/group__complex__matgen_ga6b623095dea5337d8a8cc4e32c7990e0.html#ga6b623095dea5337d8a8cc4e32c7990e0":[0,1,0,2,14],
+"d7/dd7/group__complex__matgen_ga6b623095dea5337d8a8cc4e32c7990e0.html#ga6b623095dea5337d8a8cc4e32c7990e0":[2,0,5,2,14,0],
 "d7/dd7/group__complex__matgen_ga7a28051d16bc46beecf83a6cacad4b37.html#ga7a28051d16bc46beecf83a6cacad4b37":[0,1,0,2,4],
 "d7/dd7/group__complex__matgen_ga7a28051d16bc46beecf83a6cacad4b37.html#ga7a28051d16bc46beecf83a6cacad4b37":[2,0,5,2,4,0],
 "d7/dd7/group__complex__matgen_ga7b4d68bedb34b4e82b4a7cb32be76d24.html#ga7b4d68bedb34b4e82b4a7cb32be76d24":[0,1,0,2,1],
 "d7/dd7/group__complex__matgen_ga7b4d68bedb34b4e82b4a7cb32be76d24.html#ga7b4d68bedb34b4e82b4a7cb32be76d24":[2,0,5,2,1,0],
-"d7/dd7/group__complex__matgen_ga8aa042af7a3bfa320c567338f1bb8421.html#ga8aa042af7a3bfa320c567338f1bb8421":[0,1,0,2,10],
-"d7/dd7/group__complex__matgen_ga8aa042af7a3bfa320c567338f1bb8421.html#ga8aa042af7a3bfa320c567338f1bb8421":[2,0,5,2,10,0],
-"d7/dd7/group__complex__matgen_gaaa6a4ddadc16c69e914f6f8a21c8f2d5.html#gaaa6a4ddadc16c69e914f6f8a21c8f2d5":[0,1,0,2,16],
-"d7/dd7/group__complex__matgen_gaaa6a4ddadc16c69e914f6f8a21c8f2d5.html#gaaa6a4ddadc16c69e914f6f8a21c8f2d5":[2,0,5,2,16,0],
+"d7/dd7/group__complex__matgen_ga8b101f20bbd35d0294b4579e539dc607.html#ga8b101f20bbd35d0294b4579e539dc607":[0,1,0,2,8],
+"d7/dd7/group__complex__matgen_ga8b101f20bbd35d0294b4579e539dc607.html#ga8b101f20bbd35d0294b4579e539dc607":[2,0,5,2,8,0],
+"d7/dd7/group__complex__matgen_ga929f663f785e4b5841d06d9a947d670c.html#ga929f663f785e4b5841d06d9a947d670c":[0,1,0,2,11],
+"d7/dd7/group__complex__matgen_ga929f663f785e4b5841d06d9a947d670c.html#ga929f663f785e4b5841d06d9a947d670c":[2,0,5,2,11,0],
+"d7/dd7/group__complex__matgen_ga965cf56889238ff917eba10e6dbea93e.html#ga965cf56889238ff917eba10e6dbea93e":[0,1,0,2,15],
+"d7/dd7/group__complex__matgen_ga965cf56889238ff917eba10e6dbea93e.html#ga965cf56889238ff917eba10e6dbea93e":[2,0,5,2,15,0],
 "d7/dd7/group__complex__matgen_gac45992478d4a059e7d62f403077a78fd.html#gac45992478d4a059e7d62f403077a78fd":[0,1,0,2,6],
 "d7/dd7/group__complex__matgen_gac45992478d4a059e7d62f403077a78fd.html#gac45992478d4a059e7d62f403077a78fd":[2,0,5,2,6,0],
-"d7/dd7/group__complex__matgen_gac4fb1c41dc2a3c76492a90bc6ee73407.html#gac4fb1c41dc2a3c76492a90bc6ee73407":[0,1,0,2,8],
-"d7/dd7/group__complex__matgen_gac4fb1c41dc2a3c76492a90bc6ee73407.html#gac4fb1c41dc2a3c76492a90bc6ee73407":[2,0,5,2,8,0],
-"d7/dd7/group__complex__matgen_gaccb8b77dc0c3bceadd96040284dd610e.html#gaccb8b77dc0c3bceadd96040284dd610e":[0,1,0,2,15],
-"d7/dd7/group__complex__matgen_gaccb8b77dc0c3bceadd96040284dd610e.html#gaccb8b77dc0c3bceadd96040284dd610e":[2,0,5,2,15,0],
+"d7/dd7/group__complex__matgen_gacbcffc07d8119265fdd7ec81f961e75a.html#gacbcffc07d8119265fdd7ec81f961e75a":[0,1,0,2,17],
+"d7/dd7/group__complex__matgen_gacbcffc07d8119265fdd7ec81f961e75a.html#gacbcffc07d8119265fdd7ec81f961e75a":[2,0,5,2,17,0],
 "d7/dd7/group__complex__matgen_gad3c84db8fbdfd2f970e682caa31e72a6.html#gad3c84db8fbdfd2f970e682caa31e72a6":[0,1,0,2,9],
 "d7/dd7/group__complex__matgen_gad3c84db8fbdfd2f970e682caa31e72a6.html#gad3c84db8fbdfd2f970e682caa31e72a6":[2,0,5,2,9,0],
-"d7/dd7/group__complex__matgen_gad57aa8243382cb72c72beaf0d9be1f39.html#gad57aa8243382cb72c72beaf0d9be1f39":[0,1,0,2,12],
-"d7/dd7/group__complex__matgen_gad57aa8243382cb72c72beaf0d9be1f39.html#gad57aa8243382cb72c72beaf0d9be1f39":[2,0,5,2,12,0],
+"d7/dd7/group__complex__matgen_gad3cf156a3529004d8ca739e77a1b4e16.html#gad3cf156a3529004d8ca739e77a1b4e16":[0,1,0,2,3],
+"d7/dd7/group__complex__matgen_gad3cf156a3529004d8ca739e77a1b4e16.html#gad3cf156a3529004d8ca739e77a1b4e16":[2,0,5,2,3,0],
 "d7/dd7/group__complex__matgen_gae43d0be5e9d0999d6a512e6842a6d65f.html#gae43d0be5e9d0999d6a512e6842a6d65f":[0,1,0,2,2],
 "d7/dd7/group__complex__matgen_gae43d0be5e9d0999d6a512e6842a6d65f.html#gae43d0be5e9d0999d6a512e6842a6d65f":[2,0,5,2,2,0],
+"d7/dd7/group__complex__matgen_gae9d75b31c19f718d006ac8059071b253.html#gae9d75b31c19f718d006ac8059071b253":[0,1,0,2,13],
+"d7/dd7/group__complex__matgen_gae9d75b31c19f718d006ac8059071b253.html#gae9d75b31c19f718d006ac8059071b253":[2,0,5,2,13,0],
 "d7/dd8/dlascl2_8f.html":[2,0,4,706],
 "d7/dd8/dlascl2_8f_source.html":[2,0,4,706],
-"d7/dd8/lapacke__slagsy_8c.html":[2,0,3,3,1393],
-"d7/dd8/lapacke__slagsy_8c_a4d8fdc269f351b1e7056e23275443c1b.html#a4d8fdc269f351b1e7056e23275443c1b":[2,0,3,3,1393,0],
-"d7/dd8/lapacke__slagsy_8c_source.html":[2,0,3,3,1393],
-"d7/dd9/lapacke__dgesv__work_8c.html":[2,0,3,3,725],
-"d7/dd9/lapacke__dgesv__work_8c_a6e4e6f43f3ea01a131316aabc0f2c10a.html#a6e4e6f43f3ea01a131316aabc0f2c10a":[2,0,3,3,725,0],
-"d7/dd9/lapacke__dgesv__work_8c_source.html":[2,0,3,3,725],
-"d7/dd9/ssytrs_8f.html":[2,0,4,1414],
-"d7/dd9/ssytrs_8f_source.html":[2,0,4,1414],
-"d7/dd9/zlags2_8f.html":[2,0,4,1684],
-"d7/dd9/zlags2_8f_source.html":[2,0,4,1684],
-"d7/dda/slaed7_8f.html":[2,0,4,1118],
-"d7/dda/slaed7_8f_source.html":[2,0,4,1118],
+"d7/dd8/lapacke__slagsy_8c.html":[2,0,3,3,1397],
+"d7/dd8/lapacke__slagsy_8c_a4d8fdc269f351b1e7056e23275443c1b.html#a4d8fdc269f351b1e7056e23275443c1b":[2,0,3,3,1397,0],
+"d7/dd8/lapacke__slagsy_8c_source.html":[2,0,3,3,1397],
+"d7/dd9/lapacke__dgesv__work_8c.html":[2,0,3,3,727],
+"d7/dd9/lapacke__dgesv__work_8c_a6e4e6f43f3ea01a131316aabc0f2c10a.html#a6e4e6f43f3ea01a131316aabc0f2c10a":[2,0,3,3,727,0],
+"d7/dd9/lapacke__dgesv__work_8c_source.html":[2,0,3,3,727],
+"d7/dd9/ssytrs_8f.html":[2,0,4,1413],
+"d7/dd9/ssytrs_8f_source.html":[2,0,4,1413],
+"d7/dd9/zlags2_8f.html":[2,0,4,1683],
+"d7/dd9/zlags2_8f_source.html":[2,0,4,1683],
+"d7/dda/slaed7_8f.html":[2,0,4,1117],
+"d7/dda/slaed7_8f_source.html":[2,0,4,1117],
 "d7/ddb/dlarrr_8f.html":[2,0,4,693],
 "d7/ddb/dlarrr_8f_source.html":[2,0,4,693],
-"d7/dde/lapacke__sptcon__work_8c.html":[2,0,3,3,1542],
-"d7/dde/lapacke__sptcon__work_8c_a8e40abbfbbfad9f03d53c71fb4e0b93d.html#a8e40abbfbbfad9f03d53c71fb4e0b93d":[2,0,3,3,1542,0],
-"d7/dde/lapacke__sptcon__work_8c_source.html":[2,0,3,3,1542],
-"d7/ddf/lapacke__sgbrfs__work_8c.html":[2,0,3,3,1222],
-"d7/ddf/lapacke__sgbrfs__work_8c_a4b07231277e494fa42fc46183e5635cd.html#a4b07231277e494fa42fc46183e5635cd":[2,0,3,3,1222,0],
-"d7/ddf/lapacke__sgbrfs__work_8c_source.html":[2,0,3,3,1222],
-"d7/de0/zlatrd_8f.html":[2,0,4,1766],
-"d7/de0/zlatrd_8f_source.html":[2,0,4,1766],
-"d7/de2/lapacke__zlacp2_8c.html":[2,0,3,3,2095],
-"d7/de2/lapacke__zlacp2_8c_af501e307ad2e3ced2e0d4f5b1f632fb2.html#af501e307ad2e3ced2e0d4f5b1f632fb2":[2,0,3,3,2095,0],
-"d7/de2/lapacke__zlacp2_8c_source.html":[2,0,3,3,2095],
+"d7/dde/lapacke__sptcon__work_8c.html":[2,0,3,3,1548],
+"d7/dde/lapacke__sptcon__work_8c_a8e40abbfbbfad9f03d53c71fb4e0b93d.html#a8e40abbfbbfad9f03d53c71fb4e0b93d":[2,0,3,3,1548,0],
+"d7/dde/lapacke__sptcon__work_8c_source.html":[2,0,3,3,1548],
+"d7/ddf/lapacke__sgbrfs__work_8c.html":[2,0,3,3,1226],
+"d7/ddf/lapacke__sgbrfs__work_8c_a4b07231277e494fa42fc46183e5635cd.html#a4b07231277e494fa42fc46183e5635cd":[2,0,3,3,1226,0],
+"d7/ddf/lapacke__sgbrfs__work_8c_source.html":[2,0,3,3,1226],
+"d7/de0/zlatrd_8f.html":[2,0,4,1765],
+"d7/de0/zlatrd_8f_source.html":[2,0,4,1765],
+"d7/de2/lapacke__zlacp2_8c.html":[2,0,3,3,2101],
+"d7/de2/lapacke__zlacp2_8c_af501e307ad2e3ced2e0d4f5b1f632fb2.html#af501e307ad2e3ced2e0d4f5b1f632fb2":[2,0,3,3,2101,0],
+"d7/de2/lapacke__zlacp2_8c_source.html":[2,0,3,3,2101],
 "d7/de3/cgeqrt_8f.html":[2,0,4,51],
 "d7/de3/cgeqrt_8f_source.html":[2,0,4,51],
 "d7/de5/cblas__zswap_8c.html":[2,0,1,2,132],
@@ -131,11 +149,11 @@ var NAVTREEINDEX49 =
 "d7/de5/cblas__zswap_8c_source.html":[2,0,1,2,132],
 "d7/de6/dtpmqrt_8f.html":[2,0,4,939],
 "d7/de6/dtpmqrt_8f_source.html":[2,0,4,939],
-"d7/de6/lapacke__dsyevr__work_8c.html":[2,0,3,3,1071],
-"d7/de6/lapacke__dsyevr__work_8c_a5542586fdcc41b2bb42f38a1ab4fd566.html#a5542586fdcc41b2bb42f38a1ab4fd566":[2,0,3,3,1071,0],
-"d7/de6/lapacke__dsyevr__work_8c_source.html":[2,0,3,3,1071],
-"d7/de6/ssbgst_8f.html":[2,0,4,1335],
-"d7/de6/ssbgst_8f_source.html":[2,0,4,1335],
+"d7/de6/lapacke__dsyevr__work_8c.html":[2,0,3,3,1075],
+"d7/de6/lapacke__dsyevr__work_8c_a5542586fdcc41b2bb42f38a1ab4fd566.html#a5542586fdcc41b2bb42f38a1ab4fd566":[2,0,3,3,1075,0],
+"d7/de6/lapacke__dsyevr__work_8c_source.html":[2,0,3,3,1075],
+"d7/de6/ssbgst_8f.html":[2,0,4,1334],
+"d7/de6/ssbgst_8f_source.html":[2,0,4,1334],
 "d7/de7/ctgsyl_8f.html":[2,0,4,417],
 "d7/de7/ctgsyl_8f_source.html":[2,0,4,417],
 "d7/de7/lapacke__cgbequb_8c.html":[2,0,3,3,10],
@@ -144,8 +162,8 @@ var NAVTREEINDEX49 =
 "d7/de7/lapacke__stb__trans_8c.html":[2,0,3,4,102],
 "d7/de7/lapacke__stb__trans_8c_ad747de8cd5276e30889f34e8b1cb054c.html#ad747de8cd5276e30889f34e8b1cb054c":[2,0,3,4,102,0],
 "d7/de7/lapacke__stb__trans_8c_source.html":[2,0,3,4,102],
-"d7/de7/sopmtr_8f.html":[2,0,4,1249],
-"d7/de7/sopmtr_8f_source.html":[2,0,4,1249],
+"d7/de7/sopmtr_8f.html":[2,0,4,1248],
+"d7/de7/sopmtr_8f_source.html":[2,0,4,1248],
 "d7/de8/cblas__test_8h.html":[2,0,1,1,2],
 "d7/de8/cblas__test_8h_a0553fa4e0aa5ae85d3ed2c6d52347373.html#a0553fa4e0aa5ae85d3ed2c6d52347373":[2,0,1,1,2,22],
 "d7/de8/cblas__test_8h_a0646bf1e99ebf193e64c32dfaf9a4294.html#a0646bf1e99ebf193e64c32dfaf9a4294":[2,0,1,1,2,45],
@@ -231,23 +249,5 @@ var NAVTREEINDEX49 =
 "d7/de8/cblas__test_8h_a83db4d797dc4e9fb34c7c53c86b68a84.html#a83db4d797dc4e9fb34c7c53c86b68a84":[2,0,1,1,2,77],
 "d7/de8/cblas__test_8h_a8422da294fb80ad4669bb67a094e6cd0.html#a8422da294fb80ad4669bb67a094e6cd0":[2,0,1,1,2,28],
 "d7/de8/cblas__test_8h_a84395d8c79ae506c40f105e8c3809167.html#a84395d8c79ae506c40f105e8c3809167":[2,0,1,1,2,11],
-"d7/de8/cblas__test_8h_a86a5d6b5a33186767971c22d8f14fc2a.html#a86a5d6b5a33186767971c22d8f14fc2a":[2,0,1,1,2,124],
-"d7/de8/cblas__test_8h_a88937d0d575e301f118368647f4ec7e5.html#a88937d0d575e301f118368647f4ec7e5":[2,0,1,1,2,70],
-"d7/de8/cblas__test_8h_a8d2b41542b6ae355eb829fe8434de12f.html#a8d2b41542b6ae355eb829fe8434de12f":[2,0,1,1,2,72],
-"d7/de8/cblas__test_8h_a8e904d01c48a94b8c8663644bb773eac.html#a8e904d01c48a94b8c8663644bb773eac":[2,0,1,1,2,123],
-"d7/de8/cblas__test_8h_a8f10e641f4bc248e46d3a2b73ec29d23.html#a8f10e641f4bc248e46d3a2b73ec29d23":[2,0,1,1,2,71],
-"d7/de8/cblas__test_8h_a93ec1171fd30c5d88cf1f9e1f22d018f.html#a93ec1171fd30c5d88cf1f9e1f22d018f":[2,0,1,1,2,135],
-"d7/de8/cblas__test_8h_a950c36f878936d7ad4e370eb4182f351.html#a950c36f878936d7ad4e370eb4182f351":[2,0,1,1,2,29],
-"d7/de8/cblas__test_8h_a9606fb5bc39bf3f080f5259635ddbf41.html#a9606fb5bc39bf3f080f5259635ddbf41":[2,0,1,1,2,47],
-"d7/de8/cblas__test_8h_a960ea2dfca9c21fd01ef3750d40768c9.html#a960ea2dfca9c21fd01ef3750d40768c9":[2,0,1,1,2,151],
-"d7/de8/cblas__test_8h_a967067e5edc4ce5da1eb5406df151e9d.html#a967067e5edc4ce5da1eb5406df151e9d":[2,0,1,1,2,65],
-"d7/de8/cblas__test_8h_a9bb9d474cd2dba544beaf27a55e75a6b.html#a9bb9d474cd2dba544beaf27a55e75a6b":[2,0,1,1,2,79],
-"d7/de8/cblas__test_8h_a9c852021615ed599f6e05152e7c62c3b.html#a9c852021615ed599f6e05152e7c62c3b":[2,0,1,1,2,6],
-"d7/de8/cblas__test_8h_a9e7f3e50297aa0fdbaabe22337e65ce8.html#a9e7f3e50297aa0fdbaabe22337e65ce8":[2,0,1,1,2,81],
-"d7/de8/cblas__test_8h_a9f497ca91fecb0a362385b8d22a67e25.html#a9f497ca91fecb0a362385b8d22a67e25":[2,0,1,1,2,44],
-"d7/de8/cblas__test_8h_aa107ca868e061db57f21897068d17260.html#aa107ca868e061db57f21897068d17260":[2,0,1,1,2,119],
-"d7/de8/cblas__test_8h_aa11729dbac77406af1186decea780e26.html#aa11729dbac77406af1186decea780e26":[2,0,1,1,2,113],
-"d7/de8/cblas__test_8h_aa33b878ccc859614f62c25d72c5b2d03.html#aa33b878ccc859614f62c25d72c5b2d03":[2,0,1,1,2,114],
-"d7/de8/cblas__test_8h_aa3fb55c6f9c16d14c0e7fa7d93f397fa.html#aa3fb55c6f9c16d14c0e7fa7d93f397fa":[2,0,1,1,2,32],
-"d7/de8/cblas__test_8h_aa50b7f7dc002c414c36cdc52231ca126.html#aa50b7f7dc002c414c36cdc52231ca126":[2,0,1,1,2,115]
+"d7/de8/cblas__test_8h_a86a5d6b5a33186767971c22d8f14fc2a.html#a86a5d6b5a33186767971c22d8f14fc2a":[2,0,1,1,2,124]
 };
