@@ -1,5 +1,23 @@
 var NAVTREEINDEX50 =
 {
+"d7/de8/cblas__test_8h_a88937d0d575e301f118368647f4ec7e5.html#a88937d0d575e301f118368647f4ec7e5":[2,0,1,1,2,70],
+"d7/de8/cblas__test_8h_a8d2b41542b6ae355eb829fe8434de12f.html#a8d2b41542b6ae355eb829fe8434de12f":[2,0,1,1,2,72],
+"d7/de8/cblas__test_8h_a8e904d01c48a94b8c8663644bb773eac.html#a8e904d01c48a94b8c8663644bb773eac":[2,0,1,1,2,123],
+"d7/de8/cblas__test_8h_a8f10e641f4bc248e46d3a2b73ec29d23.html#a8f10e641f4bc248e46d3a2b73ec29d23":[2,0,1,1,2,71],
+"d7/de8/cblas__test_8h_a93ec1171fd30c5d88cf1f9e1f22d018f.html#a93ec1171fd30c5d88cf1f9e1f22d018f":[2,0,1,1,2,135],
+"d7/de8/cblas__test_8h_a950c36f878936d7ad4e370eb4182f351.html#a950c36f878936d7ad4e370eb4182f351":[2,0,1,1,2,29],
+"d7/de8/cblas__test_8h_a9606fb5bc39bf3f080f5259635ddbf41.html#a9606fb5bc39bf3f080f5259635ddbf41":[2,0,1,1,2,47],
+"d7/de8/cblas__test_8h_a960ea2dfca9c21fd01ef3750d40768c9.html#a960ea2dfca9c21fd01ef3750d40768c9":[2,0,1,1,2,151],
+"d7/de8/cblas__test_8h_a967067e5edc4ce5da1eb5406df151e9d.html#a967067e5edc4ce5da1eb5406df151e9d":[2,0,1,1,2,65],
+"d7/de8/cblas__test_8h_a9bb9d474cd2dba544beaf27a55e75a6b.html#a9bb9d474cd2dba544beaf27a55e75a6b":[2,0,1,1,2,79],
+"d7/de8/cblas__test_8h_a9c852021615ed599f6e05152e7c62c3b.html#a9c852021615ed599f6e05152e7c62c3b":[2,0,1,1,2,6],
+"d7/de8/cblas__test_8h_a9e7f3e50297aa0fdbaabe22337e65ce8.html#a9e7f3e50297aa0fdbaabe22337e65ce8":[2,0,1,1,2,81],
+"d7/de8/cblas__test_8h_a9f497ca91fecb0a362385b8d22a67e25.html#a9f497ca91fecb0a362385b8d22a67e25":[2,0,1,1,2,44],
+"d7/de8/cblas__test_8h_aa107ca868e061db57f21897068d17260.html#aa107ca868e061db57f21897068d17260":[2,0,1,1,2,119],
+"d7/de8/cblas__test_8h_aa11729dbac77406af1186decea780e26.html#aa11729dbac77406af1186decea780e26":[2,0,1,1,2,113],
+"d7/de8/cblas__test_8h_aa33b878ccc859614f62c25d72c5b2d03.html#aa33b878ccc859614f62c25d72c5b2d03":[2,0,1,1,2,114],
+"d7/de8/cblas__test_8h_aa3fb55c6f9c16d14c0e7fa7d93f397fa.html#aa3fb55c6f9c16d14c0e7fa7d93f397fa":[2,0,1,1,2,32],
+"d7/de8/cblas__test_8h_aa50b7f7dc002c414c36cdc52231ca126.html#aa50b7f7dc002c414c36cdc52231ca126":[2,0,1,1,2,115],
 "d7/de8/cblas__test_8h_aa66f3b9070c73c2b35d8da0ec009eb56.html#aa66f3b9070c73c2b35d8da0ec009eb56":[2,0,1,1,2,37],
 "d7/de8/cblas__test_8h_aa673f02ed0992360ea5bd8f11fb075b6.html#aa673f02ed0992360ea5bd8f11fb075b6":[2,0,1,1,2,94],
 "d7/de8/cblas__test_8h_aa8cecfc5c5c054d2875c03e77b7be15d.html#aa8cecfc5c5c054d2875c03e77b7be15d":[2,0,1,1,2,159],
@@ -63,12 +81,12 @@ var NAVTREEINDEX50 =
 "d7/de8/cblas__test_8h_source.html":[2,0,1,1,2],
 "d7/de8/cherfsx_8f.html":[2,0,4,129],
 "d7/de8/cherfsx_8f_source.html":[2,0,4,129],
-"d7/de8/sgesv_8f.html":[2,0,4,1044],
-"d7/de8/sgesv_8f_source.html":[2,0,4,1044],
-"d7/de8/slaruv_8f.html":[2,0,4,1202],
-"d7/de8/slaruv_8f_source.html":[2,0,4,1202],
-"d7/de8/zsytrs__rook_8f.html":[2,0,4,1865],
-"d7/de8/zsytrs__rook_8f_source.html":[2,0,4,1865],
+"d7/de8/sgesv_8f.html":[2,0,4,1043],
+"d7/de8/sgesv_8f_source.html":[2,0,4,1043],
+"d7/de8/slaruv_8f.html":[2,0,4,1201],
+"d7/de8/slaruv_8f_source.html":[2,0,4,1201],
+"d7/de8/zsytrs__rook_8f.html":[2,0,4,1864],
+"d7/de8/zsytrs__rook_8f_source.html":[2,0,4,1864],
 "d7/de9/cgehd2_8f.html":[2,0,4,27],
 "d7/de9/cgehd2_8f_source.html":[2,0,4,27],
 "d7/dea/cchkeq_8f.html":[2,0,5,1,8],
@@ -79,9 +97,9 @@ var NAVTREEINDEX50 =
 "d7/dea/stpt05_8f_source.html":[2,0,5,1,542],
 "d7/deb/aladhd_8f.html":[2,0,5,1,0],
 "d7/deb/aladhd_8f_source.html":[2,0,5,1,0],
-"d7/deb/lapacke__sstein_8c.html":[2,0,3,3,1615],
-"d7/deb/lapacke__sstein_8c_a0391b10aed7585c2b736e0afea9228a0.html#a0391b10aed7585c2b736e0afea9228a0":[2,0,3,3,1615,0],
-"d7/deb/lapacke__sstein_8c_source.html":[2,0,3,3,1615],
+"d7/deb/lapacke__sstein_8c.html":[2,0,3,3,1621],
+"d7/deb/lapacke__sstein_8c_a0391b10aed7585c2b736e0afea9228a0.html#a0391b10aed7585c2b736e0afea9228a0":[2,0,3,3,1621,0],
+"d7/deb/lapacke__sstein_8c_source.html":[2,0,3,3,1621],
 "d7/dee/ddrvpo_8f.html":[2,0,5,1,243],
 "d7/dee/ddrvpo_8f_source.html":[2,0,5,1,243],
 "d7/dee/schktz_8f.html":[2,0,5,1,410],
@@ -89,16 +107,16 @@ var NAVTREEINDEX50 =
 "d7/def/lapacke__clange_8c.html":[2,0,3,3,322],
 "d7/def/lapacke__clange_8c_a74d0913fb3fa04f6b35405c43f3d5059.html#a74d0913fb3fa04f6b35405c43f3d5059":[2,0,3,3,322,0],
 "d7/def/lapacke__clange_8c_source.html":[2,0,3,3,322],
-"d7/def/spptrs_8f.html":[2,0,4,1316],
-"d7/def/spptrs_8f_source.html":[2,0,4,1316],
-"d7/df1/lapacke__sormtr__work_8c.html":[2,0,3,3,1476],
-"d7/df1/lapacke__sormtr__work_8c_a345792fedb3632cebc623479e4bf886d.html#a345792fedb3632cebc623479e4bf886d":[2,0,3,3,1476,0],
-"d7/df1/lapacke__sormtr__work_8c_source.html":[2,0,3,3,1476],
+"d7/def/spptrs_8f.html":[2,0,4,1315],
+"d7/def/spptrs_8f_source.html":[2,0,4,1315],
+"d7/df1/lapacke__sormtr__work_8c.html":[2,0,3,3,1482],
+"d7/df1/lapacke__sormtr__work_8c_a345792fedb3632cebc623479e4bf886d.html#a345792fedb3632cebc623479e4bf886d":[2,0,3,3,1482,0],
+"d7/df1/lapacke__sormtr__work_8c_source.html":[2,0,3,3,1482],
 "d7/df1/snrm2_8f.html":[2,0,0,0,89],
 "d7/df1/snrm2_8f_source.html":[2,0,0,0,89],
-"d7/df2/lapacke__zpptrs_8c.html":[2,0,3,3,2199],
-"d7/df2/lapacke__zpptrs_8c_a1147ffe0abe55b1b7964bc18764b5184.html#a1147ffe0abe55b1b7964bc18764b5184":[2,0,3,3,2199,0],
-"d7/df2/lapacke__zpptrs_8c_source.html":[2,0,3,3,2199],
+"d7/df2/lapacke__zpptrs_8c.html":[2,0,3,3,2207],
+"d7/df2/lapacke__zpptrs_8c_a1147ffe0abe55b1b7964bc18764b5184.html#a1147ffe0abe55b1b7964bc18764b5184":[2,0,3,3,2207,0],
+"d7/df2/lapacke__zpptrs_8c_source.html":[2,0,3,3,2207],
 "d7/df3/derrlq_8f.html":[2,0,5,1,264],
 "d7/df3/derrlq_8f_source.html":[2,0,5,1,264],
 "d7/df3/dsygv__2stage_8f.html":[2,0,4,886],
@@ -109,111 +127,111 @@ var NAVTREEINDEX50 =
 "d7/df5/cgelqt3_8f_source.html":[2,0,4,34],
 "d7/df5/dlasd4_8f.html":[2,0,4,711],
 "d7/df5/dlasd4_8f_source.html":[2,0,4,711],
-"d7/df5/lapacke__dlagge__work_8c.html":[2,0,3,3,809],
-"d7/df5/lapacke__dlagge__work_8c_ab253055689a26d8fd91cabc128bc5a12.html#ab253055689a26d8fd91cabc128bc5a12":[2,0,3,3,809,0],
-"d7/df5/lapacke__dlagge__work_8c_source.html":[2,0,3,3,809],
+"d7/df5/lapacke__dlagge__work_8c.html":[2,0,3,3,811],
+"d7/df5/lapacke__dlagge__work_8c_ab253055689a26d8fd91cabc128bc5a12.html#ab253055689a26d8fd91cabc128bc5a12":[2,0,3,3,811,0],
+"d7/df5/lapacke__dlagge__work_8c_source.html":[2,0,3,3,811],
 "d7/df6/dgbrfs_8f.html":[2,0,4,490],
 "d7/df6/dgbrfs_8f_source.html":[2,0,4,490],
 "d7/df7/ddrvgt_8f.html":[2,0,5,1,240],
 "d7/df7/ddrvgt_8f_source.html":[2,0,5,1,240],
-"d7/df7/zla__heamv_8f.html":[2,0,4,1652],
-"d7/df7/zla__heamv_8f_source.html":[2,0,4,1652],
-"d7/df8/zporfsx_8f.html":[2,0,4,1788],
-"d7/df8/zporfsx_8f_source.html":[2,0,4,1788],
+"d7/df7/zla__heamv_8f.html":[2,0,4,1651],
+"d7/df7/zla__heamv_8f_source.html":[2,0,4,1651],
+"d7/df8/zporfsx_8f.html":[2,0,4,1787],
+"d7/df8/zporfsx_8f_source.html":[2,0,4,1787],
 "d7/df9/drzt01_8f.html":[2,0,5,1,356],
 "d7/df9/drzt01_8f_source.html":[2,0,5,1,356],
 "d7/df9/zerrgg_8f.html":[2,0,5,0,319],
 "d7/df9/zerrgg_8f_source.html":[2,0,5,0,319],
 "d7/dfa/zher2k_8f.html":[2,0,0,0,132],
 "d7/dfa/zher2k_8f_source.html":[2,0,0,0,132],
-"d7/dfb/lapacke__zpbequ_8c.html":[2,0,3,3,2141],
-"d7/dfb/lapacke__zpbequ_8c_aaf3ef80c38b985a7d9f5bfcf5f7c3a70.html#aaf3ef80c38b985a7d9f5bfcf5f7c3a70":[2,0,3,3,2141,0],
-"d7/dfb/lapacke__zpbequ_8c_source.html":[2,0,3,3,2141],
+"d7/dfb/lapacke__zpbequ_8c.html":[2,0,3,3,2149],
+"d7/dfb/lapacke__zpbequ_8c_aaf3ef80c38b985a7d9f5bfcf5f7c3a70.html#aaf3ef80c38b985a7d9f5bfcf5f7c3a70":[2,0,3,3,2149,0],
+"d7/dfb/lapacke__zpbequ_8c_source.html":[2,0,3,3,2149],
 "d7/dfc/lapacke__dgb__trans_8c.html":[2,0,3,4,40],
 "d7/dfc/lapacke__dgb__trans_8c_ad8e0d3e5080e9522fb9551d4635c4218.html#ad8e0d3e5080e9522fb9551d4635c4218":[2,0,3,4,40,0],
 "d7/dfc/lapacke__dgb__trans_8c_source.html":[2,0,3,4,40],
-"d7/dfd/lapacke__cpbstf__work_8c.html":[2,0,3,3,361],
-"d7/dfd/lapacke__cpbstf__work_8c_a39a0affda59aaf8129c76e4ef3ed8fa9.html#a39a0affda59aaf8129c76e4ef3ed8fa9":[2,0,3,3,361,0],
-"d7/dfd/lapacke__cpbstf__work_8c_source.html":[2,0,3,3,361],
-"d7/dfd/ssptrs_8f.html":[2,0,4,1355],
-"d7/dfd/ssptrs_8f_source.html":[2,0,4,1355],
-"d7/dfe/lapacke__stpqrt2_8c.html":[2,0,3,3,1742],
-"d7/dfe/lapacke__stpqrt2_8c_a78c5a04a335abd99150c157551078a3b.html#a78c5a04a335abd99150c157551078a3b":[2,0,3,3,1742,0],
-"d7/dfe/lapacke__stpqrt2_8c_source.html":[2,0,3,3,1742],
+"d7/dfd/lapacke__cpbstf__work_8c.html":[2,0,3,3,363],
+"d7/dfd/lapacke__cpbstf__work_8c_a39a0affda59aaf8129c76e4ef3ed8fa9.html#a39a0affda59aaf8129c76e4ef3ed8fa9":[2,0,3,3,363,0],
+"d7/dfd/lapacke__cpbstf__work_8c_source.html":[2,0,3,3,363],
+"d7/dfd/ssptrs_8f.html":[2,0,4,1354],
+"d7/dfd/ssptrs_8f_source.html":[2,0,4,1354],
+"d7/dfe/lapacke__stpqrt2_8c.html":[2,0,3,3,1748],
+"d7/dfe/lapacke__stpqrt2_8c_a78c5a04a335abd99150c157551078a3b.html#a78c5a04a335abd99150c157551078a3b":[2,0,3,3,1748,0],
+"d7/dfe/lapacke__stpqrt2_8c_source.html":[2,0,3,3,1748],
 "d7/dff/claqhb_8f.html":[2,0,4,255],
 "d7/dff/claqhb_8f_source.html":[2,0,4,255],
-"d8/d00/lapacke__ctrsna__work_8c.html":[2,0,3,3,567],
-"d8/d00/lapacke__ctrsna__work_8c_a00310d4a175e5f26637b484ff9d5892d.html#a00310d4a175e5f26637b484ff9d5892d":[2,0,3,3,567,0],
-"d8/d00/lapacke__ctrsna__work_8c_source.html":[2,0,3,3,567],
-"d8/d00/lapacke__ztpqrt2_8c.html":[2,0,3,3,2326],
-"d8/d00/lapacke__ztpqrt2_8c_adadd3a2dc68105d00f7c79d0708817c9.html#adadd3a2dc68105d00f7c79d0708817c9":[2,0,3,3,2326,0],
-"d8/d00/lapacke__ztpqrt2_8c_source.html":[2,0,3,3,2326],
+"d8/d00/lapacke__ctrsna__work_8c.html":[2,0,3,3,569],
+"d8/d00/lapacke__ctrsna__work_8c_a00310d4a175e5f26637b484ff9d5892d.html#a00310d4a175e5f26637b484ff9d5892d":[2,0,3,3,569,0],
+"d8/d00/lapacke__ctrsna__work_8c_source.html":[2,0,3,3,569],
+"d8/d00/lapacke__ztpqrt2_8c.html":[2,0,3,3,2334],
+"d8/d00/lapacke__ztpqrt2_8c_adadd3a2dc68105d00f7c79d0708817c9.html#adadd3a2dc68105d00f7c79d0708817c9":[2,0,3,3,2334,0],
+"d8/d00/lapacke__ztpqrt2_8c_source.html":[2,0,3,3,2334],
 "d8/d01/serrgg_8f.html":[2,0,5,0,224],
 "d8/d01/serrgg_8f_source.html":[2,0,5,0,224],
-"d8/d01/slanhs_8f.html":[2,0,4,1147],
-"d8/d01/slanhs_8f_source.html":[2,0,4,1147],
-"d8/d02/lapacke__ztpqrt__work_8c.html":[2,0,3,3,2328],
-"d8/d02/lapacke__ztpqrt__work_8c_a0a29c7d09b47c79bfb62ed649684b6d4.html#a0a29c7d09b47c79bfb62ed649684b6d4":[2,0,3,3,2328,0],
-"d8/d02/lapacke__ztpqrt__work_8c_source.html":[2,0,3,3,2328],
-"d8/d02/sisnan_8f.html":[2,0,4,1085],
-"d8/d02/sisnan_8f_source.html":[2,0,4,1085],
-"d8/d03/lapacke__ctbrfs__work_8c.html":[2,0,3,3,513],
-"d8/d03/lapacke__ctbrfs__work_8c_af6b61851b69d07d02cdf28c2941df845.html#af6b61851b69d07d02cdf28c2941df845":[2,0,3,3,513,0],
-"d8/d03/lapacke__ctbrfs__work_8c_source.html":[2,0,3,3,513],
-"d8/d03/lapacke__dspevx_8c.html":[2,0,3,3,1004],
-"d8/d03/lapacke__dspevx_8c_ac09f408a1bb79b25dc06514225fe8079.html#ac09f408a1bb79b25dc06514225fe8079":[2,0,3,3,1004,0],
-"d8/d03/lapacke__dspevx_8c_source.html":[2,0,3,3,1004],
+"d8/d01/slanhs_8f.html":[2,0,4,1146],
+"d8/d01/slanhs_8f_source.html":[2,0,4,1146],
+"d8/d02/lapacke__ztpqrt__work_8c.html":[2,0,3,3,2336],
+"d8/d02/lapacke__ztpqrt__work_8c_a0a29c7d09b47c79bfb62ed649684b6d4.html#a0a29c7d09b47c79bfb62ed649684b6d4":[2,0,3,3,2336,0],
+"d8/d02/lapacke__ztpqrt__work_8c_source.html":[2,0,3,3,2336],
+"d8/d02/sisnan_8f.html":[2,0,4,1084],
+"d8/d02/sisnan_8f_source.html":[2,0,4,1084],
+"d8/d03/lapacke__ctbrfs__work_8c.html":[2,0,3,3,515],
+"d8/d03/lapacke__ctbrfs__work_8c_af6b61851b69d07d02cdf28c2941df845.html#af6b61851b69d07d02cdf28c2941df845":[2,0,3,3,515,0],
+"d8/d03/lapacke__ctbrfs__work_8c_source.html":[2,0,3,3,515],
+"d8/d03/lapacke__dspevx_8c.html":[2,0,3,3,1008],
+"d8/d03/lapacke__dspevx_8c_ac09f408a1bb79b25dc06514225fe8079.html#ac09f408a1bb79b25dc06514225fe8079":[2,0,3,3,1008,0],
+"d8/d03/lapacke__dspevx_8c_source.html":[2,0,3,3,1008],
 "d8/d04/dlarnd_8f.html":[2,0,5,2,24],
 "d8/d04/dlarnd_8f_source.html":[2,0,5,2,24],
-"d8/d04/lapacke__csytrf_8c.html":[2,0,3,3,484],
-"d8/d04/lapacke__csytrf_8c_aeed2d6b51c7a0403a477f9c7e521ba6b.html#aeed2d6b51c7a0403a477f9c7e521ba6b":[2,0,3,3,484,0],
-"d8/d04/lapacke__csytrf_8c_source.html":[2,0,3,3,484],
+"d8/d04/lapacke__csytrf_8c.html":[2,0,3,3,486],
+"d8/d04/lapacke__csytrf_8c_aeed2d6b51c7a0403a477f9c7e521ba6b.html#aeed2d6b51c7a0403a477f9c7e521ba6b":[2,0,3,3,486,0],
+"d8/d04/lapacke__csytrf_8c_source.html":[2,0,3,3,486],
 "d8/d05/dtptri_8f.html":[2,0,4,944],
 "d8/d05/dtptri_8f_source.html":[2,0,4,944],
 "d8/d05/zlatm5_8f.html":[2,0,5,2,68],
 "d8/d05/zlatm5_8f_source.html":[2,0,5,2,68],
 "d8/d06/dlatm7_8f.html":[2,0,5,2,32],
 "d8/d06/dlatm7_8f_source.html":[2,0,5,2,32],
-"d8/d06/lapacke__dgebak__work_8c.html":[2,0,3,3,653],
-"d8/d06/lapacke__dgebak__work_8c_a17e825b3f5cd373904e33fa032abf62a.html#a17e825b3f5cd373904e33fa032abf62a":[2,0,3,3,653,0],
-"d8/d06/lapacke__dgebak__work_8c_source.html":[2,0,3,3,653],
-"d8/d06/lapacke__sspcon__work_8c.html":[2,0,3,3,1580],
-"d8/d06/lapacke__sspcon__work_8c_a7e72c99ea8e5df020b81f8a20dc3dbda.html#a7e72c99ea8e5df020b81f8a20dc3dbda":[2,0,3,3,1580,0],
-"d8/d06/lapacke__sspcon__work_8c_source.html":[2,0,3,3,1580],
-"d8/d07/lapacke__cpptrf_8c.html":[2,0,3,3,410],
-"d8/d07/lapacke__cpptrf_8c_a6b4643142d555b38a26f892c91f888ac.html#a6b4643142d555b38a26f892c91f888ac":[2,0,3,3,410,0],
-"d8/d07/lapacke__cpptrf_8c_source.html":[2,0,3,3,410],
-"d8/d09/zhgeqz_8f.html":[2,0,4,1624],
-"d8/d09/zhgeqz_8f_source.html":[2,0,4,1624],
+"d8/d06/lapacke__dgebak__work_8c.html":[2,0,3,3,655],
+"d8/d06/lapacke__dgebak__work_8c_a17e825b3f5cd373904e33fa032abf62a.html#a17e825b3f5cd373904e33fa032abf62a":[2,0,3,3,655,0],
+"d8/d06/lapacke__dgebak__work_8c_source.html":[2,0,3,3,655],
+"d8/d06/lapacke__sspcon__work_8c.html":[2,0,3,3,1586],
+"d8/d06/lapacke__sspcon__work_8c_a7e72c99ea8e5df020b81f8a20dc3dbda.html#a7e72c99ea8e5df020b81f8a20dc3dbda":[2,0,3,3,1586,0],
+"d8/d06/lapacke__sspcon__work_8c_source.html":[2,0,3,3,1586],
+"d8/d07/lapacke__cpptrf_8c.html":[2,0,3,3,412],
+"d8/d07/lapacke__cpptrf_8c_a6b4643142d555b38a26f892c91f888ac.html#a6b4643142d555b38a26f892c91f888ac":[2,0,3,3,412,0],
+"d8/d07/lapacke__cpptrf_8c_source.html":[2,0,3,3,412],
+"d8/d09/zhgeqz_8f.html":[2,0,4,1623],
+"d8/d09/zhgeqz_8f_source.html":[2,0,4,1623],
 "d8/d0b/ztbt03_8f.html":[2,0,5,1,740],
 "d8/d0b/ztbt03_8f_source.html":[2,0,5,1,740],
-"d8/d0d/lapacke__csytrs__3__work_8c.html":[2,0,3,3,504],
-"d8/d0d/lapacke__csytrs__3__work_8c_af65d77ec56d0b76451328ab087a0af8c.html#af65d77ec56d0b76451328ab087a0af8c":[2,0,3,3,504,0],
-"d8/d0d/lapacke__csytrs__3__work_8c_source.html":[2,0,3,3,504],
-"d8/d0d/lapacke__dstemr__work_8c.html":[2,0,3,3,1039],
-"d8/d0d/lapacke__dstemr__work_8c_ad197ab2526684f30078ff2171c2d42c7.html#ad197ab2526684f30078ff2171c2d42c7":[2,0,3,3,1039,0],
-"d8/d0d/lapacke__dstemr__work_8c_source.html":[2,0,3,3,1039],
+"d8/d0d/lapacke__csytrs__3__work_8c.html":[2,0,3,3,506],
+"d8/d0d/lapacke__csytrs__3__work_8c_af65d77ec56d0b76451328ab087a0af8c.html#af65d77ec56d0b76451328ab087a0af8c":[2,0,3,3,506,0],
+"d8/d0d/lapacke__csytrs__3__work_8c_source.html":[2,0,3,3,506],
+"d8/d0d/lapacke__dstemr__work_8c.html":[2,0,3,3,1043],
+"d8/d0d/lapacke__dstemr__work_8c_ad197ab2526684f30078ff2171c2d42c7.html#ad197ab2526684f30078ff2171c2d42c7":[2,0,3,3,1043,0],
+"d8/d0d/lapacke__dstemr__work_8c_source.html":[2,0,3,3,1043],
 "d8/d0e/sdrvst_8f.html":[2,0,5,0,217],
 "d8/d0e/sdrvst_8f_source.html":[2,0,5,0,217],
 "d8/d0f/lapacke__chbev__2stage__work_8c.html":[2,0,3,3,172],
 "d8/d0f/lapacke__chbev__2stage__work_8c_ae410d9aab3d3831bc2543e3ddce3d836.html#ae410d9aab3d3831bc2543e3ddce3d836":[2,0,3,3,172,0],
 "d8/d0f/lapacke__chbev__2stage__work_8c_source.html":[2,0,3,3,172],
-"d8/d0f/lapacke__slagge__work_8c.html":[2,0,3,3,1392],
-"d8/d0f/lapacke__slagge__work_8c_a6ec7d6a474cc2efe39c2867f375c9ca8.html#a6ec7d6a474cc2efe39c2867f375c9ca8":[2,0,3,3,1392,0],
-"d8/d0f/lapacke__slagge__work_8c_source.html":[2,0,3,3,1392],
-"d8/d11/lapacke__csycon__3_8c.html":[2,0,3,3,457],
-"d8/d11/lapacke__csycon__3_8c_a33b080780b510f6e5c08f252a514bef0.html#a33b080780b510f6e5c08f252a514bef0":[2,0,3,3,457,0],
-"d8/d11/lapacke__csycon__3_8c_source.html":[2,0,3,3,457],
-"d8/d12/lapacke__stpttr_8c.html":[2,0,3,3,1755],
-"d8/d12/lapacke__stpttr_8c_a84408d018bce6034d44fe4f26fb0de97.html#a84408d018bce6034d44fe4f26fb0de97":[2,0,3,3,1755,0],
-"d8/d12/lapacke__stpttr_8c_source.html":[2,0,3,3,1755],
-"d8/d13/lapacke__zgeqrf__work_8c.html":[2,0,3,3,1866],
-"d8/d13/lapacke__zgeqrf__work_8c_a363f0a019b5f0f8268129cfa9b2113d4.html#a363f0a019b5f0f8268129cfa9b2113d4":[2,0,3,3,1866,0],
-"d8/d13/lapacke__zgeqrf__work_8c_source.html":[2,0,3,3,1866],
+"d8/d0f/lapacke__slagge__work_8c.html":[2,0,3,3,1396],
+"d8/d0f/lapacke__slagge__work_8c_a6ec7d6a474cc2efe39c2867f375c9ca8.html#a6ec7d6a474cc2efe39c2867f375c9ca8":[2,0,3,3,1396,0],
+"d8/d0f/lapacke__slagge__work_8c_source.html":[2,0,3,3,1396],
+"d8/d11/lapacke__csycon__3_8c.html":[2,0,3,3,459],
+"d8/d11/lapacke__csycon__3_8c_a33b080780b510f6e5c08f252a514bef0.html#a33b080780b510f6e5c08f252a514bef0":[2,0,3,3,459,0],
+"d8/d11/lapacke__csycon__3_8c_source.html":[2,0,3,3,459],
+"d8/d12/lapacke__stpttr_8c.html":[2,0,3,3,1761],
+"d8/d12/lapacke__stpttr_8c_a84408d018bce6034d44fe4f26fb0de97.html#a84408d018bce6034d44fe4f26fb0de97":[2,0,3,3,1761,0],
+"d8/d12/lapacke__stpttr_8c_source.html":[2,0,3,3,1761],
+"d8/d13/lapacke__zgeqrf__work_8c.html":[2,0,3,3,1872],
+"d8/d13/lapacke__zgeqrf__work_8c_a363f0a019b5f0f8268129cfa9b2113d4.html#a363f0a019b5f0f8268129cfa9b2113d4":[2,0,3,3,1872,0],
+"d8/d13/lapacke__zgeqrf__work_8c_source.html":[2,0,3,3,1872],
 "d8/d14/dsytrs__3_8f.html":[2,0,4,917],
 "d8/d14/dsytrs__3_8f_source.html":[2,0,4,917],
-"d8/d15/zgebak_8f.html":[2,0,4,1480],
-"d8/d15/zgebak_8f_source.html":[2,0,4,1480],
+"d8/d15/zgebak_8f.html":[2,0,4,1479],
+"d8/d15/zgebak_8f_source.html":[2,0,4,1479],
 "d8/d16/cblas__cherk_8c.html":[2,0,1,2,15],
 "d8/d16/cblas__cherk_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[2,0,1,2,15,2],
 "d8/d16/cblas__cherk_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[2,0,1,2,15,0],
@@ -223,31 +241,13 @@ var NAVTREEINDEX50 =
 "d8/d16/cblas__cherk_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[2,0,1,2,15,5],
 "d8/d16/cblas__cherk_8c_af949419c7fe5cce53313b41badcbc534.html#af949419c7fe5cce53313b41badcbc534":[2,0,1,2,15,6],
 "d8/d16/cblas__cherk_8c_source.html":[2,0,1,2,15],
-"d8/d16/zgbequ_8f.html":[2,0,4,1470],
-"d8/d16/zgbequ_8f_source.html":[2,0,4,1470],
+"d8/d16/zgbequ_8f.html":[2,0,4,1469],
+"d8/d16/zgbequ_8f_source.html":[2,0,4,1469],
 "d8/d17/_t_e_s_t_i_n_g_2_l_i_n_2dtplqt_8f.html":[2,0,5,1,367],
 "d8/d17/_t_e_s_t_i_n_g_2_l_i_n_2dtplqt_8f_source.html":[2,0,5,1,367],
 "d8/d17/cungqr_8f.html":[2,0,4,461],
 "d8/d17/cungqr_8f_source.html":[2,0,4,461],
-"d8/d17/lapacke__sgels__work_8c.html":[2,0,3,3,1266],
-"d8/d17/lapacke__sgels__work_8c_a2cc44bf3c88af516e7c0d05c9a7e3cef.html#a2cc44bf3c88af516e7c0d05c9a7e3cef":[2,0,3,3,1266,0],
-"d8/d17/lapacke__sgels__work_8c_source.html":[2,0,3,3,1266],
-"d8/d17/sptcon_8f.html":[2,0,4,1319],
-"d8/d17/sptcon_8f_source.html":[2,0,4,1319],
-"d8/d1b/lapacke__chbevx__2stage_8c.html":[2,0,3,3,179],
-"d8/d1b/lapacke__chbevx__2stage_8c_aab7d01e689a93ca53fadd11d4465ede2.html#aab7d01e689a93ca53fadd11d4465ede2":[2,0,3,3,179,0],
-"d8/d1b/lapacke__chbevx__2stage_8c_source.html":[2,0,3,3,179],
-"d8/d1c/lapacke__ctpmqrt__work_8c.html":[2,0,3,3,539],
-"d8/d1c/lapacke__ctpmqrt__work_8c_a3b622400297769f95d24088a860d97c5.html#a3b622400297769f95d24088a860d97c5":[2,0,3,3,539,0],
-"d8/d1c/lapacke__ctpmqrt__work_8c_source.html":[2,0,3,3,539],
-"d8/d1c/schkge_8f.html":[2,0,5,1,384],
-"d8/d1c/schkge_8f_source.html":[2,0,5,1,384],
-"d8/d1d/cerrlq_8f.html":[2,0,5,1,76],
-"d8/d1d/cerrlq_8f_source.html":[2,0,5,1,76],
-"d8/d1d/zslect_8f.html":[2,0,5,0,351],
-"d8/d1d/zslect_8f_source.html":[2,0,5,0,351],
-"d8/d1e/dsbmv_8f.html":[2,0,0,0,49],
-"d8/d1e/dsbmv_8f_source.html":[2,0,0,0,49],
-"d8/d1f/_v_a_r_i_a_n_t_s_2lu_2_l_l_2cgetrf_8f.html":[2,0,4,1,1,1,0],
-"d8/d1f/_v_a_r_i_a_n_t_s_2lu_2_l_l_2cgetrf_8f_source.html":[2,0,4,1,1,1,0]
+"d8/d17/lapacke__sgels__work_8c.html":[2,0,3,3,1270],
+"d8/d17/lapacke__sgels__work_8c_a2cc44bf3c88af516e7c0d05c9a7e3cef.html#a2cc44bf3c88af516e7c0d05c9a7e3cef":[2,0,3,3,1270,0],
+"d8/d17/lapacke__sgels__work_8c_source.html":[2,0,3,3,1270]
 };
