@@ -1,6 +1,24 @@
 var NAVTREEINDEX52 =
 {
-"d8/d49/sgesvd_8f_source.html":[2,0,4,1045],
+"d8/d44/lapacke__spoequ_8c_source.html":[2,0,3,3,1507],
+"d8/d44/zlascl2_8f.html":[2,0,4,1751],
+"d8/d44/zlascl2_8f_source.html":[2,0,4,1751],
+"d8/d45/zlauum_8f.html":[2,0,4,1770],
+"d8/d45/zlauum_8f_source.html":[2,0,4,1770],
+"d8/d46/lapacke__zstein_8c.html":[2,0,3,3,2243],
+"d8/d46/lapacke__zstein_8c_a4c5a9cb4132a5a5fbb4710101d37645e.html#a4c5a9cb4132a5a5fbb4710101d37645e":[2,0,3,3,2243,0],
+"d8/d46/lapacke__zstein_8c_source.html":[2,0,3,3,2243],
+"d8/d46/zsyswapr_8f.html":[2,0,4,1846],
+"d8/d46/zsyswapr_8f_source.html":[2,0,4,1846],
+"d8/d48/cgeqr_8f.html":[2,0,4,46],
+"d8/d48/cgeqr_8f_a67fc4b5034f55173b2460a10436d591a.html#a67fc4b5034f55173b2460a10436d591a":[2,0,4,46,0],
+"d8/d48/cgeqr_8f_source.html":[2,0,4,46],
+"d8/d48/serrst_8f.html":[2,0,5,0,226],
+"d8/d48/serrst_8f_source.html":[2,0,5,0,226],
+"d8/d49/cget35_8f.html":[2,0,5,0,56],
+"d8/d49/cget35_8f_source.html":[2,0,5,0,56],
+"d8/d49/sgesvd_8f.html":[2,0,4,1044],
+"d8/d49/sgesvd_8f_source.html":[2,0,4,1044],
 "d8/d4a/cgegs_8f.html":[2,0,4,0,0],
 "d8/d4a/cgegs_8f_source.html":[2,0,4,0,0],
 "d8/d4a/lapacke__checon_8c.html":[2,0,3,3,192],
@@ -16,11 +34,11 @@ var NAVTREEINDEX52 =
 "d8/d50/lapacke__cgtsvx__work_8c.html":[2,0,3,3,165],
 "d8/d50/lapacke__cgtsvx__work_8c_a0771ac08846677090e43bd388085e71b.html#a0771ac08846677090e43bd388085e71b":[2,0,3,3,165,0],
 "d8/d50/lapacke__cgtsvx__work_8c_source.html":[2,0,3,3,165],
-"d8/d50/lapacke__ztfttp__work_8c.html":[2,0,3,3,2306],
-"d8/d50/lapacke__ztfttp__work_8c_ac164efdd64a4dfa831cef69d44348d67.html#ac164efdd64a4dfa831cef69d44348d67":[2,0,3,3,2306,0],
-"d8/d50/lapacke__ztfttp__work_8c_source.html":[2,0,3,3,2306],
+"d8/d50/lapacke__ztfttp__work_8c.html":[2,0,3,3,2314],
+"d8/d50/lapacke__ztfttp__work_8c_ac164efdd64a4dfa831cef69d44348d67.html#ac164efdd64a4dfa831cef69d44348d67":[2,0,3,3,2314,0],
+"d8/d50/lapacke__ztfttp__work_8c_source.html":[2,0,3,3,2314],
 "d8/d51/clamswlq_8f.html":[2,0,4,233],
-"d8/d51/clamswlq_8f_a5a2c0487522b324c2fc49556f3015204.html#a5a2c0487522b324c2fc49556f3015204":[2,0,4,233,0],
+"d8/d51/clamswlq_8f_add7bf6db65fb9a14f9f1c638a87b9d36.html#add7bf6db65fb9a14f9f1c638a87b9d36":[2,0,4,233,0],
 "d8/d51/clamswlq_8f_source.html":[2,0,4,233],
 "d8/d51/dsbev_8f.html":[2,0,4,828],
 "d8/d51/dsbev_8f_source.html":[2,0,4,828],
@@ -28,36 +46,36 @@ var NAVTREEINDEX52 =
 "d8/d51/dtrt06_8f_source.html":[2,0,5,1,377],
 "d8/d52/cherk_8f.html":[2,0,0,0,15],
 "d8/d52/cherk_8f_source.html":[2,0,0,0,15],
-"d8/d52/lapacke__dsfrk__work_8c.html":[2,0,3,3,995],
-"d8/d52/lapacke__dsfrk__work_8c_aba01128f3154110131600a47823ccb7a.html#aba01128f3154110131600a47823ccb7a":[2,0,3,3,995,0],
-"d8/d52/lapacke__dsfrk__work_8c_source.html":[2,0,3,3,995],
-"d8/d54/lapacke__dgetrs_8c.html":[2,0,3,3,744],
-"d8/d54/lapacke__dgetrs_8c_a044782d17dd9592ab7d2b5b4f5c0f7a7.html#a044782d17dd9592ab7d2b5b4f5c0f7a7":[2,0,3,3,744,0],
-"d8/d54/lapacke__dgetrs_8c_source.html":[2,0,3,3,744],
-"d8/d54/zgesdd_8f.html":[2,0,4,1523],
-"d8/d54/zgesdd_8f_source.html":[2,0,4,1523],
+"d8/d52/lapacke__dsfrk__work_8c.html":[2,0,3,3,999],
+"d8/d52/lapacke__dsfrk__work_8c_aba01128f3154110131600a47823ccb7a.html#aba01128f3154110131600a47823ccb7a":[2,0,3,3,999,0],
+"d8/d52/lapacke__dsfrk__work_8c_source.html":[2,0,3,3,999],
+"d8/d54/lapacke__dgetrs_8c.html":[2,0,3,3,746],
+"d8/d54/lapacke__dgetrs_8c_a044782d17dd9592ab7d2b5b4f5c0f7a7.html#a044782d17dd9592ab7d2b5b4f5c0f7a7":[2,0,3,3,746,0],
+"d8/d54/lapacke__dgetrs_8c_source.html":[2,0,3,3,746],
+"d8/d54/zgesdd_8f.html":[2,0,4,1522],
+"d8/d54/zgesdd_8f_source.html":[2,0,4,1522],
 "d8/d56/ctpsv_8f.html":[2,0,0,0,30],
 "d8/d56/ctpsv_8f_source.html":[2,0,0,0,30],
 "d8/d57/lapacke__cgelsd_8c.html":[2,0,3,3,58],
 "d8/d57/lapacke__cgelsd_8c_ab51b4e2cd4127ce015319c8625be6459.html#ab51b4e2cd4127ce015319c8625be6459":[2,0,3,3,58,0],
 "d8/d57/lapacke__cgelsd_8c_source.html":[2,0,3,3,58],
-"d8/d58/lapacke__sbdsvdx_8c.html":[2,0,3,3,1209],
-"d8/d58/lapacke__sbdsvdx_8c_a7e64eb3be4d33ddd2b289f1b410fbe3f.html#a7e64eb3be4d33ddd2b289f1b410fbe3f":[2,0,3,3,1209,0],
-"d8/d58/lapacke__sbdsvdx_8c_source.html":[2,0,3,3,1209],
+"d8/d58/lapacke__sbdsvdx_8c.html":[2,0,3,3,1213],
+"d8/d58/lapacke__sbdsvdx_8c_a7e64eb3be4d33ddd2b289f1b410fbe3f.html#a7e64eb3be4d33ddd2b289f1b410fbe3f":[2,0,3,3,1213,0],
+"d8/d58/lapacke__sbdsvdx_8c_source.html":[2,0,3,3,1213],
 "d8/d58/lapacke__xerbla_8c.html":[2,0,3,4,109],
 "d8/d58/lapacke__xerbla_8c_a1f7e7b3c999d7974e1666689a7bf81c7.html#a1f7e7b3c999d7974e1666689a7bf81c7":[2,0,3,4,109,0],
 "d8/d58/lapacke__xerbla_8c_source.html":[2,0,3,4,109],
 "d8/d59/cla__syrfsx__extended_8f.html":[2,0,4,202],
 "d8/d59/cla__syrfsx__extended_8f_source.html":[2,0,4,202],
-"d8/d59/lapacke__sorgtr_8c.html":[2,0,3,3,1459],
-"d8/d59/lapacke__sorgtr_8c_a9407708ae4987885602555636a558fcf.html#a9407708ae4987885602555636a558fcf":[2,0,3,3,1459,0],
-"d8/d59/lapacke__sorgtr_8c_source.html":[2,0,3,3,1459],
-"d8/d5a/lapacke__stptri_8c.html":[2,0,3,3,1749],
-"d8/d5a/lapacke__stptri_8c_a50ddaa17be480c15f4ac35d829b061e1.html#a50ddaa17be480c15f4ac35d829b061e1":[2,0,3,3,1749,0],
-"d8/d5a/lapacke__stptri_8c_source.html":[2,0,3,3,1749],
-"d8/d5c/lapacke__zgelsd_8c.html":[2,0,3,3,1843],
-"d8/d5c/lapacke__zgelsd_8c_af9f3a46b3e4f4d8005d7961057a8c59e.html#af9f3a46b3e4f4d8005d7961057a8c59e":[2,0,3,3,1843,0],
-"d8/d5c/lapacke__zgelsd_8c_source.html":[2,0,3,3,1843],
+"d8/d59/lapacke__sorgtr_8c.html":[2,0,3,3,1465],
+"d8/d59/lapacke__sorgtr_8c_a9407708ae4987885602555636a558fcf.html#a9407708ae4987885602555636a558fcf":[2,0,3,3,1465,0],
+"d8/d59/lapacke__sorgtr_8c_source.html":[2,0,3,3,1465],
+"d8/d5a/lapacke__stptri_8c.html":[2,0,3,3,1755],
+"d8/d5a/lapacke__stptri_8c_a50ddaa17be480c15f4ac35d829b061e1.html#a50ddaa17be480c15f4ac35d829b061e1":[2,0,3,3,1755,0],
+"d8/d5a/lapacke__stptri_8c_source.html":[2,0,3,3,1755],
+"d8/d5c/lapacke__zgelsd_8c.html":[2,0,3,3,1849],
+"d8/d5c/lapacke__zgelsd_8c_af9f3a46b3e4f4d8005d7961057a8c59e.html#af9f3a46b3e4f4d8005d7961057a8c59e":[2,0,3,3,1849,0],
+"d8/d5c/lapacke__zgelsd_8c_source.html":[2,0,3,3,1849],
 "d8/d5d/cblas__ztrsm_8c.html":[2,0,1,2,142],
 "d8/d5d/cblas__ztrsm_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[2,0,1,2,142,0],
 "d8/d5d/cblas__ztrsm_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[2,0,1,2,142,2],
@@ -72,17 +90,17 @@ var NAVTREEINDEX52 =
 "d8/d5d/lapacke__cheevd_8c.html":[2,0,3,3,202],
 "d8/d5d/lapacke__cheevd_8c_ac6e2fdd7a11e453f6503f05c38084469.html#ac6e2fdd7a11e453f6503f05c38084469":[2,0,3,3,202,0],
 "d8/d5d/lapacke__cheevd_8c_source.html":[2,0,3,3,202],
-"d8/d5d/lapacke__dporfsx_8c.html":[2,0,3,3,924],
-"d8/d5d/lapacke__dporfsx_8c_a1f20459b62343124eaf21b8855ea4c7f.html#a1f20459b62343124eaf21b8855ea4c7f":[2,0,3,3,924,0],
-"d8/d5d/lapacke__dporfsx_8c_source.html":[2,0,3,3,924],
-"d8/d5e/lapacke__sgelq2__work_8c.html":[2,0,3,3,1261],
-"d8/d5e/lapacke__sgelq2__work_8c_a2db012c6cd98c6a246311ccd993e5fa9.html#a2db012c6cd98c6a246311ccd993e5fa9":[2,0,3,3,1261,0],
-"d8/d5e/lapacke__sgelq2__work_8c_source.html":[2,0,3,3,1261],
-"d8/d5e/lapacke__zunmqr__work_8c.html":[2,0,3,3,2394],
-"d8/d5e/lapacke__zunmqr__work_8c_a53b199238acd5d748ebd6fd1a9bced8c.html#a53b199238acd5d748ebd6fd1a9bced8c":[2,0,3,3,2394,0],
-"d8/d5e/lapacke__zunmqr__work_8c_source.html":[2,0,3,3,2394],
-"d8/d5e/stpmlqt_8f.html":[2,0,4,1437],
-"d8/d5e/stpmlqt_8f_source.html":[2,0,4,1437],
+"d8/d5d/lapacke__dporfsx_8c.html":[2,0,3,3,928],
+"d8/d5d/lapacke__dporfsx_8c_a1f20459b62343124eaf21b8855ea4c7f.html#a1f20459b62343124eaf21b8855ea4c7f":[2,0,3,3,928,0],
+"d8/d5d/lapacke__dporfsx_8c_source.html":[2,0,3,3,928],
+"d8/d5e/lapacke__sgelq2__work_8c.html":[2,0,3,3,1265],
+"d8/d5e/lapacke__sgelq2__work_8c_a2db012c6cd98c6a246311ccd993e5fa9.html#a2db012c6cd98c6a246311ccd993e5fa9":[2,0,3,3,1265,0],
+"d8/d5e/lapacke__sgelq2__work_8c_source.html":[2,0,3,3,1265],
+"d8/d5e/lapacke__zunmqr__work_8c.html":[2,0,3,3,2402],
+"d8/d5e/lapacke__zunmqr__work_8c_a53b199238acd5d748ebd6fd1a9bced8c.html#a53b199238acd5d748ebd6fd1a9bced8c":[2,0,3,3,2402,0],
+"d8/d5e/lapacke__zunmqr__work_8c_source.html":[2,0,3,3,2402],
+"d8/d5e/stpmlqt_8f.html":[2,0,4,1436],
+"d8/d5e/stpmlqt_8f_source.html":[2,0,4,1436],
 "d8/d61/cblas__ctrsm_8c.html":[2,0,1,2,31],
 "d8/d61/cblas__ctrsm_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[2,0,1,2,31,0],
 "d8/d61/cblas__ctrsm_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[2,0,1,2,31,2],
@@ -94,28 +112,28 @@ var NAVTREEINDEX52 =
 "d8/d61/cblas__ctrsm_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[2,0,1,2,31,3],
 "d8/d61/cblas__ctrsm_8c_ae075537b174d76ef166e155bda3e18ba.html#ae075537b174d76ef166e155bda3e18ba":[2,0,1,2,31,8],
 "d8/d61/cblas__ctrsm_8c_source.html":[2,0,1,2,31],
-"d8/d61/sgeesx_8f.html":[2,0,4,1008],
-"d8/d61/sgeesx_8f_source.html":[2,0,4,1008],
+"d8/d61/sgeesx_8f.html":[2,0,4,1007],
+"d8/d61/sgeesx_8f_source.html":[2,0,4,1007],
 "d8/d63/dpotri_8f.html":[2,0,4,806],
 "d8/d63/dpotri_8f_source.html":[2,0,4,806],
-"d8/d63/lapacke__zgesvj_8c.html":[2,0,3,3,1889],
-"d8/d63/lapacke__zgesvj_8c_a67348828623908b24f9d04f40e12f13b.html#a67348828623908b24f9d04f40e12f13b":[2,0,3,3,1889,0],
-"d8/d63/lapacke__zgesvj_8c_source.html":[2,0,3,3,1889],
+"d8/d63/lapacke__zgesvj_8c.html":[2,0,3,3,1895],
+"d8/d63/lapacke__zgesvj_8c_a67348828623908b24f9d04f40e12f13b.html#a67348828623908b24f9d04f40e12f13b":[2,0,3,3,1895,0],
+"d8/d63/lapacke__zgesvj_8c_source.html":[2,0,3,3,1895],
 "d8/d66/cstt22_8f.html":[2,0,5,0,83],
 "d8/d66/cstt22_8f_source.html":[2,0,5,0,83],
 "d8/d66/dhseqr_8f.html":[2,0,4,582],
 "d8/d66/dhseqr_8f_source.html":[2,0,4,582],
-"d8/d66/lapacke__sgerfsx_8c.html":[2,0,3,3,1301],
-"d8/d66/lapacke__sgerfsx_8c_a64574af3d4f9dd86ac95069c19517a33.html#a64574af3d4f9dd86ac95069c19517a33":[2,0,3,3,1301,0],
-"d8/d66/lapacke__sgerfsx_8c_source.html":[2,0,3,3,1301],
+"d8/d66/lapacke__sgerfsx_8c.html":[2,0,3,3,1305],
+"d8/d66/lapacke__sgerfsx_8c_a64574af3d4f9dd86ac95069c19517a33.html#a64574af3d4f9dd86ac95069c19517a33":[2,0,3,3,1305,0],
+"d8/d66/lapacke__sgerfsx_8c_source.html":[2,0,3,3,1305],
 "d8/d67/isamaxsub_8f.html":[2,0,1,2,154],
 "d8/d67/isamaxsub_8f_a0f2c0b4af3ee757213ae42712e3084a5.html#a0f2c0b4af3ee757213ae42712e3084a5":[2,0,1,2,154,0],
 "d8/d67/isamaxsub_8f_source.html":[2,0,1,2,154],
-"d8/d67/sgesdd_8f.html":[2,0,4,1043],
-"d8/d67/sgesdd_8f_source.html":[2,0,4,1043],
-"d8/d68/lapacke__zsytrs__3_8c.html":[2,0,3,3,2288],
-"d8/d68/lapacke__zsytrs__3_8c_a4d9316a627860399a08a8be1ed472a4c.html#a4d9316a627860399a08a8be1ed472a4c":[2,0,3,3,2288,0],
-"d8/d68/lapacke__zsytrs__3_8c_source.html":[2,0,3,3,2288],
+"d8/d67/sgesdd_8f.html":[2,0,4,1042],
+"d8/d67/sgesdd_8f_source.html":[2,0,4,1042],
+"d8/d68/lapacke__zsytrs__3_8c.html":[2,0,3,3,2296],
+"d8/d68/lapacke__zsytrs__3_8c_a4d9316a627860399a08a8be1ed472a4c.html#a4d9316a627860399a08a8be1ed472a4c":[2,0,3,3,2296,0],
+"d8/d68/lapacke__zsytrs__3_8c_source.html":[2,0,3,3,2296],
 "d8/d68/spst01_8f.html":[2,0,5,1,503],
 "d8/d68/spst01_8f_source.html":[2,0,5,1,503],
 "d8/d68/sspmv_8f.html":[2,0,0,0,96],
@@ -130,17 +148,17 @@ var NAVTREEINDEX52 =
 "d8/d69/cblas__cher2k_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[2,0,1,2,14,1],
 "d8/d69/cblas__cher2k_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[2,0,1,2,14,6],
 "d8/d69/cblas__cher2k_8c_source.html":[2,0,1,2,14],
-"d8/d69/lapacke__csytri2__work_8c.html":[2,0,3,3,494],
-"d8/d69/lapacke__csytri2__work_8c_a1e463ed9f30650fc5dcc4ae97e2c8a63.html#a1e463ed9f30650fc5dcc4ae97e2c8a63":[2,0,3,3,494,0],
-"d8/d69/lapacke__csytri2__work_8c_source.html":[2,0,3,3,494],
-"d8/d6b/lapacke__slauum__work_8c.html":[2,0,3,3,1436],
-"d8/d6b/lapacke__slauum__work_8c_a4627ea39e5de429c585c5befd66903fd.html#a4627ea39e5de429c585c5befd66903fd":[2,0,3,3,1436,0],
-"d8/d6b/lapacke__slauum__work_8c_source.html":[2,0,3,3,1436],
+"d8/d69/lapacke__csytri2__work_8c.html":[2,0,3,3,496],
+"d8/d69/lapacke__csytri2__work_8c_a1e463ed9f30650fc5dcc4ae97e2c8a63.html#a1e463ed9f30650fc5dcc4ae97e2c8a63":[2,0,3,3,496,0],
+"d8/d69/lapacke__csytri2__work_8c_source.html":[2,0,3,3,496],
+"d8/d6b/lapacke__slauum__work_8c.html":[2,0,3,3,1442],
+"d8/d6b/lapacke__slauum__work_8c_a4627ea39e5de429c585c5befd66903fd.html#a4627ea39e5de429c585c5befd66903fd":[2,0,3,3,1442,0],
+"d8/d6b/lapacke__slauum__work_8c_source.html":[2,0,3,3,1442],
 "d8/d6b/lapacke__ztp__nancheck_8c.html":[2,0,3,4,144],
 "d8/d6b/lapacke__ztp__nancheck_8c_a90ce2e4972f1f2a133ac2264aceb4149.html#a90ce2e4972f1f2a133ac2264aceb4149":[2,0,3,4,144,0],
 "d8/d6b/lapacke__ztp__nancheck_8c_source.html":[2,0,3,4,144],
-"d8/d6b/zlacon_8f.html":[2,0,4,1671],
-"d8/d6b/zlacon_8f_source.html":[2,0,4,1671],
+"d8/d6b/zlacon_8f.html":[2,0,4,1670],
+"d8/d6b/zlacon_8f_source.html":[2,0,4,1670],
 "d8/d6c/group__variants_p_ocomputational.html":[0,0,4,2],
 "d8/d6c/group__variants_p_ocomputational_ga2f55f604a6003d03b5cd4a0adcfb74d6.html#ga2f55f604a6003d03b5cd4a0adcfb74d6":[2,0,4,1,0,0,1,0],
 "d8/d6c/group__variants_p_ocomputational_ga2f55f604a6003d03b5cd4a0adcfb74d6.html#ga2f55f604a6003d03b5cd4a0adcfb74d6":[2,0,4,1,0,1,1,0],
@@ -154,15 +172,15 @@ var NAVTREEINDEX52 =
 "d8/d6c/group__variants_p_ocomputational_gaaf31db7ab15b4f4ba527a3d31a15a58e.html#gaaf31db7ab15b4f4ba527a3d31a15a58e":[2,0,4,1,0,0,2,0],
 "d8/d6c/group__variants_p_ocomputational_gaaf31db7ab15b4f4ba527a3d31a15a58e.html#gaaf31db7ab15b4f4ba527a3d31a15a58e":[2,0,4,1,0,1,2,0],
 "d8/d6c/group__variants_p_ocomputational_gaaf31db7ab15b4f4ba527a3d31a15a58e.html#gaaf31db7ab15b4f4ba527a3d31a15a58e":[0,0,4,2,2],
-"d8/d6c/lapacke__sgbsvxx_8c.html":[2,0,3,3,1229],
-"d8/d6c/lapacke__sgbsvxx_8c_a581a16b9c0235d0618386122ab9643cb.html#a581a16b9c0235d0618386122ab9643cb":[2,0,3,3,1229,0],
-"d8/d6c/lapacke__sgbsvxx_8c_source.html":[2,0,3,3,1229],
-"d8/d6c/lapacke__ssprfs_8c.html":[2,0,3,3,1595],
-"d8/d6c/lapacke__ssprfs_8c_afa83d857b3963fb42137d68def9f6559.html#afa83d857b3963fb42137d68def9f6559":[2,0,3,3,1595,0],
-"d8/d6c/lapacke__ssprfs_8c_source.html":[2,0,3,3,1595],
-"d8/d6c/lapacke__ssptrs__work_8c.html":[2,0,3,3,1608],
-"d8/d6c/lapacke__ssptrs__work_8c_a2aa5fc20dfc94b89e52f72e431c2d020.html#a2aa5fc20dfc94b89e52f72e431c2d020":[2,0,3,3,1608,0],
-"d8/d6c/lapacke__ssptrs__work_8c_source.html":[2,0,3,3,1608],
+"d8/d6c/lapacke__sgbsvxx_8c.html":[2,0,3,3,1233],
+"d8/d6c/lapacke__sgbsvxx_8c_a581a16b9c0235d0618386122ab9643cb.html#a581a16b9c0235d0618386122ab9643cb":[2,0,3,3,1233,0],
+"d8/d6c/lapacke__sgbsvxx_8c_source.html":[2,0,3,3,1233],
+"d8/d6c/lapacke__ssprfs_8c.html":[2,0,3,3,1601],
+"d8/d6c/lapacke__ssprfs_8c_afa83d857b3963fb42137d68def9f6559.html#afa83d857b3963fb42137d68def9f6559":[2,0,3,3,1601,0],
+"d8/d6c/lapacke__ssprfs_8c_source.html":[2,0,3,3,1601],
+"d8/d6c/lapacke__ssptrs__work_8c.html":[2,0,3,3,1614],
+"d8/d6c/lapacke__ssptrs__work_8c_a2aa5fc20dfc94b89e52f72e431c2d020.html#a2aa5fc20dfc94b89e52f72e431c2d020":[2,0,3,3,1614,0],
+"d8/d6c/lapacke__ssptrs__work_8c_source.html":[2,0,3,3,1614],
 "d8/d6d/_s_r_c_2ilaenv_8f.html":[2,0,4,970],
 "d8/d6d/_s_r_c_2ilaenv_8f_source.html":[2,0,4,970],
 "d8/d6d/clatm2_8f.html":[2,0,5,2,10],
@@ -175,79 +193,61 @@ var NAVTREEINDEX52 =
 "d8/d6e/ctrti2_8f_source.html":[2,0,4,439],
 "d8/d6e/dgerqs_8f.html":[2,0,5,1,292],
 "d8/d6e/dgerqs_8f_source.html":[2,0,5,1,292],
-"d8/d6e/zgelsy_8f.html":[2,0,4,1502],
-"d8/d6e/zgelsy_8f_source.html":[2,0,4,1502],
+"d8/d6e/zgelsy_8f.html":[2,0,4,1501],
+"d8/d6e/zgelsy_8f_source.html":[2,0,4,1501],
 "d8/d70/cgesvj_8f.html":[2,0,4,63],
 "d8/d70/cgesvj_8f_source.html":[2,0,4,63],
 "d8/d70/group__lapack.html":[0,0],
-"d8/d70/lapacke__stfttp_8c.html":[2,0,3,3,1721],
-"d8/d70/lapacke__stfttp_8c_a8c3084690ea8bf60956d34c7e03df39a.html#a8c3084690ea8bf60956d34c7e03df39a":[2,0,3,3,1721,0],
-"d8/d70/lapacke__stfttp_8c_source.html":[2,0,3,3,1721],
+"d8/d70/lapacke__stfttp_8c.html":[2,0,3,3,1727],
+"d8/d70/lapacke__stfttp_8c_a8c3084690ea8bf60956d34c7e03df39a.html#a8c3084690ea8bf60956d34c7e03df39a":[2,0,3,3,1727,0],
+"d8/d70/lapacke__stfttp_8c_source.html":[2,0,3,3,1727],
 "d8/d71/csysv__aa_8f.html":[2,0,4,379],
 "d8/d71/csysv__aa_8f_source.html":[2,0,4,379],
-"d8/d71/lapacke__cungbr_8c.html":[2,0,3,3,586],
-"d8/d71/lapacke__cungbr_8c_aeda54a969969e3da60081412542e8f5f.html#aeda54a969969e3da60081412542e8f5f":[2,0,3,3,586,0],
-"d8/d71/lapacke__cungbr_8c_source.html":[2,0,3,3,586],
-"d8/d71/lapacke__zgesv__work_8c.html":[2,0,3,3,1884],
-"d8/d71/lapacke__zgesv__work_8c_ad065ae24f838006ed4ecb2959480fd6e.html#ad065ae24f838006ed4ecb2959480fd6e":[2,0,3,3,1884,0],
-"d8/d71/lapacke__zgesv__work_8c_source.html":[2,0,3,3,1884],
-"d8/d71/slasy2_8f.html":[2,0,4,1234],
-"d8/d71/slasy2_8f_source.html":[2,0,4,1234],
+"d8/d71/lapacke__cungbr_8c.html":[2,0,3,3,588],
+"d8/d71/lapacke__cungbr_8c_aeda54a969969e3da60081412542e8f5f.html#aeda54a969969e3da60081412542e8f5f":[2,0,3,3,588,0],
+"d8/d71/lapacke__cungbr_8c_source.html":[2,0,3,3,588],
+"d8/d71/lapacke__zgesv__work_8c.html":[2,0,3,3,1890],
+"d8/d71/lapacke__zgesv__work_8c_ad065ae24f838006ed4ecb2959480fd6e.html#ad065ae24f838006ed4ecb2959480fd6e":[2,0,3,3,1890,0],
+"d8/d71/lapacke__zgesv__work_8c_source.html":[2,0,3,3,1890],
+"d8/d71/slasy2_8f.html":[2,0,4,1233],
+"d8/d71/slasy2_8f_source.html":[2,0,4,1233],
 "d8/d71/zchksy__rk_8f.html":[2,0,5,1,581],
 "d8/d71/zchksy__rk_8f_source.html":[2,0,5,1,581],
 "d8/d72/dgesv_8f.html":[2,0,4,542],
 "d8/d72/dgesv_8f_source.html":[2,0,4,542],
-"d8/d72/lapacke__dposvx_8c.html":[2,0,3,3,928],
-"d8/d72/lapacke__dposvx_8c_acb416efe12b4b99ec1f57787d3d0f869.html#acb416efe12b4b99ec1f57787d3d0f869":[2,0,3,3,928,0],
-"d8/d72/lapacke__dposvx_8c_source.html":[2,0,3,3,928],
-"d8/d72/lapacke__dstebz__work_8c.html":[2,0,3,3,1031],
-"d8/d72/lapacke__dstebz__work_8c_a889a9ae693881594c50b505af28c05fa.html#a889a9ae693881594c50b505af28c05fa":[2,0,3,3,1031,0],
-"d8/d72/lapacke__dstebz__work_8c_source.html":[2,0,3,3,1031],
+"d8/d72/lapacke__dposvx_8c.html":[2,0,3,3,932],
+"d8/d72/lapacke__dposvx_8c_acb416efe12b4b99ec1f57787d3d0f869.html#acb416efe12b4b99ec1f57787d3d0f869":[2,0,3,3,932,0],
+"d8/d72/lapacke__dposvx_8c_source.html":[2,0,3,3,932],
+"d8/d72/lapacke__dstebz__work_8c.html":[2,0,3,3,1035],
+"d8/d72/lapacke__dstebz__work_8c_a889a9ae693881594c50b505af28c05fa.html#a889a9ae693881594c50b505af28c05fa":[2,0,3,3,1035,0],
+"d8/d72/lapacke__dstebz__work_8c_source.html":[2,0,3,3,1035],
 "d8/d73/cladiv_8f.html":[2,0,4,213],
 "d8/d73/cladiv_8f_source.html":[2,0,4,213],
 "d8/d74/dlarrk_8f.html":[2,0,4,692],
 "d8/d74/dlarrk_8f_source.html":[2,0,4,692],
-"d8/d74/lapacke__ctpcon__work_8c.html":[2,0,3,3,537],
-"d8/d74/lapacke__ctpcon__work_8c_aad566037b84986d3881ed6c235731b17.html#aad566037b84986d3881ed6c235731b17":[2,0,3,3,537,0],
-"d8/d74/lapacke__ctpcon__work_8c_source.html":[2,0,3,3,537],
-"d8/d74/lapacke__sgesvj_8c.html":[2,0,3,3,1313],
-"d8/d74/lapacke__sgesvj_8c_af1bfce14f5ccca01fb29f1992ec9601e.html#af1bfce14f5ccca01fb29f1992ec9601e":[2,0,3,3,1313,0],
-"d8/d74/lapacke__sgesvj_8c_source.html":[2,0,3,3,1313],
+"d8/d74/lapacke__ctpcon__work_8c.html":[2,0,3,3,539],
+"d8/d74/lapacke__ctpcon__work_8c_aad566037b84986d3881ed6c235731b17.html#aad566037b84986d3881ed6c235731b17":[2,0,3,3,539,0],
+"d8/d74/lapacke__ctpcon__work_8c_source.html":[2,0,3,3,539],
+"d8/d74/lapacke__sgesvj_8c.html":[2,0,3,3,1317],
+"d8/d74/lapacke__sgesvj_8c_af1bfce14f5ccca01fb29f1992ec9601e.html#af1bfce14f5ccca01fb29f1992ec9601e":[2,0,3,3,1317,0],
+"d8/d74/lapacke__sgesvj_8c_source.html":[2,0,3,3,1317],
 "d8/d75/cchkrfp_8f.html":[2,0,5,1,30],
 "d8/d75/cchkrfp_8f_source.html":[2,0,5,1,30],
 "d8/d75/dla__syrcond_8f.html":[2,0,4,597],
 "d8/d75/dla__syrcond_8f_source.html":[2,0,4,597],
-"d8/d75/lapacke__sstev_8c.html":[2,0,3,3,1623],
-"d8/d75/lapacke__sstev_8c_aa4094511b62d92cc41e362e9d208d314.html#aa4094511b62d92cc41e362e9d208d314":[2,0,3,3,1623,0],
-"d8/d75/lapacke__sstev_8c_source.html":[2,0,3,3,1623],
-"d8/d75/zunmql_8f.html":[2,0,4,1935],
-"d8/d75/zunmql_8f_source.html":[2,0,4,1935],
-"d8/d76/lapacke__zpocon__work_8c.html":[2,0,3,3,2162],
-"d8/d76/lapacke__zpocon__work_8c_a3ce842936724d182363cac9e16dfab0c.html#a3ce842936724d182363cac9e16dfab0c":[2,0,3,3,2162,0],
-"d8/d76/lapacke__zpocon__work_8c_source.html":[2,0,3,3,2162],
+"d8/d75/lapacke__sstev_8c.html":[2,0,3,3,1629],
+"d8/d75/lapacke__sstev_8c_aa4094511b62d92cc41e362e9d208d314.html#aa4094511b62d92cc41e362e9d208d314":[2,0,3,3,1629,0],
+"d8/d75/lapacke__sstev_8c_source.html":[2,0,3,3,1629],
+"d8/d75/zunmql_8f.html":[2,0,4,1934],
+"d8/d75/zunmql_8f_source.html":[2,0,4,1934],
+"d8/d76/lapacke__zpocon__work_8c.html":[2,0,3,3,2170],
+"d8/d76/lapacke__zpocon__work_8c_a3ce842936724d182363cac9e16dfab0c.html#a3ce842936724d182363cac9e16dfab0c":[2,0,3,3,2170,0],
+"d8/d76/lapacke__zpocon__work_8c_source.html":[2,0,3,3,2170],
 "d8/d76/srzt02_8f.html":[2,0,5,1,528],
 "d8/d76/srzt02_8f_source.html":[2,0,5,1,528],
-"d8/d77/zgejsv_8f.html":[2,0,4,1493],
-"d8/d77/zgejsv_8f_source.html":[2,0,4,1493],
-"d8/d77/zlals0_8f.html":[2,0,4,1693],
-"d8/d77/zlals0_8f_source.html":[2,0,4,1693],
-"d8/d78/lapacke__zhpev_8c.html":[2,0,3,3,2059],
-"d8/d78/lapacke__zhpev_8c_a3df04326013f4742d18d3f50155311e8.html#a3df04326013f4742d18d3f50155311e8":[2,0,3,3,2059,0],
-"d8/d78/lapacke__zhpev_8c_source.html":[2,0,3,3,2059],
-"d8/d78/ssygst_8f.html":[2,0,4,1383],
-"d8/d78/ssygst_8f_source.html":[2,0,4,1383],
-"d8/d78/ztpmqrt_8f.html":[2,0,4,1885],
-"d8/d78/ztpmqrt_8f_source.html":[2,0,4,1885],
-"d8/d79/lapacke__dlarft_8c.html":[2,0,3,3,832],
-"d8/d79/lapacke__dlarft_8c_ac5f63317d06448f502f54652966c6526.html#ac5f63317d06448f502f54652966c6526":[2,0,3,3,832,0],
-"d8/d79/lapacke__dlarft_8c_source.html":[2,0,3,3,832],
-"d8/d7a/lapacke__dgesvj__work_8c.html":[2,0,3,3,731],
-"d8/d7a/lapacke__dgesvj__work_8c_a1a95bd0ac7cb3cdf1517ea4fe930e29e.html#a1a95bd0ac7cb3cdf1517ea4fe930e29e":[2,0,3,3,731,0],
-"d8/d7a/lapacke__dgesvj__work_8c_source.html":[2,0,3,3,731],
-"d8/d7a/lapacke__sggbal_8c.html":[2,0,3,3,1333],
-"d8/d7a/lapacke__sggbal_8c_a5d3e2f41bec6dc56c37157634bc66a6d.html#a5d3e2f41bec6dc56c37157634bc66a6d":[2,0,3,3,1333,0],
-"d8/d7a/lapacke__sggbal_8c_source.html":[2,0,3,3,1333],
-"d8/d7b/cblas__csyr2k_8c.html":[2,0,1,2,23],
-"d8/d7b/cblas__csyr2k_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[2,0,1,2,23,3],
-"d8/d7b/cblas__csyr2k_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[2,0,1,2,23,0]
+"d8/d77/zgejsv_8f.html":[2,0,4,1492],
+"d8/d77/zgejsv_8f_source.html":[2,0,4,1492],
+"d8/d77/zlals0_8f.html":[2,0,4,1692],
+"d8/d77/zlals0_8f_source.html":[2,0,4,1692],
+"d8/d78/lapacke__zhpev_8c.html":[2,0,3,3,2065]
 };
