@@ -1,54 +1,73 @@
 var NAVTREEINDEX64 =
 {
-"da/d69/lapacke__ztrttp__work_8c_source.html":[2,0,3,3,2362],
+"da/d61/lapacke__chpgv__work_8c_afda00508e63cef0d99e5bd416906a2b3.html#afda00508e63cef0d99e5bd416906a2b3":[2,0,3,3,283,0],
+"da/d61/lapacke__chpgv__work_8c_source.html":[2,0,3,3,283],
+"da/d61/slansp_8f.html":[2,0,4,1149],
+"da/d61/slansp_8f_source.html":[2,0,4,1149],
+"da/d61/zlarnd_8f.html":[2,0,5,2,62],
+"da/d61/zlarnd_8f_source.html":[2,0,5,2,62],
+"da/d62/zget22_8f.html":[2,0,5,0,324],
+"da/d62/zget22_8f_source.html":[2,0,5,0,324],
+"da/d62/zhpev_8f.html":[2,0,4,1625],
+"da/d62/zhpev_8f_source.html":[2,0,4,1625],
+"da/d65/sormql_8f.html":[2,0,4,1276],
+"da/d65/sormql_8f_source.html":[2,0,4,1276],
+"da/d66/lapacke__ssy__trans_8c.html":[2,0,3,4,100],
+"da/d66/lapacke__ssy__trans_8c_a87be122c24a8c088556e46c09ab5bb34.html#a87be122c24a8c088556e46c09ab5bb34":[2,0,3,4,100,0],
+"da/d66/lapacke__ssy__trans_8c_source.html":[2,0,3,4,100],
+"da/d66/zchkaa_8f.html":[2,0,5,1,552],
+"da/d66/zchkaa_8f_source.html":[2,0,5,1,552],
+"da/d69/lapacke__ztrttp__work_8c.html":[2,0,3,3,2370],
+"da/d69/lapacke__ztrttp__work_8c_ab3dafd64ea1105fc69bb6797208f8cb8.html#ab3dafd64ea1105fc69bb6797208f8cb8":[2,0,3,3,2370,0],
+"da/d69/lapacke__ztrttp__work_8c_source.html":[2,0,3,3,2370],
 "da/d6a/lapacke__cggsvd_8c.html":[2,0,3,3,150],
 "da/d6a/lapacke__cggsvd_8c_ad83749e565c9e09ef7512c2df3948409.html#ad83749e565c9e09ef7512c2df3948409":[2,0,3,3,150,0],
 "da/d6a/lapacke__cggsvd_8c_source.html":[2,0,3,3,150],
-"da/d6a/lapacke__ctrtrs_8c.html":[2,0,3,3,572],
-"da/d6a/lapacke__ctrtrs_8c_a2518acdacf125d73d59c2cd0ea845ac7.html#a2518acdacf125d73d59c2cd0ea845ac7":[2,0,3,3,572,0],
-"da/d6a/lapacke__ctrtrs_8c_source.html":[2,0,3,3,572],
-"da/d6a/lapacke__sbbcsd__work_8c.html":[2,0,3,3,1204],
-"da/d6a/lapacke__sbbcsd__work_8c_a7ae649c3cfb3075f25bd85013db4d345.html#a7ae649c3cfb3075f25bd85013db4d345":[2,0,3,3,1204,0],
-"da/d6a/lapacke__sbbcsd__work_8c_source.html":[2,0,3,3,1204],
-"da/d6b/zhpcon_8f.html":[2,0,4,1625],
-"da/d6b/zhpcon_8f_source.html":[2,0,4,1625],
+"da/d6a/lapacke__ctrtrs_8c.html":[2,0,3,3,574],
+"da/d6a/lapacke__ctrtrs_8c_a2518acdacf125d73d59c2cd0ea845ac7.html#a2518acdacf125d73d59c2cd0ea845ac7":[2,0,3,3,574,0],
+"da/d6a/lapacke__ctrtrs_8c_source.html":[2,0,3,3,574],
+"da/d6a/lapacke__sbbcsd__work_8c.html":[2,0,3,3,1208],
+"da/d6a/lapacke__sbbcsd__work_8c_a7ae649c3cfb3075f25bd85013db4d345.html#a7ae649c3cfb3075f25bd85013db4d345":[2,0,3,3,1208,0],
+"da/d6a/lapacke__sbbcsd__work_8c_source.html":[2,0,3,3,1208],
+"da/d6b/zhpcon_8f.html":[2,0,4,1624],
+"da/d6b/zhpcon_8f_source.html":[2,0,4,1624],
 "da/d6c/dcopy_8f.html":[2,0,0,0,38],
 "da/d6c/dcopy_8f_source.html":[2,0,0,0,38],
-"da/d6c/lapacke__dsptri_8c.html":[2,0,3,3,1026],
-"da/d6c/lapacke__dsptri_8c_a70aaa3a5e1cb34e2af429ea028c41f7d.html#a70aaa3a5e1cb34e2af429ea028c41f7d":[2,0,3,3,1026,0],
-"da/d6c/lapacke__dsptri_8c_source.html":[2,0,3,3,1026],
-"da/d6e/lapacke__ssygv__work_8c.html":[2,0,3,3,1660],
-"da/d6e/lapacke__ssygv__work_8c_a4d3ac550abaedcba2288d03af4de3acd.html#a4d3ac550abaedcba2288d03af4de3acd":[2,0,3,3,1660,0],
-"da/d6e/lapacke__ssygv__work_8c_source.html":[2,0,3,3,1660],
+"da/d6c/lapacke__dsptri_8c.html":[2,0,3,3,1030],
+"da/d6c/lapacke__dsptri_8c_a70aaa3a5e1cb34e2af429ea028c41f7d.html#a70aaa3a5e1cb34e2af429ea028c41f7d":[2,0,3,3,1030,0],
+"da/d6c/lapacke__dsptri_8c_source.html":[2,0,3,3,1030],
+"da/d6e/lapacke__ssygv__work_8c.html":[2,0,3,3,1666],
+"da/d6e/lapacke__ssygv__work_8c_a4d3ac550abaedcba2288d03af4de3acd.html#a4d3ac550abaedcba2288d03af4de3acd":[2,0,3,3,1666,0],
+"da/d6e/lapacke__ssygv__work_8c_source.html":[2,0,3,3,1666],
 "da/d6f/zget24_8f.html":[2,0,5,0,326],
 "da/d6f/zget24_8f_source.html":[2,0,5,0,326],
 "da/d70/crzt01_8f.html":[2,0,5,1,176],
 "da/d70/crzt01_8f_source.html":[2,0,5,1,176],
-"da/d70/lapacke__sgesdd__work_8c.html":[2,0,3,3,1306],
-"da/d70/lapacke__sgesdd__work_8c_ae0b79db6e10307cc39fdebe6750128a8.html#ae0b79db6e10307cc39fdebe6750128a8":[2,0,3,3,1306,0],
-"da/d70/lapacke__sgesdd__work_8c_source.html":[2,0,3,3,1306],
+"da/d70/lapacke__sgesdd__work_8c.html":[2,0,3,3,1310],
+"da/d70/lapacke__sgesdd__work_8c_ae0b79db6e10307cc39fdebe6750128a8.html#ae0b79db6e10307cc39fdebe6750128a8":[2,0,3,3,1310,0],
+"da/d70/lapacke__sgesdd__work_8c_source.html":[2,0,3,3,1310],
 "da/d70/slarnd_8f.html":[2,0,5,2,43],
 "da/d70/slarnd_8f_source.html":[2,0,5,2,43],
 "da/d73/dstt22_8f.html":[2,0,5,0,174],
 "da/d73/dstt22_8f_source.html":[2,0,5,0,174],
-"da/d74/lapacke__ssyev__2stage__work_8c.html":[2,0,3,3,1641],
-"da/d74/lapacke__ssyev__2stage__work_8c_a78ac6aafcc0ac04e4e7bb340970f514c.html#a78ac6aafcc0ac04e4e7bb340970f514c":[2,0,3,3,1641,0],
-"da/d74/lapacke__ssyev__2stage__work_8c_source.html":[2,0,3,3,1641],
+"da/d74/lapacke__ssyev__2stage__work_8c.html":[2,0,3,3,1647],
+"da/d74/lapacke__ssyev__2stage__work_8c_a78ac6aafcc0ac04e4e7bb340970f514c.html#a78ac6aafcc0ac04e4e7bb340970f514c":[2,0,3,3,1647,0],
+"da/d74/lapacke__ssyev__2stage__work_8c_source.html":[2,0,3,3,1647],
 "da/d75/clargv_8f.html":[2,0,4,279],
 "da/d75/clargv_8f_source.html":[2,0,4,279],
 "da/d76/lapacke__cggrqf__work_8c.html":[2,0,3,3,149],
 "da/d76/lapacke__cggrqf__work_8c_a6074888e4e190584b64f10efbf1fc1d4.html#a6074888e4e190584b64f10efbf1fc1d4":[2,0,3,3,149,0],
 "da/d76/lapacke__cggrqf__work_8c_source.html":[2,0,3,3,149],
-"da/d76/lapacke__ztgsyl_8c.html":[2,0,3,3,2319],
-"da/d76/lapacke__ztgsyl_8c_a73efbd851a576be3a664bf8f9173f7bb.html#a73efbd851a576be3a664bf8f9173f7bb":[2,0,3,3,2319,0],
-"da/d76/lapacke__ztgsyl_8c_source.html":[2,0,3,3,2319],
-"da/d76/sorbdb3_8f.html":[2,0,4,1253],
-"da/d76/sorbdb3_8f_source.html":[2,0,4,1253],
+"da/d76/lapacke__ztgsyl_8c.html":[2,0,3,3,2327],
+"da/d76/lapacke__ztgsyl_8c_a73efbd851a576be3a664bf8f9173f7bb.html#a73efbd851a576be3a664bf8f9173f7bb":[2,0,3,3,2327,0],
+"da/d76/lapacke__ztgsyl_8c_source.html":[2,0,3,3,2327],
+"da/d76/sorbdb3_8f.html":[2,0,4,1252],
+"da/d76/sorbdb3_8f_source.html":[2,0,4,1252],
 "da/d77/_l_i_n_2dlarhs_8f.html":[2,0,5,1,306],
 "da/d77/_l_i_n_2dlarhs_8f_source.html":[2,0,5,1,306],
-"da/d77/lapacke__sggsvd__work_8c.html":[2,0,3,3,1362],
-"da/d77/lapacke__sggsvd__work_8c_af007975d2446962c9f133a4aa29d9ab2.html#af007975d2446962c9f133a4aa29d9ab2":[2,0,3,3,1362,0],
-"da/d77/lapacke__sggsvd__work_8c_source.html":[2,0,3,3,1362],
+"da/d77/lapacke__sggsvd__work_8c.html":[2,0,3,3,1366],
+"da/d77/lapacke__sggsvd__work_8c_af007975d2446962c9f133a4aa29d9ab2.html#af007975d2446962c9f133a4aa29d9ab2":[2,0,3,3,1366,0],
+"da/d77/lapacke__sggsvd__work_8c_source.html":[2,0,3,3,1366],
 "da/d78/cblas__sspr2_8c.html":[2,0,1,2,94],
 "da/d78/cblas__sspr2_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[2,0,1,2,94,0],
 "da/d78/cblas__sspr2_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[2,0,1,2,94,1],
@@ -56,39 +75,39 @@ var NAVTREEINDEX64 =
 "da/d78/cblas__sspr2_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[2,0,1,2,94,3],
 "da/d78/cblas__sspr2_8c_ab35f4947242d3b3d7239d3b9740c56cd.html#ab35f4947242d3b3d7239d3b9740c56cd":[2,0,1,2,94,4],
 "da/d78/cblas__sspr2_8c_source.html":[2,0,1,2,94],
-"da/d78/lapacke__stgsen__work_8c.html":[2,0,3,3,1730],
-"da/d78/lapacke__stgsen__work_8c_a583c9843df7b61f0088c99ea204f01c3.html#a583c9843df7b61f0088c99ea204f01c3":[2,0,3,3,1730,0],
-"da/d78/lapacke__stgsen__work_8c_source.html":[2,0,3,3,1730],
+"da/d78/lapacke__stgsen__work_8c.html":[2,0,3,3,1736],
+"da/d78/lapacke__stgsen__work_8c_a583c9843df7b61f0088c99ea204f01c3.html#a583c9843df7b61f0088c99ea204f01c3":[2,0,3,3,1736,0],
+"da/d78/lapacke__stgsen__work_8c_source.html":[2,0,3,3,1736],
 "da/d79/lapacke__sst__nancheck_8c.html":[2,0,3,4,98],
 "da/d79/lapacke__sst__nancheck_8c_a86dbfb33bd62384a1b0e3408b30568e5.html#a86dbfb33bd62384a1b0e3408b30568e5":[2,0,3,4,98,0],
 "da/d79/lapacke__sst__nancheck_8c_source.html":[2,0,3,4,98],
-"da/d79/ssygvx_8f.html":[2,0,4,1387],
-"da/d79/ssygvx_8f_source.html":[2,0,4,1387],
+"da/d79/ssygvx_8f.html":[2,0,4,1386],
+"da/d79/ssygvx_8f_source.html":[2,0,4,1386],
 "da/d7a/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2zpotrf_8f.html":[2,0,4,1,0,0,3],
 "da/d7a/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2zpotrf_8f_source.html":[2,0,4,1,0,0,3],
-"da/d7a/lapacke__cpbequ__work_8c.html":[2,0,3,3,357],
-"da/d7a/lapacke__cpbequ__work_8c_a8ae9a742a21fb0e738068ccf23aba574.html#a8ae9a742a21fb0e738068ccf23aba574":[2,0,3,3,357,0],
-"da/d7a/lapacke__cpbequ__work_8c_source.html":[2,0,3,3,357],
-"da/d7a/lapacke__dbbcsd__work_8c.html":[2,0,3,3,621],
-"da/d7a/lapacke__dbbcsd__work_8c_a241ea3c1dc8cf9b5321d06d9e78ed85a.html#a241ea3c1dc8cf9b5321d06d9e78ed85a":[2,0,3,3,621,0],
-"da/d7a/lapacke__dbbcsd__work_8c_source.html":[2,0,3,3,621],
-"da/d7a/lapacke__ssygvd_8c.html":[2,0,3,3,1661],
-"da/d7a/lapacke__ssygvd_8c_a76a92f497137541bf0a56ccc3452b709.html#a76a92f497137541bf0a56ccc3452b709":[2,0,3,3,1661,0],
-"da/d7a/lapacke__ssygvd_8c_source.html":[2,0,3,3,1661],
-"da/d7b/lapacke__dggsvd_8c.html":[2,0,3,3,776],
-"da/d7b/lapacke__dggsvd_8c_a389e39a5f6e3586210870503c9a2ed02.html#a389e39a5f6e3586210870503c9a2ed02":[2,0,3,3,776,0],
-"da/d7b/lapacke__dggsvd_8c_source.html":[2,0,3,3,776],
-"da/d7b/lapacke__dpotrs__work_8c.html":[2,0,3,3,939],
-"da/d7b/lapacke__dpotrs__work_8c_a28522bfad8ce0fbe7fca4e678df7269b.html#a28522bfad8ce0fbe7fca4e678df7269b":[2,0,3,3,939,0],
-"da/d7b/lapacke__dpotrs__work_8c_source.html":[2,0,3,3,939],
-"da/d7b/lapacke__dspgv_8c.html":[2,0,3,3,1008],
-"da/d7b/lapacke__dspgv_8c_aac9ca346715c25080d94c9f46c5b5ee8.html#aac9ca346715c25080d94c9f46c5b5ee8":[2,0,3,3,1008,0],
-"da/d7b/lapacke__dspgv_8c_source.html":[2,0,3,3,1008],
+"da/d7a/lapacke__cpbequ__work_8c.html":[2,0,3,3,359],
+"da/d7a/lapacke__cpbequ__work_8c_a8ae9a742a21fb0e738068ccf23aba574.html#a8ae9a742a21fb0e738068ccf23aba574":[2,0,3,3,359,0],
+"da/d7a/lapacke__cpbequ__work_8c_source.html":[2,0,3,3,359],
+"da/d7a/lapacke__dbbcsd__work_8c.html":[2,0,3,3,623],
+"da/d7a/lapacke__dbbcsd__work_8c_a241ea3c1dc8cf9b5321d06d9e78ed85a.html#a241ea3c1dc8cf9b5321d06d9e78ed85a":[2,0,3,3,623,0],
+"da/d7a/lapacke__dbbcsd__work_8c_source.html":[2,0,3,3,623],
+"da/d7a/lapacke__ssygvd_8c.html":[2,0,3,3,1667],
+"da/d7a/lapacke__ssygvd_8c_a76a92f497137541bf0a56ccc3452b709.html#a76a92f497137541bf0a56ccc3452b709":[2,0,3,3,1667,0],
+"da/d7a/lapacke__ssygvd_8c_source.html":[2,0,3,3,1667],
+"da/d7b/lapacke__dggsvd_8c.html":[2,0,3,3,778],
+"da/d7b/lapacke__dggsvd_8c_a389e39a5f6e3586210870503c9a2ed02.html#a389e39a5f6e3586210870503c9a2ed02":[2,0,3,3,778,0],
+"da/d7b/lapacke__dggsvd_8c_source.html":[2,0,3,3,778],
+"da/d7b/lapacke__dpotrs__work_8c.html":[2,0,3,3,943],
+"da/d7b/lapacke__dpotrs__work_8c_a28522bfad8ce0fbe7fca4e678df7269b.html#a28522bfad8ce0fbe7fca4e678df7269b":[2,0,3,3,943,0],
+"da/d7b/lapacke__dpotrs__work_8c_source.html":[2,0,3,3,943],
+"da/d7b/lapacke__dspgv_8c.html":[2,0,3,3,1012],
+"da/d7b/lapacke__dspgv_8c_aac9ca346715c25080d94c9f46c5b5ee8.html#aac9ca346715c25080d94c9f46c5b5ee8":[2,0,3,3,1012,0],
+"da/d7b/lapacke__dspgv_8c_source.html":[2,0,3,3,1012],
 "da/d7e/dptt01_8f.html":[2,0,5,1,333],
 "da/d7e/dptt01_8f_source.html":[2,0,5,1,333],
-"da/d7e/lapacke__dbdsqr__work_8c.html":[2,0,3,3,625],
-"da/d7e/lapacke__dbdsqr__work_8c_a5bb81b76aabe49f4114faabf26b70478.html#a5bb81b76aabe49f4114faabf26b70478":[2,0,3,3,625,0],
-"da/d7e/lapacke__dbdsqr__work_8c_source.html":[2,0,3,3,625],
+"da/d7e/lapacke__dbdsqr__work_8c.html":[2,0,3,3,627],
+"da/d7e/lapacke__dbdsqr__work_8c_a5bb81b76aabe49f4114faabf26b70478.html#a5bb81b76aabe49f4114faabf26b70478":[2,0,3,3,627,0],
+"da/d7e/lapacke__dbdsqr__work_8c_source.html":[2,0,3,3,627],
 "da/d7f/cblas__drotm_8c.html":[2,0,1,2,44],
 "da/d7f/cblas__drotm_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[2,0,1,2,44,0],
 "da/d7f/cblas__drotm_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[2,0,1,2,44,1],
@@ -230,24 +249,5 @@ var NAVTREEINDEX64 =
 "da/d81/cblas__f77_8h_a6f61826abf84601f9fbb4f6d997cfc37.html#a6f61826abf84601f9fbb4f6d997cfc37":[2,0,1,1,1,43],
 "da/d81/cblas__f77_8h_a6f84e195f719c7722cca09b201e3d22c.html#a6f84e195f719c7722cca09b201e3d22c":[2,0,1,1,1,193],
 "da/d81/cblas__f77_8h_a70f923dc89f7e927acbadbdbb78103ac.html#a70f923dc89f7e927acbadbdbb78103ac":[2,0,1,1,1,181],
-"da/d81/cblas__f77_8h_a7157bb03692d9e012622bd590839ba80.html#a7157bb03692d9e012622bd590839ba80":[2,0,1,1,1,89],
-"da/d81/cblas__f77_8h_a71aee781b26855dfea97e6b66b1b1fb6.html#a71aee781b26855dfea97e6b66b1b1fb6":[2,0,1,1,1,142],
-"da/d81/cblas__f77_8h_a7281fc013f62668a176fe1c555a19cbf.html#a7281fc013f62668a176fe1c555a19cbf":[2,0,1,1,1,132],
-"da/d81/cblas__f77_8h_a752a5152d8da7a6ebb2e34d889fb62bc.html#a752a5152d8da7a6ebb2e34d889fb62bc":[2,0,1,1,1,27],
-"da/d81/cblas__f77_8h_a758411e61357d65d66a1ce6998e749a7.html#a758411e61357d65d66a1ce6998e749a7":[2,0,1,1,1,268],
-"da/d81/cblas__f77_8h_a762cfb845a2e6a044f75943b814c51e9.html#a762cfb845a2e6a044f75943b814c51e9":[2,0,1,1,1,189],
-"da/d81/cblas__f77_8h_a7781d633103baa5fa3875b35f0d50803.html#a7781d633103baa5fa3875b35f0d50803":[2,0,1,1,1,171],
-"da/d81/cblas__f77_8h_a7929cc9b1290d78ee7f098f527df72ea.html#a7929cc9b1290d78ee7f098f527df72ea":[2,0,1,1,1,44],
-"da/d81/cblas__f77_8h_a7a9c8147e6ca247cbb8edc50784e86ce.html#a7a9c8147e6ca247cbb8edc50784e86ce":[2,0,1,1,1,22],
-"da/d81/cblas__f77_8h_a7bbf41a87a7825254a6aef7c0afc5e2f.html#a7bbf41a87a7825254a6aef7c0afc5e2f":[2,0,1,1,1,53],
-"da/d81/cblas__f77_8h_a7bd27fc270a5ef78bc3e4896750d0f3e.html#a7bd27fc270a5ef78bc3e4896750d0f3e":[2,0,1,1,1,49],
-"da/d81/cblas__f77_8h_a7d9b7866dfd900c037e794c5cda61905.html#a7d9b7866dfd900c037e794c5cda61905":[2,0,1,1,1,130],
-"da/d81/cblas__f77_8h_a7dd0d065dfacf253c21669b44ba15afe.html#a7dd0d065dfacf253c21669b44ba15afe":[2,0,1,1,1,286],
-"da/d81/cblas__f77_8h_a7df337dd7b855da2306a2c03e1df3d61.html#a7df337dd7b855da2306a2c03e1df3d61":[2,0,1,1,1,122],
-"da/d81/cblas__f77_8h_a7ecd7558f0030832e93475b1c2a72d94.html#a7ecd7558f0030832e93475b1c2a72d94":[2,0,1,1,1,161],
-"da/d81/cblas__f77_8h_a7f50d087f78cb1c4cad42e03b1eb8ed1.html#a7f50d087f78cb1c4cad42e03b1eb8ed1":[2,0,1,1,1,277],
-"da/d81/cblas__f77_8h_a7f7bae8e021cf702174be9ea8466fd08.html#a7f7bae8e021cf702174be9ea8466fd08":[2,0,1,1,1,13],
-"da/d81/cblas__f77_8h_a839c1ae93e8cdb39f3f83928ba61ba99.html#a839c1ae93e8cdb39f3f83928ba61ba99":[2,0,1,1,1,273],
-"da/d81/cblas__f77_8h_a8422da294fb80ad4669bb67a094e6cd0.html#a8422da294fb80ad4669bb67a094e6cd0":[2,0,1,1,1,24],
-"da/d81/cblas__f77_8h_a84395d8c79ae506c40f105e8c3809167.html#a84395d8c79ae506c40f105e8c3809167":[2,0,1,1,1,7]
+"da/d81/cblas__f77_8h_a7157bb03692d9e012622bd590839ba80.html#a7157bb03692d9e012622bd590839ba80":[2,0,1,1,1,89]
 };
