@@ -1,5 +1,24 @@
 var NAVTREEINDEX65 =
 {
+"da/d81/cblas__f77_8h_a71aee781b26855dfea97e6b66b1b1fb6.html#a71aee781b26855dfea97e6b66b1b1fb6":[2,0,1,1,1,142],
+"da/d81/cblas__f77_8h_a7281fc013f62668a176fe1c555a19cbf.html#a7281fc013f62668a176fe1c555a19cbf":[2,0,1,1,1,132],
+"da/d81/cblas__f77_8h_a752a5152d8da7a6ebb2e34d889fb62bc.html#a752a5152d8da7a6ebb2e34d889fb62bc":[2,0,1,1,1,27],
+"da/d81/cblas__f77_8h_a758411e61357d65d66a1ce6998e749a7.html#a758411e61357d65d66a1ce6998e749a7":[2,0,1,1,1,268],
+"da/d81/cblas__f77_8h_a762cfb845a2e6a044f75943b814c51e9.html#a762cfb845a2e6a044f75943b814c51e9":[2,0,1,1,1,189],
+"da/d81/cblas__f77_8h_a7781d633103baa5fa3875b35f0d50803.html#a7781d633103baa5fa3875b35f0d50803":[2,0,1,1,1,171],
+"da/d81/cblas__f77_8h_a7929cc9b1290d78ee7f098f527df72ea.html#a7929cc9b1290d78ee7f098f527df72ea":[2,0,1,1,1,44],
+"da/d81/cblas__f77_8h_a7a9c8147e6ca247cbb8edc50784e86ce.html#a7a9c8147e6ca247cbb8edc50784e86ce":[2,0,1,1,1,22],
+"da/d81/cblas__f77_8h_a7bbf41a87a7825254a6aef7c0afc5e2f.html#a7bbf41a87a7825254a6aef7c0afc5e2f":[2,0,1,1,1,53],
+"da/d81/cblas__f77_8h_a7bd27fc270a5ef78bc3e4896750d0f3e.html#a7bd27fc270a5ef78bc3e4896750d0f3e":[2,0,1,1,1,49],
+"da/d81/cblas__f77_8h_a7d9b7866dfd900c037e794c5cda61905.html#a7d9b7866dfd900c037e794c5cda61905":[2,0,1,1,1,130],
+"da/d81/cblas__f77_8h_a7dd0d065dfacf253c21669b44ba15afe.html#a7dd0d065dfacf253c21669b44ba15afe":[2,0,1,1,1,286],
+"da/d81/cblas__f77_8h_a7df337dd7b855da2306a2c03e1df3d61.html#a7df337dd7b855da2306a2c03e1df3d61":[2,0,1,1,1,122],
+"da/d81/cblas__f77_8h_a7ecd7558f0030832e93475b1c2a72d94.html#a7ecd7558f0030832e93475b1c2a72d94":[2,0,1,1,1,161],
+"da/d81/cblas__f77_8h_a7f50d087f78cb1c4cad42e03b1eb8ed1.html#a7f50d087f78cb1c4cad42e03b1eb8ed1":[2,0,1,1,1,277],
+"da/d81/cblas__f77_8h_a7f7bae8e021cf702174be9ea8466fd08.html#a7f7bae8e021cf702174be9ea8466fd08":[2,0,1,1,1,13],
+"da/d81/cblas__f77_8h_a839c1ae93e8cdb39f3f83928ba61ba99.html#a839c1ae93e8cdb39f3f83928ba61ba99":[2,0,1,1,1,273],
+"da/d81/cblas__f77_8h_a8422da294fb80ad4669bb67a094e6cd0.html#a8422da294fb80ad4669bb67a094e6cd0":[2,0,1,1,1,24],
+"da/d81/cblas__f77_8h_a84395d8c79ae506c40f105e8c3809167.html#a84395d8c79ae506c40f105e8c3809167":[2,0,1,1,1,7],
 "da/d81/cblas__f77_8h_a8679e7b6fbf52229f5553c1888c0ba92.html#a8679e7b6fbf52229f5553c1888c0ba92":[2,0,1,1,1,164],
 "da/d81/cblas__f77_8h_a86a5d6b5a33186767971c22d8f14fc2a.html#a86a5d6b5a33186767971c22d8f14fc2a":[2,0,1,1,1,114],
 "da/d81/cblas__f77_8h_a8876ff14dcead04a27542e6c93591e1f.html#a8876ff14dcead04a27542e6c93591e1f":[2,0,1,1,1,238],
@@ -145,25 +164,25 @@ var NAVTREEINDEX65 =
 "da/d82/lapacke__cheev__2stage_8c.html":[2,0,3,3,199],
 "da/d82/lapacke__cheev__2stage_8c_a3c8e46967e56812eb99f3451168355ff.html#a3c8e46967e56812eb99f3451168355ff":[2,0,3,3,199,0],
 "da/d82/lapacke__cheev__2stage_8c_source.html":[2,0,3,3,199],
-"da/d82/lapacke__dsbevd__work_8c.html":[2,0,3,3,979],
-"da/d82/lapacke__dsbevd__work_8c_abd275a4f08765e6e7aca69105295ff23.html#abd275a4f08765e6e7aca69105295ff23":[2,0,3,3,979,0],
-"da/d82/lapacke__dsbevd__work_8c_source.html":[2,0,3,3,979],
-"da/d83/lapacke__dtgsyl_8c.html":[2,0,3,3,1156],
-"da/d83/lapacke__dtgsyl_8c_ad9e792188523cdea688f5169d9506958.html#ad9e792188523cdea688f5169d9506958":[2,0,3,3,1156,0],
-"da/d83/lapacke__dtgsyl_8c_source.html":[2,0,3,3,1156],
-"da/d83/lapacke__dtpqrt2__work_8c.html":[2,0,3,3,1164],
-"da/d83/lapacke__dtpqrt2__work_8c_a19d34ad3e4fb60c3419968c6825ee285.html#a19d34ad3e4fb60c3419968c6825ee285":[2,0,3,3,1164,0],
-"da/d83/lapacke__dtpqrt2__work_8c_source.html":[2,0,3,3,1164],
-"da/d83/lapacke__sgetri__work_8c.html":[2,0,3,3,1326],
-"da/d83/lapacke__sgetri__work_8c_aeaecbe8dffe6463d3255ff4261ee4549.html#aeaecbe8dffe6463d3255ff4261ee4549":[2,0,3,3,1326,0],
-"da/d83/lapacke__sgetri__work_8c_source.html":[2,0,3,3,1326],
-"da/d84/lapacke__sormql_8c.html":[2,0,3,3,1467],
-"da/d84/lapacke__sormql_8c_a30afe80ad49c76f825ab7ee525d63206.html#a30afe80ad49c76f825ab7ee525d63206":[2,0,3,3,1467,0],
-"da/d84/lapacke__sormql_8c_source.html":[2,0,3,3,1467],
-"da/d84/slaqr1_8f.html":[2,0,4,1167],
-"da/d84/slaqr1_8f_source.html":[2,0,4,1167],
-"da/d84/zhetrs_8f.html":[2,0,4,1618],
-"da/d84/zhetrs_8f_source.html":[2,0,4,1618],
+"da/d82/lapacke__dsbevd__work_8c.html":[2,0,3,3,983],
+"da/d82/lapacke__dsbevd__work_8c_abd275a4f08765e6e7aca69105295ff23.html#abd275a4f08765e6e7aca69105295ff23":[2,0,3,3,983,0],
+"da/d82/lapacke__dsbevd__work_8c_source.html":[2,0,3,3,983],
+"da/d83/lapacke__dtgsyl_8c.html":[2,0,3,3,1160],
+"da/d83/lapacke__dtgsyl_8c_ad9e792188523cdea688f5169d9506958.html#ad9e792188523cdea688f5169d9506958":[2,0,3,3,1160,0],
+"da/d83/lapacke__dtgsyl_8c_source.html":[2,0,3,3,1160],
+"da/d83/lapacke__dtpqrt2__work_8c.html":[2,0,3,3,1168],
+"da/d83/lapacke__dtpqrt2__work_8c_a19d34ad3e4fb60c3419968c6825ee285.html#a19d34ad3e4fb60c3419968c6825ee285":[2,0,3,3,1168,0],
+"da/d83/lapacke__dtpqrt2__work_8c_source.html":[2,0,3,3,1168],
+"da/d83/lapacke__sgetri__work_8c.html":[2,0,3,3,1330],
+"da/d83/lapacke__sgetri__work_8c_aeaecbe8dffe6463d3255ff4261ee4549.html#aeaecbe8dffe6463d3255ff4261ee4549":[2,0,3,3,1330,0],
+"da/d83/lapacke__sgetri__work_8c_source.html":[2,0,3,3,1330],
+"da/d84/lapacke__sormql_8c.html":[2,0,3,3,1473],
+"da/d84/lapacke__sormql_8c_a30afe80ad49c76f825ab7ee525d63206.html#a30afe80ad49c76f825ab7ee525d63206":[2,0,3,3,1473,0],
+"da/d84/lapacke__sormql_8c_source.html":[2,0,3,3,1473],
+"da/d84/slaqr1_8f.html":[2,0,4,1166],
+"da/d84/slaqr1_8f_source.html":[2,0,4,1166],
+"da/d84/zhetrs_8f.html":[2,0,4,1617],
+"da/d84/zhetrs_8f_source.html":[2,0,4,1617],
 "da/d85/chbevx_8f.html":[2,0,4,103],
 "da/d85/chbevx_8f_source.html":[2,0,4,103],
 "da/d85/dgsvj1_8f.html":[2,0,4,572],
@@ -181,39 +200,39 @@ var NAVTREEINDEX65 =
 "da/d87/dgbtrf_8f_source.html":[2,0,4,496],
 "da/d87/dgeesx_8f.html":[2,0,4,506],
 "da/d87/dgeesx_8f_source.html":[2,0,4,506],
-"da/d88/lapacke__zlansy_8c.html":[2,0,3,3,2111],
-"da/d88/lapacke__zlansy_8c_a9433a265009a85f822f65607ab5fbbb3.html#a9433a265009a85f822f65607ab5fbbb3":[2,0,3,3,2111,0],
-"da/d88/lapacke__zlansy_8c_source.html":[2,0,3,3,2111],
+"da/d88/lapacke__zlansy_8c.html":[2,0,3,3,2117],
+"da/d88/lapacke__zlansy_8c_a9433a265009a85f822f65607ab5fbbb3.html#a9433a265009a85f822f65607ab5fbbb3":[2,0,3,3,2117,0],
+"da/d88/lapacke__zlansy_8c_source.html":[2,0,3,3,2117],
 "da/d89/lapacke__cheevr__2stage_8c.html":[2,0,3,3,207],
 "da/d89/lapacke__cheevr__2stage_8c_a1b74d9d6f7730ff34988b905c15fe3aa.html#a1b74d9d6f7730ff34988b905c15fe3aa":[2,0,3,3,207,0],
 "da/d89/lapacke__cheevr__2stage_8c_source.html":[2,0,3,3,207],
 "da/d89/lapacke__claset__work_8c.html":[2,0,3,3,347],
 "da/d89/lapacke__claset__work_8c_ad2b82cc1ac86e2daf395acb2166c4aad.html#ad2b82cc1ac86e2daf395acb2166c4aad":[2,0,3,3,347,0],
 "da/d89/lapacke__claset__work_8c_source.html":[2,0,3,3,347],
-"da/d89/lapacke__dgerfs_8c.html":[2,0,3,3,716],
-"da/d89/lapacke__dgerfs_8c_a832c5c44ed0285d97737a60531760c0b.html#a832c5c44ed0285d97737a60531760c0b":[2,0,3,3,716,0],
-"da/d89/lapacke__dgerfs_8c_source.html":[2,0,3,3,716],
-"da/d89/lapacke__dorgbr_8c.html":[2,0,3,3,864],
-"da/d89/lapacke__dorgbr_8c_ab04e9d06dd3a1325332aff1abcbb53c0.html#ab04e9d06dd3a1325332aff1abcbb53c0":[2,0,3,3,864,0],
-"da/d89/lapacke__dorgbr_8c_source.html":[2,0,3,3,864],
-"da/d89/lapacke__zsytrs_8c.html":[2,0,3,3,2285],
-"da/d89/lapacke__zsytrs_8c_a56bf3788d59323e71f8cbf5b57b1ab4a.html#a56bf3788d59323e71f8cbf5b57b1ab4a":[2,0,3,3,2285,0],
-"da/d89/lapacke__zsytrs_8c_source.html":[2,0,3,3,2285],
-"da/d8a/lapacke__ssytrs__work_8c.html":[2,0,3,3,1710],
-"da/d8a/lapacke__ssytrs__work_8c_acc1f372abb52ef0677343bfe95b86462.html#acc1f372abb52ef0677343bfe95b86462":[2,0,3,3,1710,0],
-"da/d8a/lapacke__ssytrs__work_8c_source.html":[2,0,3,3,1710],
+"da/d89/lapacke__dgerfs_8c.html":[2,0,3,3,718],
+"da/d89/lapacke__dgerfs_8c_a832c5c44ed0285d97737a60531760c0b.html#a832c5c44ed0285d97737a60531760c0b":[2,0,3,3,718,0],
+"da/d89/lapacke__dgerfs_8c_source.html":[2,0,3,3,718],
+"da/d89/lapacke__dorgbr_8c.html":[2,0,3,3,868],
+"da/d89/lapacke__dorgbr_8c_ab04e9d06dd3a1325332aff1abcbb53c0.html#ab04e9d06dd3a1325332aff1abcbb53c0":[2,0,3,3,868,0],
+"da/d89/lapacke__dorgbr_8c_source.html":[2,0,3,3,868],
+"da/d89/lapacke__zsytrs_8c.html":[2,0,3,3,2293],
+"da/d89/lapacke__zsytrs_8c_a56bf3788d59323e71f8cbf5b57b1ab4a.html#a56bf3788d59323e71f8cbf5b57b1ab4a":[2,0,3,3,2293,0],
+"da/d89/lapacke__zsytrs_8c_source.html":[2,0,3,3,2293],
+"da/d8a/lapacke__ssytrs__work_8c.html":[2,0,3,3,1716],
+"da/d8a/lapacke__ssytrs__work_8c_acc1f372abb52ef0677343bfe95b86462.html#acc1f372abb52ef0677343bfe95b86462":[2,0,3,3,1716,0],
+"da/d8a/lapacke__ssytrs__work_8c_source.html":[2,0,3,3,1716],
 "da/d8a/zher2_8f.html":[2,0,0,0,131],
 "da/d8a/zher2_8f_source.html":[2,0,0,0,131],
 "da/d8b/lapacke__chbtrd_8c.html":[2,0,3,3,190],
 "da/d8b/lapacke__chbtrd_8c_a1b5a9c66a354d4b3a3f6e08ded61bf61.html#a1b5a9c66a354d4b3a3f6e08ded61bf61":[2,0,3,3,190,0],
 "da/d8b/lapacke__chbtrd_8c_source.html":[2,0,3,3,190],
-"da/d8b/zspmv_8f.html":[2,0,4,1817],
-"da/d8b/zspmv_8f_source.html":[2,0,4,1817],
-"da/d8c/lapacke__cuncsd2by1_8c.html":[2,0,3,3,583],
-"da/d8c/lapacke__cuncsd2by1_8c_ad7f9f7dfe9bb069ca8cd45b38ea63c78.html#ad7f9f7dfe9bb069ca8cd45b38ea63c78":[2,0,3,3,583,0],
-"da/d8c/lapacke__cuncsd2by1_8c_source.html":[2,0,3,3,583],
-"da/d8d/zlanht_8f.html":[2,0,4,1706],
-"da/d8d/zlanht_8f_source.html":[2,0,4,1706],
+"da/d8b/zspmv_8f.html":[2,0,4,1816],
+"da/d8b/zspmv_8f_source.html":[2,0,4,1816],
+"da/d8c/lapacke__cuncsd2by1_8c.html":[2,0,3,3,585],
+"da/d8c/lapacke__cuncsd2by1_8c_ad7f9f7dfe9bb069ca8cd45b38ea63c78.html#ad7f9f7dfe9bb069ca8cd45b38ea63c78":[2,0,3,3,585,0],
+"da/d8c/lapacke__cuncsd2by1_8c_source.html":[2,0,3,3,585],
+"da/d8d/zlanht_8f.html":[2,0,4,1705],
+"da/d8d/zlanht_8f_source.html":[2,0,4,1705],
 "da/d8e/cppt03_8f.html":[2,0,5,1,150],
 "da/d8e/cppt03_8f_source.html":[2,0,5,1,150],
 "da/d8e/dgelsx_8f.html":[2,0,4,0,11],
@@ -230,24 +249,5 @@ var NAVTREEINDEX65 =
 "da/d8e/lapacke__utils_8h_a0b0a8619f55f06a99dcf61234149d0c3.html#a0b0a8619f55f06a99dcf61234149d0c3":[2,0,3,1,3,145],
 "da/d8e/lapacke__utils_8h_a0b662c7341db0a2e95f5aea12e5ae78f.html#a0b662c7341db0a2e95f5aea12e5ae78f":[2,0,3,1,3,57],
 "da/d8e/lapacke__utils_8h_a14602c39dd6593c44e9f432e9fc2e6af.html#a14602c39dd6593c44e9f432e9fc2e6af":[2,0,3,1,3,140],
-"da/d8e/lapacke__utils_8h_a161bf64b1651e407325e5ced98b1af09.html#a161bf64b1651e407325e5ced98b1af09":[2,0,3,1,3,106],
-"da/d8e/lapacke__utils_8h_a169052a3bf2219d74a261f398bb0ce47.html#a169052a3bf2219d74a261f398bb0ce47":[2,0,3,1,3,85],
-"da/d8e/lapacke__utils_8h_a1925b8535bd1d9ee93db1d0dc4da1225.html#a1925b8535bd1d9ee93db1d0dc4da1225":[2,0,3,1,3,7],
-"da/d8e/lapacke__utils_8h_a1ace3dafc4f616743a3150f6423e6a1b.html#a1ace3dafc4f616743a3150f6423e6a1b":[2,0,3,1,3,80],
-"da/d8e/lapacke__utils_8h_a1cc2788313df3ef441d6cf37229789da.html#a1cc2788313df3ef441d6cf37229789da":[2,0,3,1,3,1],
-"da/d8e/lapacke__utils_8h_a1f7e7b3c999d7974e1666689a7bf81c7.html#a1f7e7b3c999d7974e1666689a7bf81c7":[2,0,3,1,3,120],
-"da/d8e/lapacke__utils_8h_a21e1e2f15ce0995e9bcda13cdf93f603.html#a21e1e2f15ce0995e9bcda13cdf93f603":[2,0,3,1,3,23],
-"da/d8e/lapacke__utils_8h_a2850ba9f786d34a2b9d30f51db4285e8.html#a2850ba9f786d34a2b9d30f51db4285e8":[2,0,3,1,3,39],
-"da/d8e/lapacke__utils_8h_a2b48c1d2944f756d8d29b40f97287bc6.html#a2b48c1d2944f756d8d29b40f97287bc6":[2,0,3,1,3,71],
-"da/d8e/lapacke__utils_8h_a2fb7e26f3586bb1a302c4d26bba07448.html#a2fb7e26f3586bb1a302c4d26bba07448":[2,0,3,1,3,103],
-"da/d8e/lapacke__utils_8h_a30c387eb6659451bbac17d1c90b7a0d2.html#a30c387eb6659451bbac17d1c90b7a0d2":[2,0,3,1,3,70],
-"da/d8e/lapacke__utils_8h_a312a8798eaf2d8776e696518754f25e3.html#a312a8798eaf2d8776e696518754f25e3":[2,0,3,1,3,133],
-"da/d8e/lapacke__utils_8h_a31362e93347bb83bc794e2d79a476544.html#a31362e93347bb83bc794e2d79a476544":[2,0,3,1,3,149],
-"da/d8e/lapacke__utils_8h_a31639cbfcf91e691be7866900ab9e666.html#a31639cbfcf91e691be7866900ab9e666":[2,0,3,1,3,116],
-"da/d8e/lapacke__utils_8h_a323efd501d9f474eaeb2375a0fca974b.html#a323efd501d9f474eaeb2375a0fca974b":[2,0,3,1,3,24],
-"da/d8e/lapacke__utils_8h_a348bc0ad92280d588b815d8e3ffeef19.html#a348bc0ad92280d588b815d8e3ffeef19":[2,0,3,1,3,100],
-"da/d8e/lapacke__utils_8h_a35b7ad2c713984356f5c36f94a850fd7.html#a35b7ad2c713984356f5c36f94a850fd7":[2,0,3,1,3,14],
-"da/d8e/lapacke__utils_8h_a35f9caf319b9c1a1f3b23c7d5a940fda.html#a35f9caf319b9c1a1f3b23c7d5a940fda":[2,0,3,1,3,125],
-"da/d8e/lapacke__utils_8h_a3777b0e4351852aa632e3e2183e9c2d3.html#a3777b0e4351852aa632e3e2183e9c2d3":[2,0,3,1,3,105],
-"da/d8e/lapacke__utils_8h_a3842444d7cb940efcb8a2399c8dd0302.html#a3842444d7cb940efcb8a2399c8dd0302":[2,0,3,1,3,94]
+"da/d8e/lapacke__utils_8h_a161bf64b1651e407325e5ced98b1af09.html#a161bf64b1651e407325e5ced98b1af09":[2,0,3,1,3,106]
 };
