@@ -1,5 +1,24 @@
 var NAVTREEINDEX66 =
 {
+"da/d8e/lapacke__utils_8h_a169052a3bf2219d74a261f398bb0ce47.html#a169052a3bf2219d74a261f398bb0ce47":[2,0,3,1,3,85],
+"da/d8e/lapacke__utils_8h_a1925b8535bd1d9ee93db1d0dc4da1225.html#a1925b8535bd1d9ee93db1d0dc4da1225":[2,0,3,1,3,7],
+"da/d8e/lapacke__utils_8h_a1ace3dafc4f616743a3150f6423e6a1b.html#a1ace3dafc4f616743a3150f6423e6a1b":[2,0,3,1,3,80],
+"da/d8e/lapacke__utils_8h_a1cc2788313df3ef441d6cf37229789da.html#a1cc2788313df3ef441d6cf37229789da":[2,0,3,1,3,1],
+"da/d8e/lapacke__utils_8h_a1f7e7b3c999d7974e1666689a7bf81c7.html#a1f7e7b3c999d7974e1666689a7bf81c7":[2,0,3,1,3,120],
+"da/d8e/lapacke__utils_8h_a21e1e2f15ce0995e9bcda13cdf93f603.html#a21e1e2f15ce0995e9bcda13cdf93f603":[2,0,3,1,3,23],
+"da/d8e/lapacke__utils_8h_a2850ba9f786d34a2b9d30f51db4285e8.html#a2850ba9f786d34a2b9d30f51db4285e8":[2,0,3,1,3,39],
+"da/d8e/lapacke__utils_8h_a2b48c1d2944f756d8d29b40f97287bc6.html#a2b48c1d2944f756d8d29b40f97287bc6":[2,0,3,1,3,71],
+"da/d8e/lapacke__utils_8h_a2fb7e26f3586bb1a302c4d26bba07448.html#a2fb7e26f3586bb1a302c4d26bba07448":[2,0,3,1,3,103],
+"da/d8e/lapacke__utils_8h_a30c387eb6659451bbac17d1c90b7a0d2.html#a30c387eb6659451bbac17d1c90b7a0d2":[2,0,3,1,3,70],
+"da/d8e/lapacke__utils_8h_a312a8798eaf2d8776e696518754f25e3.html#a312a8798eaf2d8776e696518754f25e3":[2,0,3,1,3,133],
+"da/d8e/lapacke__utils_8h_a31362e93347bb83bc794e2d79a476544.html#a31362e93347bb83bc794e2d79a476544":[2,0,3,1,3,149],
+"da/d8e/lapacke__utils_8h_a31639cbfcf91e691be7866900ab9e666.html#a31639cbfcf91e691be7866900ab9e666":[2,0,3,1,3,116],
+"da/d8e/lapacke__utils_8h_a323efd501d9f474eaeb2375a0fca974b.html#a323efd501d9f474eaeb2375a0fca974b":[2,0,3,1,3,24],
+"da/d8e/lapacke__utils_8h_a348bc0ad92280d588b815d8e3ffeef19.html#a348bc0ad92280d588b815d8e3ffeef19":[2,0,3,1,3,100],
+"da/d8e/lapacke__utils_8h_a35b7ad2c713984356f5c36f94a850fd7.html#a35b7ad2c713984356f5c36f94a850fd7":[2,0,3,1,3,14],
+"da/d8e/lapacke__utils_8h_a35f9caf319b9c1a1f3b23c7d5a940fda.html#a35f9caf319b9c1a1f3b23c7d5a940fda":[2,0,3,1,3,125],
+"da/d8e/lapacke__utils_8h_a3777b0e4351852aa632e3e2183e9c2d3.html#a3777b0e4351852aa632e3e2183e9c2d3":[2,0,3,1,3,105],
+"da/d8e/lapacke__utils_8h_a3842444d7cb940efcb8a2399c8dd0302.html#a3842444d7cb940efcb8a2399c8dd0302":[2,0,3,1,3,94],
 "da/d8e/lapacke__utils_8h_a38a9eb7eea154f94f313f8d1ac4b45a3.html#a38a9eb7eea154f94f313f8d1ac4b45a3":[2,0,3,1,3,127],
 "da/d8e/lapacke__utils_8h_a38eec1c343e5a9ec28ed2b06881f6e0a.html#a38eec1c343e5a9ec28ed2b06881f6e0a":[2,0,3,1,3,8],
 "da/d8e/lapacke__utils_8h_a396a7b09e9fa73a2c099b11be37faed1.html#a396a7b09e9fa73a2c099b11be37faed1":[2,0,3,1,3,147],
@@ -134,53 +153,53 @@ var NAVTREEINDEX66 =
 "da/d8e/lapacke__utils_8h_source.html":[2,0,3,1,3],
 "da/d8f/cspsvx_8f.html":[2,0,4,357],
 "da/d8f/cspsvx_8f_source.html":[2,0,4,357],
-"da/d8f/lapacke__dgeqpf_8c.html":[2,0,3,3,700],
-"da/d8f/lapacke__dgeqpf_8c_a06fbb095eebe4b77737712ed3b10cc67.html#a06fbb095eebe4b77737712ed3b10cc67":[2,0,3,3,700,0],
-"da/d8f/lapacke__dgeqpf_8c_source.html":[2,0,3,3,700],
+"da/d8f/lapacke__dgeqpf_8c.html":[2,0,3,3,702],
+"da/d8f/lapacke__dgeqpf_8c_a06fbb095eebe4b77737712ed3b10cc67.html#a06fbb095eebe4b77737712ed3b10cc67":[2,0,3,3,702,0],
+"da/d8f/lapacke__dgeqpf_8c_source.html":[2,0,3,3,702],
 "da/d8f/serrrq_8f.html":[2,0,5,1,450],
 "da/d8f/serrrq_8f_source.html":[2,0,5,1,450],
 "da/d90/lapacke__chptrs_8c.html":[2,0,3,3,300],
 "da/d90/lapacke__chptrs_8c_a20c43650cd9b7e38b9aacc49c4d5aced.html#a20c43650cd9b7e38b9aacc49c4d5aced":[2,0,3,3,300,0],
 "da/d90/lapacke__chptrs_8c_source.html":[2,0,3,3,300],
-"da/d90/lapacke__stgsyl__work_8c.html":[2,0,3,3,1736],
-"da/d90/lapacke__stgsyl__work_8c_a2d6c60011905225fa054d3939de5f330.html#a2d6c60011905225fa054d3939de5f330":[2,0,3,3,1736,0],
-"da/d90/lapacke__stgsyl__work_8c_source.html":[2,0,3,3,1736],
+"da/d90/lapacke__stgsyl__work_8c.html":[2,0,3,3,1742],
+"da/d90/lapacke__stgsyl__work_8c_a2d6c60011905225fa054d3939de5f330.html#a2d6c60011905225fa054d3939de5f330":[2,0,3,3,1742,0],
+"da/d90/lapacke__stgsyl__work_8c_source.html":[2,0,3,3,1742],
 "da/d92/lapacke__chegv_8c.html":[2,0,3,3,216],
 "da/d92/lapacke__chegv_8c_a04dbfef4f578331d84e995060e48ba0b.html#a04dbfef4f578331d84e995060e48ba0b":[2,0,3,3,216,0],
 "da/d92/lapacke__chegv_8c_source.html":[2,0,3,3,216],
-"da/d93/lapacke__spptrs__work_8c.html":[2,0,3,3,1538],
-"da/d93/lapacke__spptrs__work_8c_a80231f19cabf489d4ea94d490287269a.html#a80231f19cabf489d4ea94d490287269a":[2,0,3,3,1538,0],
-"da/d93/lapacke__spptrs__work_8c_source.html":[2,0,3,3,1538],
+"da/d93/lapacke__spptrs__work_8c.html":[2,0,3,3,1544],
+"da/d93/lapacke__spptrs__work_8c_a80231f19cabf489d4ea94d490287269a.html#a80231f19cabf489d4ea94d490287269a":[2,0,3,3,1544,0],
+"da/d93/lapacke__spptrs__work_8c_source.html":[2,0,3,3,1544],
 "da/d94/group__complex_g_tcomputational.html":[0,0,5,1,2],
 "da/d94/group__complex_g_tcomputational_ga74d1d5397dae5f211149667ea29c36b9.html#ga74d1d5397dae5f211149667ea29c36b9":[2,0,4,95,0],
 "da/d94/group__complex_g_tcomputational_ga74d1d5397dae5f211149667ea29c36b9.html#ga74d1d5397dae5f211149667ea29c36b9":[0,0,5,1,2,2],
-"da/d94/group__complex_g_tcomputational_ga78033228f7cbf104d0974824c51802c9.html#ga78033228f7cbf104d0974824c51802c9":[2,0,4,96,0],
-"da/d94/group__complex_g_tcomputational_ga78033228f7cbf104d0974824c51802c9.html#ga78033228f7cbf104d0974824c51802c9":[0,0,5,1,2,3],
-"da/d94/group__complex_g_tcomputational_ga8c9bbcbd4fcbaa905dad4154638f1f50.html#ga8c9bbcbd4fcbaa905dad4154638f1f50":[2,0,4,92,0],
-"da/d94/group__complex_g_tcomputational_ga8c9bbcbd4fcbaa905dad4154638f1f50.html#ga8c9bbcbd4fcbaa905dad4154638f1f50":[0,0,5,1,2,1],
+"da/d94/group__complex_g_tcomputational_ga8f80227b32b600dc75a5e982005ec1c2.html#ga8f80227b32b600dc75a5e982005ec1c2":[2,0,4,91,0],
+"da/d94/group__complex_g_tcomputational_ga8f80227b32b600dc75a5e982005ec1c2.html#ga8f80227b32b600dc75a5e982005ec1c2":[0,0,5,1,2,0],
+"da/d94/group__complex_g_tcomputational_ga92eec53c6ac6c6285a10e7d05d9c00d5.html#ga92eec53c6ac6c6285a10e7d05d9c00d5":[2,0,4,92,0],
+"da/d94/group__complex_g_tcomputational_ga92eec53c6ac6c6285a10e7d05d9c00d5.html#ga92eec53c6ac6c6285a10e7d05d9c00d5":[0,0,5,1,2,1],
 "da/d94/group__complex_g_tcomputational_gab3cb48a1dae8355cc937e9c97ac5ded0.html#gab3cb48a1dae8355cc937e9c97ac5ded0":[2,0,4,97,0],
 "da/d94/group__complex_g_tcomputational_gab3cb48a1dae8355cc937e9c97ac5ded0.html#gab3cb48a1dae8355cc937e9c97ac5ded0":[0,0,5,1,2,4],
-"da/d94/group__complex_g_tcomputational_gadcf72ac6959afb636b0277a7ce5782ff.html#gadcf72ac6959afb636b0277a7ce5782ff":[2,0,4,91,0],
-"da/d94/group__complex_g_tcomputational_gadcf72ac6959afb636b0277a7ce5782ff.html#gadcf72ac6959afb636b0277a7ce5782ff":[0,0,5,1,2,0],
+"da/d94/group__complex_g_tcomputational_gafe8bdadc6f4da5aa5df3fe22dbe6b05b.html#gafe8bdadc6f4da5aa5df3fe22dbe6b05b":[2,0,4,96,0],
+"da/d94/group__complex_g_tcomputational_gafe8bdadc6f4da5aa5df3fe22dbe6b05b.html#gafe8bdadc6f4da5aa5df3fe22dbe6b05b":[0,0,5,1,2,3],
 "da/d94/zlahrd_8f.html":[2,0,4,0,33],
 "da/d94/zlahrd_8f_source.html":[2,0,4,0,33],
 "da/d94/zlavhe__rook_8f.html":[2,0,5,1,681],
 "da/d94/zlavhe__rook_8f_source.html":[2,0,5,1,681],
-"da/d94/zsytrf_8f.html":[2,0,4,1851],
-"da/d94/zsytrf_8f_source.html":[2,0,4,1851],
+"da/d94/zsytrf_8f.html":[2,0,4,1850],
+"da/d94/zsytrf_8f_source.html":[2,0,4,1850],
 "da/d95/cgbrfsx_8f.html":[2,0,4,9],
 "da/d95/cgbrfsx_8f_source.html":[2,0,4,9],
 "da/d96/cerrsyx_8f.html":[2,0,5,1,91],
 "da/d96/cerrsyx_8f_source.html":[2,0,5,1,91],
 "da/d96/ddrvls_8f.html":[2,0,5,1,241],
 "da/d96/ddrvls_8f_source.html":[2,0,5,1,241],
-"da/d97/lapacke__dormtr__work_8c.html":[2,0,3,3,893],
-"da/d97/lapacke__dormtr__work_8c_a2fe49377184d9cd6d8e8237c2ac59320.html#a2fe49377184d9cd6d8e8237c2ac59320":[2,0,3,3,893,0],
-"da/d97/lapacke__dormtr__work_8c_source.html":[2,0,3,3,893],
+"da/d97/lapacke__dormtr__work_8c.html":[2,0,3,3,897],
+"da/d97/lapacke__dormtr__work_8c_a2fe49377184d9cd6d8e8237c2ac59320.html#a2fe49377184d9cd6d8e8237c2ac59320":[2,0,3,3,897,0],
+"da/d97/lapacke__dormtr__work_8c_source.html":[2,0,3,3,897],
 "da/d98/sdrvls_8f.html":[2,0,5,1,416],
 "da/d98/sdrvls_8f_source.html":[2,0,5,1,416],
-"da/d99/zsprfs_8f.html":[2,0,4,1819],
-"da/d99/zsprfs_8f_source.html":[2,0,4,1819],
+"da/d99/zsprfs_8f.html":[2,0,4,1818],
+"da/d99/zsprfs_8f_source.html":[2,0,4,1818],
 "da/d9b/_cintface_8c.html":[2,0,3,2,0],
 "da/d9b/_cintface_8c_a4a3ad144d505252637f3347504c998a0.html#a4a3ad144d505252637f3347504c998a0":[2,0,3,2,0,2],
 "da/d9b/_cintface_8c_a6259ea61712e34e7c7781485c260d8c2.html#a6259ea61712e34e7c7781485c260d8c2":[2,0,3,2,0,1],
@@ -196,13 +215,13 @@ var NAVTREEINDEX66 =
 "da/d9b/group__single__blas__testing_gaed614e5d25dd65001fae0671947d4b3c.html#gaed614e5d25dd65001fae0671947d4b3c":[2,0,0,1,6,6],
 "da/d9b/group__single__blas__testing_gaeec1d20ed538f1a0d9a200b8c8747fd2.html#gaeec1d20ed538f1a0d9a200b8c8747fd2":[0,2,4,0,2],
 "da/d9b/group__single__blas__testing_gaeec1d20ed538f1a0d9a200b8c8747fd2.html#gaeec1d20ed538f1a0d9a200b8c8747fd2":[2,0,0,1,8,4],
-"da/d9b/zlabrd_8f.html":[2,0,4,1668],
-"da/d9b/zlabrd_8f_source.html":[2,0,4,1668],
+"da/d9b/zlabrd_8f.html":[2,0,4,1667],
+"da/d9b/zlabrd_8f_source.html":[2,0,4,1667],
 "da/d9d/dgeequ_8f.html":[2,0,4,503],
 "da/d9d/dgeequ_8f_source.html":[2,0,4,503],
-"da/d9d/lapacke__sgeqrt2__work_8c.html":[2,0,3,3,1295],
-"da/d9d/lapacke__sgeqrt2__work_8c_af63cdc671439acf9bce398a9f03c39d4.html#af63cdc671439acf9bce398a9f03c39d4":[2,0,3,3,1295,0],
-"da/d9d/lapacke__sgeqrt2__work_8c_source.html":[2,0,3,3,1295],
+"da/d9d/lapacke__sgeqrt2__work_8c.html":[2,0,3,3,1299],
+"da/d9d/lapacke__sgeqrt2__work_8c_af63cdc671439acf9bce398a9f03c39d4.html#af63cdc671439acf9bce398a9f03c39d4":[2,0,3,3,1299,0],
+"da/d9d/lapacke__sgeqrt2__work_8c_source.html":[2,0,3,3,1299],
 "da/d9e/serrlqtp_8f.html":[2,0,5,1,439],
 "da/d9e/serrlqtp_8f_source.html":[2,0,5,1,439],
 "da/d9f/cblas__sgbmv_8c.html":[2,0,1,2,81],
@@ -222,32 +241,13 @@ var NAVTREEINDEX66 =
 "da/d9f/lapacke__chetrd_8c.html":[2,0,3,3,240],
 "da/d9f/lapacke__chetrd_8c_a317dd9044bfe6462ea41a6bd51f7e7ae.html#a317dd9044bfe6462ea41a6bd51f7e7ae":[2,0,3,3,240,0],
 "da/d9f/lapacke__chetrd_8c_source.html":[2,0,3,3,240],
-"da/d9f/lapacke__stgexc__work_8c.html":[2,0,3,3,1728],
-"da/d9f/lapacke__stgexc__work_8c_aaaa935d4e8b48a45c7415a74a747a76a.html#aaaa935d4e8b48a45c7415a74a747a76a":[2,0,3,3,1728,0],
-"da/d9f/lapacke__stgexc__work_8c_source.html":[2,0,3,3,1728],
-"da/d9f/lapacke__zpotrs_8c.html":[2,0,3,3,2183],
-"da/d9f/lapacke__zpotrs_8c_afcaccad29266cc4dcc45b71b28977cbe.html#afcaccad29266cc4dcc45b71b28977cbe":[2,0,3,3,2183,0],
-"da/d9f/lapacke__zpotrs_8c_source.html":[2,0,3,3,2183],
+"da/d9f/lapacke__stgexc__work_8c.html":[2,0,3,3,1734],
+"da/d9f/lapacke__stgexc__work_8c_aaaa935d4e8b48a45c7415a74a747a76a.html#aaaa935d4e8b48a45c7415a74a747a76a":[2,0,3,3,1734,0],
+"da/d9f/lapacke__stgexc__work_8c_source.html":[2,0,3,3,1734],
+"da/d9f/lapacke__zpotrs_8c.html":[2,0,3,3,2191],
+"da/d9f/lapacke__zpotrs_8c_afcaccad29266cc4dcc45b71b28977cbe.html#afcaccad29266cc4dcc45b71b28977cbe":[2,0,3,3,2191,0],
+"da/d9f/lapacke__zpotrs_8c_source.html":[2,0,3,3,2191],
 "da/d9f/sgbt05_8f.html":[2,0,5,1,460],
 "da/d9f/sgbt05_8f_source.html":[2,0,5,1,460],
-"da/d9f/sspt21_8f.html":[2,0,5,0,265],
-"da/d9f/sspt21_8f_source.html":[2,0,5,0,265],
-"da/da2/dorbdb1_8f.html":[2,0,4,750],
-"da/da2/dorbdb1_8f_source.html":[2,0,4,750],
-"da/da2/lapacke__dlaswp_8c.html":[2,0,3,3,848],
-"da/da2/lapacke__dlaswp_8c_a6ffca7082560c6858f8e11698217dc32.html#a6ffca7082560c6858f8e11698217dc32":[2,0,3,3,848,0],
-"da/da2/lapacke__dlaswp_8c_source.html":[2,0,3,3,848],
-"da/da3/lapacke__zgemqr_8c.html":[2,0,3,3,1851],
-"da/da3/lapacke__zgemqr_8c_a8f97b4b3433ce806ac97846f6e576ba7.html#a8f97b4b3433ce806ac97846f6e576ba7":[2,0,3,3,1851,0],
-"da/da3/lapacke__zgemqr_8c_source.html":[2,0,3,3,1851],
-"da/da4/dlasyf__rk_8f.html":[2,0,4,735],
-"da/da4/dlasyf__rk_8f_source.html":[2,0,4,735],
-"da/da4/zhet01__aa_8f.html":[2,0,5,1,666],
-"da/da4/zhet01__aa_8f_source.html":[2,0,5,1,666],
-"da/da5/chet01__rook_8f.html":[2,0,5,1,116],
-"da/da5/chet01__rook_8f_source.html":[2,0,5,1,116],
-"da/da5/lapacke__spbstf_8c.html":[2,0,3,3,1483],
-"da/da5/lapacke__spbstf_8c_abc8f015f208b52c7f26bd22b4e074e86.html#abc8f015f208b52c7f26bd22b4e074e86":[2,0,3,3,1483,0],
-"da/da5/lapacke__spbstf_8c_source.html":[2,0,3,3,1483],
-"da/da5/zhetrf__rk_8f.html":[2,0,4,1610]
+"da/d9f/sspt21_8f.html":[2,0,5,0,265]
 };
