@@ -1,30 +1,49 @@
 var NAVTREEINDEX69 =
 {
+"da/dd4/lapacke__zhseqr_8c.html":[2,0,3,3,2095],
+"da/dd4/lapacke__zhseqr_8c_a339c97e0da4dc8ddc3c5da9cae0ec173.html#a339c97e0da4dc8ddc3c5da9cae0ec173":[2,0,3,3,2095,0],
+"da/dd4/lapacke__zhseqr_8c_source.html":[2,0,3,3,2095],
+"da/dd5/lapacke__spftri__work_8c.html":[2,0,3,3,1502],
+"da/dd5/lapacke__spftri__work_8c_a4b3e660815e788fe41e6c4493d8f6e47.html#a4b3e660815e788fe41e6c4493d8f6e47":[2,0,3,3,1502,0],
+"da/dd5/lapacke__spftri__work_8c_source.html":[2,0,3,3,1502],
+"da/dd6/cgels_8f.html":[2,0,4,35],
+"da/dd6/cgels_8f_source.html":[2,0,4,35],
+"da/dd6/ssyev_8f.html":[2,0,4,1373],
+"da/dd6/ssyev_8f_source.html":[2,0,4,1373],
+"da/dd7/cunm2l_8f.html":[2,0,4,466],
+"da/dd7/cunm2l_8f_source.html":[2,0,4,466],
+"da/dd7/lapacke__ztb__trans_8c.html":[2,0,3,4,141],
+"da/dd7/lapacke__ztb__trans_8c_acf6da91717640ddda1dfd3f485204bed.html#acf6da91717640ddda1dfd3f485204bed":[2,0,3,4,141,0],
+"da/dd7/lapacke__ztb__trans_8c_source.html":[2,0,3,4,141],
+"da/dda/lapacke__chesv__rk_8c.html":[2,0,3,3,231],
+"da/dda/lapacke__chesv__rk_8c_af2fc1f36dd6b9fb89790a3441f133179.html#af2fc1f36dd6b9fb89790a3441f133179":[2,0,3,3,231,0],
+"da/dda/lapacke__chesv__rk_8c_source.html":[2,0,3,3,231],
+"da/dda/lapacke__chetrf__rook_8c.html":[2,0,3,3,247],
 "da/dda/lapacke__chetrf__rook_8c_a9169b8fbfb1da405f60805171e93e3b7.html#a9169b8fbfb1da405f60805171e93e3b7":[2,0,3,3,247,0],
 "da/dda/lapacke__chetrf__rook_8c_source.html":[2,0,3,3,247],
-"da/ddb/lapacke__zhetrf__aa_8c.html":[2,0,3,3,2028],
-"da/ddb/lapacke__zhetrf__aa_8c_a4eef75a439d3df7d914e13a166156785.html#a4eef75a439d3df7d914e13a166156785":[2,0,3,3,2028,0],
-"da/ddb/lapacke__zhetrf__aa_8c_source.html":[2,0,3,3,2028],
+"da/ddb/lapacke__zhetrf__aa_8c.html":[2,0,3,3,2034],
+"da/ddb/lapacke__zhetrf__aa_8c_a4eef75a439d3df7d914e13a166156785.html#a4eef75a439d3df7d914e13a166156785":[2,0,3,3,2034,0],
+"da/ddb/lapacke__zhetrf__aa_8c_source.html":[2,0,3,3,2034],
 "da/ddd/_s_r_c_2dlarfy_8f.html":[2,0,4,682],
 "da/ddd/_s_r_c_2dlarfy_8f_source.html":[2,0,4,682],
-"da/ddd/lapacke__zhsein_8c.html":[2,0,3,3,2087],
-"da/ddd/lapacke__zhsein_8c_abfd551f8beb2ed97161deab2a3c4b248.html#abfd551f8beb2ed97161deab2a3c4b248":[2,0,3,3,2087,0],
-"da/ddd/lapacke__zhsein_8c_source.html":[2,0,3,3,2087],
-"da/dde/lapacke__dormtr_8c.html":[2,0,3,3,892],
-"da/dde/lapacke__dormtr_8c_acc8eabefd0137b52ab1b1d74f655a3b2.html#acc8eabefd0137b52ab1b1d74f655a3b2":[2,0,3,3,892,0],
-"da/dde/lapacke__dormtr_8c_source.html":[2,0,3,3,892],
-"da/dde/lapacke__zhptrd_8c.html":[2,0,3,3,2079],
-"da/dde/lapacke__zhptrd_8c_afdd718508b9aa17e9a6315e896fe5854.html#afdd718508b9aa17e9a6315e896fe5854":[2,0,3,3,2079,0],
-"da/dde/lapacke__zhptrd_8c_source.html":[2,0,3,3,2079],
+"da/ddd/lapacke__zhsein_8c.html":[2,0,3,3,2093],
+"da/ddd/lapacke__zhsein_8c_abfd551f8beb2ed97161deab2a3c4b248.html#abfd551f8beb2ed97161deab2a3c4b248":[2,0,3,3,2093,0],
+"da/ddd/lapacke__zhsein_8c_source.html":[2,0,3,3,2093],
+"da/dde/lapacke__dormtr_8c.html":[2,0,3,3,896],
+"da/dde/lapacke__dormtr_8c_acc8eabefd0137b52ab1b1d74f655a3b2.html#acc8eabefd0137b52ab1b1d74f655a3b2":[2,0,3,3,896,0],
+"da/dde/lapacke__dormtr_8c_source.html":[2,0,3,3,896],
+"da/dde/lapacke__zhptrd_8c.html":[2,0,3,3,2085],
+"da/dde/lapacke__zhptrd_8c_afdd718508b9aa17e9a6315e896fe5854.html#afdd718508b9aa17e9a6315e896fe5854":[2,0,3,3,2085,0],
+"da/dde/lapacke__zhptrd_8c_source.html":[2,0,3,3,2085],
 "da/ddf/dlqt03_8f.html":[2,0,5,1,317],
 "da/ddf/dlqt03_8f_source.html":[2,0,5,1,317],
-"da/de0/lapacke__zgeqrt3_8c.html":[2,0,3,3,1872],
-"da/de0/lapacke__zgeqrt3_8c_ae016be0754a4f92cd9cfc132b60ce116.html#ae016be0754a4f92cd9cfc132b60ce116":[2,0,3,3,1872,0],
-"da/de0/lapacke__zgeqrt3_8c_source.html":[2,0,3,3,1872],
+"da/de0/lapacke__zgeqrt3_8c.html":[2,0,3,3,1878],
+"da/de0/lapacke__zgeqrt3_8c_ae016be0754a4f92cd9cfc132b60ce116.html#ae016be0754a4f92cd9cfc132b60ce116":[2,0,3,3,1878,0],
+"da/de0/lapacke__zgeqrt3_8c_source.html":[2,0,3,3,1878],
 "da/de1/chet21_8f.html":[2,0,5,0,68],
 "da/de1/chet21_8f_source.html":[2,0,5,0,68],
-"da/de1/sorcsd_8f.html":[2,0,4,1257],
-"da/de1/sorcsd_8f_source.html":[2,0,4,1257],
+"da/de1/sorcsd_8f.html":[2,0,4,1256],
+"da/de1/sorcsd_8f_source.html":[2,0,4,1256],
 "da/de1/srzt01_8f.html":[2,0,5,1,527],
 "da/de1/srzt01_8f_source.html":[2,0,5,1,527],
 "da/de2/zchkgl_8f.html":[2,0,5,0,289],
@@ -48,37 +67,37 @@ var NAVTREEINDEX69 =
 "da/de6/zdrvpo_8f_source.html":[2,0,5,1,603],
 "da/de6/zgelqs_8f.html":[2,0,5,1,650],
 "da/de6/zgelqs_8f_source.html":[2,0,5,1,650],
-"da/de6/zlaqsp_8f.html":[2,0,4,1730],
-"da/de6/zlaqsp_8f_source.html":[2,0,4,1730],
-"da/de7/lapacke__csysvx_8c.html":[2,0,3,3,478],
-"da/de7/lapacke__csysvx_8c_a3b07e4fa70bd1e2c196aa748095fa922.html#a3b07e4fa70bd1e2c196aa748095fa922":[2,0,3,3,478,0],
-"da/de7/lapacke__csysvx_8c_source.html":[2,0,3,3,478],
-"da/de7/ztprfb_8f.html":[2,0,4,1888],
-"da/de7/ztprfb_8f_source.html":[2,0,4,1888],
-"da/de8/lapacke__dstevr__work_8c.html":[2,0,3,3,1049],
-"da/de8/lapacke__dstevr__work_8c_af8d6d0762e9a898916aa708d6343fd6b.html#af8d6d0762e9a898916aa708d6343fd6b":[2,0,3,3,1049,0],
-"da/de8/lapacke__dstevr__work_8c_source.html":[2,0,3,3,1049],
+"da/de6/zlaqsp_8f.html":[2,0,4,1729],
+"da/de6/zlaqsp_8f_source.html":[2,0,4,1729],
+"da/de7/lapacke__csysvx_8c.html":[2,0,3,3,480],
+"da/de7/lapacke__csysvx_8c_a3b07e4fa70bd1e2c196aa748095fa922.html#a3b07e4fa70bd1e2c196aa748095fa922":[2,0,3,3,480,0],
+"da/de7/lapacke__csysvx_8c_source.html":[2,0,3,3,480],
+"da/de7/ztprfb_8f.html":[2,0,4,1887],
+"da/de7/ztprfb_8f_source.html":[2,0,4,1887],
+"da/de8/lapacke__dstevr__work_8c.html":[2,0,3,3,1053],
+"da/de8/lapacke__dstevr__work_8c_af8d6d0762e9a898916aa708d6343fd6b.html#af8d6d0762e9a898916aa708d6343fd6b":[2,0,3,3,1053,0],
+"da/de8/lapacke__dstevr__work_8c_source.html":[2,0,3,3,1053],
 "da/de9/dlahd2_8f.html":[2,0,5,0,156],
 "da/de9/dlahd2_8f_source.html":[2,0,5,0,156],
-"da/de9/lapacke__dlascl__work_8c.html":[2,0,3,3,843],
-"da/de9/lapacke__dlascl__work_8c_a312d8fe8cdf38c8cb096edb04c9192f7.html#a312d8fe8cdf38c8cb096edb04c9192f7":[2,0,3,3,843,0],
-"da/de9/lapacke__dlascl__work_8c_source.html":[2,0,3,3,843],
+"da/de9/lapacke__dlascl__work_8c.html":[2,0,3,3,845],
+"da/de9/lapacke__dlascl__work_8c_a312d8fe8cdf38c8cb096edb04c9192f7.html#a312d8fe8cdf38c8cb096edb04c9192f7":[2,0,3,3,845,0],
+"da/de9/lapacke__dlascl__work_8c_source.html":[2,0,3,3,845],
 "da/de9/lapacke__dpf__nancheck_8c.html":[2,0,3,4,50],
 "da/de9/lapacke__dpf__nancheck_8c_ae88010c6a69459c81270d2ddc333c1ba.html#ae88010c6a69459c81270d2ddc333c1ba":[2,0,3,4,50,0],
 "da/de9/lapacke__dpf__nancheck_8c_source.html":[2,0,3,4,50],
-"da/de9/ssytrf_8f.html":[2,0,4,1404],
-"da/de9/ssytrf_8f_source.html":[2,0,4,1404],
-"da/dec/lapacke__spotrf2__work_8c.html":[2,0,3,3,1517],
-"da/dec/lapacke__spotrf2__work_8c_a04fc533c8a62a18dfc5ed220e8ac3c66.html#a04fc533c8a62a18dfc5ed220e8ac3c66":[2,0,3,3,1517,0],
-"da/dec/lapacke__spotrf2__work_8c_source.html":[2,0,3,3,1517],
+"da/de9/ssytrf_8f.html":[2,0,4,1403],
+"da/de9/ssytrf_8f_source.html":[2,0,4,1403],
+"da/dec/lapacke__spotrf2__work_8c.html":[2,0,3,3,1523],
+"da/dec/lapacke__spotrf2__work_8c_a04fc533c8a62a18dfc5ed220e8ac3c66.html#a04fc533c8a62a18dfc5ed220e8ac3c66":[2,0,3,3,1523,0],
+"da/dec/lapacke__spotrf2__work_8c_source.html":[2,0,3,3,1523],
 "da/dec/zdrgev_8f.html":[2,0,5,0,303],
 "da/dec/zdrgev_8f_source.html":[2,0,5,0,303],
-"da/ded/spbrfs_8f.html":[2,0,4,1286],
-"da/ded/spbrfs_8f_source.html":[2,0,4,1286],
-"da/ded/zsysvx_8f.html":[2,0,4,1845],
-"da/ded/zsysvx_8f_source.html":[2,0,4,1845],
-"da/df0/sopgtr_8f.html":[2,0,4,1248],
-"da/df0/sopgtr_8f_source.html":[2,0,4,1248],
+"da/ded/spbrfs_8f.html":[2,0,4,1285],
+"da/ded/spbrfs_8f_source.html":[2,0,4,1285],
+"da/ded/zsysvx_8f.html":[2,0,4,1844],
+"da/ded/zsysvx_8f_source.html":[2,0,4,1844],
+"da/df0/sopgtr_8f.html":[2,0,4,1247],
+"da/df0/sopgtr_8f_source.html":[2,0,4,1247],
 "da/df1/claqr5_8f.html":[2,0,4,265],
 "da/df1/claqr5_8f_source.html":[2,0,4,265],
 "da/df1/zdrvgb_8f.html":[2,0,5,1,590],
@@ -106,24 +125,24 @@ var NAVTREEINDEX69 =
 "da/df6/group__complex__blas__level1_ga7ac1991bb0c9da7b63fd64c999d6b859.html#ga7ac1991bb0c9da7b63fd64c999d6b859":[2,0,0,0,22,0],
 "da/df6/group__complex__blas__level1_ga9605cb98791e2038fd89aaef63a31be1.html#ga9605cb98791e2038fd89aaef63a31be1":[0,2,0,2,0],
 "da/df6/group__complex__blas__level1_ga9605cb98791e2038fd89aaef63a31be1.html#ga9605cb98791e2038fd89aaef63a31be1":[2,0,0,0,0,0],
-"da/df6/group__complex__blas__level1_gaa50b533bbd2eceac1f59dbc780d7a182.html#gaa50b533bbd2eceac1f59dbc780d7a182":[0,2,0,2,8],
 "da/df6/group__complex__blas__level1_gaa50b533bbd2eceac1f59dbc780d7a182.html#gaa50b533bbd2eceac1f59dbc780d7a182":[2,0,0,0,23,0],
-"da/df6/group__complex__blas__level1_gab2d569bbfe6356599c69c057ecc2b3f7.html#gab2d569bbfe6356599c69c057ecc2b3f7":[2,0,0,0,20,0],
+"da/df6/group__complex__blas__level1_gaa50b533bbd2eceac1f59dbc780d7a182.html#gaa50b533bbd2eceac1f59dbc780d7a182":[0,2,0,2,8],
 "da/df6/group__complex__blas__level1_gab2d569bbfe6356599c69c057ecc2b3f7.html#gab2d569bbfe6356599c69c057ecc2b3f7":[0,2,0,2,5],
+"da/df6/group__complex__blas__level1_gab2d569bbfe6356599c69c057ecc2b3f7.html#gab2d569bbfe6356599c69c057ecc2b3f7":[2,0,0,0,20,0],
 "da/df6/group__complex__blas__level1_gadd72f1b633553acc77250e32bc704a78.html#gadd72f1b633553acc77250e32bc704a78":[0,2,0,2,3],
 "da/df6/group__complex__blas__level1_gadd72f1b633553acc77250e32bc704a78.html#gadd72f1b633553acc77250e32bc704a78":[2,0,0,0,3,0],
 "da/df6/group__complex__blas__level1_gaf660f9cda67820f314f36c9668272987.html#gaf660f9cda67820f314f36c9668272987":[0,2,0,2,6],
 "da/df6/group__complex__blas__level1_gaf660f9cda67820f314f36c9668272987.html#gaf660f9cda67820f314f36c9668272987":[2,0,0,0,21,0],
-"da/df7/lapacke__zgetrf2__work_8c.html":[2,0,3,3,1899],
-"da/df7/lapacke__zgetrf2__work_8c_a4f1a1075c0def2e5d53ce4c28c05bedb.html#a4f1a1075c0def2e5d53ce4c28c05bedb":[2,0,3,3,1899,0],
-"da/df7/lapacke__zgetrf2__work_8c_source.html":[2,0,3,3,1899],
+"da/df7/lapacke__zgetrf2__work_8c.html":[2,0,3,3,1905],
+"da/df7/lapacke__zgetrf2__work_8c_a4f1a1075c0def2e5d53ce4c28c05bedb.html#a4f1a1075c0def2e5d53ce4c28c05bedb":[2,0,3,3,1905,0],
+"da/df7/lapacke__zgetrf2__work_8c_source.html":[2,0,3,3,1905],
 "da/df9/clarfb_8f.html":[2,0,4,273],
 "da/df9/clarfb_8f_source.html":[2,0,4,273],
 "da/dfa/dlaexc_8f.html":[2,0,4,622],
 "da/dfa/dlaexc_8f_source.html":[2,0,4,622],
-"da/dfa/lapacke__cpbcon__work_8c.html":[2,0,3,3,355],
-"da/dfa/lapacke__cpbcon__work_8c_ae93a03e5b893887f3ce23f56407f0e50.html#ae93a03e5b893887f3ce23f56407f0e50":[2,0,3,3,355,0],
-"da/dfa/lapacke__cpbcon__work_8c_source.html":[2,0,3,3,355],
+"da/dfa/lapacke__cpbcon__work_8c.html":[2,0,3,3,357],
+"da/dfa/lapacke__cpbcon__work_8c_ae93a03e5b893887f3ce23f56407f0e50.html#ae93a03e5b893887f3ce23f56407f0e50":[2,0,3,3,357,0],
+"da/dfa/lapacke__cpbcon__work_8c_source.html":[2,0,3,3,357],
 "da/dfc/_v_a_r_i_a_n_t_s_2qr_2_l_l_2cgeqrf_8f.html":[2,0,4,1,2,0,0],
 "da/dfc/_v_a_r_i_a_n_t_s_2qr_2_l_l_2cgeqrf_8f_source.html":[2,0,4,1,2,0,0],
 "da/dfc/schkql_8f.html":[2,0,5,1,395],
@@ -132,96 +151,96 @@ var NAVTREEINDEX69 =
 "da/dfd/cstemr_8f_source.html":[2,0,4,365],
 "da/dfd/dlantp_8f.html":[2,0,4,652],
 "da/dfd/dlantp_8f_source.html":[2,0,4,652],
-"da/dfd/lapacke__dsteqr__work_8c.html":[2,0,3,3,1041],
-"da/dfd/lapacke__dsteqr__work_8c_a1b199e31309aeae1a58494a0236b28ed.html#a1b199e31309aeae1a58494a0236b28ed":[2,0,3,3,1041,0],
-"da/dfd/lapacke__dsteqr__work_8c_source.html":[2,0,3,3,1041],
-"da/dfe/lapacke__dtprfb__work_8c.html":[2,0,3,3,1167],
-"da/dfe/lapacke__dtprfb__work_8c_ae507d90186f0e0a3bca0030ce1a096a8.html#ae507d90186f0e0a3bca0030ce1a096a8":[2,0,3,3,1167,0],
-"da/dfe/lapacke__dtprfb__work_8c_source.html":[2,0,3,3,1167],
+"da/dfd/lapacke__dsteqr__work_8c.html":[2,0,3,3,1045],
+"da/dfd/lapacke__dsteqr__work_8c_a1b199e31309aeae1a58494a0236b28ed.html#a1b199e31309aeae1a58494a0236b28ed":[2,0,3,3,1045,0],
+"da/dfd/lapacke__dsteqr__work_8c_source.html":[2,0,3,3,1045],
+"da/dfe/lapacke__dtprfb__work_8c.html":[2,0,3,3,1171],
+"da/dfe/lapacke__dtprfb__work_8c_ae507d90186f0e0a3bca0030ce1a096a8.html#ae507d90186f0e0a3bca0030ce1a096a8":[2,0,3,3,1171,0],
+"da/dfe/lapacke__dtprfb__work_8c_source.html":[2,0,3,3,1171],
 "da/dff/group__complex_s_ycomputational.html":[0,0,2,2,2],
 "da/dff/group__complex_s_ycomputational_ga076074a11ac1385855e8efe9cc3ca048.html#ga076074a11ac1385855e8efe9cc3ca048":[0,0,2,2,2,16],
 "da/dff/group__complex_s_ycomputational_ga076074a11ac1385855e8efe9cc3ca048.html#ga076074a11ac1385855e8efe9cc3ca048":[2,0,4,373,0],
+"da/dff/group__complex_s_ycomputational_ga0da0534f2f1e9be1670bf62a60274a8c.html#ga0da0534f2f1e9be1670bf62a60274a8c":[0,0,2,2,2,38],
+"da/dff/group__complex_s_ycomputational_ga0da0534f2f1e9be1670bf62a60274a8c.html#ga0da0534f2f1e9be1670bf62a60274a8c":[2,0,4,438,0],
 "da/dff/group__complex_s_ycomputational_ga0f12a3d0375451dcb483147e125665a1.html#ga0f12a3d0375451dcb483147e125665a1":[0,0,2,2,2,19],
 "da/dff/group__complex_s_ycomputational_ga0f12a3d0375451dcb483147e125665a1.html#ga0f12a3d0375451dcb483147e125665a1":[2,0,4,385,0],
-"da/dff/group__complex_s_ycomputational_ga10960cfda3c0aeeae0d985053b5bfe5a.html#ga10960cfda3c0aeeae0d985053b5bfe5a":[2,0,4,417,0],
-"da/dff/group__complex_s_ycomputational_ga10960cfda3c0aeeae0d985053b5bfe5a.html#ga10960cfda3c0aeeae0d985053b5bfe5a":[0,0,2,2,2,37],
-"da/dff/group__complex_s_ycomputational_ga1486a4b3b1275af7d4d92fdb4396a4f6.html#ga1486a4b3b1275af7d4d92fdb4396a4f6":[0,0,2,2,2,36],
-"da/dff/group__complex_s_ycomputational_ga1486a4b3b1275af7d4d92fdb4396a4f6.html#ga1486a4b3b1275af7d4d92fdb4396a4f6":[2,0,4,402,0],
-"da/dff/group__complex_s_ycomputational_ga199cd084bf5a1a733adb8f2073dc7ec2.html#ga199cd084bf5a1a733adb8f2073dc7ec2":[0,0,2,2,2,38],
-"da/dff/group__complex_s_ycomputational_ga199cd084bf5a1a733adb8f2073dc7ec2.html#ga199cd084bf5a1a733adb8f2073dc7ec2":[2,0,4,438,0],
-"da/dff/group__complex_s_ycomputational_ga1a6f222329bc1748a27dbf1c7828a6b1.html#ga1a6f222329bc1748a27dbf1c7828a6b1":[0,0,2,2,2,24],
-"da/dff/group__complex_s_ycomputational_ga1a6f222329bc1748a27dbf1c7828a6b1.html#ga1a6f222329bc1748a27dbf1c7828a6b1":[2,0,4,390,0],
-"da/dff/group__complex_s_ycomputational_ga1df28adabe677e3b1974a66b7d252603.html#ga1df28adabe677e3b1974a66b7d252603":[2,0,4,296,0],
-"da/dff/group__complex_s_ycomputational_ga1df28adabe677e3b1974a66b7d252603.html#ga1df28adabe677e3b1974a66b7d252603":[0,0,2,2,2,7],
-"da/dff/group__complex_s_ycomputational_ga203400191e31546208e8f2ee50023125.html#ga203400191e31546208e8f2ee50023125":[0,0,2,2,2,0],
-"da/dff/group__complex_s_ycomputational_ga203400191e31546208e8f2ee50023125.html#ga203400191e31546208e8f2ee50023125":[2,0,4,199,0],
-"da/dff/group__complex_s_ycomputational_ga289f1d773d9af1fcc3a54dbf704e93c6.html#ga289f1d773d9af1fcc3a54dbf704e93c6":[0,0,2,2,2,29],
-"da/dff/group__complex_s_ycomputational_ga289f1d773d9af1fcc3a54dbf704e93c6.html#ga289f1d773d9af1fcc3a54dbf704e93c6":[2,0,4,395,0],
+"da/dff/group__complex_s_ycomputational_ga0f93ca9ab2fc02b8de5f578316353b87.html#ga0f93ca9ab2fc02b8de5f578316353b87":[0,0,2,2,2,18],
+"da/dff/group__complex_s_ycomputational_ga0f93ca9ab2fc02b8de5f578316353b87.html#ga0f93ca9ab2fc02b8de5f578316353b87":[2,0,4,377,0],
+"da/dff/group__complex_s_ycomputational_ga113d1d314f674eb00b05547429716515.html#ga113d1d314f674eb00b05547429716515":[2,0,4,202,0],
+"da/dff/group__complex_s_ycomputational_ga113d1d314f674eb00b05547429716515.html#ga113d1d314f674eb00b05547429716515":[0,0,2,2,2,3],
+"da/dff/group__complex_s_ycomputational_ga12f53031b5c662c050106452af5f2d93.html#ga12f53031b5c662c050106452af5f2d93":[0,0,2,2,2,35],
+"da/dff/group__complex_s_ycomputational_ga12f53031b5c662c050106452af5f2d93.html#ga12f53031b5c662c050106452af5f2d93":[2,0,4,401,0],
+"da/dff/group__complex_s_ycomputational_ga1d5b0252ad96edd8494a10d06eb97482.html#ga1d5b0252ad96edd8494a10d06eb97482":[0,0,2,2,2,17],
+"da/dff/group__complex_s_ycomputational_ga1d5b0252ad96edd8494a10d06eb97482.html#ga1d5b0252ad96edd8494a10d06eb97482":[2,0,4,376,0],
+"da/dff/group__complex_s_ycomputational_ga26da8d6aacbabc9792e7d456f1317238.html#ga26da8d6aacbabc9792e7d456f1317238":[0,0,2,2,2,1],
+"da/dff/group__complex_s_ycomputational_ga26da8d6aacbabc9792e7d456f1317238.html#ga26da8d6aacbabc9792e7d456f1317238":[2,0,4,200,0],
+"da/dff/group__complex_s_ycomputational_ga2b5b978f7ae256e0174ce1df690aa5f1.html#ga2b5b978f7ae256e0174ce1df690aa5f1":[0,0,2,2,2,12],
+"da/dff/group__complex_s_ycomputational_ga2b5b978f7ae256e0174ce1df690aa5f1.html#ga2b5b978f7ae256e0174ce1df690aa5f1":[2,0,4,369,0],
 "da/dff/group__complex_s_ycomputational_ga2d7c0e6bd15ea0feb3e19156fd6222ef.html#ga2d7c0e6bd15ea0feb3e19156fd6222ef":[0,0,2,2,2,27],
 "da/dff/group__complex_s_ycomputational_ga2d7c0e6bd15ea0feb3e19156fd6222ef.html#ga2d7c0e6bd15ea0feb3e19156fd6222ef":[2,0,4,393,0],
-"da/dff/group__complex_s_ycomputational_ga37233e061812d93146d7485d191a4eae.html#ga37233e061812d93146d7485d191a4eae":[0,0,2,2,2,10],
-"da/dff/group__complex_s_ycomputational_ga37233e061812d93146d7485d191a4eae.html#ga37233e061812d93146d7485d191a4eae":[2,0,4,367,0],
+"da/dff/group__complex_s_ycomputational_ga2effd037ac49e21caf28a78b063f41a3.html#ga2effd037ac49e21caf28a78b063f41a3":[0,0,2,2,2,0],
+"da/dff/group__complex_s_ycomputational_ga2effd037ac49e21caf28a78b063f41a3.html#ga2effd037ac49e21caf28a78b063f41a3":[2,0,4,199,0],
+"da/dff/group__complex_s_ycomputational_ga3402040636f0ebdb6510b2b2820c7b25.html#ga3402040636f0ebdb6510b2b2820c7b25":[2,0,4,395,0],
+"da/dff/group__complex_s_ycomputational_ga3402040636f0ebdb6510b2b2820c7b25.html#ga3402040636f0ebdb6510b2b2820c7b25":[0,0,2,2,2,29],
 "da/dff/group__complex_s_ycomputational_ga3c11429e2e0abc1d273478856b74d5e3.html#ga3c11429e2e0abc1d273478856b74d5e3":[0,0,2,2,2,20],
 "da/dff/group__complex_s_ycomputational_ga3c11429e2e0abc1d273478856b74d5e3.html#ga3c11429e2e0abc1d273478856b74d5e3":[2,0,4,386,0],
-"da/dff/group__complex_s_ycomputational_ga4cdfd3792dc33f48966d47a117f416a0.html#ga4cdfd3792dc33f48966d47a117f416a0":[0,0,2,2,2,34],
-"da/dff/group__complex_s_ycomputational_ga4cdfd3792dc33f48966d47a117f416a0.html#ga4cdfd3792dc33f48966d47a117f416a0":[2,0,4,400,0],
-"da/dff/group__complex_s_ycomputational_ga514923aecf24449d42b0bf1311f50ea5.html#ga514923aecf24449d42b0bf1311f50ea5":[0,0,2,2,2,17],
-"da/dff/group__complex_s_ycomputational_ga514923aecf24449d42b0bf1311f50ea5.html#ga514923aecf24449d42b0bf1311f50ea5":[2,0,4,376,0],
-"da/dff/group__complex_s_ycomputational_ga525e6b7b04c6e3d0a86fd22f463f8a61.html#ga525e6b7b04c6e3d0a86fd22f463f8a61":[0,0,2,2,2,13],
+"da/dff/group__complex_s_ycomputational_ga42a41ab8eb74337350d74dd39d3cd564.html#ga42a41ab8eb74337350d74dd39d3cd564":[0,0,2,2,2,11],
+"da/dff/group__complex_s_ycomputational_ga42a41ab8eb74337350d74dd39d3cd564.html#ga42a41ab8eb74337350d74dd39d3cd564":[2,0,4,368,0],
+"da/dff/group__complex_s_ycomputational_ga4ede0bcbc69ca218b7b286e767577220.html#ga4ede0bcbc69ca218b7b286e767577220":[0,0,2,2,2,36],
+"da/dff/group__complex_s_ycomputational_ga4ede0bcbc69ca218b7b286e767577220.html#ga4ede0bcbc69ca218b7b286e767577220":[2,0,4,402,0],
 "da/dff/group__complex_s_ycomputational_ga525e6b7b04c6e3d0a86fd22f463f8a61.html#ga525e6b7b04c6e3d0a86fd22f463f8a61":[2,0,4,370,0],
-"da/dff/group__complex_s_ycomputational_ga53ada38e8d3ca62ce8dba585dc105a45.html#ga53ada38e8d3ca62ce8dba585dc105a45":[0,0,2,2,2,35],
-"da/dff/group__complex_s_ycomputational_ga53ada38e8d3ca62ce8dba585dc105a45.html#ga53ada38e8d3ca62ce8dba585dc105a45":[2,0,4,401,0],
-"da/dff/group__complex_s_ycomputational_ga579740b5c73f8f686c93d9cc9d74bb95.html#ga579740b5c73f8f686c93d9cc9d74bb95":[0,0,2,2,2,33],
-"da/dff/group__complex_s_ycomputational_ga579740b5c73f8f686c93d9cc9d74bb95.html#ga579740b5c73f8f686c93d9cc9d74bb95":[2,0,4,399,0],
-"da/dff/group__complex_s_ycomputational_ga5d25357c736b25b4db16640ae711dcd6.html#ga5d25357c736b25b4db16640ae711dcd6":[0,0,2,2,2,1],
-"da/dff/group__complex_s_ycomputational_ga5d25357c736b25b4db16640ae711dcd6.html#ga5d25357c736b25b4db16640ae711dcd6":[2,0,4,200,0],
-"da/dff/group__complex_s_ycomputational_ga652dad3ec5efe416466f2b634a0b7398.html#ga652dad3ec5efe416466f2b634a0b7398":[0,0,2,2,2,23],
+"da/dff/group__complex_s_ycomputational_ga525e6b7b04c6e3d0a86fd22f463f8a61.html#ga525e6b7b04c6e3d0a86fd22f463f8a61":[0,0,2,2,2,13],
 "da/dff/group__complex_s_ycomputational_ga652dad3ec5efe416466f2b634a0b7398.html#ga652dad3ec5efe416466f2b634a0b7398":[2,0,4,389,0],
+"da/dff/group__complex_s_ycomputational_ga652dad3ec5efe416466f2b634a0b7398.html#ga652dad3ec5efe416466f2b634a0b7398":[0,0,2,2,2,23],
 "da/dff/group__complex_s_ycomputational_ga6ae55c9045ed09e937098d79f7ab3b0f.html#ga6ae55c9045ed09e937098d79f7ab3b0f":[0,0,2,2,2,6],
 "da/dff/group__complex_s_ycomputational_ga6ae55c9045ed09e937098d79f7ab3b0f.html#ga6ae55c9045ed09e937098d79f7ab3b0f":[2,0,4,295,0],
-"da/dff/group__complex_s_ycomputational_ga6d1d109f0d4440affd318fa7714a0b2c.html#ga6d1d109f0d4440affd318fa7714a0b2c":[0,0,2,2,2,3],
-"da/dff/group__complex_s_ycomputational_ga6d1d109f0d4440affd318fa7714a0b2c.html#ga6d1d109f0d4440affd318fa7714a0b2c":[2,0,4,202,0],
-"da/dff/group__complex_s_ycomputational_ga7f05f7e397f26b4b909379193f3530ab.html#ga7f05f7e397f26b4b909379193f3530ab":[2,0,4,392,0],
+"da/dff/group__complex_s_ycomputational_ga6ec6eb2e72afc7323c5125bce19473dc.html#ga6ec6eb2e72afc7323c5125bce19473dc":[0,0,2,2,2,10],
+"da/dff/group__complex_s_ycomputational_ga6ec6eb2e72afc7323c5125bce19473dc.html#ga6ec6eb2e72afc7323c5125bce19473dc":[2,0,4,367,0],
 "da/dff/group__complex_s_ycomputational_ga7f05f7e397f26b4b909379193f3530ab.html#ga7f05f7e397f26b4b909379193f3530ab":[0,0,2,2,2,26],
-"da/dff/group__complex_s_ycomputational_ga95c3b8bdb7e9ac2e51529140f010037c.html#ga95c3b8bdb7e9ac2e51529140f010037c":[0,0,2,2,2,5],
-"da/dff/group__complex_s_ycomputational_ga95c3b8bdb7e9ac2e51529140f010037c.html#ga95c3b8bdb7e9ac2e51529140f010037c":[2,0,4,224,0],
+"da/dff/group__complex_s_ycomputational_ga7f05f7e397f26b4b909379193f3530ab.html#ga7f05f7e397f26b4b909379193f3530ab":[2,0,4,392,0],
+"da/dff/group__complex_s_ycomputational_ga83c04c706f23cb68b4243cf7a40db229.html#ga83c04c706f23cb68b4243cf7a40db229":[0,0,2,2,2,33],
+"da/dff/group__complex_s_ycomputational_ga83c04c706f23cb68b4243cf7a40db229.html#ga83c04c706f23cb68b4243cf7a40db229":[2,0,4,399,0],
+"da/dff/group__complex_s_ycomputational_ga8ab617e2baa9fc9c4728d8cbd1bfde70.html#ga8ab617e2baa9fc9c4728d8cbd1bfde70":[0,0,2,2,2,9],
+"da/dff/group__complex_s_ycomputational_ga8ab617e2baa9fc9c4728d8cbd1bfde70.html#ga8ab617e2baa9fc9c4728d8cbd1bfde70":[2,0,4,298,0],
+"da/dff/group__complex_s_ycomputational_ga92d8371d36124d4439f63473ee47854b.html#ga92d8371d36124d4439f63473ee47854b":[0,0,2,2,2,4],
+"da/dff/group__complex_s_ycomputational_ga92d8371d36124d4439f63473ee47854b.html#ga92d8371d36124d4439f63473ee47854b":[2,0,4,203,0],
+"da/dff/group__complex_s_ycomputational_ga93458339ea93230f0ad25a86910af28a.html#ga93458339ea93230f0ad25a86910af28a":[0,0,2,2,2,2],
+"da/dff/group__complex_s_ycomputational_ga93458339ea93230f0ad25a86910af28a.html#ga93458339ea93230f0ad25a86910af28a":[2,0,4,201,0],
 "da/dff/group__complex_s_ycomputational_ga9baea00306a19fc23c46b5052f4168f7.html#ga9baea00306a19fc23c46b5052f4168f7":[0,0,2,2,2,21],
 "da/dff/group__complex_s_ycomputational_ga9baea00306a19fc23c46b5052f4168f7.html#ga9baea00306a19fc23c46b5052f4168f7":[2,0,4,387,0],
 "da/dff/group__complex_s_ycomputational_gaaa37e0850860440f4893fef9d5f815d5.html#gaaa37e0850860440f4893fef9d5f815d5":[0,0,2,2,2,25],
 "da/dff/group__complex_s_ycomputational_gaaa37e0850860440f4893fef9d5f815d5.html#gaaa37e0850860440f4893fef9d5f815d5":[2,0,4,391,0],
+"da/dff/group__complex_s_ycomputational_gaab727615e3d598e9e28a14978d5ca759.html#gaab727615e3d598e9e28a14978d5ca759":[0,0,2,2,2,7],
+"da/dff/group__complex_s_ycomputational_gaab727615e3d598e9e28a14978d5ca759.html#gaab727615e3d598e9e28a14978d5ca759":[2,0,4,296,0],
 "da/dff/group__complex_s_ycomputational_gaab94d207da90a7fc4248793bbce9d803.html#gaab94d207da90a7fc4248793bbce9d803":[0,0,2,2,2,30],
 "da/dff/group__complex_s_ycomputational_gaab94d207da90a7fc4248793bbce9d803.html#gaab94d207da90a7fc4248793bbce9d803":[2,0,4,396,0],
-"da/dff/group__complex_s_ycomputational_gab601ed5a5c4b9ff770ab51eff784aba5.html#gab601ed5a5c4b9ff770ab51eff784aba5":[2,0,4,203,0],
-"da/dff/group__complex_s_ycomputational_gab601ed5a5c4b9ff770ab51eff784aba5.html#gab601ed5a5c4b9ff770ab51eff784aba5":[0,0,2,2,2,4],
+"da/dff/group__complex_s_ycomputational_gaaddd0c600d154a354ed3aab9dbe538d7.html#gaaddd0c600d154a354ed3aab9dbe538d7":[2,0,4,297,0],
+"da/dff/group__complex_s_ycomputational_gaaddd0c600d154a354ed3aab9dbe538d7.html#gaaddd0c600d154a354ed3aab9dbe538d7":[0,0,2,2,2,8],
 "da/dff/group__complex_s_ycomputational_gabce9144e260f297b4424e543a9a263ec.html#gabce9144e260f297b4424e543a9a263ec":[0,0,2,2,2,15],
 "da/dff/group__complex_s_ycomputational_gabce9144e260f297b4424e543a9a263ec.html#gabce9144e260f297b4424e543a9a263ec":[2,0,4,372,0],
 "da/dff/group__complex_s_ycomputational_gabd38670b8caa9c8b2f0be9f0a7c14e38.html#gabd38670b8caa9c8b2f0be9f0a7c14e38":[0,0,2,2,2,32],
 "da/dff/group__complex_s_ycomputational_gabd38670b8caa9c8b2f0be9f0a7c14e38.html#gabd38670b8caa9c8b2f0be9f0a7c14e38":[2,0,4,398,0],
-"da/dff/group__complex_s_ycomputational_gac4ac19ee6fd3145bf802dc89160f046b.html#gac4ac19ee6fd3145bf802dc89160f046b":[2,0,4,297,0],
-"da/dff/group__complex_s_ycomputational_gac4ac19ee6fd3145bf802dc89160f046b.html#gac4ac19ee6fd3145bf802dc89160f046b":[0,0,2,2,2,8],
 "da/dff/group__complex_s_ycomputational_gacd5839d735315079d2ecc8afc9402352.html#gacd5839d735315079d2ecc8afc9402352":[0,0,2,2,2,22],
 "da/dff/group__complex_s_ycomputational_gacd5839d735315079d2ecc8afc9402352.html#gacd5839d735315079d2ecc8afc9402352":[2,0,4,388,0],
-"da/dff/group__complex_s_ycomputational_gad07e9fd6c895d5ed717eb2394f8ec55b.html#gad07e9fd6c895d5ed717eb2394f8ec55b":[0,0,2,2,2,11],
-"da/dff/group__complex_s_ycomputational_gad07e9fd6c895d5ed717eb2394f8ec55b.html#gad07e9fd6c895d5ed717eb2394f8ec55b":[2,0,4,368,0],
-"da/dff/group__complex_s_ycomputational_gad6f44e301fddef5f0c93421ea13f576e.html#gad6f44e301fddef5f0c93421ea13f576e":[0,0,2,2,2,18],
-"da/dff/group__complex_s_ycomputational_gad6f44e301fddef5f0c93421ea13f576e.html#gad6f44e301fddef5f0c93421ea13f576e":[2,0,4,377,0],
 "da/dff/group__complex_s_ycomputational_gad885e99b62087bfc142f1ca6e51f6941.html#gad885e99b62087bfc142f1ca6e51f6941":[0,0,2,2,2,28],
 "da/dff/group__complex_s_ycomputational_gad885e99b62087bfc142f1ca6e51f6941.html#gad885e99b62087bfc142f1ca6e51f6941":[2,0,4,394,0],
-"da/dff/group__complex_s_ycomputational_gaddc67fa72343787eebcd527f21a4c112.html#gaddc67fa72343787eebcd527f21a4c112":[0,0,2,2,2,12],
-"da/dff/group__complex_s_ycomputational_gaddc67fa72343787eebcd527f21a4c112.html#gaddc67fa72343787eebcd527f21a4c112":[2,0,4,369,0],
-"da/dff/group__complex_s_ycomputational_gaddedc7be67d858405bb3bbdd98b779b6.html#gaddedc7be67d858405bb3bbdd98b779b6":[2,0,4,371,0],
+"da/dff/group__complex_s_ycomputational_gad8ebf2778aa871f9f2efc3cea43af789.html#gad8ebf2778aa871f9f2efc3cea43af789":[0,0,2,2,2,24],
+"da/dff/group__complex_s_ycomputational_gad8ebf2778aa871f9f2efc3cea43af789.html#gad8ebf2778aa871f9f2efc3cea43af789":[2,0,4,390,0],
 "da/dff/group__complex_s_ycomputational_gaddedc7be67d858405bb3bbdd98b779b6.html#gaddedc7be67d858405bb3bbdd98b779b6":[0,0,2,2,2,14],
-"da/dff/group__complex_s_ycomputational_gae2db0c6baec4576cb42b5d0ee55714b1.html#gae2db0c6baec4576cb42b5d0ee55714b1":[0,0,2,2,2,2],
-"da/dff/group__complex_s_ycomputational_gae2db0c6baec4576cb42b5d0ee55714b1.html#gae2db0c6baec4576cb42b5d0ee55714b1":[2,0,4,201,0],
-"da/dff/group__complex_s_ycomputational_gaf27d1dc318a9f5633222699afa5b984a.html#gaf27d1dc318a9f5633222699afa5b984a":[0,0,2,2,2,9],
-"da/dff/group__complex_s_ycomputational_gaf27d1dc318a9f5633222699afa5b984a.html#gaf27d1dc318a9f5633222699afa5b984a":[2,0,4,298,0],
+"da/dff/group__complex_s_ycomputational_gaddedc7be67d858405bb3bbdd98b779b6.html#gaddedc7be67d858405bb3bbdd98b779b6":[2,0,4,371,0],
+"da/dff/group__complex_s_ycomputational_gaef7add4f653067c9b3e44569e6766d95.html#gaef7add4f653067c9b3e44569e6766d95":[0,0,2,2,2,37],
+"da/dff/group__complex_s_ycomputational_gaef7add4f653067c9b3e44569e6766d95.html#gaef7add4f653067c9b3e44569e6766d95":[2,0,4,417,0],
+"da/dff/group__complex_s_ycomputational_gaf000d2b89e57201eeb048c5ba949039b.html#gaf000d2b89e57201eeb048c5ba949039b":[0,0,2,2,2,5],
+"da/dff/group__complex_s_ycomputational_gaf000d2b89e57201eeb048c5ba949039b.html#gaf000d2b89e57201eeb048c5ba949039b":[2,0,4,224,0],
 "da/dff/group__complex_s_ycomputational_gafb343bb24f1cd1459070aeff219956ad.html#gafb343bb24f1cd1459070aeff219956ad":[0,0,2,2,2,31],
 "da/dff/group__complex_s_ycomputational_gafb343bb24f1cd1459070aeff219956ad.html#gafb343bb24f1cd1459070aeff219956ad":[2,0,4,397,0],
+"da/dff/group__complex_s_ycomputational_gafcf66602434cd99d92d69e74177d78db.html#gafcf66602434cd99d92d69e74177d78db":[0,0,2,2,2,34],
+"da/dff/group__complex_s_ycomputational_gafcf66602434cd99d92d69e74177d78db.html#gafcf66602434cd99d92d69e74177d78db":[2,0,4,400,0],
 "da/dff/sgbt01_8f.html":[2,0,5,1,458],
 "da/dff/sgbt01_8f_source.html":[2,0,5,1,458],
-"db/d00/lapacke__sgeqp3_8c.html":[2,0,3,3,1281],
-"db/d00/lapacke__sgeqp3_8c_a61aca10c79bd5c2089518ce987725f75.html#a61aca10c79bd5c2089518ce987725f75":[2,0,3,3,1281,0],
-"db/d00/lapacke__sgeqp3_8c_source.html":[2,0,3,3,1281],
+"db/d00/lapacke__sgeqp3_8c.html":[2,0,3,3,1285],
+"db/d00/lapacke__sgeqp3_8c_a61aca10c79bd5c2089518ce987725f75.html#a61aca10c79bd5c2089518ce987725f75":[2,0,3,3,1285,0],
+"db/d00/lapacke__sgeqp3_8c_source.html":[2,0,3,3,1285],
 "db/d01/chbtrd_8f.html":[2,0,4,109],
 "db/d01/chbtrd_8f_source.html":[2,0,4,109],
 "db/d01/zerrpo_8f.html":[2,0,5,1,630],
@@ -230,24 +249,5 @@ var NAVTREEINDEX69 =
 "db/d02/cgtsvx_8f_source.html":[2,0,4,94],
 "db/d03/ctftri_8f.html":[2,0,4,407],
 "db/d03/ctftri_8f_source.html":[2,0,4,407],
-"db/d03/lapacke__chbevd__2stage_8c.html":[2,0,3,3,175],
-"db/d03/lapacke__chbevd__2stage_8c_a075bc2633e0be9d5faca468f25cba19c.html#a075bc2633e0be9d5faca468f25cba19c":[2,0,3,3,175,0],
-"db/d03/lapacke__chbevd__2stage_8c_source.html":[2,0,3,3,175],
-"db/d04/lapacke__zpt__nancheck_8c.html":[2,0,3,4,134],
-"db/d04/lapacke__zpt__nancheck_8c_a0b0a8619f55f06a99dcf61234149d0c3.html#a0b0a8619f55f06a99dcf61234149d0c3":[2,0,3,4,134,0],
-"db/d04/lapacke__zpt__nancheck_8c_source.html":[2,0,3,4,134],
-"db/d06/lapacke__sspgst__work_8c.html":[2,0,3,3,1588],
-"db/d06/lapacke__sspgst__work_8c_af6f23ffd703223deafd6abc245d09d41.html#af6f23ffd703223deafd6abc245d09d41":[2,0,3,3,1588,0],
-"db/d06/lapacke__sspgst__work_8c_source.html":[2,0,3,3,1588],
-"db/d07/lapacke__dstevx_8c.html":[2,0,3,3,1050],
-"db/d07/lapacke__dstevx_8c_a708289b83eb3e0e1f5e5150ac0f93342.html#a708289b83eb3e0e1f5e5150ac0f93342":[2,0,3,3,1050,0],
-"db/d07/lapacke__dstevx_8c_source.html":[2,0,3,3,1050],
-"db/d08/clacrm_8f.html":[2,0,4,211],
-"db/d08/clacrm_8f_source.html":[2,0,4,211],
-"db/d08/lapacke__sgetf2_8c.html":[2,0,3,3,1319],
-"db/d08/lapacke__sgetf2_8c_ac4357d82662dfa556cfc8850e43feb01.html#ac4357d82662dfa556cfc8850e43feb01":[2,0,3,3,1319,0],
-"db/d08/lapacke__sgetf2_8c_source.html":[2,0,3,3,1319],
-"db/d08/schkpo_8f.html":[2,0,5,1,390],
-"db/d08/schkpo_8f_source.html":[2,0,5,1,390],
-"db/d0b/cblas__saxpy_8c.html":[2,0,1,2,75]
+"db/d03/lapacke__chbevd__2stage_8c.html":[2,0,3,3,175]
 };
