@@ -1,21 +1,40 @@
 var NAVTREEINDEX73 =
 {
+"db/db2/zpttrf_8f_source.html":[2,0,4,1811],
+"db/db3/dlasd7_8f.html":[2,0,4,714],
+"db/db3/dlasd7_8f_source.html":[2,0,4,714],
+"db/db3/lapacke__cgemqrt__work_8c.html":[2,0,3,3,69],
+"db/db3/lapacke__cgemqrt__work_8c_a20bb416e88dec0f088a4227e20733586.html#a20bb416e88dec0f088a4227e20733586":[2,0,3,3,69,0],
+"db/db3/lapacke__cgemqrt__work_8c_source.html":[2,0,3,3,69],
+"db/db4/clarft_8f.html":[2,0,4,276],
+"db/db4/clarft_8f_source.html":[2,0,4,276],
+"db/db4/dgesdd_8f.html":[2,0,4,541],
+"db/db4/dgesdd_8f_source.html":[2,0,4,541],
+"db/db5/lapacke__chpgst_8c.html":[2,0,3,3,280],
+"db/db5/lapacke__chpgst_8c_afab06212402f3341a6020f83ee029060.html#afab06212402f3341a6020f83ee029060":[2,0,3,3,280,0],
+"db/db5/lapacke__chpgst_8c_source.html":[2,0,3,3,280],
+"db/db6/lapacke__sgglse__work_8c.html":[2,0,3,3,1358],
+"db/db6/lapacke__sgglse__work_8c_a099f9d649a429966151ebc2ce90523c3.html#a099f9d649a429966151ebc2ce90523c3":[2,0,3,3,1358,0],
+"db/db6/lapacke__sgglse__work_8c_source.html":[2,0,3,3,1358],
+"db/db6/lapacke__zgglse_8c.html":[2,0,3,3,1935],
+"db/db6/lapacke__zgglse_8c_ab9afa51cf9d1111ea9434e827f88f80b.html#ab9afa51cf9d1111ea9434e827f88f80b":[2,0,3,3,1935,0],
+"db/db6/lapacke__zgglse_8c_source.html":[2,0,3,3,1935],
 "db/db8/dtptrs_8f.html":[2,0,4,945],
 "db/db8/dtptrs_8f_source.html":[2,0,4,945],
-"db/dba/lapacke__sposvxx_8c.html":[2,0,3,3,1513],
-"db/dba/lapacke__sposvxx_8c_a9f0010eb50e42f478b56a7acba4ec312.html#a9f0010eb50e42f478b56a7acba4ec312":[2,0,3,3,1513,0],
-"db/dba/lapacke__sposvxx_8c_source.html":[2,0,3,3,1513],
-"db/dba/lapacke__ssbgv_8c.html":[2,0,3,3,1569],
-"db/dba/lapacke__ssbgv_8c_af25c4961fcd11aca38b9ae274a354559.html#af25c4961fcd11aca38b9ae274a354559":[2,0,3,3,1569,0],
-"db/dba/lapacke__ssbgv_8c_source.html":[2,0,3,3,1569],
-"db/dba/lapacke__ssygst__work_8c.html":[2,0,3,3,1656],
-"db/dba/lapacke__ssygst__work_8c_abc183df3c15f265273c0c2bb4bfbb4a4.html#abc183df3c15f265273c0c2bb4bfbb4a4":[2,0,3,3,1656,0],
-"db/dba/lapacke__ssygst__work_8c_source.html":[2,0,3,3,1656],
-"db/dba/zpstrf_8f.html":[2,0,4,1806],
-"db/dba/zpstrf_8f_source.html":[2,0,4,1806],
-"db/dbd/lapacke__stpttf__work_8c.html":[2,0,3,3,1754],
-"db/dbd/lapacke__stpttf__work_8c_a2b9c3e8d6e30ba85de32623c2ee1bf76.html#a2b9c3e8d6e30ba85de32623c2ee1bf76":[2,0,3,3,1754,0],
-"db/dbd/lapacke__stpttf__work_8c_source.html":[2,0,3,3,1754],
+"db/dba/lapacke__sposvxx_8c.html":[2,0,3,3,1519],
+"db/dba/lapacke__sposvxx_8c_a9f0010eb50e42f478b56a7acba4ec312.html#a9f0010eb50e42f478b56a7acba4ec312":[2,0,3,3,1519,0],
+"db/dba/lapacke__sposvxx_8c_source.html":[2,0,3,3,1519],
+"db/dba/lapacke__ssbgv_8c.html":[2,0,3,3,1575],
+"db/dba/lapacke__ssbgv_8c_af25c4961fcd11aca38b9ae274a354559.html#af25c4961fcd11aca38b9ae274a354559":[2,0,3,3,1575,0],
+"db/dba/lapacke__ssbgv_8c_source.html":[2,0,3,3,1575],
+"db/dba/lapacke__ssygst__work_8c.html":[2,0,3,3,1662],
+"db/dba/lapacke__ssygst__work_8c_abc183df3c15f265273c0c2bb4bfbb4a4.html#abc183df3c15f265273c0c2bb4bfbb4a4":[2,0,3,3,1662,0],
+"db/dba/lapacke__ssygst__work_8c_source.html":[2,0,3,3,1662],
+"db/dba/zpstrf_8f.html":[2,0,4,1805],
+"db/dba/zpstrf_8f_source.html":[2,0,4,1805],
+"db/dbd/lapacke__stpttf__work_8c.html":[2,0,3,3,1760],
+"db/dbd/lapacke__stpttf__work_8c_a2b9c3e8d6e30ba85de32623c2ee1bf76.html#a2b9c3e8d6e30ba85de32623c2ee1bf76":[2,0,3,3,1760,0],
+"db/dbd/lapacke__stpttf__work_8c_source.html":[2,0,3,3,1760],
 "db/dbf/csytrs__3_8f.html":[2,0,4,400],
 "db/dbf/csytrs__3_8f_source.html":[2,0,4,400],
 "db/dbf/lapacke__sgg__nancheck_8c.html":[2,0,3,4,80],
@@ -23,9 +42,9 @@ var NAVTREEINDEX73 =
 "db/dbf/lapacke__sgg__nancheck_8c_source.html":[2,0,3,4,80],
 "db/dc0/dlqt02_8f.html":[2,0,5,1,316],
 "db/dc0/dlqt02_8f_source.html":[2,0,5,1,316],
-"db/dc0/lapacke__ctpttf_8c.html":[2,0,3,3,552],
-"db/dc0/lapacke__ctpttf_8c_a1aac7b4d01fea403ee4c5b0070e5bf82.html#a1aac7b4d01fea403ee4c5b0070e5bf82":[2,0,3,3,552,0],
-"db/dc0/lapacke__ctpttf_8c_source.html":[2,0,3,3,552],
+"db/dc0/lapacke__ctpttf_8c.html":[2,0,3,3,554],
+"db/dc0/lapacke__ctpttf_8c_a1aac7b4d01fea403ee4c5b0070e5bf82.html#a1aac7b4d01fea403ee4c5b0070e5bf82":[2,0,3,3,554,0],
+"db/dc0/lapacke__ctpttf_8c_source.html":[2,0,3,3,554],
 "db/dc2/cblas__cher_8c.html":[2,0,1,2,12],
 "db/dc2/cblas__cher_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[2,0,1,2,12,0],
 "db/dc2/cblas__cher_8c_a1bbf6616ae8c06cb6a67e5799b6a6000.html#a1bbf6616ae8c06cb6a67e5799b6a6000":[2,0,1,2,12,4],
@@ -40,9 +59,9 @@ var NAVTREEINDEX73 =
 "db/dc4/lapacke__example__aux_8c_aca4a7f245594ed0dceb562747019aa23.html#aca4a7f245594ed0dceb562747019aa23":[2,0,3,0,5,2],
 "db/dc4/lapacke__example__aux_8c_aea6079ddbe35ed06b9550a0680179643.html#aea6079ddbe35ed06b9550a0680179643":[2,0,3,0,5,0],
 "db/dc4/lapacke__example__aux_8c_source.html":[2,0,3,0,5],
-"db/dc4/lapacke__zlantr__work_8c.html":[2,0,3,3,2114],
-"db/dc4/lapacke__zlantr__work_8c_ab3443e61206e88709af576b9fac61b79.html#ab3443e61206e88709af576b9fac61b79":[2,0,3,3,2114,0],
-"db/dc4/lapacke__zlantr__work_8c_source.html":[2,0,3,3,2114],
+"db/dc4/lapacke__zlantr__work_8c.html":[2,0,3,3,2120],
+"db/dc4/lapacke__zlantr__work_8c_ab3443e61206e88709af576b9fac61b79.html#ab3443e61206e88709af576b9fac61b79":[2,0,3,3,2120,0],
+"db/dc4/lapacke__zlantr__work_8c_source.html":[2,0,3,3,2120],
 "db/dc4/ssyt22_8f.html":[2,0,5,0,274],
 "db/dc4/ssyt22_8f_source.html":[2,0,5,0,274],
 "db/dc5/cblas__ctpmv_8c.html":[2,0,1,2,27],
@@ -64,14 +83,14 @@ var NAVTREEINDEX73 =
 "db/dc5/lapacke__cpf__nancheck_8c_source.html":[2,0,3,4,18],
 "db/dc5/zchkqrtp_8f.html":[2,0,5,1,575],
 "db/dc5/zchkqrtp_8f_source.html":[2,0,5,1,575],
-"db/dc5/zlahr2_8f.html":[2,0,4,1691],
-"db/dc5/zlahr2_8f_source.html":[2,0,4,1691],
+"db/dc5/zlahr2_8f.html":[2,0,4,1690],
+"db/dc5/zlahr2_8f_source.html":[2,0,4,1690],
 "db/dc6/lapacke__cggsvp__work_8c.html":[2,0,3,3,157],
 "db/dc6/lapacke__cggsvp__work_8c_ab5718bbe8a8aea87fcf36a6417e37570.html#ab5718bbe8a8aea87fcf36a6417e37570":[2,0,3,3,157,0],
 "db/dc6/lapacke__cggsvp__work_8c_source.html":[2,0,3,3,157],
-"db/dc6/lapacke__sgeqrt__work_8c.html":[2,0,3,3,1298],
-"db/dc6/lapacke__sgeqrt__work_8c_a6037fa77acfc85313f29cd5672480204.html#a6037fa77acfc85313f29cd5672480204":[2,0,3,3,1298,0],
-"db/dc6/lapacke__sgeqrt__work_8c_source.html":[2,0,3,3,1298],
+"db/dc6/lapacke__sgeqrt__work_8c.html":[2,0,3,3,1302],
+"db/dc6/lapacke__sgeqrt__work_8c_a6037fa77acfc85313f29cd5672480204.html#a6037fa77acfc85313f29cd5672480204":[2,0,3,3,1302,0],
+"db/dc6/lapacke__sgeqrt__work_8c_source.html":[2,0,3,3,1302],
 "db/dc6/lapacke__zhe__trans_8c.html":[2,0,3,4,121],
 "db/dc6/lapacke__zhe__trans_8c_a45d4452378d45f842aa898d74c350ca5.html#a45d4452378d45f842aa898d74c350ca5":[2,0,3,4,121,0],
 "db/dc6/lapacke__zhe__trans_8c_source.html":[2,0,3,4,121],
@@ -88,8 +107,8 @@ var NAVTREEINDEX73 =
 "db/dc9/group__single__blas__level3_ga8e8391a9873114d97e2b63e39fe83b2e.html#ga8e8391a9873114d97e2b63e39fe83b2e":[2,0,0,0,100,0],
 "db/dc9/group__single__blas__level3_ga9893cceb3ffc7ce400eee405970191b3.html#ga9893cceb3ffc7ce400eee405970191b3":[0,2,2,0,5],
 "db/dc9/group__single__blas__level3_ga9893cceb3ffc7ce400eee405970191b3.html#ga9893cceb3ffc7ce400eee405970191b3":[2,0,0,0,112,0],
-"db/dc9/group__single__blas__level3_gae953a93420ca237670f5c67bbde9d9ff.html#gae953a93420ca237670f5c67bbde9d9ff":[0,2,2,0,3],
 "db/dc9/group__single__blas__level3_gae953a93420ca237670f5c67bbde9d9ff.html#gae953a93420ca237670f5c67bbde9d9ff":[2,0,0,0,105,0],
+"db/dc9/group__single__blas__level3_gae953a93420ca237670f5c67bbde9d9ff.html#gae953a93420ca237670f5c67bbde9d9ff":[0,2,2,0,3],
 "db/dc9/group__single__blas__level3_gafe51bacb54592ff5de056acabd83c260.html#gafe51bacb54592ff5de056acabd83c260":[0,2,2,0,0],
 "db/dc9/group__single__blas__level3_gafe51bacb54592ff5de056acabd83c260.html#gafe51bacb54592ff5de056acabd83c260":[2,0,0,0,86,0],
 "db/dc9/lapacke__dpb__trans_8c.html":[2,0,3,4,49],
@@ -101,41 +120,41 @@ var NAVTREEINDEX73 =
 "db/dca/dtrevc_8f_source.html":[2,0,4,949],
 "db/dcc/dbdsqr_8f.html":[2,0,4,483],
 "db/dcc/dbdsqr_8f_source.html":[2,0,4,483],
-"db/dcc/lapacke__zgeqp3_8c.html":[2,0,3,3,1857],
-"db/dcc/lapacke__zgeqp3_8c_a0fcaba8b557fab4d463b415d1a65ed68.html#a0fcaba8b557fab4d463b415d1a65ed68":[2,0,3,3,1857,0],
-"db/dcc/lapacke__zgeqp3_8c_source.html":[2,0,3,3,1857],
+"db/dcc/lapacke__zgeqp3_8c.html":[2,0,3,3,1863],
+"db/dcc/lapacke__zgeqp3_8c_a0fcaba8b557fab4d463b415d1a65ed68.html#a0fcaba8b557fab4d463b415d1a65ed68":[2,0,3,3,1863,0],
+"db/dcc/lapacke__zgeqp3_8c_source.html":[2,0,3,3,1863],
 "db/dcd/cdrvrf1_8f.html":[2,0,5,1,59],
 "db/dcd/cdrvrf1_8f_source.html":[2,0,5,1,59],
 "db/dcd/chpr_8f.html":[2,0,0,0,17],
 "db/dcd/chpr_8f_source.html":[2,0,0,0,17],
 "db/dcd/dchksy__aa_8f.html":[2,0,5,1,226],
 "db/dcd/dchksy__aa_8f_source.html":[2,0,5,1,226],
-"db/dcd/lapacke__spotrf2_8c.html":[2,0,3,3,1516],
-"db/dcd/lapacke__spotrf2_8c_a82d994b19ff078eeff60af28b8e85e14.html#a82d994b19ff078eeff60af28b8e85e14":[2,0,3,3,1516,0],
-"db/dcd/lapacke__spotrf2_8c_source.html":[2,0,3,3,1516],
-"db/dcd/zgetc2_8f.html":[2,0,4,1530],
-"db/dcd/zgetc2_8f_source.html":[2,0,4,1530],
+"db/dcd/lapacke__spotrf2_8c.html":[2,0,3,3,1522],
+"db/dcd/lapacke__spotrf2_8c_a82d994b19ff078eeff60af28b8e85e14.html#a82d994b19ff078eeff60af28b8e85e14":[2,0,3,3,1522,0],
+"db/dcd/lapacke__spotrf2_8c_source.html":[2,0,3,3,1522],
+"db/dcd/zgetc2_8f.html":[2,0,4,1529],
+"db/dcd/zgetc2_8f_source.html":[2,0,4,1529],
 "db/dd1/group__sing_g_e.html":[0,0,0,2],
-"db/dd1/lapacke__cpftrf_8c.html":[2,0,3,3,370],
-"db/dd1/lapacke__cpftrf_8c_a3db1bdb4e15d7d379fe2fd1be0d7d35b.html#a3db1bdb4e15d7d379fe2fd1be0d7d35b":[2,0,3,3,370,0],
-"db/dd1/lapacke__cpftrf_8c_source.html":[2,0,3,3,370],
+"db/dd1/lapacke__cpftrf_8c.html":[2,0,3,3,372],
+"db/dd1/lapacke__cpftrf_8c_a3db1bdb4e15d7d379fe2fd1be0d7d35b.html#a3db1bdb4e15d7d379fe2fd1be0d7d35b":[2,0,3,3,372,0],
+"db/dd1/lapacke__cpftrf_8c_source.html":[2,0,3,3,372],
 "db/dd2/lapacke__cgehrd_8c.html":[2,0,3,3,46],
 "db/dd2/lapacke__cgehrd_8c_a39a0d43b9231a8926fce6fee55261966.html#a39a0d43b9231a8926fce6fee55261966":[2,0,3,3,46,0],
 "db/dd2/lapacke__cgehrd_8c_source.html":[2,0,3,3,46],
 "db/dd3/cgeqp3_8f.html":[2,0,4,45],
 "db/dd3/cgeqp3_8f_source.html":[2,0,4,45],
-"db/dd3/lapacke__zggsvp3__work_8c.html":[2,0,3,3,1941],
-"db/dd3/lapacke__zggsvp3__work_8c_a282b46203847471e7da72e9d3cbcd3b0.html#a282b46203847471e7da72e9d3cbcd3b0":[2,0,3,3,1941,0],
-"db/dd3/lapacke__zggsvp3__work_8c_source.html":[2,0,3,3,1941],
+"db/dd3/lapacke__zggsvp3__work_8c.html":[2,0,3,3,1947],
+"db/dd3/lapacke__zggsvp3__work_8c_a282b46203847471e7da72e9d3cbcd3b0.html#a282b46203847471e7da72e9d3cbcd3b0":[2,0,3,3,1947,0],
+"db/dd3/lapacke__zggsvp3__work_8c_source.html":[2,0,3,3,1947],
 "db/dd4/clascl_8f.html":[2,0,4,288],
 "db/dd4/clascl_8f_source.html":[2,0,4,288],
 "db/dd4/dswap_8f.html":[2,0,0,0,55],
 "db/dd4/dswap_8f_source.html":[2,0,0,0,55],
 "db/dd5/cgeesx_8f.html":[2,0,4,24],
 "db/dd5/cgeesx_8f_source.html":[2,0,4,24],
-"db/dd5/lapacke__dtgsna_8c.html":[2,0,3,3,1154],
-"db/dd5/lapacke__dtgsna_8c_acad3de50111c8c1e12cd3af5263135d0.html#acad3de50111c8c1e12cd3af5263135d0":[2,0,3,3,1154,0],
-"db/dd5/lapacke__dtgsna_8c_source.html":[2,0,3,3,1154],
+"db/dd5/lapacke__dtgsna_8c.html":[2,0,3,3,1158],
+"db/dd5/lapacke__dtgsna_8c_acad3de50111c8c1e12cd3af5263135d0.html#acad3de50111c8c1e12cd3af5263135d0":[2,0,3,3,1158,0],
+"db/dd5/lapacke__dtgsna_8c_source.html":[2,0,3,3,1158],
 "db/dd6/zerrab_8f.html":[2,0,5,1,619],
 "db/dd6/zerrab_8f_source.html":[2,0,5,1,619],
 "db/dd6/zlqt03_8f.html":[2,0,5,1,688],
@@ -144,52 +163,52 @@ var NAVTREEINDEX73 =
 "db/dd7/dtrt02_8f_source.html":[2,0,5,1,374],
 "db/ddb/dgges_8f.html":[2,0,4,557],
 "db/ddb/dgges_8f_source.html":[2,0,4,557],
-"db/ddb/lapacke__ztrtrs_8c.html":[2,0,3,3,2357],
-"db/ddb/lapacke__ztrtrs_8c_ab7070dc14fffff06d20e58efe520c4d3.html#ab7070dc14fffff06d20e58efe520c4d3":[2,0,3,3,2357,0],
-"db/ddb/lapacke__ztrtrs_8c_source.html":[2,0,3,3,2357],
-"db/ddc/lapacke__sgesdd_8c.html":[2,0,3,3,1305],
-"db/ddc/lapacke__sgesdd_8c_a07c09ab3de69b4842dccc856905727e3.html#a07c09ab3de69b4842dccc856905727e3":[2,0,3,3,1305,0],
-"db/ddc/lapacke__sgesdd_8c_source.html":[2,0,3,3,1305],
-"db/ddc/lapacke__zpprfs_8c.html":[2,0,3,3,2189],
-"db/ddc/lapacke__zpprfs_8c_a7b0956c283af2df88dbe6c469954a1aa.html#a7b0956c283af2df88dbe6c469954a1aa":[2,0,3,3,2189,0],
-"db/ddc/lapacke__zpprfs_8c_source.html":[2,0,3,3,2189],
-"db/ddf/ztrttf_8f.html":[2,0,4,1905],
-"db/ddf/ztrttf_8f_source.html":[2,0,4,1905],
+"db/ddb/lapacke__ztrtrs_8c.html":[2,0,3,3,2365],
+"db/ddb/lapacke__ztrtrs_8c_ab7070dc14fffff06d20e58efe520c4d3.html#ab7070dc14fffff06d20e58efe520c4d3":[2,0,3,3,2365,0],
+"db/ddb/lapacke__ztrtrs_8c_source.html":[2,0,3,3,2365],
+"db/ddc/lapacke__sgesdd_8c.html":[2,0,3,3,1309],
+"db/ddc/lapacke__sgesdd_8c_a07c09ab3de69b4842dccc856905727e3.html#a07c09ab3de69b4842dccc856905727e3":[2,0,3,3,1309,0],
+"db/ddc/lapacke__sgesdd_8c_source.html":[2,0,3,3,1309],
+"db/ddc/lapacke__zpprfs_8c.html":[2,0,3,3,2197],
+"db/ddc/lapacke__zpprfs_8c_a7b0956c283af2df88dbe6c469954a1aa.html#a7b0956c283af2df88dbe6c469954a1aa":[2,0,3,3,2197,0],
+"db/ddc/lapacke__zpprfs_8c_source.html":[2,0,3,3,2197],
+"db/ddf/ztrttf_8f.html":[2,0,4,1904],
+"db/ddf/ztrttf_8f_source.html":[2,0,4,1904],
 "db/de1/clasyf_8f.html":[2,0,4,295],
 "db/de1/clasyf_8f_source.html":[2,0,4,295],
 "db/de4/dgecon_8f.html":[2,0,4,502],
 "db/de4/dgecon_8f_source.html":[2,0,4,502],
-"db/de4/lapacke__dpftrf_8c.html":[2,0,3,3,910],
-"db/de4/lapacke__dpftrf_8c_a8cd516c9f3a88d54392bd04678af7977.html#a8cd516c9f3a88d54392bd04678af7977":[2,0,3,3,910,0],
-"db/de4/lapacke__dpftrf_8c_source.html":[2,0,3,3,910],
-"db/de4/lapacke__sgbsvxx__work_8c.html":[2,0,3,3,1230],
-"db/de4/lapacke__sgbsvxx__work_8c_a39b655147be5534950c64e7cfa60bbc1.html#a39b655147be5534950c64e7cfa60bbc1":[2,0,3,3,1230,0],
-"db/de4/lapacke__sgbsvxx__work_8c_source.html":[2,0,3,3,1230],
+"db/de4/lapacke__dpftrf_8c.html":[2,0,3,3,914],
+"db/de4/lapacke__dpftrf_8c_a8cd516c9f3a88d54392bd04678af7977.html#a8cd516c9f3a88d54392bd04678af7977":[2,0,3,3,914,0],
+"db/de4/lapacke__dpftrf_8c_source.html":[2,0,3,3,914],
+"db/de4/lapacke__sgbsvxx__work_8c.html":[2,0,3,3,1234],
+"db/de4/lapacke__sgbsvxx__work_8c_a39b655147be5534950c64e7cfa60bbc1.html#a39b655147be5534950c64e7cfa60bbc1":[2,0,3,3,1234,0],
+"db/de4/lapacke__sgbsvxx__work_8c_source.html":[2,0,3,3,1234],
 "db/de5/clatzm_8f.html":[2,0,4,0,7],
 "db/de5/clatzm_8f_source.html":[2,0,4,0,7],
 "db/de5/dgeqp3_8f.html":[2,0,4,527],
 "db/de5/dgeqp3_8f_source.html":[2,0,4,527],
-"db/de5/lapacke__zgbtrf_8c.html":[2,0,3,3,1807],
-"db/de5/lapacke__zgbtrf_8c_a8749b35bbb4f32553a65a6b2a17d18c1.html#a8749b35bbb4f32553a65a6b2a17d18c1":[2,0,3,3,1807,0],
-"db/de5/lapacke__zgbtrf_8c_source.html":[2,0,3,3,1807],
-"db/de6/zpftri_8f.html":[2,0,4,1782],
-"db/de6/zpftri_8f_source.html":[2,0,4,1782],
-"db/de7/lapacke__ctprfs__work_8c.html":[2,0,3,3,547],
-"db/de7/lapacke__ctprfs__work_8c_a06536b61edd487afedd908275686dd6a.html#a06536b61edd487afedd908275686dd6a":[2,0,3,3,547,0],
-"db/de7/lapacke__ctprfs__work_8c_source.html":[2,0,3,3,547],
-"db/de8/lapacke__zlarfx_8c.html":[2,0,3,3,2125],
-"db/de8/lapacke__zlarfx_8c_a647e228eb5dfe00865d43d6234c5add3.html#a647e228eb5dfe00865d43d6234c5add3":[2,0,3,3,2125,0],
-"db/de8/lapacke__zlarfx_8c_source.html":[2,0,3,3,2125],
+"db/de5/lapacke__zgbtrf_8c.html":[2,0,3,3,1813],
+"db/de5/lapacke__zgbtrf_8c_a8749b35bbb4f32553a65a6b2a17d18c1.html#a8749b35bbb4f32553a65a6b2a17d18c1":[2,0,3,3,1813,0],
+"db/de5/lapacke__zgbtrf_8c_source.html":[2,0,3,3,1813],
+"db/de6/zpftri_8f.html":[2,0,4,1781],
+"db/de6/zpftri_8f_source.html":[2,0,4,1781],
+"db/de7/lapacke__ctprfs__work_8c.html":[2,0,3,3,549],
+"db/de7/lapacke__ctprfs__work_8c_a06536b61edd487afedd908275686dd6a.html#a06536b61edd487afedd908275686dd6a":[2,0,3,3,549,0],
+"db/de7/lapacke__ctprfs__work_8c_source.html":[2,0,3,3,549],
+"db/de8/lapacke__zlarfx_8c.html":[2,0,3,3,2131],
+"db/de8/lapacke__zlarfx_8c_a647e228eb5dfe00865d43d6234c5add3.html#a647e228eb5dfe00865d43d6234c5add3":[2,0,3,3,2131,0],
+"db/de8/lapacke__zlarfx_8c_source.html":[2,0,3,3,2131],
 "db/dea/ddrvsyx_8f.html":[2,0,5,1,257],
 "db/dea/ddrvsyx_8f_source.html":[2,0,5,1,257],
-"db/dea/slansy_8f.html":[2,0,4,1152],
-"db/dea/slansy_8f_source.html":[2,0,4,1152],
-"db/deb/lapacke__zlanhe_8c.html":[2,0,3,3,2109],
-"db/deb/lapacke__zlanhe_8c_abc785249729389d5737af5e6d3b44e77.html#abc785249729389d5737af5e6d3b44e77":[2,0,3,3,2109,0],
-"db/deb/lapacke__zlanhe_8c_source.html":[2,0,3,3,2109],
-"db/deb/lapacke__ztgevc__work_8c.html":[2,0,3,3,2310],
-"db/deb/lapacke__ztgevc__work_8c_a4c0c8178580dca1ef2a9e58b53e1c0be.html#a4c0c8178580dca1ef2a9e58b53e1c0be":[2,0,3,3,2310,0],
-"db/deb/lapacke__ztgevc__work_8c_source.html":[2,0,3,3,2310],
+"db/dea/slansy_8f.html":[2,0,4,1151],
+"db/dea/slansy_8f_source.html":[2,0,4,1151],
+"db/deb/lapacke__zlanhe_8c.html":[2,0,3,3,2115],
+"db/deb/lapacke__zlanhe_8c_abc785249729389d5737af5e6d3b44e77.html#abc785249729389d5737af5e6d3b44e77":[2,0,3,3,2115,0],
+"db/deb/lapacke__zlanhe_8c_source.html":[2,0,3,3,2115],
+"db/deb/lapacke__ztgevc__work_8c.html":[2,0,3,3,2318],
+"db/deb/lapacke__ztgevc__work_8c_a4c0c8178580dca1ef2a9e58b53e1c0be.html#a4c0c8178580dca1ef2a9e58b53e1c0be":[2,0,3,3,2318,0],
+"db/deb/lapacke__ztgevc__work_8c_source.html":[2,0,3,3,2318],
 "db/deb/tstiee_8f.html":[2,0,2,22],
 "db/deb/tstiee_8f_a97715c995b884378afbbff7915d884c5.html#a97715c995b884378afbbff7915d884c5":[2,0,2,22,0],
 "db/deb/tstiee_8f_ac9e158139ad16abc79a0dce7ae8ad8c9.html#ac9e158139ad16abc79a0dce7ae8ad8c9":[2,0,2,22,2],
@@ -208,46 +227,27 @@ var NAVTREEINDEX73 =
 "db/def/group__complex__blas__level3_ga1b4f63daf04fdf3061bd25dfec0d3e84.html#ga1b4f63daf04fdf3061bd25dfec0d3e84":[2,0,0,0,26,0],
 "db/def/group__complex__blas__level3_ga2490eea9e962fd69b9902e22aaa3a634.html#ga2490eea9e962fd69b9902e22aaa3a634":[0,2,2,2,4],
 "db/def/group__complex__blas__level3_ga2490eea9e962fd69b9902e22aaa3a634.html#ga2490eea9e962fd69b9902e22aaa3a634":[2,0,0,0,24,0],
-"db/def/group__complex__blas__level3_gaa8320d51ded07cd3038db237fd400547.html#gaa8320d51ded07cd3038db237fd400547":[2,0,0,0,25,0],
 "db/def/group__complex__blas__level3_gaa8320d51ded07cd3038db237fd400547.html#gaa8320d51ded07cd3038db237fd400547":[0,2,2,2,5],
+"db/def/group__complex__blas__level3_gaa8320d51ded07cd3038db237fd400547.html#gaa8320d51ded07cd3038db237fd400547":[2,0,0,0,25,0],
 "db/def/group__complex__blas__level3_gac4e11e8e8a4b0c802d2229b08da341f6.html#gac4e11e8e8a4b0c802d2229b08da341f6":[0,2,2,2,0],
 "db/def/group__complex__blas__level3_gac4e11e8e8a4b0c802d2229b08da341f6.html#gac4e11e8e8a4b0c802d2229b08da341f6":[2,0,0,0,5,0],
-"db/def/group__complex__blas__level3_gad2d1853a142397404eae974b6574ece3.html#gad2d1853a142397404eae974b6574ece3":[0,2,2,2,1],
 "db/def/group__complex__blas__level3_gad2d1853a142397404eae974b6574ece3.html#gad2d1853a142397404eae974b6574ece3":[2,0,0,0,10,0],
-"db/def/group__complex__blas__level3_gad7c297c05b482699b6d60a29c8d4a165.html#gad7c297c05b482699b6d60a29c8d4a165":[2,0,0,0,31,0],
+"db/def/group__complex__blas__level3_gad2d1853a142397404eae974b6574ece3.html#gad2d1853a142397404eae974b6574ece3":[0,2,2,2,1],
 "db/def/group__complex__blas__level3_gad7c297c05b482699b6d60a29c8d4a165.html#gad7c297c05b482699b6d60a29c8d4a165":[0,2,2,2,7],
+"db/def/group__complex__blas__level3_gad7c297c05b482699b6d60a29c8d4a165.html#gad7c297c05b482699b6d60a29c8d4a165":[2,0,0,0,31,0],
 "db/def/group__complex__blas__level3_gade9f14cf41f0cefea7918d716f3e1c20.html#gade9f14cf41f0cefea7918d716f3e1c20":[0,2,2,2,3],
 "db/def/group__complex__blas__level3_gade9f14cf41f0cefea7918d716f3e1c20.html#gade9f14cf41f0cefea7918d716f3e1c20":[2,0,0,0,15,0],
-"db/def/group__complex__blas__level3_gaf33844c7fd27e5434496d2ce0c1fc9d4.html#gaf33844c7fd27e5434496d2ce0c1fc9d4":[2,0,0,0,33,0],
 "db/def/group__complex__blas__level3_gaf33844c7fd27e5434496d2ce0c1fc9d4.html#gaf33844c7fd27e5434496d2ce0c1fc9d4":[0,2,2,2,8],
-"db/def/group__complex__blas__level3_gaf5266b622e0fbbd972cfc2df3061984f.html#gaf5266b622e0fbbd972cfc2df3061984f":[2,0,0,0,14,0],
+"db/def/group__complex__blas__level3_gaf33844c7fd27e5434496d2ce0c1fc9d4.html#gaf33844c7fd27e5434496d2ce0c1fc9d4":[2,0,0,0,33,0],
 "db/def/group__complex__blas__level3_gaf5266b622e0fbbd972cfc2df3061984f.html#gaf5266b622e0fbbd972cfc2df3061984f":[0,2,2,2,2],
-"db/def/lapacke__csytrs__3_8c.html":[2,0,3,3,503],
-"db/def/lapacke__csytrs__3_8c_ac757fedc69744ff07d30cd27acae356f.html#ac757fedc69744ff07d30cd27acae356f":[2,0,3,3,503,0],
-"db/def/lapacke__csytrs__3_8c_source.html":[2,0,3,3,503],
-"db/def/lapacke__dgbtrs__work_8c.html":[2,0,3,3,651],
-"db/def/lapacke__dgbtrs__work_8c_a10798bcaf52a3610626a000b9a32ae66.html#a10798bcaf52a3610626a000b9a32ae66":[2,0,3,3,651,0],
-"db/def/lapacke__dgbtrs__work_8c_source.html":[2,0,3,3,651],
+"db/def/group__complex__blas__level3_gaf5266b622e0fbbd972cfc2df3061984f.html#gaf5266b622e0fbbd972cfc2df3061984f":[2,0,0,0,14,0],
+"db/def/lapacke__csytrs__3_8c.html":[2,0,3,3,505],
+"db/def/lapacke__csytrs__3_8c_ac757fedc69744ff07d30cd27acae356f.html#ac757fedc69744ff07d30cd27acae356f":[2,0,3,3,505,0],
+"db/def/lapacke__csytrs__3_8c_source.html":[2,0,3,3,505],
+"db/def/lapacke__dgbtrs__work_8c.html":[2,0,3,3,653],
+"db/def/lapacke__dgbtrs__work_8c_a10798bcaf52a3610626a000b9a32ae66.html#a10798bcaf52a3610626a000b9a32ae66":[2,0,3,3,653,0],
+"db/def/lapacke__dgbtrs__work_8c_source.html":[2,0,3,3,653],
 "db/df0/dormrz_8f.html":[2,0,4,781],
 "db/df0/dormrz_8f_source.html":[2,0,4,781],
-"db/df0/slantr_8f.html":[2,0,4,1155],
-"db/df0/slantr_8f_source.html":[2,0,4,1155],
-"db/df2/dsyconvf__rook_8f.html":[2,0,4,873],
-"db/df2/dsyconvf__rook_8f_source.html":[2,0,4,873],
-"db/df2/lapacke__dggesx_8c.html":[2,0,3,3,756],
-"db/df2/lapacke__dggesx_8c_a4ae664231117af153833f9a19131c471.html#a4ae664231117af153833f9a19131c471":[2,0,3,3,756,0],
-"db/df2/lapacke__dggesx_8c_source.html":[2,0,3,3,756],
-"db/df3/zhesv__rk_8f.html":[2,0,4,1596],
-"db/df3/zhesv__rk_8f_source.html":[2,0,4,1596],
-"db/df4/dlamswlq_8f.html":[2,0,4,639],
-"db/df4/dlamswlq_8f_acaed25cba36a6f5b414d68936a010b29.html#acaed25cba36a6f5b414d68936a010b29":[2,0,4,639,0],
-"db/df4/dlamswlq_8f_source.html":[2,0,4,639],
-"db/df4/dlarfb_8f.html":[2,0,4,677],
-"db/df4/dlarfb_8f_source.html":[2,0,4,677],
-"db/df4/dsytrf__rook_8f.html":[2,0,4,908],
-"db/df4/dsytrf__rook_8f_source.html":[2,0,4,908],
-"db/df4/lapacke__ctzrzf__work_8c.html":[2,0,3,3,579],
-"db/df4/lapacke__ctzrzf__work_8c_a5fae983ee8b7d27f3bc33b7a851929e3.html#a5fae983ee8b7d27f3bc33b7a851929e3":[2,0,3,3,579,0],
-"db/df4/lapacke__ctzrzf__work_8c_source.html":[2,0,3,3,579],
-"db/df4/lapacke__dgehrd_8c.html":[2,0,3,3,672]
+"db/df0/slantr_8f.html":[2,0,4,1154]
 };
