@@ -1,18 +1,37 @@
 var NAVTREEINDEX74 =
 {
-"db/df4/lapacke__dgehrd_8c_ae67d6b61da9a6478cc82177de3490f49.html#ae67d6b61da9a6478cc82177de3490f49":[2,0,3,3,672,0],
-"db/df4/lapacke__dgehrd_8c_source.html":[2,0,3,3,672],
+"db/df0/slantr_8f_source.html":[2,0,4,1154],
+"db/df2/dsyconvf__rook_8f.html":[2,0,4,873],
+"db/df2/dsyconvf__rook_8f_source.html":[2,0,4,873],
+"db/df2/lapacke__dggesx_8c.html":[2,0,3,3,758],
+"db/df2/lapacke__dggesx_8c_a4ae664231117af153833f9a19131c471.html#a4ae664231117af153833f9a19131c471":[2,0,3,3,758,0],
+"db/df2/lapacke__dggesx_8c_source.html":[2,0,3,3,758],
+"db/df3/zhesv__rk_8f.html":[2,0,4,1595],
+"db/df3/zhesv__rk_8f_source.html":[2,0,4,1595],
+"db/df4/dlamswlq_8f.html":[2,0,4,639],
+"db/df4/dlamswlq_8f_a1fa2f387d69d499a33db38d9e0d9065f.html#a1fa2f387d69d499a33db38d9e0d9065f":[2,0,4,639,0],
+"db/df4/dlamswlq_8f_source.html":[2,0,4,639],
+"db/df4/dlarfb_8f.html":[2,0,4,677],
+"db/df4/dlarfb_8f_source.html":[2,0,4,677],
+"db/df4/dsytrf__rook_8f.html":[2,0,4,908],
+"db/df4/dsytrf__rook_8f_source.html":[2,0,4,908],
+"db/df4/lapacke__ctzrzf__work_8c.html":[2,0,3,3,581],
+"db/df4/lapacke__ctzrzf__work_8c_a5fae983ee8b7d27f3bc33b7a851929e3.html#a5fae983ee8b7d27f3bc33b7a851929e3":[2,0,3,3,581,0],
+"db/df4/lapacke__ctzrzf__work_8c_source.html":[2,0,3,3,581],
+"db/df4/lapacke__dgehrd_8c.html":[2,0,3,3,674],
+"db/df4/lapacke__dgehrd_8c_ae67d6b61da9a6478cc82177de3490f49.html#ae67d6b61da9a6478cc82177de3490f49":[2,0,3,3,674,0],
+"db/df4/lapacke__dgehrd_8c_source.html":[2,0,3,3,674],
 "db/df5/lapacke__csy__trans_8c.html":[2,0,3,4,29],
 "db/df5/lapacke__csy__trans_8c_a84d515478e58184bd2c89f748766a584.html#a84d515478e58184bd2c89f748766a584":[2,0,3,4,29,0],
 "db/df5/lapacke__csy__trans_8c_source.html":[2,0,3,4,29],
-"db/df5/lapacke__dtbrfs_8c.html":[2,0,3,3,1134],
-"db/df5/lapacke__dtbrfs_8c_a2416d529c18275d41ae506e2542a6480.html#a2416d529c18275d41ae506e2542a6480":[2,0,3,3,1134,0],
-"db/df5/lapacke__dtbrfs_8c_source.html":[2,0,3,3,1134],
+"db/df5/lapacke__dtbrfs_8c.html":[2,0,3,3,1138],
+"db/df5/lapacke__dtbrfs_8c_a2416d529c18275d41ae506e2542a6480.html#a2416d529c18275d41ae506e2542a6480":[2,0,3,3,1138,0],
+"db/df5/lapacke__dtbrfs_8c_source.html":[2,0,3,3,1138],
 "db/df6/cchkgt_8f.html":[2,0,5,1,11],
 "db/df6/cchkgt_8f_source.html":[2,0,5,1,11],
-"db/df7/lapacke__zposvx_8c.html":[2,0,3,3,2173],
-"db/df7/lapacke__zposvx_8c_a6563b0919eb7640d59bde1473dbbc4c5.html#a6563b0919eb7640d59bde1473dbbc4c5":[2,0,3,3,2173,0],
-"db/df7/lapacke__zposvx_8c_source.html":[2,0,3,3,2173],
+"db/df7/lapacke__zposvx_8c.html":[2,0,3,3,2181],
+"db/df7/lapacke__zposvx_8c_a6563b0919eb7640d59bde1473dbbc4c5.html#a6563b0919eb7640d59bde1473dbbc4c5":[2,0,3,3,2181,0],
+"db/df7/lapacke__zposvx_8c_source.html":[2,0,3,3,2181],
 "db/df7/zggsvp_8f.html":[2,0,4,0,32],
 "db/df7/zggsvp_8f_source.html":[2,0,4,0,32],
 "db/df8/c__zblas2_8c.html":[2,0,1,3,29],
@@ -50,9 +69,9 @@ var NAVTREEINDEX74 =
 "db/dfb/cgeqr2_8f_source.html":[2,0,4,47],
 "db/dfc/dtgexc_8f.html":[2,0,4,929],
 "db/dfc/dtgexc_8f_source.html":[2,0,4,929],
-"db/dfd/lapacke__dtgevc_8c.html":[2,0,3,3,1146],
-"db/dfd/lapacke__dtgevc_8c_a87ae4c118f8c87b0052ae4db4b7643b4.html#a87ae4c118f8c87b0052ae4db4b7643b4":[2,0,3,3,1146,0],
-"db/dfd/lapacke__dtgevc_8c_source.html":[2,0,3,3,1146],
+"db/dfd/lapacke__dtgevc_8c.html":[2,0,3,3,1150],
+"db/dfd/lapacke__dtgevc_8c_a87ae4c118f8c87b0052ae4db4b7643b4.html#a87ae4c118f8c87b0052ae4db4b7643b4":[2,0,3,3,1150,0],
+"db/dfd/lapacke__dtgevc_8c_source.html":[2,0,3,3,1150],
 "db/dfe/lapacke__chbtrd__work_8c.html":[2,0,3,3,191],
 "db/dfe/lapacke__chbtrd__work_8c_ab0ec72c1b8a7af65936a88fcacc2052e.html#ab0ec72c1b8a7af65936a88fcacc2052e":[2,0,3,3,191,0],
 "db/dfe/lapacke__chbtrd__work_8c_source.html":[2,0,3,3,191],
@@ -67,14 +86,14 @@ var NAVTREEINDEX74 =
 "dc/d01/_t_e_s_t_i_n_g_2_e_i_g_2dlarfy_8f_source.html":[2,0,5,0,157],
 "dc/d01/dsdot_8f.html":[2,0,0,0,51],
 "dc/d01/dsdot_8f_source.html":[2,0,0,0,51],
-"dc/d01/lapacke__sspevd_8c.html":[2,0,3,3,1583],
-"dc/d01/lapacke__sspevd_8c_adaf13e5959358a926341458f0c6d1331.html#adaf13e5959358a926341458f0c6d1331":[2,0,3,3,1583,0],
-"dc/d01/lapacke__sspevd_8c_source.html":[2,0,3,3,1583],
+"dc/d01/lapacke__sspevd_8c.html":[2,0,3,3,1589],
+"dc/d01/lapacke__sspevd_8c_adaf13e5959358a926341458f0c6d1331.html#adaf13e5959358a926341458f0c6d1331":[2,0,3,3,1589,0],
+"dc/d01/lapacke__sspevd_8c_source.html":[2,0,3,3,1589],
 "dc/d02/cdrvpo_8f.html":[2,0,5,1,55],
 "dc/d02/cdrvpo_8f_source.html":[2,0,5,1,55],
-"dc/d02/lapacke__zunmqr_8c.html":[2,0,3,3,2393],
-"dc/d02/lapacke__zunmqr_8c_a70a83145d0b21ca5775fa96ecd6d6644.html#a70a83145d0b21ca5775fa96ecd6d6644":[2,0,3,3,2393,0],
-"dc/d02/lapacke__zunmqr_8c_source.html":[2,0,3,3,2393],
+"dc/d02/lapacke__zunmqr_8c.html":[2,0,3,3,2401],
+"dc/d02/lapacke__zunmqr_8c_a70a83145d0b21ca5775fa96ecd6d6644.html#a70a83145d0b21ca5775fa96ecd6d6644":[2,0,3,3,2401,0],
+"dc/d02/lapacke__zunmqr_8c_source.html":[2,0,3,3,2401],
 "dc/d04/dsygst_8f.html":[2,0,4,884],
 "dc/d04/dsygst_8f_source.html":[2,0,4,884],
 "dc/d04/group___h_e.html":[0,0,3],
@@ -84,9 +103,9 @@ var NAVTREEINDEX74 =
 "dc/d05/dsyrk_8f_source.html":[2,0,0,0,61],
 "dc/d06/ilaclc_8f.html":[2,0,4,965],
 "dc/d06/ilaclc_8f_source.html":[2,0,4,965],
-"dc/d06/lapacke__zppsv_8c.html":[2,0,3,3,2191],
-"dc/d06/lapacke__zppsv_8c_aaea1b1f6c9999b10dda36e63a2c0a218.html#aaea1b1f6c9999b10dda36e63a2c0a218":[2,0,3,3,2191,0],
-"dc/d06/lapacke__zppsv_8c_source.html":[2,0,3,3,2191],
+"dc/d06/lapacke__zppsv_8c.html":[2,0,3,3,2199],
+"dc/d06/lapacke__zppsv_8c_aaea1b1f6c9999b10dda36e63a2c0a218.html#aaea1b1f6c9999b10dda36e63a2c0a218":[2,0,3,3,2199,0],
+"dc/d06/lapacke__zppsv_8c_source.html":[2,0,3,3,2199],
 "dc/d06/sspt01_8f.html":[2,0,5,1,529],
 "dc/d06/sspt01_8f_source.html":[2,0,5,1,529],
 "dc/d07/dgbequb_8f.html":[2,0,4,489],
@@ -101,71 +120,71 @@ var NAVTREEINDEX74 =
 "dc/d09/cblas__srot_8c_source.html":[2,0,1,2,86],
 "dc/d09/dlange_8f.html":[2,0,4,643],
 "dc/d09/dlange_8f_source.html":[2,0,4,643],
-"dc/d09/lapacke__sporfs_8c.html":[2,0,3,3,1505],
-"dc/d09/lapacke__sporfs_8c_a022a274558ce78113b67697ee0d0b6fe.html#a022a274558ce78113b67697ee0d0b6fe":[2,0,3,3,1505,0],
-"dc/d09/lapacke__sporfs_8c_source.html":[2,0,3,3,1505],
-"dc/d09/lapacke__zheevr__2stage_8c.html":[2,0,3,3,1992],
-"dc/d09/lapacke__zheevr__2stage_8c_a1644ad7a37bb638e1b884ed8c938490e.html#a1644ad7a37bb638e1b884ed8c938490e":[2,0,3,3,1992,0],
-"dc/d09/lapacke__zheevr__2stage_8c_source.html":[2,0,3,3,1992],
-"dc/d09/slamswlq_8f.html":[2,0,4,1141],
-"dc/d09/slamswlq_8f_a118168444fca5bbc2480be8cd6c897f3.html#a118168444fca5bbc2480be8cd6c897f3":[2,0,4,1141,0],
-"dc/d09/slamswlq_8f_source.html":[2,0,4,1141],
+"dc/d09/lapacke__sporfs_8c.html":[2,0,3,3,1511],
+"dc/d09/lapacke__sporfs_8c_a022a274558ce78113b67697ee0d0b6fe.html#a022a274558ce78113b67697ee0d0b6fe":[2,0,3,3,1511,0],
+"dc/d09/lapacke__sporfs_8c_source.html":[2,0,3,3,1511],
+"dc/d09/lapacke__zheevr__2stage_8c.html":[2,0,3,3,1998],
+"dc/d09/lapacke__zheevr__2stage_8c_a1644ad7a37bb638e1b884ed8c938490e.html#a1644ad7a37bb638e1b884ed8c938490e":[2,0,3,3,1998,0],
+"dc/d09/lapacke__zheevr__2stage_8c_source.html":[2,0,3,3,1998],
+"dc/d09/slamswlq_8f.html":[2,0,4,1140],
+"dc/d09/slamswlq_8f_a31ca6763f721e788df6de9e4e4fdaf19.html#a31ca6763f721e788df6de9e4e4fdaf19":[2,0,4,1140,0],
+"dc/d09/slamswlq_8f_source.html":[2,0,4,1140],
 "dc/d0a/dsytri2_8f.html":[2,0,4,910],
 "dc/d0a/dsytri2_8f_source.html":[2,0,4,910],
-"dc/d0a/spprfs_8f.html":[2,0,4,1311],
-"dc/d0a/spprfs_8f_source.html":[2,0,4,1311],
-"dc/d0a/zpftrf_8f.html":[2,0,4,1781],
-"dc/d0a/zpftrf_8f_source.html":[2,0,4,1781],
+"dc/d0a/spprfs_8f.html":[2,0,4,1310],
+"dc/d0a/spprfs_8f_source.html":[2,0,4,1310],
+"dc/d0a/zpftrf_8f.html":[2,0,4,1780],
+"dc/d0a/zpftrf_8f_source.html":[2,0,4,1780],
 "dc/d0b/cblas__csscal_8c.html":[2,0,1,2,20],
 "dc/d0b/cblas__csscal_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[2,0,1,2,20,0],
 "dc/d0b/cblas__csscal_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[2,0,1,2,20,1],
 "dc/d0b/cblas__csscal_8c_aa78e552aa309959046117a7a6ed77fa8.html#aa78e552aa309959046117a7a6ed77fa8":[2,0,1,2,20,2],
 "dc/d0b/cblas__csscal_8c_source.html":[2,0,1,2,20],
 "dc/d0b/group__complex16_g_bauxiliary.html":[0,0,1,2,3],
-"dc/d0b/group__complex16_g_bauxiliary_ga19d1e2f9b96e3935d911285736481b5b.html#ga19d1e2f9b96e3935d911285736481b5b":[2,0,4,1716,0],
-"dc/d0b/group__complex16_g_bauxiliary_ga19d1e2f9b96e3935d911285736481b5b.html#ga19d1e2f9b96e3935d911285736481b5b":[0,0,1,2,3,1],
-"dc/d0b/group__complex16_g_bauxiliary_ga9a7fcf07eb1b4f472f40f6b0b5e92b13.html#ga9a7fcf07eb1b4f472f40f6b0b5e92b13":[0,0,1,2,3,0],
-"dc/d0b/group__complex16_g_bauxiliary_ga9a7fcf07eb1b4f472f40f6b0b5e92b13.html#ga9a7fcf07eb1b4f472f40f6b0b5e92b13":[2,0,4,1698,0],
-"dc/d0b/lapacke__dgeqlf_8c.html":[2,0,3,3,696],
-"dc/d0b/lapacke__dgeqlf_8c_a28926ae7122ed0291070837f4afa6f70.html#a28926ae7122ed0291070837f4afa6f70":[2,0,3,3,696,0],
-"dc/d0b/lapacke__dgeqlf_8c_source.html":[2,0,3,3,696],
+"dc/d0b/group__complex16_g_bauxiliary_ga0a7b3dc47c271db64d0f1001bcd2cdf7.html#ga0a7b3dc47c271db64d0f1001bcd2cdf7":[0,0,1,2,3,1],
+"dc/d0b/group__complex16_g_bauxiliary_ga0a7b3dc47c271db64d0f1001bcd2cdf7.html#ga0a7b3dc47c271db64d0f1001bcd2cdf7":[2,0,4,1715,0],
+"dc/d0b/group__complex16_g_bauxiliary_gad6a0255b5203b49d0f7828f0e03522aa.html#gad6a0255b5203b49d0f7828f0e03522aa":[2,0,4,1697,0],
+"dc/d0b/group__complex16_g_bauxiliary_gad6a0255b5203b49d0f7828f0e03522aa.html#gad6a0255b5203b49d0f7828f0e03522aa":[0,0,1,2,3,0],
+"dc/d0b/lapacke__dgeqlf_8c.html":[2,0,3,3,698],
+"dc/d0b/lapacke__dgeqlf_8c_a28926ae7122ed0291070837f4afa6f70.html#a28926ae7122ed0291070837f4afa6f70":[2,0,3,3,698,0],
+"dc/d0b/lapacke__dgeqlf_8c_source.html":[2,0,3,3,698],
 "dc/d0b/sggsvd_8f.html":[2,0,4,0,22],
-"dc/d0b/sggsvd_8f_aed548fcfdbce578154ecdde4e36a6716.html#aed548fcfdbce578154ecdde4e36a6716":[2,0,4,0,22,0],
+"dc/d0b/sggsvd_8f_a1f5fc3fcbce9d081fd9b409626b47db5.html#a1f5fc3fcbce9d081fd9b409626b47db5":[2,0,4,0,22,0],
 "dc/d0b/sggsvd_8f_source.html":[2,0,4,0,22],
 "dc/d0b/sgrqts_8f.html":[2,0,5,0,247],
 "dc/d0b/sgrqts_8f_source.html":[2,0,5,0,247],
-"dc/d0b/slansf_8f.html":[2,0,4,1149],
-"dc/d0b/slansf_8f_source.html":[2,0,4,1149],
+"dc/d0b/slansf_8f.html":[2,0,4,1148],
+"dc/d0b/slansf_8f_source.html":[2,0,4,1148],
 "dc/d0c/dtgsna_8f.html":[2,0,4,932],
 "dc/d0c/dtgsna_8f_source.html":[2,0,4,932],
 "dc/d0c/zdrvhe__rook_8f.html":[2,0,5,1,598],
 "dc/d0c/zdrvhe__rook_8f_source.html":[2,0,5,1,598],
-"dc/d0c/zrot_8f.html":[2,0,4,1815],
-"dc/d0c/zrot_8f_source.html":[2,0,4,1815],
-"dc/d0d/zlanhp_8f.html":[2,0,4,1704],
-"dc/d0d/zlanhp_8f_source.html":[2,0,4,1704],
+"dc/d0c/zrot_8f.html":[2,0,4,1814],
+"dc/d0c/zrot_8f_source.html":[2,0,4,1814],
+"dc/d0d/zlanhp_8f.html":[2,0,4,1703],
+"dc/d0d/zlanhp_8f_source.html":[2,0,4,1703],
 "dc/d0e/ddrges_8f.html":[2,0,5,0,111],
 "dc/d0e/ddrges_8f_source.html":[2,0,5,0,111],
-"dc/d10/lapacke__zhetrs__rook_8c.html":[2,0,3,3,2050],
-"dc/d10/lapacke__zhetrs__rook_8c_a05affa1a8f8c57a1acb9262a36b23806.html#a05affa1a8f8c57a1acb9262a36b23806":[2,0,3,3,2050,0],
-"dc/d10/lapacke__zhetrs__rook_8c_source.html":[2,0,3,3,2050],
+"dc/d10/lapacke__zhetrs__rook_8c.html":[2,0,3,3,2056],
+"dc/d10/lapacke__zhetrs__rook_8c_a05affa1a8f8c57a1acb9262a36b23806.html#a05affa1a8f8c57a1acb9262a36b23806":[2,0,3,3,2056,0],
+"dc/d10/lapacke__zhetrs__rook_8c_source.html":[2,0,3,3,2056],
 "dc/d12/claqp2_8f.html":[2,0,4,258],
 "dc/d12/claqp2_8f_source.html":[2,0,4,258],
-"dc/d12/lapacke__zhbevd_8c.html":[2,0,3,3,1959],
-"dc/d12/lapacke__zhbevd_8c_ac18b0ede20f17a74114ad50c9dc4b1c4.html#ac18b0ede20f17a74114ad50c9dc4b1c4":[2,0,3,3,1959,0],
-"dc/d12/lapacke__zhbevd_8c_source.html":[2,0,3,3,1959],
+"dc/d12/lapacke__zhbevd_8c.html":[2,0,3,3,1965],
+"dc/d12/lapacke__zhbevd_8c_ac18b0ede20f17a74114ad50c9dc4b1c4.html#ac18b0ede20f17a74114ad50c9dc4b1c4":[2,0,3,3,1965,0],
+"dc/d12/lapacke__zhbevd_8c_source.html":[2,0,3,3,1965],
 "dc/d13/clasyf__aa_8f.html":[2,0,4,296],
 "dc/d13/clasyf__aa_8f_source.html":[2,0,4,296],
-"dc/d13/sorml2_8f.html":[2,0,4,1275],
-"dc/d13/sorml2_8f_source.html":[2,0,4,1275],
-"dc/d14/lapacke__zggsvd_8c.html":[2,0,3,3,1935],
-"dc/d14/lapacke__zggsvd_8c_a8dea9e6a81ab80654e4f7800e94bb6ac.html#a8dea9e6a81ab80654e4f7800e94bb6ac":[2,0,3,3,1935,0],
-"dc/d14/lapacke__zggsvd_8c_source.html":[2,0,3,3,1935],
+"dc/d13/sorml2_8f.html":[2,0,4,1274],
+"dc/d13/sorml2_8f_source.html":[2,0,4,1274],
+"dc/d14/lapacke__zggsvd_8c.html":[2,0,3,3,1941],
+"dc/d14/lapacke__zggsvd_8c_a8dea9e6a81ab80654e4f7800e94bb6ac.html#a8dea9e6a81ab80654e4f7800e94bb6ac":[2,0,3,3,1941,0],
+"dc/d14/lapacke__zggsvd_8c_source.html":[2,0,3,3,1941],
 "dc/d15/cla__porfsx__extended_8f.html":[2,0,4,197],
 "dc/d15/cla__porfsx__extended_8f_source.html":[2,0,4,197],
-"dc/d15/lapacke__ssysv__aa_8c.html":[2,0,3,3,1670],
-"dc/d15/lapacke__ssysv__aa_8c_ae7c2a0d3306ba2a62cf13f454e530ca2.html#ae7c2a0d3306ba2a62cf13f454e530ca2":[2,0,3,3,1670,0],
-"dc/d15/lapacke__ssysv__aa_8c_source.html":[2,0,3,3,1670],
+"dc/d15/lapacke__ssysv__aa_8c.html":[2,0,3,3,1676],
+"dc/d15/lapacke__ssysv__aa_8c_ae7c2a0d3306ba2a62cf13f454e530ca2.html#ae7c2a0d3306ba2a62cf13f454e530ca2":[2,0,3,3,1676,0],
+"dc/d15/lapacke__ssysv__aa_8c_source.html":[2,0,3,3,1676],
 "dc/d16/ctptrs_8f.html":[2,0,4,428],
 "dc/d16/ctptrs_8f_source.html":[2,0,4,428],
 "dc/d16/slatb4_8f.html":[2,0,5,1,479],
@@ -177,8 +196,8 @@ var NAVTREEINDEX74 =
 "dc/d17/group__complex16__blas__level3_ga263a46a500f5c7f04bee1b75ea7f64f6.html#ga263a46a500f5c7f04bee1b75ea7f64f6":[2,0,0,0,140,0],
 "dc/d17/group__complex16__blas__level3_ga3faec48d92afecad0a791157278b184c.html#ga3faec48d92afecad0a791157278b184c":[0,2,2,3,6],
 "dc/d17/group__complex16__blas__level3_ga3faec48d92afecad0a791157278b184c.html#ga3faec48d92afecad0a791157278b184c":[2,0,0,0,142,0],
-"dc/d17/group__complex16__blas__level3_ga4ef748ade85e685b8b2241a7c56dd21c.html#ga4ef748ade85e685b8b2241a7c56dd21c":[2,0,0,0,123,0],
 "dc/d17/group__complex16__blas__level3_ga4ef748ade85e685b8b2241a7c56dd21c.html#ga4ef748ade85e685b8b2241a7c56dd21c":[0,2,2,3,0],
+"dc/d17/group__complex16__blas__level3_ga4ef748ade85e685b8b2241a7c56dd21c.html#ga4ef748ade85e685b8b2241a7c56dd21c":[2,0,0,0,123,0],
 "dc/d17/group__complex16__blas__level3_ga6c1fde6c797cc1032c19242662f370f2.html#ga6c1fde6c797cc1032c19242662f370f2":[0,2,2,3,1],
 "dc/d17/group__complex16__blas__level3_ga6c1fde6c797cc1032c19242662f370f2.html#ga6c1fde6c797cc1032c19242662f370f2":[2,0,0,0,128,0],
 "dc/d17/group__complex16__blas__level3_ga71e68893445a523b923411ebf4c22582.html#ga71e68893445a523b923411ebf4c22582":[0,2,2,3,3],
@@ -217,37 +236,18 @@ var NAVTREEINDEX74 =
 "dc/d1a/lapacke__cgetrs_8c_source.html":[2,0,3,3,118],
 "dc/d1c/chesv_8f.html":[2,0,4,130],
 "dc/d1c/chesv_8f_source.html":[2,0,4,130],
-"dc/d1c/lapacke__dlascl_8c.html":[2,0,3,3,842],
-"dc/d1c/lapacke__dlascl_8c_a7c65930622ecac278c2916fcf6a39bd8.html#a7c65930622ecac278c2916fcf6a39bd8":[2,0,3,3,842,0],
-"dc/d1c/lapacke__dlascl_8c_source.html":[2,0,3,3,842],
-"dc/d1d/lapacke__ctbcon_8c.html":[2,0,3,3,510],
-"dc/d1d/lapacke__ctbcon_8c_a0adb7ca7be6572de1cf32a0fd7627fda.html#a0adb7ca7be6572de1cf32a0fd7627fda":[2,0,3,3,510,0],
-"dc/d1d/lapacke__ctbcon_8c_source.html":[2,0,3,3,510],
+"dc/d1c/lapacke__dlascl_8c.html":[2,0,3,3,844],
+"dc/d1c/lapacke__dlascl_8c_a7c65930622ecac278c2916fcf6a39bd8.html#a7c65930622ecac278c2916fcf6a39bd8":[2,0,3,3,844,0],
+"dc/d1c/lapacke__dlascl_8c_source.html":[2,0,3,3,844],
+"dc/d1d/lapacke__ctbcon_8c.html":[2,0,3,3,512],
+"dc/d1d/lapacke__ctbcon_8c_a0adb7ca7be6572de1cf32a0fd7627fda.html#a0adb7ca7be6572de1cf32a0fd7627fda":[2,0,3,3,512,0],
+"dc/d1d/lapacke__ctbcon_8c_source.html":[2,0,3,3,512],
 "dc/d1e/strt06_8f.html":[2,0,5,1,548],
 "dc/d1e/strt06_8f_source.html":[2,0,5,1,548],
-"dc/d1f/sgeev_8f.html":[2,0,4,1009],
-"dc/d1f/sgeev_8f_source.html":[2,0,4,1009],
+"dc/d1f/sgeev_8f.html":[2,0,4,1008],
+"dc/d1f/sgeev_8f_source.html":[2,0,4,1008],
 "dc/d20/cla__syrcond__x_8f.html":[2,0,4,201],
 "dc/d20/cla__syrcond__x_8f_source.html":[2,0,4,201],
 "dc/d21/chetf2_8f.html":[2,0,4,138],
-"dc/d21/chetf2_8f_source.html":[2,0,4,138],
-"dc/d21/cunbdb5_8f.html":[2,0,4,450],
-"dc/d21/cunbdb5_8f_source.html":[2,0,4,450],
-"dc/d21/dgerfsx_8f.html":[2,0,4,537],
-"dc/d21/dgerfsx_8f_source.html":[2,0,4,537],
-"dc/d21/lapacke__cgt__nancheck_8c.html":[2,0,3,4,7],
-"dc/d21/lapacke__cgt__nancheck_8c_a63a94370c10fc2a97391fb77a0034e81.html#a63a94370c10fc2a97391fb77a0034e81":[2,0,3,4,7,0],
-"dc/d21/lapacke__cgt__nancheck_8c_source.html":[2,0,3,4,7],
-"dc/d21/lapacke__sppsvx_8c.html":[2,0,3,3,1531],
-"dc/d21/lapacke__sppsvx_8c_a7ee9551e6406d01de37491eb8e702700.html#a7ee9551e6406d01de37491eb8e702700":[2,0,3,3,1531,0],
-"dc/d21/lapacke__sppsvx_8c_source.html":[2,0,3,3,1531],
-"dc/d22/cblas__chbmv_8c.html":[2,0,1,2,9],
-"dc/d22/cblas__chbmv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[2,0,1,2,9,0],
-"dc/d22/cblas__chbmv_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[2,0,1,2,9,1],
-"dc/d22/cblas__chbmv_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[2,0,1,2,9,2],
-"dc/d22/cblas__chbmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[2,0,1,2,9,4],
-"dc/d22/cblas__chbmv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[2,0,1,2,9,3],
-"dc/d22/cblas__chbmv_8c_a9b291e527c6c99949fccadfa9942352f.html#a9b291e527c6c99949fccadfa9942352f":[2,0,1,2,9,6],
-"dc/d22/cblas__chbmv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[2,0,1,2,9,5],
-"dc/d22/cblas__chbmv_8c_source.html":[2,0,1,2,9]
+"dc/d21/chetf2_8f_source.html":[2,0,4,138]
 };
