@@ -1,152 +1,174 @@
 var NAVTREEINDEX81 =
 {
+"dd/d87/lapacke__example__aux_8h_aea6079ddbe35ed06b9550a0680179643.html#aea6079ddbe35ed06b9550a0680179643":[2,0,3,0,6,0],
+"dd/d87/lapacke__example__aux_8h_source.html":[2,0,3,0,6],
+"dd/d8a/dorghr_8f.html":[2,0,4,761],
+"dd/d8a/dorghr_8f_source.html":[2,0,4,761],
+"dd/d8a/lapacke__zlarnv__work_8c.html":[2,0,3,3,2134],
+"dd/d8a/lapacke__zlarnv__work_8c_ad2a990ecbb560f746f9a598359dc1e01.html#ad2a990ecbb560f746f9a598359dc1e01":[2,0,3,3,2134,0],
+"dd/d8a/lapacke__zlarnv__work_8c_source.html":[2,0,3,3,2134],
+"dd/d8b/_t_e_s_t_i_n_g_2_e_i_g_2xerbla_8f.html":[2,0,5,0,275],
+"dd/d8b/_t_e_s_t_i_n_g_2_e_i_g_2xerbla_8f_source.html":[2,0,5,0,275],
+"dd/d8c/lapacke__sorgqr__work_8c.html":[2,0,3,3,1462],
+"dd/d8c/lapacke__sorgqr__work_8c_ae21b88c7fb2e63ba66b61f33cb4c6f6c.html#ae21b88c7fb2e63ba66b61f33cb4c6f6c":[2,0,3,3,1462,0],
+"dd/d8c/lapacke__sorgqr__work_8c_source.html":[2,0,3,3,1462],
+"dd/d8c/lapacke__sporfsx_8c.html":[2,0,3,3,1513],
+"dd/d8c/lapacke__sporfsx_8c_a85450ed74b4fa5db7a41a0f4b61a190c.html#a85450ed74b4fa5db7a41a0f4b61a190c":[2,0,3,3,1513,0],
+"dd/d8c/lapacke__sporfsx_8c_source.html":[2,0,3,3,1513],
+"dd/d8e/lapacke__ctgevc__work_8c.html":[2,0,3,3,527],
+"dd/d8e/lapacke__ctgevc__work_8c_a1949a099ba799c98c93f7a24a13f0777.html#a1949a099ba799c98c93f7a24a13f0777":[2,0,3,3,527,0],
+"dd/d8e/lapacke__ctgevc__work_8c_source.html":[2,0,3,3,527],
+"dd/d8e/lapacke__stpmqrt__work_8c.html":[2,0,3,3,1746],
+"dd/d8e/lapacke__stpmqrt__work_8c_a9e913e74d819a98d4566b99f81672142.html#a9e913e74d819a98d4566b99f81672142":[2,0,3,3,1746,0],
+"dd/d8e/lapacke__stpmqrt__work_8c_source.html":[2,0,3,3,1746],
+"dd/d8e/ztrt06_8f.html":[2,0,5,1,752],
 "dd/d8e/ztrt06_8f_source.html":[2,0,5,1,752],
 "dd/d91/serrqrtp_8f.html":[2,0,5,1,448],
 "dd/d91/serrqrtp_8f_source.html":[2,0,5,1,448],
 "dd/d92/dgetc2_8f.html":[2,0,4,548],
 "dd/d92/dgetc2_8f_source.html":[2,0,4,548],
-"dd/d92/lapacke__slatms__work_8c.html":[2,0,3,3,1434],
-"dd/d92/lapacke__slatms__work_8c_a593087ce669ce66d54399dd1b50d0ba1.html#a593087ce669ce66d54399dd1b50d0ba1":[2,0,3,3,1434,0],
-"dd/d92/lapacke__slatms__work_8c_source.html":[2,0,3,3,1434],
+"dd/d92/lapacke__slatms__work_8c.html":[2,0,3,3,1440],
+"dd/d92/lapacke__slatms__work_8c_a593087ce669ce66d54399dd1b50d0ba1.html#a593087ce669ce66d54399dd1b50d0ba1":[2,0,3,3,1440,0],
+"dd/d92/lapacke__slatms__work_8c_source.html":[2,0,3,3,1440],
 "dd/d94/dsytrs__rook_8f.html":[2,0,4,919],
 "dd/d94/dsytrs__rook_8f_source.html":[2,0,4,919],
 "dd/d94/lapacke__chpgvx_8c.html":[2,0,3,3,286],
 "dd/d94/lapacke__chpgvx_8c_aa72da7a6c46c8a1eebe458b7648ed5b3.html#aa72da7a6c46c8a1eebe458b7648ed5b3":[2,0,3,3,286,0],
 "dd/d94/lapacke__chpgvx_8c_source.html":[2,0,3,3,286],
-"dd/d95/zheevx_8f.html":[2,0,4,1584],
-"dd/d95/zheevx_8f_source.html":[2,0,4,1584],
-"dd/d96/lapacke__ssbtrd__work_8c.html":[2,0,3,3,1576],
-"dd/d96/lapacke__ssbtrd__work_8c_a675cb281124f533dc14d8765e8be932a.html#a675cb281124f533dc14d8765e8be932a":[2,0,3,3,1576,0],
-"dd/d96/lapacke__ssbtrd__work_8c_source.html":[2,0,3,3,1576],
+"dd/d95/zheevx_8f.html":[2,0,4,1583],
+"dd/d95/zheevx_8f_source.html":[2,0,4,1583],
+"dd/d96/lapacke__ssbtrd__work_8c.html":[2,0,3,3,1582],
+"dd/d96/lapacke__ssbtrd__work_8c_a675cb281124f533dc14d8765e8be932a.html#a675cb281124f533dc14d8765e8be932a":[2,0,3,3,1582,0],
+"dd/d96/lapacke__ssbtrd__work_8c_source.html":[2,0,3,3,1582],
 "dd/d97/clatm6_8f.html":[2,0,5,2,13],
 "dd/d97/clatm6_8f_source.html":[2,0,5,2,13],
 "dd/d98/cchkbb_8f.html":[2,0,5,0,10],
 "dd/d98/cchkbb_8f_source.html":[2,0,5,0,10],
-"dd/d98/strttf_8f.html":[2,0,4,1458],
-"dd/d98/strttf_8f_source.html":[2,0,4,1458],
+"dd/d98/strttf_8f.html":[2,0,4,1457],
+"dd/d98/strttf_8f_source.html":[2,0,4,1457],
 "dd/d98/ztrt01_8f.html":[2,0,5,1,748],
 "dd/d98/ztrt01_8f_source.html":[2,0,5,1,748],
 "dd/d9a/group__double_g_ecomputational.html":[0,0,0,3,0],
 "dd/d9a/group__double_g_ecomputational_ga0019443faea08275ca60a734d0593e60.html#ga0019443faea08275ca60a734d0593e60":[2,0,4,550,0],
 "dd/d9a/group__double_g_ecomputational_ga0019443faea08275ca60a734d0593e60.html#ga0019443faea08275ca60a734d0593e60":[0,0,0,3,0,35],
-"dd/d9a/group__double_g_ecomputational_ga060b34c3874dd74899f0832fe4564b28.html#ga060b34c3874dd74899f0832fe4564b28":[0,0,0,3,0,30],
-"dd/d9a/group__double_g_ecomputational_ga060b34c3874dd74899f0832fe4564b28.html#ga060b34c3874dd74899f0832fe4564b28":[2,0,4,537,0],
-"dd/d9a/group__double_g_ecomputational_ga06e0be3e29ccab046a1936e6fd210607.html#ga06e0be3e29ccab046a1936e6fd210607":[0,0,0,3,0,33],
-"dd/d9a/group__double_g_ecomputational_ga06e0be3e29ccab046a1936e6fd210607.html#ga06e0be3e29ccab046a1936e6fd210607":[2,0,4,545,0],
-"dd/d9a/group__double_g_ecomputational_ga0860daeae9b6084202a647418f54af27.html#ga0860daeae9b6084202a647418f54af27":[0,0,0,3,0,19],
 "dd/d9a/group__double_g_ecomputational_ga0860daeae9b6084202a647418f54af27.html#ga0860daeae9b6084202a647418f54af27":[2,0,4,526,0],
-"dd/d9a/group__double_g_ecomputational_ga14ddd93ddf8aa38daf5a0ce1f6052ce3.html#ga14ddd93ddf8aa38daf5a0ce1f6052ce3":[2,0,4,500,0],
+"dd/d9a/group__double_g_ecomputational_ga0860daeae9b6084202a647418f54af27.html#ga0860daeae9b6084202a647418f54af27":[0,0,0,3,0,19],
 "dd/d9a/group__double_g_ecomputational_ga14ddd93ddf8aa38daf5a0ce1f6052ce3.html#ga14ddd93ddf8aa38daf5a0ce1f6052ce3":[0,0,0,3,0,5],
-"dd/d9a/group__double_g_ecomputational_ga197166c1c1b1b1d365b66c6251053c5c.html#ga197166c1c1b1b1d365b66c6251053c5c":[0,0,0,3,0,43],
-"dd/d9a/group__double_g_ecomputational_ga197166c1c1b1b1d365b66c6251053c5c.html#ga197166c1c1b1b1d365b66c6251053c5c":[2,0,4,591,0],
+"dd/d9a/group__double_g_ecomputational_ga14ddd93ddf8aa38daf5a0ce1f6052ce3.html#ga14ddd93ddf8aa38daf5a0ce1f6052ce3":[2,0,4,500,0],
+"dd/d9a/group__double_g_ecomputational_ga188b8d30443d14b1a3f7f8331d87ae60.html#ga188b8d30443d14b1a3f7f8331d87ae60":[0,0,0,3,0,7],
+"dd/d9a/group__double_g_ecomputational_ga188b8d30443d14b1a3f7f8331d87ae60.html#ga188b8d30443d14b1a3f7f8331d87ae60":[2,0,4,502,0],
+"dd/d9a/group__double_g_ecomputational_ga19c6e9e133a5ea3f59a24959889429f2.html#ga19c6e9e133a5ea3f59a24959889429f2":[2,0,4,590,0],
+"dd/d9a/group__double_g_ecomputational_ga19c6e9e133a5ea3f59a24959889429f2.html#ga19c6e9e133a5ea3f59a24959889429f2":[0,0,0,3,0,42],
 "dd/d9a/group__double_g_ecomputational_ga1a3e42d2dea189bfdd5ca5de2a0439e7.html#ga1a3e42d2dea189bfdd5ca5de2a0439e7":[0,0,0,3,0,0],
 "dd/d9a/group__double_g_ecomputational_ga1a3e42d2dea189bfdd5ca5de2a0439e7.html#ga1a3e42d2dea189bfdd5ca5de2a0439e7":[2,0,4,33,0],
 "dd/d9a/group__double_g_ecomputational_ga1b0500f49e03d2771b797c6e88adabbb.html#ga1b0500f49e03d2771b797c6e88adabbb":[2,0,4,527,0],
 "dd/d9a/group__double_g_ecomputational_ga1b0500f49e03d2771b797c6e88adabbb.html#ga1b0500f49e03d2771b797c6e88adabbb":[0,0,0,3,0,20],
-"dd/d9a/group__double_g_ecomputational_ga23aa35b5a5b38810d55ce4c7bd82952b.html#ga23aa35b5a5b38810d55ce4c7bd82952b":[2,0,4,927,0],
-"dd/d9a/group__double_g_ecomputational_ga23aa35b5a5b38810d55ce4c7bd82952b.html#ga23aa35b5a5b38810d55ce4c7bd82952b":[0,0,0,3,0,44],
+"dd/d9a/group__double_g_ecomputational_ga21c89aba210fbfb8cca635e47dccbdb3.html#ga21c89aba210fbfb8cca635e47dccbdb3":[2,0,4,580,0],
+"dd/d9a/group__double_g_ecomputational_ga21c89aba210fbfb8cca635e47dccbdb3.html#ga21c89aba210fbfb8cca635e47dccbdb3":[0,0,0,3,0,39],
+"dd/d9a/group__double_g_ecomputational_ga2510d68d70194719d570cbcfe24b3e74.html#ga2510d68d70194719d570cbcfe24b3e74":[0,0,0,3,0,45],
+"dd/d9a/group__double_g_ecomputational_ga2510d68d70194719d570cbcfe24b3e74.html#ga2510d68d70194719d570cbcfe24b3e74":[2,0,4,929,0],
 "dd/d9a/group__double_g_ecomputational_ga2611cc9dfdc84e2a08ec57a5dd6cdd2e.html#ga2611cc9dfdc84e2a08ec57a5dd6cdd2e":[0,0,0,3,0,11],
 "dd/d9a/group__double_g_ecomputational_ga2611cc9dfdc84e2a08ec57a5dd6cdd2e.html#ga2611cc9dfdc84e2a08ec57a5dd6cdd2e":[2,0,4,510,0],
-"dd/d9a/group__double_g_ecomputational_ga2f10ebf79772a5399be9ed6169c9d975.html#ga2f10ebf79772a5399be9ed6169c9d975":[0,0,0,3,0,12],
 "dd/d9a/group__double_g_ecomputational_ga2f10ebf79772a5399be9ed6169c9d975.html#ga2f10ebf79772a5399be9ed6169c9d975":[2,0,4,513,0],
+"dd/d9a/group__double_g_ecomputational_ga2f10ebf79772a5399be9ed6169c9d975.html#ga2f10ebf79772a5399be9ed6169c9d975":[0,0,0,3,0,12],
 "dd/d9a/group__double_g_ecomputational_ga360f5b8b756dc7d366c3decfcdf89000.html#ga360f5b8b756dc7d366c3decfcdf89000":[0,0,0,3,0,31],
 "dd/d9a/group__double_g_ecomputational_ga360f5b8b756dc7d366c3decfcdf89000.html#ga360f5b8b756dc7d366c3decfcdf89000":[2,0,4,538,0],
 "dd/d9a/group__double_g_ecomputational_ga3766ea903391b5cf9008132f7440ec7b.html#ga3766ea903391b5cf9008132f7440ec7b":[0,0,0,3,0,24],
 "dd/d9a/group__double_g_ecomputational_ga3766ea903391b5cf9008132f7440ec7b.html#ga3766ea903391b5cf9008132f7440ec7b":[2,0,4,531,0],
 "dd/d9a/group__double_g_ecomputational_ga3a43ee755a96cc411fcf7e4c58156839.html#ga3a43ee755a96cc411fcf7e4c58156839":[0,0,0,3,0,15],
 "dd/d9a/group__double_g_ecomputational_ga3a43ee755a96cc411fcf7e4c58156839.html#ga3a43ee755a96cc411fcf7e4c58156839":[2,0,4,516,0],
-"dd/d9a/group__double_g_ecomputational_ga3ad112f2b0890b3815e696628906f30c.html#ga3ad112f2b0890b3815e696628906f30c":[0,0,0,3,0,28],
 "dd/d9a/group__double_g_ecomputational_ga3ad112f2b0890b3815e696628906f30c.html#ga3ad112f2b0890b3815e696628906f30c":[2,0,4,535,0],
+"dd/d9a/group__double_g_ecomputational_ga3ad112f2b0890b3815e696628906f30c.html#ga3ad112f2b0890b3815e696628906f30c":[0,0,0,3,0,28],
+"dd/d9a/group__double_g_ecomputational_ga3b18b13aeed841f1d7d6c5581573ee4e.html#ga3b18b13aeed841f1d7d6c5581573ee4e":[2,0,4,1503,0],
+"dd/d9a/group__double_g_ecomputational_ga3b18b13aeed841f1d7d6c5581573ee4e.html#ga3b18b13aeed841f1d7d6c5581573ee4e":[0,0,0,3,0,51],
 "dd/d9a/group__double_g_ecomputational_ga411292dd693c20ff9c27650fb7bddf85.html#ga411292dd693c20ff9c27650fb7bddf85":[0,0,0,3,0,4],
 "dd/d9a/group__double_g_ecomputational_ga411292dd693c20ff9c27650fb7bddf85.html#ga411292dd693c20ff9c27650fb7bddf85":[2,0,4,499,0],
 "dd/d9a/group__double_g_ecomputational_ga436228e38ef5c55e3229502afa2c4220.html#ga436228e38ef5c55e3229502afa2c4220":[0,0,0,3,0,13],
 "dd/d9a/group__double_g_ecomputational_ga436228e38ef5c55e3229502afa2c4220.html#ga436228e38ef5c55e3229502afa2c4220":[2,0,4,514,0],
-"dd/d9a/group__double_g_ecomputational_ga49d3d0c5758eb9fcb7c1bd6bc0082fe2.html#ga49d3d0c5758eb9fcb7c1bd6bc0082fe2":[2,0,4,522,0],
-"dd/d9a/group__double_g_ecomputational_ga49d3d0c5758eb9fcb7c1bd6bc0082fe2.html#ga49d3d0c5758eb9fcb7c1bd6bc0082fe2":[0,0,0,3,0,16],
-"dd/d9a/group__double_g_ecomputational_ga4b004d2ebecb407abd16bde43606bbcf.html#ga4b004d2ebecb407abd16bde43606bbcf":[0,0,0,3,0,40],
-"dd/d9a/group__double_g_ecomputational_ga4b004d2ebecb407abd16bde43606bbcf.html#ga4b004d2ebecb407abd16bde43606bbcf":[2,0,4,588,0],
-"dd/d9a/group__double_g_ecomputational_ga50aa58c97b389375440f74164d508537.html#ga50aa58c97b389375440f74164d508537":[2,0,4,1017,0],
+"dd/d9a/group__double_g_ecomputational_ga4547be7cf34938979c5d741d148e4d3b.html#ga4547be7cf34938979c5d741d148e4d3b":[2,0,4,504,0],
+"dd/d9a/group__double_g_ecomputational_ga4547be7cf34938979c5d741d148e4d3b.html#ga4547be7cf34938979c5d741d148e4d3b":[0,0,0,3,0,9],
+"dd/d9a/group__double_g_ecomputational_ga464f0a0d80d32e6d6b164de84460e027.html#ga464f0a0d80d32e6d6b164de84460e027":[2,0,4,522,0],
+"dd/d9a/group__double_g_ecomputational_ga464f0a0d80d32e6d6b164de84460e027.html#ga464f0a0d80d32e6d6b164de84460e027":[0,0,0,3,0,16],
+"dd/d9a/group__double_g_ecomputational_ga486d8da01d3304d595dab4cef3353ce6.html#ga486d8da01d3304d595dab4cef3353ce6":[0,0,0,3,0,3],
+"dd/d9a/group__double_g_ecomputational_ga486d8da01d3304d595dab4cef3353ce6.html#ga486d8da01d3304d595dab4cef3353ce6":[2,0,4,498,0],
+"dd/d9a/group__double_g_ecomputational_ga50aa58c97b389375440f74164d508537.html#ga50aa58c97b389375440f74164d508537":[2,0,4,1016,0],
 "dd/d9a/group__double_g_ecomputational_ga50aa58c97b389375440f74164d508537.html#ga50aa58c97b389375440f74164d508537":[0,0,0,3,0,46],
+"dd/d9a/group__double_g_ecomputational_ga5539077fbd3a92c4d92b75bf58da5db3.html#ga5539077fbd3a92c4d92b75bf58da5db3":[2,0,4,589,0],
+"dd/d9a/group__double_g_ecomputational_ga5539077fbd3a92c4d92b75bf58da5db3.html#ga5539077fbd3a92c4d92b75bf58da5db3":[0,0,0,3,0,41],
+"dd/d9a/group__double_g_ecomputational_ga56565ae06016954202aee24cdfc38257.html#ga56565ae06016954202aee24cdfc38257":[0,0,0,3,0,8],
+"dd/d9a/group__double_g_ecomputational_ga56565ae06016954202aee24cdfc38257.html#ga56565ae06016954202aee24cdfc38257":[2,0,4,503,0],
 "dd/d9a/group__double_g_ecomputational_ga56d9c860ce4ce42ded7f914fdb0683ff.html#ga56d9c860ce4ce42ded7f914fdb0683ff":[2,0,4,552,0],
 "dd/d9a/group__double_g_ecomputational_ga56d9c860ce4ce42ded7f914fdb0683ff.html#ga56d9c860ce4ce42ded7f914fdb0683ff":[0,0,0,3,0,37],
-"dd/d9a/group__double_g_ecomputational_ga57133b8664ecefa47f290a47770c7dcf.html#ga57133b8664ecefa47f290a47770c7dcf":[2,0,4,1504,0],
-"dd/d9a/group__double_g_ecomputational_ga57133b8664ecefa47f290a47770c7dcf.html#ga57133b8664ecefa47f290a47770c7dcf":[0,0,0,3,0,51],
-"dd/d9a/group__double_g_ecomputational_ga58577004bb5ca9674b34f1e7d7b16f1c.html#ga58577004bb5ca9674b34f1e7d7b16f1c":[2,0,4,503,0],
-"dd/d9a/group__double_g_ecomputational_ga58577004bb5ca9674b34f1e7d7b16f1c.html#ga58577004bb5ca9674b34f1e7d7b16f1c":[0,0,0,3,0,8],
-"dd/d9a/group__double_g_ecomputational_ga58e332cb1b8ab770270843221a48296d.html#ga58e332cb1b8ab770270843221a48296d":[0,0,0,3,0,38],
 "dd/d9a/group__double_g_ecomputational_ga58e332cb1b8ab770270843221a48296d.html#ga58e332cb1b8ab770270843221a48296d":[2,0,4,553,0],
-"dd/d9a/group__double_g_ecomputational_ga5dc72a0f55ff4c08f1a3596f56e04aaa.html#ga5dc72a0f55ff4c08f1a3596f56e04aaa":[2,0,4,532,0],
+"dd/d9a/group__double_g_ecomputational_ga58e332cb1b8ab770270843221a48296d.html#ga58e332cb1b8ab770270843221a48296d":[0,0,0,3,0,38],
 "dd/d9a/group__double_g_ecomputational_ga5dc72a0f55ff4c08f1a3596f56e04aaa.html#ga5dc72a0f55ff4c08f1a3596f56e04aaa":[0,0,0,3,0,25],
-"dd/d9a/group__double_g_ecomputational_ga6990dff8fd4b5ade76eb54e1542249dd.html#ga6990dff8fd4b5ade76eb54e1542249dd":[2,0,4,536,0],
-"dd/d9a/group__double_g_ecomputational_ga6990dff8fd4b5ade76eb54e1542249dd.html#ga6990dff8fd4b5ade76eb54e1542249dd":[0,0,0,3,0,29],
-"dd/d9a/group__double_g_ecomputational_ga7b5b0875f52af2fde4da3c5c6555aaed.html#ga7b5b0875f52af2fde4da3c5c6555aaed":[2,0,4,1024,0],
-"dd/d9a/group__double_g_ecomputational_ga7b5b0875f52af2fde4da3c5c6555aaed.html#ga7b5b0875f52af2fde4da3c5c6555aaed":[0,0,0,3,0,48],
-"dd/d9a/group__double_g_ecomputational_ga7bba0d791b011eb5425ecbf500e9be2c.html#ga7bba0d791b011eb5425ecbf500e9be2c":[0,0,0,3,0,32],
+"dd/d9a/group__double_g_ecomputational_ga5dc72a0f55ff4c08f1a3596f56e04aaa.html#ga5dc72a0f55ff4c08f1a3596f56e04aaa":[2,0,4,532,0],
+"dd/d9a/group__double_g_ecomputational_ga60fe6f45ae036702cf7affea4f0de69c.html#ga60fe6f45ae036702cf7affea4f0de69c":[0,0,0,3,0,44],
+"dd/d9a/group__double_g_ecomputational_ga60fe6f45ae036702cf7affea4f0de69c.html#ga60fe6f45ae036702cf7affea4f0de69c":[2,0,4,927,0],
 "dd/d9a/group__double_g_ecomputational_ga7bba0d791b011eb5425ecbf500e9be2c.html#ga7bba0d791b011eb5425ecbf500e9be2c":[2,0,4,539,0],
-"dd/d9a/group__double_g_ecomputational_ga8360b5b2c819e19c82bfd7e6b8285f74.html#ga8360b5b2c819e19c82bfd7e6b8285f74":[0,0,0,3,0,34],
+"dd/d9a/group__double_g_ecomputational_ga7bba0d791b011eb5425ecbf500e9be2c.html#ga7bba0d791b011eb5425ecbf500e9be2c":[0,0,0,3,0,32],
+"dd/d9a/group__double_g_ecomputational_ga7c4cd88a2446ad8eef46eb37fc4fbeb5.html#ga7c4cd88a2446ad8eef46eb37fc4fbeb5":[2,0,4,1023,0],
+"dd/d9a/group__double_g_ecomputational_ga7c4cd88a2446ad8eef46eb37fc4fbeb5.html#ga7c4cd88a2446ad8eef46eb37fc4fbeb5":[0,0,0,3,0,48],
 "dd/d9a/group__double_g_ecomputational_ga8360b5b2c819e19c82bfd7e6b8285f74.html#ga8360b5b2c819e19c82bfd7e6b8285f74":[2,0,4,549,0],
-"dd/d9a/group__double_g_ecomputational_ga849775edb5276cb73da5e9030860d30b.html#ga849775edb5276cb73da5e9030860d30b":[0,0,0,3,0,2],
-"dd/d9a/group__double_g_ecomputational_ga849775edb5276cb73da5e9030860d30b.html#ga849775edb5276cb73da5e9030860d30b":[2,0,4,40,0],
-"dd/d9a/group__double_g_ecomputational_ga86586a8c4f1c31707724ed70e92f6f34.html#ga86586a8c4f1c31707724ed70e92f6f34":[0,0,0,3,0,22],
+"dd/d9a/group__double_g_ecomputational_ga8360b5b2c819e19c82bfd7e6b8285f74.html#ga8360b5b2c819e19c82bfd7e6b8285f74":[0,0,0,3,0,34],
 "dd/d9a/group__double_g_ecomputational_ga86586a8c4f1c31707724ed70e92f6f34.html#ga86586a8c4f1c31707724ed70e92f6f34":[2,0,4,529,0],
-"dd/d9a/group__double_g_ecomputational_ga939806608a352efe62d3f5c918ca28c6.html#ga939806608a352efe62d3f5c918ca28c6":[2,0,4,502,0],
-"dd/d9a/group__double_g_ecomputational_ga939806608a352efe62d3f5c918ca28c6.html#ga939806608a352efe62d3f5c918ca28c6":[0,0,0,3,0,7],
-"dd/d9a/group__double_g_ecomputational_ga976b17056c80d4aeed6438b4118d114a.html#ga976b17056c80d4aeed6438b4118d114a":[0,0,0,3,0,10],
+"dd/d9a/group__double_g_ecomputational_ga86586a8c4f1c31707724ed70e92f6f34.html#ga86586a8c4f1c31707724ed70e92f6f34":[0,0,0,3,0,22],
 "dd/d9a/group__double_g_ecomputational_ga976b17056c80d4aeed6438b4118d114a.html#ga976b17056c80d4aeed6438b4118d114a":[2,0,4,509,0],
-"dd/d9a/group__double_g_ecomputational_ga98b75b2c589f0198ec496fb279a6341f.html#ga98b75b2c589f0198ec496fb279a6341f":[0,0,0,3,0,45],
-"dd/d9a/group__double_g_ecomputational_ga98b75b2c589f0198ec496fb279a6341f.html#ga98b75b2c589f0198ec496fb279a6341f":[2,0,4,929,0],
-"dd/d9a/group__double_g_ecomputational_gaa16ad53e2b6d3f6310b51fb2756db98d.html#gaa16ad53e2b6d3f6310b51fb2756db98d":[0,0,0,3,0,3],
-"dd/d9a/group__double_g_ecomputational_gaa16ad53e2b6d3f6310b51fb2756db98d.html#gaa16ad53e2b6d3f6310b51fb2756db98d":[2,0,4,498,0],
-"dd/d9a/group__double_g_ecomputational_gaa3566c994515b42248393b145448a128.html#gaa3566c994515b42248393b145448a128":[0,0,0,3,0,42],
-"dd/d9a/group__double_g_ecomputational_gaa3566c994515b42248393b145448a128.html#gaa3566c994515b42248393b145448a128":[2,0,4,590,0],
-"dd/d9a/group__double_g_ecomputational_gaa3c49765445900907515a341da534d19.html#gaa3c49765445900907515a341da534d19":[2,0,4,525,0],
+"dd/d9a/group__double_g_ecomputational_ga976b17056c80d4aeed6438b4118d114a.html#ga976b17056c80d4aeed6438b4118d114a":[0,0,0,3,0,10],
+"dd/d9a/group__double_g_ecomputational_ga9c735b94f840f927f8085fd23f3ee2e6.html#ga9c735b94f840f927f8085fd23f3ee2e6":[0,0,0,3,0,6],
+"dd/d9a/group__double_g_ecomputational_ga9c735b94f840f927f8085fd23f3ee2e6.html#ga9c735b94f840f927f8085fd23f3ee2e6":[2,0,4,501,0],
 "dd/d9a/group__double_g_ecomputational_gaa3c49765445900907515a341da534d19.html#gaa3c49765445900907515a341da534d19":[0,0,0,3,0,18],
+"dd/d9a/group__double_g_ecomputational_gaa3c49765445900907515a341da534d19.html#gaa3c49765445900907515a341da534d19":[2,0,4,525,0],
 "dd/d9a/group__double_g_ecomputational_gabb576e6f096eb7b999a4ec2f97e59bc2.html#gabb576e6f096eb7b999a4ec2f97e59bc2":[0,0,0,3,0,1],
 "dd/d9a/group__double_g_ecomputational_gabb576e6f096eb7b999a4ec2f97e59bc2.html#gabb576e6f096eb7b999a4ec2f97e59bc2":[2,0,4,34,0],
 "dd/d9a/group__double_g_ecomputational_gabdd3af29e9f6bbaf4b352341a1e8b464.html#gabdd3af29e9f6bbaf4b352341a1e8b464":[2,0,4,551,0],
 "dd/d9a/group__double_g_ecomputational_gabdd3af29e9f6bbaf4b352341a1e8b464.html#gabdd3af29e9f6bbaf4b352341a1e8b464":[0,0,0,3,0,36],
-"dd/d9a/group__double_g_ecomputational_gac23dcce69ba7ed823872ce3ed82b0dd6.html#gac23dcce69ba7ed823872ce3ed82b0dd6":[0,0,0,3,0,17],
-"dd/d9a/group__double_g_ecomputational_gac23dcce69ba7ed823872ce3ed82b0dd6.html#gac23dcce69ba7ed823872ce3ed82b0dd6":[2,0,4,524,0],
-"dd/d9a/group__double_g_ecomputational_gac44bd55d81edc0d66d551514bf7aa5ee.html#gac44bd55d81edc0d66d551514bf7aa5ee":[2,0,4,1018,0],
+"dd/d9a/group__double_g_ecomputational_gac14340a964d1df1b2f4483844a7c0df1.html#gac14340a964d1df1b2f4483844a7c0df1":[0,0,0,3,0,33],
+"dd/d9a/group__double_g_ecomputational_gac14340a964d1df1b2f4483844a7c0df1.html#gac14340a964d1df1b2f4483844a7c0df1":[2,0,4,545,0],
+"dd/d9a/group__double_g_ecomputational_gac150eadbadeb706cda2998e2bb0a70dd.html#gac150eadbadeb706cda2998e2bb0a70dd":[0,0,0,3,0,40],
+"dd/d9a/group__double_g_ecomputational_gac150eadbadeb706cda2998e2bb0a70dd.html#gac150eadbadeb706cda2998e2bb0a70dd":[2,0,4,588,0],
 "dd/d9a/group__double_g_ecomputational_gac44bd55d81edc0d66d551514bf7aa5ee.html#gac44bd55d81edc0d66d551514bf7aa5ee":[0,0,0,3,0,47],
-"dd/d9a/group__double_g_ecomputational_gac94a53483f7f42aa6f23e8c42dc22cbc.html#gac94a53483f7f42aa6f23e8c42dc22cbc":[2,0,4,589,0],
-"dd/d9a/group__double_g_ecomputational_gac94a53483f7f42aa6f23e8c42dc22cbc.html#gac94a53483f7f42aa6f23e8c42dc22cbc":[0,0,0,3,0,41],
+"dd/d9a/group__double_g_ecomputational_gac44bd55d81edc0d66d551514bf7aa5ee.html#gac44bd55d81edc0d66d551514bf7aa5ee":[2,0,4,1017,0],
+"dd/d9a/group__double_g_ecomputational_gac47363c60e542f007e7b6e1d48f0273b.html#gac47363c60e542f007e7b6e1d48f0273b":[0,0,0,3,0,29],
+"dd/d9a/group__double_g_ecomputational_gac47363c60e542f007e7b6e1d48f0273b.html#gac47363c60e542f007e7b6e1d48f0273b":[2,0,4,536,0],
 "dd/d9a/group__double_g_ecomputational_gacc8649ebced520728bc7086b786c7ff1.html#gacc8649ebced520728bc7086b786c7ff1":[0,0,0,3,0,23],
 "dd/d9a/group__double_g_ecomputational_gacc8649ebced520728bc7086b786c7ff1.html#gacc8649ebced520728bc7086b786c7ff1":[2,0,4,530,0],
 "dd/d9a/group__double_g_ecomputational_gacd2363728d6375717e15caf21e9daecf.html#gacd2363728d6375717e15caf21e9daecf":[0,0,0,3,0,49],
-"dd/d9a/group__double_g_ecomputational_gacd2363728d6375717e15caf21e9daecf.html#gacd2363728d6375717e15caf21e9daecf":[2,0,4,1497,0],
-"dd/d9a/group__double_g_ecomputational_gad18e81accc13bbb9b4589b2e4a68f40c.html#gad18e81accc13bbb9b4589b2e4a68f40c":[2,0,4,580,0],
-"dd/d9a/group__double_g_ecomputational_gad18e81accc13bbb9b4589b2e4a68f40c.html#gad18e81accc13bbb9b4589b2e4a68f40c":[0,0,0,3,0,39],
-"dd/d9a/group__double_g_ecomputational_gad8259ed277a5b252cde4b8802ce3be4f.html#gad8259ed277a5b252cde4b8802ce3be4f":[2,0,4,1498,0],
+"dd/d9a/group__double_g_ecomputational_gacd2363728d6375717e15caf21e9daecf.html#gacd2363728d6375717e15caf21e9daecf":[2,0,4,1496,0],
+"dd/d9a/group__double_g_ecomputational_gad8259ed277a5b252cde4b8802ce3be4f.html#gad8259ed277a5b252cde4b8802ce3be4f":[2,0,4,1497,0],
 "dd/d9a/group__double_g_ecomputational_gad8259ed277a5b252cde4b8802ce3be4f.html#gad8259ed277a5b252cde4b8802ce3be4f":[0,0,0,3,0,50],
 "dd/d9a/group__double_g_ecomputational_gaddcf152e87deec6123a1899f6f51101e.html#gaddcf152e87deec6123a1899f6f51101e":[0,0,0,3,0,26],
 "dd/d9a/group__double_g_ecomputational_gaddcf152e87deec6123a1899f6f51101e.html#gaddcf152e87deec6123a1899f6f51101e":[2,0,4,533,0],
-"dd/d9a/group__double_g_ecomputational_gade6ad2e443f1d6686471d5861a2c3e6e.html#gade6ad2e443f1d6686471d5861a2c3e6e":[0,0,0,3,0,9],
-"dd/d9a/group__double_g_ecomputational_gade6ad2e443f1d6686471d5861a2c3e6e.html#gade6ad2e443f1d6686471d5861a2c3e6e":[2,0,4,504,0],
-"dd/d9a/group__double_g_ecomputational_gae1ee3e79e729c81f5a3756a18f0323d4.html#gae1ee3e79e729c81f5a3756a18f0323d4":[0,0,0,3,0,6],
-"dd/d9a/group__double_g_ecomputational_gae1ee3e79e729c81f5a3756a18f0323d4.html#gae1ee3e79e729c81f5a3756a18f0323d4":[2,0,4,501,0],
+"dd/d9a/group__double_g_ecomputational_gae1378019437b04b2b46b5f7be3b5e175.html#gae1378019437b04b2b46b5f7be3b5e175":[0,0,0,3,0,43],
+"dd/d9a/group__double_g_ecomputational_gae1378019437b04b2b46b5f7be3b5e175.html#gae1378019437b04b2b46b5f7be3b5e175":[2,0,4,591,0],
+"dd/d9a/group__double_g_ecomputational_gae60113eba7a360d9c92cc2b627e0c5d2.html#gae60113eba7a360d9c92cc2b627e0c5d2":[2,0,4,537,0],
+"dd/d9a/group__double_g_ecomputational_gae60113eba7a360d9c92cc2b627e0c5d2.html#gae60113eba7a360d9c92cc2b627e0c5d2":[0,0,0,3,0,30],
 "dd/d9a/group__double_g_ecomputational_gaecad6eac294d2df861c6ae3b614c1ce8.html#gaecad6eac294d2df861c6ae3b614c1ce8":[2,0,4,0,12,0],
 "dd/d9a/group__double_g_ecomputational_gaecad6eac294d2df861c6ae3b614c1ce8.html#gaecad6eac294d2df861c6ae3b614c1ce8":[0,0,0,3,0,21],
 "dd/d9a/group__double_g_ecomputational_gaf52830cc84214fbf513bb7f520095aa9.html#gaf52830cc84214fbf513bb7f520095aa9":[2,0,4,534,0],
 "dd/d9a/group__double_g_ecomputational_gaf52830cc84214fbf513bb7f520095aa9.html#gaf52830cc84214fbf513bb7f520095aa9":[0,0,0,3,0,27],
+"dd/d9a/group__double_g_ecomputational_gaf55d7b3137b198647461d429a7e9b2c6.html#gaf55d7b3137b198647461d429a7e9b2c6":[2,0,4,524,0],
+"dd/d9a/group__double_g_ecomputational_gaf55d7b3137b198647461d429a7e9b2c6.html#gaf55d7b3137b198647461d429a7e9b2c6":[0,0,0,3,0,17],
 "dd/d9a/group__double_g_ecomputational_gaf9691e821373db5b6712e53c71812d0e.html#gaf9691e821373db5b6712e53c71812d0e":[2,0,4,515,0],
 "dd/d9a/group__double_g_ecomputational_gaf9691e821373db5b6712e53c71812d0e.html#gaf9691e821373db5b6712e53c71812d0e":[0,0,0,3,0,14],
-"dd/d9a/lapacke__shgeqz__work_8c.html":[2,0,3,3,1380],
-"dd/d9a/lapacke__shgeqz__work_8c_a5ad5c7720b3acb0b74d67f0212b506b2.html#a5ad5c7720b3acb0b74d67f0212b506b2":[2,0,3,3,1380,0],
-"dd/d9a/lapacke__shgeqz__work_8c_source.html":[2,0,3,3,1380],
+"dd/d9a/group__double_g_ecomputational_gaffbe855398a6733f3d3904a878cfea9e.html#gaffbe855398a6733f3d3904a878cfea9e":[0,0,0,3,0,2],
+"dd/d9a/group__double_g_ecomputational_gaffbe855398a6733f3d3904a878cfea9e.html#gaffbe855398a6733f3d3904a878cfea9e":[2,0,4,40,0],
+"dd/d9a/lapacke__shgeqz__work_8c.html":[2,0,3,3,1384],
+"dd/d9a/lapacke__shgeqz__work_8c_a5ad5c7720b3acb0b74d67f0212b506b2.html#a5ad5c7720b3acb0b74d67f0212b506b2":[2,0,3,3,1384,0],
+"dd/d9a/lapacke__shgeqz__work_8c_source.html":[2,0,3,3,1384],
 "dd/d9b/cerrgg_8f.html":[2,0,5,0,48],
 "dd/d9b/cerrgg_8f_source.html":[2,0,5,0,48],
 "dd/d9b/dchkaa_8f.html":[2,0,5,1,203],
 "dd/d9b/dchkaa_8f_source.html":[2,0,5,1,203],
-"dd/d9b/lapacke__zhpsvx_8c.html":[2,0,3,3,2077],
-"dd/d9b/lapacke__zhpsvx_8c_a8cd52f52c1dd14fbc01d2d2d77248ab7.html#a8cd52f52c1dd14fbc01d2d2d77248ab7":[2,0,3,3,2077,0],
-"dd/d9b/lapacke__zhpsvx_8c_source.html":[2,0,3,3,2077],
+"dd/d9b/lapacke__zhpsvx_8c.html":[2,0,3,3,2083],
+"dd/d9b/lapacke__zhpsvx_8c_a8cd52f52c1dd14fbc01d2d2d77248ab7.html#a8cd52f52c1dd14fbc01d2d2d77248ab7":[2,0,3,3,2083,0],
+"dd/d9b/lapacke__zhpsvx_8c_source.html":[2,0,3,3,2083],
 "dd/d9b/struct_c_b_l_a_s___t_e_s_t___c_o_m_p_l_e_x.html":[1,0,0],
 "dd/d9b/struct_c_b_l_a_s___t_e_s_t___c_o_m_p_l_e_x_ad096472a9ec33f65907315a868148594.html#ad096472a9ec33f65907315a868148594":[1,0,0,0],
 "dd/d9b/struct_c_b_l_a_s___t_e_s_t___c_o_m_p_l_e_x_ad1342ab549573f9c111d7317c4f1dd81.html#ad1342ab549573f9c111d7317c4f1dd81":[1,0,0,1],
-"dd/d9c/lapacke__ssysvx__work_8c.html":[2,0,3,3,1678],
-"dd/d9c/lapacke__ssysvx__work_8c_a7ad7d52f5e1bdf062e65d83a45be1e20.html#a7ad7d52f5e1bdf062e65d83a45be1e20":[2,0,3,3,1678,0],
-"dd/d9c/lapacke__ssysvx__work_8c_source.html":[2,0,3,3,1678],
+"dd/d9c/lapacke__ssysvx__work_8c.html":[2,0,3,3,1684],
+"dd/d9c/lapacke__ssysvx__work_8c_a7ad7d52f5e1bdf062e65d83a45be1e20.html#a7ad7d52f5e1bdf062e65d83a45be1e20":[2,0,3,3,1684,0],
+"dd/d9c/lapacke__ssysvx__work_8c_source.html":[2,0,3,3,1684],
 "dd/d9e/dspr2_8f.html":[2,0,0,0,54],
 "dd/d9e/dspr2_8f_source.html":[2,0,0,0,54],
 "dd/d9f/cblas__strmv_8c.html":[2,0,1,2,107],
@@ -158,9 +180,9 @@ var NAVTREEINDEX81 =
 "dd/d9f/cblas__strmv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[2,0,1,2,107,5],
 "dd/d9f/cblas__strmv_8c_aa6269eb8e6be57a1c67276260e0928fd.html#aa6269eb8e6be57a1c67276260e0928fd":[2,0,1,2,107,6],
 "dd/d9f/cblas__strmv_8c_source.html":[2,0,1,2,107],
-"dd/da0/lapacke__zlag2c_8c.html":[2,0,3,3,2099],
-"dd/da0/lapacke__zlag2c_8c_a5aef2501f97767d5d323910d27b566eb.html#a5aef2501f97767d5d323910d27b566eb":[2,0,3,3,2099,0],
-"dd/da0/lapacke__zlag2c_8c_source.html":[2,0,3,3,2099],
+"dd/da0/lapacke__zlag2c_8c.html":[2,0,3,3,2105],
+"dd/da0/lapacke__zlag2c_8c_a5aef2501f97767d5d323910d27b566eb.html#a5aef2501f97767d5d323910d27b566eb":[2,0,3,3,2105,0],
+"dd/da0/lapacke__zlag2c_8c_source.html":[2,0,3,3,2105],
 "dd/da0/zdrvrf2_8f.html":[2,0,5,1,608],
 "dd/da0/zdrvrf2_8f_source.html":[2,0,5,1,608],
 "dd/da1/dgemqrt_8f.html":[2,0,4,524],
@@ -171,83 +193,61 @@ var NAVTREEINDEX81 =
 "dd/da1/dlaein_8f_source.html":[2,0,4,620],
 "dd/da1/zchkrq_8f.html":[2,0,5,1,577],
 "dd/da1/zchkrq_8f_source.html":[2,0,5,1,577],
-"dd/da2/iparmq_8f.html":[2,0,4,979],
-"dd/da2/iparmq_8f_source.html":[2,0,4,979],
+"dd/da2/iparmq_8f.html":[2,0,4,978],
+"dd/da2/iparmq_8f_source.html":[2,0,4,978],
 "dd/da2/zlatb5_8f.html":[2,0,5,1,674],
 "dd/da2/zlatb5_8f_source.html":[2,0,5,1,674],
 "dd/da3/group___g_t.html":[0,0,5],
-"dd/da3/lapacke__dgerfs__work_8c.html":[2,0,3,3,717],
-"dd/da3/lapacke__dgerfs__work_8c_a85029a228b5cf325dd12439886b7a903.html#a85029a228b5cf325dd12439886b7a903":[2,0,3,3,717,0],
-"dd/da3/lapacke__dgerfs__work_8c_source.html":[2,0,3,3,717],
-"dd/da3/lapacke__dptsv_8c.html":[2,0,3,3,964],
-"dd/da3/lapacke__dptsv_8c_ad7d9b4801e00c192c17f1bfeeb7db880.html#ad7d9b4801e00c192c17f1bfeeb7db880":[2,0,3,3,964,0],
-"dd/da3/lapacke__dptsv_8c_source.html":[2,0,3,3,964],
-"dd/da3/lapacke__sorcsd2by1_8c.html":[2,0,3,3,1444],
-"dd/da3/lapacke__sorcsd2by1_8c_a9c666c03583c7c198e918eb44944ba93.html#a9c666c03583c7c198e918eb44944ba93":[2,0,3,3,1444,0],
-"dd/da3/lapacke__sorcsd2by1_8c_source.html":[2,0,3,3,1444],
+"dd/da3/lapacke__dgerfs__work_8c.html":[2,0,3,3,719],
+"dd/da3/lapacke__dgerfs__work_8c_a85029a228b5cf325dd12439886b7a903.html#a85029a228b5cf325dd12439886b7a903":[2,0,3,3,719,0],
+"dd/da3/lapacke__dgerfs__work_8c_source.html":[2,0,3,3,719],
+"dd/da3/lapacke__dptsv_8c.html":[2,0,3,3,968],
+"dd/da3/lapacke__dptsv_8c_ad7d9b4801e00c192c17f1bfeeb7db880.html#ad7d9b4801e00c192c17f1bfeeb7db880":[2,0,3,3,968,0],
+"dd/da3/lapacke__dptsv_8c_source.html":[2,0,3,3,968],
+"dd/da3/lapacke__sorcsd2by1_8c.html":[2,0,3,3,1450],
+"dd/da3/lapacke__sorcsd2by1_8c_a9c666c03583c7c198e918eb44944ba93.html#a9c666c03583c7c198e918eb44944ba93":[2,0,3,3,1450,0],
+"dd/da3/lapacke__sorcsd2by1_8c_source.html":[2,0,3,3,1450],
 "dd/da4/lapacke__cgttrs_8c.html":[2,0,3,3,168],
 "dd/da4/lapacke__cgttrs_8c_aa99c5f0a2b4294265a2014107a2313d6.html#aa99c5f0a2b4294265a2014107a2313d6":[2,0,3,3,168,0],
 "dd/da4/lapacke__cgttrs_8c_source.html":[2,0,3,3,168],
-"dd/da4/slange_8f.html":[2,0,4,1145],
-"dd/da4/slange_8f_source.html":[2,0,4,1145],
-"dd/da4/slarfb_8f.html":[2,0,4,1179],
-"dd/da4/slarfb_8f_source.html":[2,0,4,1179],
-"dd/da4/ssterf_8f.html":[2,0,4,1362],
-"dd/da4/ssterf_8f_source.html":[2,0,4,1362],
-"dd/da5/lapacke__strtrs__work_8c.html":[2,0,3,3,1774],
-"dd/da5/lapacke__strtrs__work_8c_a9f0e7c2cd55e44d92e594ee98c00be5e.html#a9f0e7c2cd55e44d92e594ee98c00be5e":[2,0,3,3,1774,0],
-"dd/da5/lapacke__strtrs__work_8c_source.html":[2,0,3,3,1774],
+"dd/da4/slange_8f.html":[2,0,4,1144],
+"dd/da4/slange_8f_source.html":[2,0,4,1144],
+"dd/da4/slarfb_8f.html":[2,0,4,1178],
+"dd/da4/slarfb_8f_source.html":[2,0,4,1178],
+"dd/da4/ssterf_8f.html":[2,0,4,1361],
+"dd/da4/ssterf_8f_source.html":[2,0,4,1361],
+"dd/da5/lapacke__strtrs__work_8c.html":[2,0,3,3,1780],
+"dd/da5/lapacke__strtrs__work_8c_a9f0e7c2cd55e44d92e594ee98c00be5e.html#a9f0e7c2cd55e44d92e594ee98c00be5e":[2,0,3,3,1780,0],
+"dd/da5/lapacke__strtrs__work_8c_source.html":[2,0,3,3,1780],
 "dd/da6/lapacke__chpevd__work_8c.html":[2,0,3,3,277],
 "dd/da6/lapacke__chpevd__work_8c_a480e2580124e66927e09df4b1a8e02e9.html#a480e2580124e66927e09df4b1a8e02e9":[2,0,3,3,277,0],
 "dd/da6/lapacke__chpevd__work_8c_source.html":[2,0,3,3,277],
 "dd/da7/ddrvrf4_8f.html":[2,0,5,1,250],
 "dd/da7/ddrvrf4_8f_source.html":[2,0,5,1,250],
-"dd/da8/lapacke__zlauum_8c.html":[2,0,3,3,2137],
-"dd/da8/lapacke__zlauum_8c_a6b60f819848426b630f165da8196c2cf.html#a6b60f819848426b630f165da8196c2cf":[2,0,3,3,2137,0],
-"dd/da8/lapacke__zlauum_8c_source.html":[2,0,3,3,2137],
-"dd/da8/zppsvx_8f.html":[2,0,4,1801],
-"dd/da8/zppsvx_8f_source.html":[2,0,4,1801],
-"dd/da8/zpttrs_8f.html":[2,0,4,1813],
-"dd/da8/zpttrs_8f_source.html":[2,0,4,1813],
+"dd/da8/lapacke__zlauum_8c.html":[2,0,3,3,2145],
+"dd/da8/lapacke__zlauum_8c_a6b60f819848426b630f165da8196c2cf.html#a6b60f819848426b630f165da8196c2cf":[2,0,3,3,2145,0],
+"dd/da8/lapacke__zlauum_8c_source.html":[2,0,3,3,2145],
+"dd/da8/zppsvx_8f.html":[2,0,4,1800],
+"dd/da8/zppsvx_8f_source.html":[2,0,4,1800],
+"dd/da8/zpttrs_8f.html":[2,0,4,1812],
+"dd/da8/zpttrs_8f_source.html":[2,0,4,1812],
 "dd/daa/dlarft_8f.html":[2,0,4,680],
 "dd/daa/dlarft_8f_source.html":[2,0,4,680],
 "dd/daa/ieeeck_8f.html":[2,0,4,964],
 "dd/daa/ieeeck_8f_source.html":[2,0,4,964],
-"dd/dac/zhpgvx_8f.html":[2,0,4,1632],
-"dd/dac/zhpgvx_8f_source.html":[2,0,4,1632],
+"dd/dac/zhpgvx_8f.html":[2,0,4,1631],
+"dd/dac/zhpgvx_8f_source.html":[2,0,4,1631],
 "dd/dad/cerrsy_8f.html":[2,0,5,1,90],
 "dd/dad/cerrsy_8f_source.html":[2,0,5,1,90],
 "dd/dad/dpstrf_8f.html":[2,0,4,817],
 "dd/dad/dpstrf_8f_source.html":[2,0,4,817],
 "dd/dae/cporfsx_8f.html":[2,0,4,324],
 "dd/dae/cporfsx_8f_source.html":[2,0,4,324],
-"dd/dae/lapacke__sposv__work_8c.html":[2,0,3,3,1510],
-"dd/dae/lapacke__sposv__work_8c_a89d64061ff2219eef8335a22dba33d2d.html#a89d64061ff2219eef8335a22dba33d2d":[2,0,3,3,1510,0],
-"dd/dae/lapacke__sposv__work_8c_source.html":[2,0,3,3,1510],
-"dd/dae/lapacke__zsytrs__rook_8c.html":[2,0,3,3,2292],
-"dd/dae/lapacke__zsytrs__rook_8c_a9fe95f22f3b9688d8a8d090653c14f42.html#a9fe95f22f3b9688d8a8d090653c14f42":[2,0,3,3,2292,0],
-"dd/dae/lapacke__zsytrs__rook_8c_source.html":[2,0,3,3,2292],
-"dd/daf/ctprfs_8f.html":[2,0,4,426],
-"dd/daf/ctprfs_8f_source.html":[2,0,4,426],
-"dd/daf/dqrt12_8f.html":[2,0,5,1,347],
-"dd/daf/dqrt12_8f_source.html":[2,0,5,1,347],
-"dd/db0/lapacke__sgeqrf_8c.html":[2,0,3,3,1289],
-"dd/db0/lapacke__sgeqrf_8c_a0019d6a960183fb3aad7ebefd25bae4c.html#a0019d6a960183fb3aad7ebefd25bae4c":[2,0,3,3,1289,0],
-"dd/db0/lapacke__sgeqrf_8c_source.html":[2,0,3,3,1289],
-"dd/db0/zdrvhex_8f.html":[2,0,5,1,599],
-"dd/db0/zdrvhex_8f_source.html":[2,0,5,1,599],
-"dd/db2/cdotc_8f.html":[2,0,0,0,2],
-"dd/db2/cdotc_8f_source.html":[2,0,0,0,2],
-"dd/db2/lapacke__spprfs__work_8c.html":[2,0,3,3,1528],
-"dd/db2/lapacke__spprfs__work_8c_a7da655f75a6b1bad955e3e69fa6cedaf.html#a7da655f75a6b1bad955e3e69fa6cedaf":[2,0,3,3,1528,0],
-"dd/db2/lapacke__spprfs__work_8c_source.html":[2,0,3,3,1528],
-"dd/db2/zggevx_8f.html":[2,0,4,1544],
-"dd/db2/zggevx_8f_source.html":[2,0,4,1544],
-"dd/db3/group__complex16_s_ycomputational.html":[0,0,2,2,3],
-"dd/db3/group__complex16_s_ycomputational_ga01840c133523c7ae6b912f6b54427981.html#ga01840c133523c7ae6b912f6b54427981":[2,0,4,1901,0],
-"dd/db3/group__complex16_s_ycomputational_ga01840c133523c7ae6b912f6b54427981.html#ga01840c133523c7ae6b912f6b54427981":[0,0,2,2,3,37],
-"dd/db3/group__complex16_s_ycomputational_ga08a69231abc76ecca401fad02c8e0821.html#ga08a69231abc76ecca401fad02c8e0821":[0,0,2,2,3,18],
-"dd/db3/group__complex16_s_ycomputational_ga08a69231abc76ecca401fad02c8e0821.html#ga08a69231abc76ecca401fad02c8e0821":[2,0,4,1848,0],
-"dd/db3/group__complex16_s_ycomputational_ga0a5a0d65f60b7fd32e60cb95d9b414b4.html#ga0a5a0d65f60b7fd32e60cb95d9b414b4":[0,0,2,2,3,15],
-"dd/db3/group__complex16_s_ycomputational_ga0a5a0d65f60b7fd32e60cb95d9b414b4.html#ga0a5a0d65f60b7fd32e60cb95d9b414b4":[2,0,4,1836,0]
+"dd/dae/lapacke__sposv__work_8c.html":[2,0,3,3,1516],
+"dd/dae/lapacke__sposv__work_8c_a89d64061ff2219eef8335a22dba33d2d.html#a89d64061ff2219eef8335a22dba33d2d":[2,0,3,3,1516,0],
+"dd/dae/lapacke__sposv__work_8c_source.html":[2,0,3,3,1516],
+"dd/dae/lapacke__zsytrs__rook_8c.html":[2,0,3,3,2300],
+"dd/dae/lapacke__zsytrs__rook_8c_a9fe95f22f3b9688d8a8d090653c14f42.html#a9fe95f22f3b9688d8a8d090653c14f42":[2,0,3,3,2300,0],
+"dd/dae/lapacke__zsytrs__rook_8c_source.html":[2,0,3,3,2300],
+"dd/daf/ctprfs_8f.html":[2,0,4,426]
 };
