@@ -1,11 +1,33 @@
 var NAVTREEINDEX88 =
 {
+"de/d99/cggglm_8f.html":[2,0,4,81],
+"de/d99/cggglm_8f_source.html":[2,0,4,81],
+"de/d99/lapacke__dstegr__work_8c.html":[2,0,3,3,1039],
+"de/d99/lapacke__dstegr__work_8c_ad9396d374050e2c623c903b059cdc729.html#ad9396d374050e2c623c903b059cdc729":[2,0,3,3,1039,0],
+"de/d99/lapacke__dstegr__work_8c_source.html":[2,0,3,3,1039],
+"de/d99/lapacke__sormqr_8c.html":[2,0,3,3,1475],
+"de/d99/lapacke__sormqr_8c_ae24c847d36a3e9b56e4fc5b150237d66.html#ae24c847d36a3e9b56e4fc5b150237d66":[2,0,3,3,1475,0],
+"de/d99/lapacke__sormqr_8c_source.html":[2,0,3,3,1475],
+"de/d9a/lapacke__cgerqf_8c.html":[2,0,3,3,94],
+"de/d9a/lapacke__cgerqf_8c_a9a3114be8c99664371cc0e4f12a0ee10.html#a9a3114be8c99664371cc0e4f12a0ee10":[2,0,3,3,94,0],
+"de/d9a/lapacke__cgerqf_8c_source.html":[2,0,3,3,94],
+"de/d9a/lapacke__csyequb_8c.html":[2,0,3,3,464],
+"de/d9a/lapacke__csyequb_8c_aafe5b048fe2e31e96ea72c3adb693929.html#aafe5b048fe2e31e96ea72c3adb693929":[2,0,3,3,464,0],
+"de/d9a/lapacke__csyequb_8c_source.html":[2,0,3,3,464],
+"de/d9b/cerrrfp_8f.html":[2,0,5,1,88],
+"de/d9b/cerrrfp_8f_source.html":[2,0,5,1,88],
+"de/d9b/dlagts_8f.html":[2,0,4,628],
+"de/d9b/dlagts_8f_source.html":[2,0,4,628],
+"de/d9b/zerrhex_8f.html":[2,0,5,1,625],
+"de/d9b/zerrhex_8f_source.html":[2,0,5,1,625],
+"de/d9c/cchksy__rook_8f.html":[2,0,5,1,36],
+"de/d9c/cchksy__rook_8f_source.html":[2,0,5,1,36],
 "de/d9e/dsbevd_8f.html":[2,0,4,830],
 "de/d9e/dsbevd_8f_source.html":[2,0,4,830],
 "de/d9e/group___s_y.html":[0,0,2],
-"de/d9e/lapacke__dpprfs_8c.html":[2,0,3,3,944],
-"de/d9e/lapacke__dpprfs_8c_aaed8ab744762a3fe829b7d5130aa8eaa.html#aaed8ab744762a3fe829b7d5130aa8eaa":[2,0,3,3,944,0],
-"de/d9e/lapacke__dpprfs_8c_source.html":[2,0,3,3,944],
+"de/d9e/lapacke__dpprfs_8c.html":[2,0,3,3,948],
+"de/d9e/lapacke__dpprfs_8c_aaed8ab744762a3fe829b7d5130aa8eaa.html#aaed8ab744762a3fe829b7d5130aa8eaa":[2,0,3,3,948,0],
+"de/d9e/lapacke__dpprfs_8c_source.html":[2,0,3,3,948],
 "de/d9f/cgegv_8f.html":[2,0,4,0,1],
 "de/d9f/cgegv_8f_source.html":[2,0,4,0,1],
 "de/d9f/derrst_8f.html":[2,0,5,0,131],
@@ -181,73 +203,51 @@ var NAVTREEINDEX88 =
 "de/da1/zget54_8f_source.html":[2,0,5,0,333],
 "de/da2/caxpy_8f.html":[2,0,0,0,0],
 "de/da2/caxpy_8f_source.html":[2,0,0,0,0],
-"de/da2/zlatsqr_8f.html":[2,0,4,1769],
-"de/da2/zlatsqr_8f_ad25c5d9c54c17139e42f0ec1bc9a1f2c.html#ad25c5d9c54c17139e42f0ec1bc9a1f2c":[2,0,4,1769,0],
-"de/da2/zlatsqr_8f_source.html":[2,0,4,1769],
-"de/da3/slarrj_8f.html":[2,0,4,1193],
-"de/da3/slarrj_8f_source.html":[2,0,4,1193],
+"de/da2/zlatsqr_8f.html":[2,0,4,1768],
+"de/da2/zlatsqr_8f_a64c1038c174ff7b5a46d72b4edf62a82.html#a64c1038c174ff7b5a46d72b4edf62a82":[2,0,4,1768,0],
+"de/da2/zlatsqr_8f_source.html":[2,0,4,1768],
+"de/da3/slarrj_8f.html":[2,0,4,1192],
+"de/da3/slarrj_8f_source.html":[2,0,4,1192],
 "de/da3/stbt02_8f.html":[2,0,5,1,534],
 "de/da3/stbt02_8f_source.html":[2,0,5,1,534],
 "de/da3/zqrt13_8f.html":[2,0,5,1,719],
 "de/da3/zqrt13_8f_source.html":[2,0,5,1,719],
 "de/da4/group__double__blas__level1.html":[0,2,0,1],
-"de/da4/group__double__blas__level1_ga0d579faa55a493933032c5dcddbe5f4f.html#ga0d579faa55a493933032c5dcddbe5f4f":[2,0,0,0,47,0],
 "de/da4/group__double__blas__level1_ga0d579faa55a493933032c5dcddbe5f4f.html#ga0d579faa55a493933032c5dcddbe5f4f":[0,2,0,1,8],
+"de/da4/group__double__blas__level1_ga0d579faa55a493933032c5dcddbe5f4f.html#ga0d579faa55a493933032c5dcddbe5f4f":[2,0,0,0,47,0],
 "de/da4/group__double__blas__level1_ga13e351a3dfafa2cd8dc5302dcf53f69a.html#ga13e351a3dfafa2cd8dc5302dcf53f69a":[0,2,0,1,9],
 "de/da4/group__double__blas__level1_ga13e351a3dfafa2cd8dc5302dcf53f69a.html#ga13e351a3dfafa2cd8dc5302dcf53f69a":[2,0,0,0,48,0],
-"de/da4/group__double__blas__level1_ga21cdaae1732dea58194c279fca30126d.html#ga21cdaae1732dea58194c279fca30126d":[2,0,0,0,38,0],
 "de/da4/group__double__blas__level1_ga21cdaae1732dea58194c279fca30126d.html#ga21cdaae1732dea58194c279fca30126d":[0,2,0,1,3],
-"de/da4/group__double__blas__level1_ga32d6fccb43cb13feafc23825f2685ba0.html#ga32d6fccb43cb13feafc23825f2685ba0":[0,2,0,1,11],
+"de/da4/group__double__blas__level1_ga21cdaae1732dea58194c279fca30126d.html#ga21cdaae1732dea58194c279fca30126d":[2,0,0,0,38,0],
 "de/da4/group__double__blas__level1_ga32d6fccb43cb13feafc23825f2685ba0.html#ga32d6fccb43cb13feafc23825f2685ba0":[2,0,0,0,51,0],
+"de/da4/group__double__blas__level1_ga32d6fccb43cb13feafc23825f2685ba0.html#ga32d6fccb43cb13feafc23825f2685ba0":[0,2,0,1,11],
 "de/da4/group__double__blas__level1_ga4b25c539b862414e6f91ebb30b391d7c.html#ga4b25c539b862414e6f91ebb30b391d7c":[0,2,0,1,5],
 "de/da4/group__double__blas__level1_ga4b25c539b862414e6f91ebb30b391d7c.html#ga4b25c539b862414e6f91ebb30b391d7c":[2,0,0,0,44,0],
 "de/da4/group__double__blas__level1_ga53914429b84cb315da483e71e27ed5c1.html#ga53914429b84cb315da483e71e27ed5c1":[2,0,0,0,37,0],
 "de/da4/group__double__blas__level1_ga53914429b84cb315da483e71e27ed5c1.html#ga53914429b84cb315da483e71e27ed5c1":[0,2,0,1,2],
-"de/da4/group__double__blas__level1_ga54d516b6e0497df179c9831f2554b1f9.html#ga54d516b6e0497df179c9831f2554b1f9":[0,2,0,1,6],
 "de/da4/group__double__blas__level1_ga54d516b6e0497df179c9831f2554b1f9.html#ga54d516b6e0497df179c9831f2554b1f9":[2,0,0,0,45,0],
-"de/da4/group__double__blas__level1_ga60d5c8001b317c929778670a15013eb4.html#ga60d5c8001b317c929778670a15013eb4":[0,2,0,1,14],
+"de/da4/group__double__blas__level1_ga54d516b6e0497df179c9831f2554b1f9.html#ga54d516b6e0497df179c9831f2554b1f9":[0,2,0,1,6],
 "de/da4/group__double__blas__level1_ga60d5c8001b317c929778670a15013eb4.html#ga60d5c8001b317c929778670a15013eb4":[2,0,0,0,70,0],
+"de/da4/group__double__blas__level1_ga60d5c8001b317c929778670a15013eb4.html#ga60d5c8001b317c929778670a15013eb4":[0,2,0,1,14],
 "de/da4/group__double__blas__level1_ga7372361a44de0649813750b3280c58cc.html#ga7372361a44de0649813750b3280c58cc":[2,0,0,0,35,0],
 "de/da4/group__double__blas__level1_ga7372361a44de0649813750b3280c58cc.html#ga7372361a44de0649813750b3280c58cc":[0,2,0,1,0],
-"de/da4/group__double__blas__level1_ga75066c4825cb6ff1c8ec4403ef8c843a.html#ga75066c4825cb6ff1c8ec4403ef8c843a":[2,0,0,0,39,0],
 "de/da4/group__double__blas__level1_ga75066c4825cb6ff1c8ec4403ef8c843a.html#ga75066c4825cb6ff1c8ec4403ef8c843a":[0,2,0,1,4],
-"de/da4/group__double__blas__level1_ga793bdd0739bbd0e0ec8655a0df08981a.html#ga793bdd0739bbd0e0ec8655a0df08981a":[2,0,0,0,50,0],
+"de/da4/group__double__blas__level1_ga75066c4825cb6ff1c8ec4403ef8c843a.html#ga75066c4825cb6ff1c8ec4403ef8c843a":[2,0,0,0,39,0],
 "de/da4/group__double__blas__level1_ga793bdd0739bbd0e0ec8655a0df08981a.html#ga793bdd0739bbd0e0ec8655a0df08981a":[0,2,0,1,10],
+"de/da4/group__double__blas__level1_ga793bdd0739bbd0e0ec8655a0df08981a.html#ga793bdd0739bbd0e0ec8655a0df08981a":[2,0,0,0,50,0],
 "de/da4/group__double__blas__level1_ga8f99d6a644d3396aa32db472e0cfc91c.html#ga8f99d6a644d3396aa32db472e0cfc91c":[0,2,0,1,1],
 "de/da4/group__double__blas__level1_ga8f99d6a644d3396aa32db472e0cfc91c.html#ga8f99d6a644d3396aa32db472e0cfc91c":[2,0,0,0,36,0],
 "de/da4/group__double__blas__level1_ga969fee86423deeced6013320c9b35b28.html#ga969fee86423deeced6013320c9b35b28":[0,2,0,1,15],
 "de/da4/group__double__blas__level1_ga969fee86423deeced6013320c9b35b28.html#ga969fee86423deeced6013320c9b35b28":[2,0,0,0,71,0],
 "de/da4/group__double__blas__level1_gaca2757ba2c3b2c6fc5d729b50345fac0.html#gaca2757ba2c3b2c6fc5d729b50345fac0":[0,2,0,1,12],
 "de/da4/group__double__blas__level1_gaca2757ba2c3b2c6fc5d729b50345fac0.html#gaca2757ba2c3b2c6fc5d729b50345fac0":[2,0,0,0,55,0],
-"de/da4/group__double__blas__level1_gacb41f9f4a646322165fcc7313b9024bf.html#gacb41f9f4a646322165fcc7313b9024bf":[2,0,0,0,46,0],
 "de/da4/group__double__blas__level1_gacb41f9f4a646322165fcc7313b9024bf.html#gacb41f9f4a646322165fcc7313b9024bf":[0,2,0,1,7],
+"de/da4/group__double__blas__level1_gacb41f9f4a646322165fcc7313b9024bf.html#gacb41f9f4a646322165fcc7313b9024bf":[2,0,0,0,46,0],
 "de/da4/group__double__blas__level1_gad2a01dd62718b28e35b752dbad8474ab.html#gad2a01dd62718b28e35b752dbad8474ab":[0,2,0,1,13],
 "de/da4/group__double__blas__level1_gad2a01dd62718b28e35b752dbad8474ab.html#gad2a01dd62718b28e35b752dbad8474ab":[2,0,0,0,69,0],
-"de/da4/sggesx_8f.html":[2,0,4,1061],
-"de/da4/sggesx_8f_source.html":[2,0,4,1061],
-"de/da4/ssytrf__rook_8f.html":[2,0,4,1407],
-"de/da4/ssytrf__rook_8f_source.html":[2,0,4,1407],
-"de/da5/chpt01_8f.html":[2,0,5,1,118],
-"de/da5/chpt01_8f_source.html":[2,0,5,1,118],
-"de/da7/dtrsm_8f.html":[2,0,0,0,68],
-"de/da7/dtrsm_8f_source.html":[2,0,0,0,68],
-"de/da7/zerrgt_8f.html":[2,0,5,1,623],
-"de/da7/zerrgt_8f_source.html":[2,0,5,1,623],
-"de/da7/ztbrfs_8f.html":[2,0,4,1867],
-"de/da7/ztbrfs_8f_source.html":[2,0,4,1867],
-"de/da8/lapacke__slasrt__work_8c.html":[2,0,3,3,1430],
-"de/da8/lapacke__slasrt__work_8c_a92e430c04b55a6c0453ee2180d111893.html#a92e430c04b55a6c0453ee2180d111893":[2,0,3,3,1430,0],
-"de/da8/lapacke__slasrt__work_8c_source.html":[2,0,3,3,1430],
-"de/dab/lapacke__slaset__work_8c.html":[2,0,3,3,1428],
-"de/dab/lapacke__slaset__work_8c_a57bd21a1fa1c31373aaef9baa438d07d.html#a57bd21a1fa1c31373aaef9baa438d07d":[2,0,3,3,1428,0],
-"de/dab/lapacke__slaset__work_8c_source.html":[2,0,3,3,1428],
-"de/dad/dtgevc_8f.html":[2,0,4,927],
-"de/dad/dtgevc_8f_source.html":[2,0,4,927],
-"de/dad/group__complex_g_bcomputational.html":[0,0,1,1,2],
-"de/dad/group__complex_g_bcomputational_ga14ebae13813109bb97e162d42a2624e6.html#ga14ebae13813109bb97e162d42a2624e6":[2,0,4,6,0],
-"de/dad/group__complex_g_bcomputational_ga14ebae13813109bb97e162d42a2624e6.html#ga14ebae13813109bb97e162d42a2624e6":[0,0,1,1,2,2],
-"de/dad/group__complex_g_bcomputational_ga2512afdab4c403fbbbf32e1c73709e22.html#ga2512afdab4c403fbbbf32e1c73709e22":[2,0,4,74,0],
-"de/dad/group__complex_g_bcomputational_ga2512afdab4c403fbbbf32e1c73709e22.html#ga2512afdab4c403fbbbf32e1c73709e22":[0,0,1,1,2,10],
-"de/dad/group__complex_g_bcomputational_ga2cec305f92dc965577ab66c64e360480.html#ga2cec305f92dc965577ab66c64e360480":[2,0,4,4,0],
-"de/dad/group__complex_g_bcomputational_ga2cec305f92dc965577ab66c64e360480.html#ga2cec305f92dc965577ab66c64e360480":[0,0,1,1,2,0]
+"de/da4/sggesx_8f.html":[2,0,4,1060],
+"de/da4/sggesx_8f_source.html":[2,0,4,1060],
+"de/da4/ssytrf__rook_8f.html":[2,0,4,1406],
+"de/da4/ssytrf__rook_8f_source.html":[2,0,4,1406],
+"de/da5/chpt01_8f.html":[2,0,5,1,118]
 };
