@@ -386,8 +386,7 @@ var searchData=
   ['cgeqr_2ef',['cgeqr.f',['../d8/d48/cgeqr_8f.html',1,'']]],
   ['cgeqr2_2ef',['cgeqr2.f',['../db/dfb/cgeqr2_8f.html',1,'']]],
   ['cgeqr2p_2ef',['cgeqr2p.f',['../dd/dd6/cgeqr2p_8f.html',1,'']]],
-  ['cgeqrf_2ef',['cgeqrf.f',['../dc/d4f/cgeqrf_8f.html',1,'']]],
-  ['cgeqrf_2ef',['cgeqrf.f',['../da/dfc/_v_a_r_i_a_n_t_s_2qr_2_l_l_2cgeqrf_8f.html',1,'']]],
+  ['cgeqrf_2ef',['cgeqrf.f',['../dc/d4f/cgeqrf_8f.html',1,'(Global Namespace)'],['../da/dfc/_v_a_r_i_a_n_t_s_2qr_2_l_l_2cgeqrf_8f.html',1,'(Global Namespace)']]],
   ['cgeqrfp_2ef',['cgeqrfp.f',['../dc/d18/cgeqrfp_8f.html',1,'']]],
   ['cgeqrs_2ef',['cgeqrs.f',['../dc/da2/cgeqrs_8f.html',1,'']]],
   ['cgeqrt_2ef',['cgeqrt.f',['../d7/de3/cgeqrt_8f.html',1,'']]],
@@ -409,8 +408,7 @@ var searchData=
   ['cgesvx_2ef',['cgesvx.f',['../d2/d42/cgesvx_8f.html',1,'']]],
   ['cgesvxx_2ef',['cgesvxx.f',['../d4/d4d/cgesvxx_8f.html',1,'']]],
   ['cget01_2ef',['cget01.f',['../da/dab/cget01_8f.html',1,'']]],
-  ['cget02_2ef',['cget02.f',['../dc/dd5/_e_i_g_2cget02_8f.html',1,'']]],
-  ['cget02_2ef',['cget02.f',['../d7/d14/_l_i_n_2cget02_8f.html',1,'']]],
+  ['cget02_2ef',['cget02.f',['../dc/dd5/_e_i_g_2cget02_8f.html',1,'(Global Namespace)'],['../d7/d14/_l_i_n_2cget02_8f.html',1,'(Global Namespace)']]],
   ['cget03_2ef',['cget03.f',['../d1/d09/cget03_8f.html',1,'']]],
   ['cget04_2ef',['cget04.f',['../d2/dae/cget04_8f.html',1,'']]],
   ['cget07_2ef',['cget07.f',['../d9/d40/cget07_8f.html',1,'']]],
@@ -427,10 +425,7 @@ var searchData=
   ['cget54_2ef',['cget54.f',['../d2/df2/cget54_8f.html',1,'']]],
   ['cgetc2_2ef',['cgetc2.f',['../dc/d8f/cgetc2_8f.html',1,'']]],
   ['cgetf2_2ef',['cgetf2.f',['../d9/d9a/cgetf2_8f.html',1,'']]],
-  ['cgetrf_2ef',['cgetrf.f',['../d9/dfb/cgetrf_8f.html',1,'']]],
-  ['cgetrf_2ef',['cgetrf.f',['../df/db3/_v_a_r_i_a_n_t_s_2lu_2_c_r_2cgetrf_8f.html',1,'']]],
-  ['cgetrf_2ef',['cgetrf.f',['../d8/d1f/_v_a_r_i_a_n_t_s_2lu_2_l_l_2cgetrf_8f.html',1,'']]],
-  ['cgetrf_2ef',['cgetrf.f',['../d8/de1/_v_a_r_i_a_n_t_s_2lu_2_r_e_c_2cgetrf_8f.html',1,'']]],
+  ['cgetrf_2ef',['cgetrf.f',['../d9/dfb/cgetrf_8f.html',1,'(Global Namespace)'],['../df/db3/_v_a_r_i_a_n_t_s_2lu_2_c_r_2cgetrf_8f.html',1,'(Global Namespace)'],['../d8/d1f/_v_a_r_i_a_n_t_s_2lu_2_l_l_2cgetrf_8f.html',1,'(Global Namespace)'],['../d8/de1/_v_a_r_i_a_n_t_s_2lu_2_r_e_c_2cgetrf_8f.html',1,'(Global Namespace)']]],
   ['cgetrf2_2ef',['cgetrf2.f',['../d1/d05/cgetrf2_8f.html',1,'']]],
   ['cgetri_2ef',['cgetri.f',['../d6/d67/cgetri_8f.html',1,'']]],
   ['cgetrs_2ef',['cgetrs.f',['../d9/dfd/cgetrs_8f.html',1,'']]],
@@ -546,8 +541,7 @@ var searchData=
   ['chetrs_5frook_2ef',['chetrs_rook.f',['../d0/db0/chetrs__rook_8f.html',1,'']]],
   ['chfrk_2ef',['chfrk.f',['../d5/db5/chfrk_8f.html',1,'']]],
   ['chgeqz_2ef',['chgeqz.f',['../d3/d90/chgeqz_8f.html',1,'']]],
-  ['chkxer_2ef',['chkxer.f',['../d0/d16/_e_i_g_2chkxer_8f.html',1,'']]],
-  ['chkxer_2ef',['chkxer.f',['../d3/dde/_l_i_n_2chkxer_8f.html',1,'']]],
+  ['chkxer_2ef',['chkxer.f',['../d0/d16/_e_i_g_2chkxer_8f.html',1,'(Global Namespace)'],['../d3/dde/_l_i_n_2chkxer_8f.html',1,'(Global Namespace)']]],
   ['chla_5ftranstype_2ef',['chla_transtype.f',['../d6/d14/chla__transtype_8f.html',1,'']]],
   ['chpcon_2ef',['chpcon.f',['../d0/d15/chpcon_8f.html',1,'']]],
   ['chpev_2ef',['chpev.f',['../d7/db0/chpev_8f.html',1,'']]],
@@ -624,8 +618,7 @@ var searchData=
   ['clahef_5faa_2ef',['clahef_aa.f',['../d9/d55/clahef__aa_8f.html',1,'']]],
   ['clahef_5frk_2ef',['clahef_rk.f',['../d2/d99/clahef__rk_8f.html',1,'']]],
   ['clahef_5frook_2ef',['clahef_rook.f',['../d6/d29/clahef__rook_8f.html',1,'']]],
-  ['clahilb_2ef',['clahilb.f',['../d0/d50/_m_a_t_g_e_n_2clahilb_8f.html',1,'']]],
-  ['clahilb_2ef',['clahilb.f',['../dd/d0c/_l_i_n_2clahilb_8f.html',1,'']]],
+  ['clahilb_2ef',['clahilb.f',['../dd/d0c/_l_i_n_2clahilb_8f.html',1,'(Global Namespace)'],['../d0/d50/_m_a_t_g_e_n_2clahilb_8f.html',1,'(Global Namespace)']]],
   ['clahqr_2ef',['clahqr.f',['../d1/dbb/clahqr_8f.html',1,'']]],
   ['clahr2_2ef',['clahr2.f',['../d6/d49/clahr2_8f.html',1,'']]],
   ['clahrd_2ef',['clahrd.f',['../d7/d73/clahrd_8f.html',1,'']]],
@@ -681,12 +674,10 @@ var searchData=
   ['clarfgp_2ef',['clarfgp.f',['../d9/dfa/clarfgp_8f.html',1,'']]],
   ['clarft_2ef',['clarft.f',['../db/db4/clarft_8f.html',1,'']]],
   ['clarfx_2ef',['clarfx.f',['../d4/d2b/clarfx_8f.html',1,'']]],
-  ['clarfy_2ef',['clarfy.f',['../d3/d9f/_s_r_c_2clarfy_8f.html',1,'']]],
-  ['clarfy_2ef',['clarfy.f',['../de/dc0/_t_e_s_t_i_n_g_2_e_i_g_2clarfy_8f.html',1,'']]],
+  ['clarfy_2ef',['clarfy.f',['../d3/d9f/_s_r_c_2clarfy_8f.html',1,'(Global Namespace)'],['../de/dc0/_t_e_s_t_i_n_g_2_e_i_g_2clarfy_8f.html',1,'(Global Namespace)']]],
   ['clarge_2ef',['clarge.f',['../d5/d5d/clarge_8f.html',1,'']]],
   ['clargv_2ef',['clargv.f',['../da/d75/clargv_8f.html',1,'']]],
-  ['clarhs_2ef',['clarhs.f',['../d7/d6a/_e_i_g_2clarhs_8f.html',1,'']]],
-  ['clarhs_2ef',['clarhs.f',['../d8/d9b/_l_i_n_2clarhs_8f.html',1,'']]],
+  ['clarhs_2ef',['clarhs.f',['../d7/d6a/_e_i_g_2clarhs_8f.html',1,'(Global Namespace)'],['../d8/d9b/_l_i_n_2clarhs_8f.html',1,'(Global Namespace)']]],
   ['clarnd_2ef',['clarnd.f',['../d5/dce/clarnd_8f.html',1,'']]],
   ['clarnv_2ef',['clarnv.f',['../df/d56/clarnv_8f.html',1,'']]],
   ['claror_2ef',['claror.f',['../d1/dfc/claror_8f.html',1,'']]],
@@ -778,9 +769,7 @@ var searchData=
   ['cpot03_2ef',['cpot03.f',['../d7/da2/cpot03_8f.html',1,'']]],
   ['cpot05_2ef',['cpot05.f',['../d2/ded/cpot05_8f.html',1,'']]],
   ['cpotf2_2ef',['cpotf2.f',['../d3/d5b/cpotf2_8f.html',1,'']]],
-  ['cpotrf_2ef',['cpotrf.f',['../dd/dce/cpotrf_8f.html',1,'']]],
-  ['cpotrf_2ef',['cpotrf.f',['../d3/dff/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2cpotrf_8f.html',1,'']]],
-  ['cpotrf_2ef',['cpotrf.f',['../d6/d19/_v_a_r_i_a_n_t_s_2cholesky_2_t_o_p_2cpotrf_8f.html',1,'']]],
+  ['cpotrf_2ef',['cpotrf.f',['../dd/dce/cpotrf_8f.html',1,'(Global Namespace)'],['../d3/dff/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2cpotrf_8f.html',1,'(Global Namespace)'],['../d6/d19/_v_a_r_i_a_n_t_s_2cholesky_2_t_o_p_2cpotrf_8f.html',1,'(Global Namespace)']]],
   ['cpotrf2_2ef',['cpotrf2.f',['../d5/d9a/cpotrf2_8f.html',1,'']]],
   ['cpotri_2ef',['cpotri.f',['../d3/d35/cpotri_8f.html',1,'']]],
   ['cpotrs_2ef',['cpotrs.f',['../d4/d98/cpotrs_8f.html',1,'']]],
@@ -834,8 +823,7 @@ var searchData=
   ['crqt03_2ef',['crqt03.f',['../d1/dbf/crqt03_8f.html',1,'']]],
   ['crzt01_2ef',['crzt01.f',['../da/d70/crzt01_8f.html',1,'']]],
   ['crzt02_2ef',['crzt02.f',['../db/dc7/crzt02_8f.html',1,'']]],
-  ['csbmv_2ef',['csbmv.f',['../df/d6e/_l_i_n_2csbmv_8f.html',1,'']]],
-  ['csbmv_2ef',['csbmv.f',['../d4/d12/_e_i_g_2csbmv_8f.html',1,'']]],
+  ['csbmv_2ef',['csbmv.f',['../d4/d12/_e_i_g_2csbmv_8f.html',1,'(Global Namespace)'],['../df/d6e/_l_i_n_2csbmv_8f.html',1,'(Global Namespace)']]],
   ['cscal_2ef',['cscal.f',['../dc/d81/cscal_8f.html',1,'']]],
   ['csgt01_2ef',['csgt01.f',['../d6/d52/csgt01_8f.html',1,'']]],
   ['cslect_2ef',['cslect.f',['../d1/d95/cslect_8f.html',1,'']]],
