@@ -201,8 +201,7 @@ var searchData=
   ['dgeqr_2ef',['dgeqr.f',['../d6/d61/dgeqr_8f.html',1,'']]],
   ['dgeqr2_2ef',['dgeqr2.f',['../d5/d0a/dgeqr2_8f.html',1,'']]],
   ['dgeqr2p_2ef',['dgeqr2p.f',['../da/d9b/dgeqr2p_8f.html',1,'']]],
-  ['dgeqrf_2ef',['dgeqrf.f',['../d3/d69/dgeqrf_8f.html',1,'']]],
-  ['dgeqrf_2ef',['dgeqrf.f',['../dd/d28/_v_a_r_i_a_n_t_s_2qr_2_l_l_2dgeqrf_8f.html',1,'']]],
+  ['dgeqrf_2ef',['dgeqrf.f',['../d3/d69/dgeqrf_8f.html',1,'(Global Namespace)'],['../dd/d28/_v_a_r_i_a_n_t_s_2qr_2_l_l_2dgeqrf_8f.html',1,'(Global Namespace)']]],
   ['dgeqrfp_2ef',['dgeqrfp.f',['../d1/dfe/dgeqrfp_8f.html',1,'']]],
   ['dgeqrs_2ef',['dgeqrs.f',['../d3/d17/dgeqrs_8f.html',1,'']]],
   ['dgeqrt_2ef',['dgeqrt.f',['../d2/dcf/dgeqrt_8f.html',1,'']]],
@@ -223,8 +222,7 @@ var searchData=
   ['dgesvx_2ef',['dgesvx.f',['../da/d21/dgesvx_8f.html',1,'']]],
   ['dgesvxx_2ef',['dgesvxx.f',['../d3/dca/dgesvxx_8f.html',1,'']]],
   ['dget01_2ef',['dget01.f',['../d8/d35/dget01_8f.html',1,'']]],
-  ['dget02_2ef',['dget02.f',['../d0/d5c/_e_i_g_2dget02_8f.html',1,'']]],
-  ['dget02_2ef',['dget02.f',['../d0/da5/_l_i_n_2dget02_8f.html',1,'']]],
+  ['dget02_2ef',['dget02.f',['../d0/d5c/_e_i_g_2dget02_8f.html',1,'(Global Namespace)'],['../d0/da5/_l_i_n_2dget02_8f.html',1,'(Global Namespace)']]],
   ['dget03_2ef',['dget03.f',['../d4/de1/dget03_8f.html',1,'']]],
   ['dget04_2ef',['dget04.f',['../dd/df6/dget04_8f.html',1,'']]],
   ['dget06_2ef',['dget06.f',['../dd/d66/dget06_8f.html',1,'']]],
@@ -249,10 +247,7 @@ var searchData=
   ['dget54_2ef',['dget54.f',['../d7/db5/dget54_8f.html',1,'']]],
   ['dgetc2_2ef',['dgetc2.f',['../dd/d92/dgetc2_8f.html',1,'']]],
   ['dgetf2_2ef',['dgetf2.f',['../d2/da1/dgetf2_8f.html',1,'']]],
-  ['dgetrf_2ef',['dgetrf.f',['../d3/d6a/dgetrf_8f.html',1,'']]],
-  ['dgetrf_2ef',['dgetrf.f',['../dc/d00/_v_a_r_i_a_n_t_s_2lu_2_l_l_2dgetrf_8f.html',1,'']]],
-  ['dgetrf_2ef',['dgetrf.f',['../d0/d39/_v_a_r_i_a_n_t_s_2lu_2_r_e_c_2dgetrf_8f.html',1,'']]],
-  ['dgetrf_2ef',['dgetrf.f',['../d7/d7f/_v_a_r_i_a_n_t_s_2lu_2_c_r_2dgetrf_8f.html',1,'']]],
+  ['dgetrf_2ef',['dgetrf.f',['../d3/d6a/dgetrf_8f.html',1,'(Global Namespace)'],['../d7/d7f/_v_a_r_i_a_n_t_s_2lu_2_c_r_2dgetrf_8f.html',1,'(Global Namespace)'],['../dc/d00/_v_a_r_i_a_n_t_s_2lu_2_l_l_2dgetrf_8f.html',1,'(Global Namespace)'],['../d0/d39/_v_a_r_i_a_n_t_s_2lu_2_r_e_c_2dgetrf_8f.html',1,'(Global Namespace)']]],
   ['dgetrf2_2ef',['dgetrf2.f',['../d1/dfc/dgetrf2_8f.html',1,'']]],
   ['dgetri_2ef',['dgetri.f',['../df/da4/dgetri_8f.html',1,'']]],
   ['dgetrs_2ef',['dgetrs.f',['../d6/d49/dgetrs_8f.html',1,'']]],
@@ -346,8 +341,7 @@ var searchData=
   ['dlagts_2ef',['dlagts.f',['../de/d9b/dlagts_8f.html',1,'']]],
   ['dlagv2_2ef',['dlagv2.f',['../d0/dcc/dlagv2_8f.html',1,'']]],
   ['dlahd2_2ef',['dlahd2.f',['../da/de9/dlahd2_8f.html',1,'']]],
-  ['dlahilb_2ef',['dlahilb.f',['../db/d68/_l_i_n_2dlahilb_8f.html',1,'']]],
-  ['dlahilb_2ef',['dlahilb.f',['../df/dd6/_m_a_t_g_e_n_2dlahilb_8f.html',1,'']]],
+  ['dlahilb_2ef',['dlahilb.f',['../db/d68/_l_i_n_2dlahilb_8f.html',1,'(Global Namespace)'],['../df/dd6/_m_a_t_g_e_n_2dlahilb_8f.html',1,'(Global Namespace)']]],
   ['dlahqr_2ef',['dlahqr.f',['../d3/d03/dlahqr_8f.html',1,'']]],
   ['dlahr2_2ef',['dlahr2.f',['../dd/d61/dlahr2_8f.html',1,'']]],
   ['dlahrd_2ef',['dlahrd.f',['../d1/d59/dlahrd_8f.html',1,'']]],
@@ -408,12 +402,10 @@ var searchData=
   ['dlarfgp_2ef',['dlarfgp.f',['../d1/d44/dlarfgp_8f.html',1,'']]],
   ['dlarft_2ef',['dlarft.f',['../dd/daa/dlarft_8f.html',1,'']]],
   ['dlarfx_2ef',['dlarfx.f',['../db/d10/dlarfx_8f.html',1,'']]],
-  ['dlarfy_2ef',['dlarfy.f',['../da/ddd/_s_r_c_2dlarfy_8f.html',1,'']]],
-  ['dlarfy_2ef',['dlarfy.f',['../dc/d01/_t_e_s_t_i_n_g_2_e_i_g_2dlarfy_8f.html',1,'']]],
+  ['dlarfy_2ef',['dlarfy.f',['../da/ddd/_s_r_c_2dlarfy_8f.html',1,'(Global Namespace)'],['../dc/d01/_t_e_s_t_i_n_g_2_e_i_g_2dlarfy_8f.html',1,'(Global Namespace)']]],
   ['dlarge_2ef',['dlarge.f',['../d8/d2f/dlarge_8f.html',1,'']]],
   ['dlargv_2ef',['dlargv.f',['../d8/d3a/dlargv_8f.html',1,'']]],
-  ['dlarhs_2ef',['dlarhs.f',['../da/d77/_l_i_n_2dlarhs_8f.html',1,'']]],
-  ['dlarhs_2ef',['dlarhs.f',['../d3/d1c/_e_i_g_2dlarhs_8f.html',1,'']]],
+  ['dlarhs_2ef',['dlarhs.f',['../d3/d1c/_e_i_g_2dlarhs_8f.html',1,'(Global Namespace)'],['../da/d77/_l_i_n_2dlarhs_8f.html',1,'(Global Namespace)']]],
   ['dlarnd_2ef',['dlarnd.f',['../d8/d04/dlarnd_8f.html',1,'']]],
   ['dlarnv_2ef',['dlarnv.f',['../db/d9c/dlarnv_8f.html',1,'']]],
   ['dlaror_2ef',['dlaror.f',['../dd/df5/dlaror_8f.html',1,'']]],
@@ -579,9 +571,7 @@ var searchData=
   ['dpot05_2ef',['dpot05.f',['../de/d88/dpot05_8f.html',1,'']]],
   ['dpot06_2ef',['dpot06.f',['../d7/d7f/dpot06_8f.html',1,'']]],
   ['dpotf2_2ef',['dpotf2.f',['../dd/d6b/dpotf2_8f.html',1,'']]],
-  ['dpotrf_2ef',['dpotrf.f',['../d6/d65/_v_a_r_i_a_n_t_s_2cholesky_2_t_o_p_2dpotrf_8f.html',1,'']]],
-  ['dpotrf_2ef',['dpotrf.f',['../d0/d8a/dpotrf_8f.html',1,'']]],
-  ['dpotrf_2ef',['dpotrf.f',['../d6/db0/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2dpotrf_8f.html',1,'']]],
+  ['dpotrf_2ef',['dpotrf.f',['../d0/d8a/dpotrf_8f.html',1,'(Global Namespace)'],['../d6/db0/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2dpotrf_8f.html',1,'(Global Namespace)'],['../d6/d65/_v_a_r_i_a_n_t_s_2cholesky_2_t_o_p_2dpotrf_8f.html',1,'(Global Namespace)']]],
   ['dpotrf2_2ef',['dpotrf2.f',['../db/d3d/dpotrf2_8f.html',1,'']]],
   ['dpotri_2ef',['dpotri.f',['../d8/d63/dpotri_8f.html',1,'']]],
   ['dpotrs_2ef',['dpotrs.f',['../d8/d2f/dpotrs_8f.html',1,'']]],
@@ -791,8 +781,7 @@ var searchData=
   ['dtgsy2_2ef',['dtgsy2.f',['../d2/db4/dtgsy2_8f.html',1,'']]],
   ['dtgsyl_2ef',['dtgsyl.f',['../db/d88/dtgsyl_8f.html',1,'']]],
   ['dtpcon_2ef',['dtpcon.f',['../d8/d96/dtpcon_8f.html',1,'']]],
-  ['dtplqt_2ef',['dtplqt.f',['../df/d93/_s_r_c_2dtplqt_8f.html',1,'']]],
-  ['dtplqt_2ef',['dtplqt.f',['../d8/d17/_t_e_s_t_i_n_g_2_l_i_n_2dtplqt_8f.html',1,'']]],
+  ['dtplqt_2ef',['dtplqt.f',['../df/d93/_s_r_c_2dtplqt_8f.html',1,'(Global Namespace)'],['../d8/d17/_t_e_s_t_i_n_g_2_l_i_n_2dtplqt_8f.html',1,'(Global Namespace)']]],
   ['dtplqt2_2ef',['dtplqt2.f',['../d4/d91/dtplqt2_8f.html',1,'']]],
   ['dtpmlqt_2ef',['dtpmlqt.f',['../d0/d8d/dtpmlqt_8f.html',1,'']]],
   ['dtpmqrt_2ef',['dtpmqrt.f',['../d7/de6/dtpmqrt_8f.html',1,'']]],
