@@ -210,8 +210,7 @@ var searchData=
   ['sgeqr_2ef',['sgeqr.f',['../da/d39/sgeqr_8f.html',1,'']]],
   ['sgeqr2_2ef',['sgeqr2.f',['../d6/dfd/sgeqr2_8f.html',1,'']]],
   ['sgeqr2p_2ef',['sgeqr2p.f',['../d6/d30/sgeqr2p_8f.html',1,'']]],
-  ['sgeqrf_2ef',['sgeqrf.f',['../df/d97/sgeqrf_8f.html',1,'']]],
-  ['sgeqrf_2ef',['sgeqrf.f',['../dc/d45/_v_a_r_i_a_n_t_s_2qr_2_l_l_2sgeqrf_8f.html',1,'']]],
+  ['sgeqrf_2ef',['sgeqrf.f',['../df/d97/sgeqrf_8f.html',1,'(Global Namespace)'],['../dc/d45/_v_a_r_i_a_n_t_s_2qr_2_l_l_2sgeqrf_8f.html',1,'(Global Namespace)']]],
   ['sgeqrfp_2ef',['sgeqrfp.f',['../dc/d8e/sgeqrfp_8f.html',1,'']]],
   ['sgeqrs_2ef',['sgeqrs.f',['../db/d5c/sgeqrs_8f.html',1,'']]],
   ['sgeqrt_2ef',['sgeqrt.f',['../d8/dfc/sgeqrt_8f.html',1,'']]],
@@ -232,8 +231,7 @@ var searchData=
   ['sgesvx_2ef',['sgesvx.f',['../d1/dfd/sgesvx_8f.html',1,'']]],
   ['sgesvxx_2ef',['sgesvxx.f',['../dd/d23/sgesvxx_8f.html',1,'']]],
   ['sget01_2ef',['sget01.f',['../de/d55/sget01_8f.html',1,'']]],
-  ['sget02_2ef',['sget02.f',['../dd/d73/_e_i_g_2sget02_8f.html',1,'']]],
-  ['sget02_2ef',['sget02.f',['../d0/d21/_l_i_n_2sget02_8f.html',1,'']]],
+  ['sget02_2ef',['sget02.f',['../dd/d73/_e_i_g_2sget02_8f.html',1,'(Global Namespace)'],['../d0/d21/_l_i_n_2sget02_8f.html',1,'(Global Namespace)']]],
   ['sget03_2ef',['sget03.f',['../d2/d9d/sget03_8f.html',1,'']]],
   ['sget04_2ef',['sget04.f',['../da/d86/sget04_8f.html',1,'']]],
   ['sget06_2ef',['sget06.f',['../dd/d77/sget06_8f.html',1,'']]],
@@ -257,10 +255,7 @@ var searchData=
   ['sget54_2ef',['sget54.f',['../d0/d69/sget54_8f.html',1,'']]],
   ['sgetc2_2ef',['sgetc2.f',['../da/d5c/sgetc2_8f.html',1,'']]],
   ['sgetf2_2ef',['sgetf2.f',['../de/d68/sgetf2_8f.html',1,'']]],
-  ['sgetrf_2ef',['sgetrf.f',['../de/de2/sgetrf_8f.html',1,'']]],
-  ['sgetrf_2ef',['sgetrf.f',['../d4/df9/_v_a_r_i_a_n_t_s_2lu_2_c_r_2sgetrf_8f.html',1,'']]],
-  ['sgetrf_2ef',['sgetrf.f',['../da/da9/_v_a_r_i_a_n_t_s_2lu_2_l_l_2sgetrf_8f.html',1,'']]],
-  ['sgetrf_2ef',['sgetrf.f',['../dc/d59/_v_a_r_i_a_n_t_s_2lu_2_r_e_c_2sgetrf_8f.html',1,'']]],
+  ['sgetrf_2ef',['sgetrf.f',['../de/de2/sgetrf_8f.html',1,'(Global Namespace)'],['../d4/df9/_v_a_r_i_a_n_t_s_2lu_2_c_r_2sgetrf_8f.html',1,'(Global Namespace)'],['../da/da9/_v_a_r_i_a_n_t_s_2lu_2_l_l_2sgetrf_8f.html',1,'(Global Namespace)'],['../dc/d59/_v_a_r_i_a_n_t_s_2lu_2_r_e_c_2sgetrf_8f.html',1,'(Global Namespace)']]],
   ['sgetrf2_2ef',['sgetrf2.f',['../d6/de6/sgetrf2_8f.html',1,'']]],
   ['sgetri_2ef',['sgetri.f',['../d0/d31/sgetri_8f.html',1,'']]],
   ['sgetrs_2ef',['sgetrs.f',['../d6/da0/sgetrs_8f.html',1,'']]],
@@ -354,8 +349,7 @@ var searchData=
   ['slagts_2ef',['slagts.f',['../d2/dd6/slagts_8f.html',1,'']]],
   ['slagv2_2ef',['slagv2.f',['../db/d4b/slagv2_8f.html',1,'']]],
   ['slahd2_2ef',['slahd2.f',['../d3/da4/slahd2_8f.html',1,'']]],
-  ['slahilb_2ef',['slahilb.f',['../d0/d0f/_l_i_n_2slahilb_8f.html',1,'']]],
-  ['slahilb_2ef',['slahilb.f',['../d0/d83/_m_a_t_g_e_n_2slahilb_8f.html',1,'']]],
+  ['slahilb_2ef',['slahilb.f',['../d0/d0f/_l_i_n_2slahilb_8f.html',1,'(Global Namespace)'],['../d0/d83/_m_a_t_g_e_n_2slahilb_8f.html',1,'(Global Namespace)']]],
   ['slahqr_2ef',['slahqr.f',['../d0/d02/slahqr_8f.html',1,'']]],
   ['slahr2_2ef',['slahr2.f',['../da/d2a/slahr2_8f.html',1,'']]],
   ['slahrd_2ef',['slahrd.f',['../db/da4/slahrd_8f.html',1,'']]],
@@ -416,12 +410,10 @@ var searchData=
   ['slarfgp_2ef',['slarfgp.f',['../da/d30/slarfgp_8f.html',1,'']]],
   ['slarft_2ef',['slarft.f',['../d3/d2f/slarft_8f.html',1,'']]],
   ['slarfx_2ef',['slarfx.f',['../d0/d3d/slarfx_8f.html',1,'']]],
-  ['slarfy_2ef',['slarfy.f',['../da/d28/_s_r_c_2slarfy_8f.html',1,'']]],
-  ['slarfy_2ef',['slarfy.f',['../d4/dcf/_t_e_s_t_i_n_g_2_e_i_g_2slarfy_8f.html',1,'']]],
+  ['slarfy_2ef',['slarfy.f',['../da/d28/_s_r_c_2slarfy_8f.html',1,'(Global Namespace)'],['../d4/dcf/_t_e_s_t_i_n_g_2_e_i_g_2slarfy_8f.html',1,'(Global Namespace)']]],
   ['slarge_2ef',['slarge.f',['../d8/dfb/slarge_8f.html',1,'']]],
   ['slargv_2ef',['slargv.f',['../d3/d6a/slargv_8f.html',1,'']]],
-  ['slarhs_2ef',['slarhs.f',['../d1/d60/_e_i_g_2slarhs_8f.html',1,'']]],
-  ['slarhs_2ef',['slarhs.f',['../d7/d58/_l_i_n_2slarhs_8f.html',1,'']]],
+  ['slarhs_2ef',['slarhs.f',['../d1/d60/_e_i_g_2slarhs_8f.html',1,'(Global Namespace)'],['../d7/d58/_l_i_n_2slarhs_8f.html',1,'(Global Namespace)']]],
   ['slarnd_2ef',['slarnd.f',['../da/d70/slarnd_8f.html',1,'']]],
   ['slarnv_2ef',['slarnv.f',['../d9/d13/slarnv_8f.html',1,'']]],
   ['slaror_2ef',['slaror.f',['../d0/d24/slaror_8f.html',1,'']]],
@@ -585,9 +577,7 @@ var searchData=
   ['spot03_2ef',['spot03.f',['../dd/d71/spot03_8f.html',1,'']]],
   ['spot05_2ef',['spot05.f',['../d2/d36/spot05_8f.html',1,'']]],
   ['spotf2_2ef',['spotf2.f',['../d8/d32/spotf2_8f.html',1,'']]],
-  ['spotrf_2ef',['spotrf.f',['../dd/d35/_v_a_r_i_a_n_t_s_2cholesky_2_t_o_p_2spotrf_8f.html',1,'']]],
-  ['spotrf_2ef',['spotrf.f',['../d0/da2/spotrf_8f.html',1,'']]],
-  ['spotrf_2ef',['spotrf.f',['../d2/d04/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2spotrf_8f.html',1,'']]],
+  ['spotrf_2ef',['spotrf.f',['../d0/da2/spotrf_8f.html',1,'(Global Namespace)'],['../d2/d04/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2spotrf_8f.html',1,'(Global Namespace)'],['../dd/d35/_v_a_r_i_a_n_t_s_2cholesky_2_t_o_p_2spotrf_8f.html',1,'(Global Namespace)']]],
   ['spotrf2_2ef',['spotrf2.f',['../dd/d7e/spotrf2_8f.html',1,'']]],
   ['spotri_2ef',['spotri.f',['../db/d26/spotri_8f.html',1,'']]],
   ['spotrs_2ef',['spotrs.f',['../da/d52/spotrs_8f.html',1,'']]],
@@ -787,8 +777,7 @@ var searchData=
   ['stgsy2_2ef',['stgsy2.f',['../d5/d46/stgsy2_8f.html',1,'']]],
   ['stgsyl_2ef',['stgsyl.f',['../dc/d67/stgsyl_8f.html',1,'']]],
   ['stpcon_2ef',['stpcon.f',['../d2/d7c/stpcon_8f.html',1,'']]],
-  ['stplqt_2ef',['stplqt.f',['../df/d9d/_s_r_c_2stplqt_8f.html',1,'']]],
-  ['stplqt_2ef',['stplqt.f',['../d4/d74/_t_e_s_t_i_n_g_2_l_i_n_2stplqt_8f.html',1,'']]],
+  ['stplqt_2ef',['stplqt.f',['../df/d9d/_s_r_c_2stplqt_8f.html',1,'(Global Namespace)'],['../d4/d74/_t_e_s_t_i_n_g_2_l_i_n_2stplqt_8f.html',1,'(Global Namespace)']]],
   ['stplqt2_2ef',['stplqt2.f',['../d6/d6b/stplqt2_8f.html',1,'']]],
   ['stpmlqt_2ef',['stpmlqt.f',['../d8/d5e/stpmlqt_8f.html',1,'']]],
   ['stpmqrt_2ef',['stpmqrt.f',['../d1/dd0/stpmqrt_8f.html',1,'']]],
