@@ -214,8 +214,7 @@ var searchData=
   ['zgeqr_2ef',['zgeqr.f',['../d4/d19/zgeqr_8f.html',1,'']]],
   ['zgeqr2_2ef',['zgeqr2.f',['../d9/d5c/zgeqr2_8f.html',1,'']]],
   ['zgeqr2p_2ef',['zgeqr2p.f',['../df/da3/zgeqr2p_8f.html',1,'']]],
-  ['zgeqrf_2ef',['zgeqrf.f',['../df/de1/_v_a_r_i_a_n_t_s_2qr_2_l_l_2zgeqrf_8f.html',1,'']]],
-  ['zgeqrf_2ef',['zgeqrf.f',['../d8/d32/zgeqrf_8f.html',1,'']]],
+  ['zgeqrf_2ef',['zgeqrf.f',['../df/de1/_v_a_r_i_a_n_t_s_2qr_2_l_l_2zgeqrf_8f.html',1,'(Global Namespace)'],['../d8/d32/zgeqrf_8f.html',1,'(Global Namespace)']]],
   ['zgeqrfp_2ef',['zgeqrfp.f',['../d5/dc0/zgeqrfp_8f.html',1,'']]],
   ['zgeqrs_2ef',['zgeqrs.f',['../d1/da5/zgeqrs_8f.html',1,'']]],
   ['zgeqrt_2ef',['zgeqrt.f',['../d3/d6e/zgeqrt_8f.html',1,'']]],
@@ -237,8 +236,7 @@ var searchData=
   ['zgesvx_2ef',['zgesvx.f',['../df/dcf/zgesvx_8f.html',1,'']]],
   ['zgesvxx_2ef',['zgesvxx.f',['../d6/df9/zgesvxx_8f.html',1,'']]],
   ['zget01_2ef',['zget01.f',['../d2/d46/zget01_8f.html',1,'']]],
-  ['zget02_2ef',['zget02.f',['../de/db2/_e_i_g_2zget02_8f.html',1,'']]],
-  ['zget02_2ef',['zget02.f',['../df/d96/_l_i_n_2zget02_8f.html',1,'']]],
+  ['zget02_2ef',['zget02.f',['../de/db2/_e_i_g_2zget02_8f.html',1,'(Global Namespace)'],['../df/d96/_l_i_n_2zget02_8f.html',1,'(Global Namespace)']]],
   ['zget03_2ef',['zget03.f',['../d5/d84/zget03_8f.html',1,'']]],
   ['zget04_2ef',['zget04.f',['../d8/dcd/zget04_8f.html',1,'']]],
   ['zget07_2ef',['zget07.f',['../d8/d8e/zget07_8f.html',1,'']]],
@@ -256,10 +254,7 @@ var searchData=
   ['zget54_2ef',['zget54.f',['../de/da1/zget54_8f.html',1,'']]],
   ['zgetc2_2ef',['zgetc2.f',['../db/dcd/zgetc2_8f.html',1,'']]],
   ['zgetf2_2ef',['zgetf2.f',['../d4/dbf/zgetf2_8f.html',1,'']]],
-  ['zgetrf_2ef',['zgetrf.f',['../d7/d99/_v_a_r_i_a_n_t_s_2lu_2_c_r_2zgetrf_8f.html',1,'']]],
-  ['zgetrf_2ef',['zgetrf.f',['../d1/d14/_v_a_r_i_a_n_t_s_2lu_2_l_l_2zgetrf_8f.html',1,'']]],
-  ['zgetrf_2ef',['zgetrf.f',['../db/d1c/_v_a_r_i_a_n_t_s_2lu_2_r_e_c_2zgetrf_8f.html',1,'']]],
-  ['zgetrf_2ef',['zgetrf.f',['../dd/dd1/zgetrf_8f.html',1,'']]],
+  ['zgetrf_2ef',['zgetrf.f',['../d7/d99/_v_a_r_i_a_n_t_s_2lu_2_c_r_2zgetrf_8f.html',1,'(Global Namespace)'],['../d1/d14/_v_a_r_i_a_n_t_s_2lu_2_l_l_2zgetrf_8f.html',1,'(Global Namespace)'],['../db/d1c/_v_a_r_i_a_n_t_s_2lu_2_r_e_c_2zgetrf_8f.html',1,'(Global Namespace)'],['../dd/dd1/zgetrf_8f.html',1,'(Global Namespace)']]],
   ['zgetrf2_2ef',['zgetrf2.f',['../dd/d4f/zgetrf2_8f.html',1,'']]],
   ['zgetri_2ef',['zgetri.f',['../d0/db3/zgetri_8f.html',1,'']]],
   ['zgetrs_2ef',['zgetrs.f',['../dd/db7/zgetrs_8f.html',1,'']]],
@@ -449,8 +444,7 @@ var searchData=
   ['zlahef_5faa_2ef',['zlahef_aa.f',['../d6/de1/zlahef__aa_8f.html',1,'']]],
   ['zlahef_5frk_2ef',['zlahef_rk.f',['../d4/da7/zlahef__rk_8f.html',1,'']]],
   ['zlahef_5frook_2ef',['zlahef_rook.f',['../df/d38/zlahef__rook_8f.html',1,'']]],
-  ['zlahilb_2ef',['zlahilb.f',['../de/d4b/_l_i_n_2zlahilb_8f.html',1,'']]],
-  ['zlahilb_2ef',['zlahilb.f',['../d5/da1/_m_a_t_g_e_n_2zlahilb_8f.html',1,'']]],
+  ['zlahilb_2ef',['zlahilb.f',['../de/d4b/_l_i_n_2zlahilb_8f.html',1,'(Global Namespace)'],['../d5/da1/_m_a_t_g_e_n_2zlahilb_8f.html',1,'(Global Namespace)']]],
   ['zlahqr_2ef',['zlahqr.f',['../de/d07/zlahqr_8f.html',1,'']]],
   ['zlahr2_2ef',['zlahr2.f',['../db/dc5/zlahr2_8f.html',1,'']]],
   ['zlahrd_2ef',['zlahrd.f',['../da/d94/zlahrd_8f.html',1,'']]],
@@ -506,12 +500,10 @@ var searchData=
   ['zlarfgp_2ef',['zlarfgp.f',['../d7/d5d/zlarfgp_8f.html',1,'']]],
   ['zlarft_2ef',['zlarft.f',['../dc/d47/zlarft_8f.html',1,'']]],
   ['zlarfx_2ef',['zlarfx.f',['../d9/d85/zlarfx_8f.html',1,'']]],
-  ['zlarfy_2ef',['zlarfy.f',['../d0/d71/_t_e_s_t_i_n_g_2_e_i_g_2zlarfy_8f.html',1,'']]],
-  ['zlarfy_2ef',['zlarfy.f',['../df/d20/_s_r_c_2zlarfy_8f.html',1,'']]],
+  ['zlarfy_2ef',['zlarfy.f',['../df/d20/_s_r_c_2zlarfy_8f.html',1,'(Global Namespace)'],['../d0/d71/_t_e_s_t_i_n_g_2_e_i_g_2zlarfy_8f.html',1,'(Global Namespace)']]],
   ['zlarge_2ef',['zlarge.f',['../d0/d65/zlarge_8f.html',1,'']]],
   ['zlargv_2ef',['zlargv.f',['../de/df7/zlargv_8f.html',1,'']]],
-  ['zlarhs_2ef',['zlarhs.f',['../d8/ddd/_l_i_n_2zlarhs_8f.html',1,'']]],
-  ['zlarhs_2ef',['zlarhs.f',['../d9/ddf/_e_i_g_2zlarhs_8f.html',1,'']]],
+  ['zlarhs_2ef',['zlarhs.f',['../d9/ddf/_e_i_g_2zlarhs_8f.html',1,'(Global Namespace)'],['../d8/ddd/_l_i_n_2zlarhs_8f.html',1,'(Global Namespace)']]],
   ['zlarnd_2ef',['zlarnd.f',['../da/d61/zlarnd_8f.html',1,'']]],
   ['zlarnv_2ef',['zlarnv.f',['../d6/d44/zlarnv_8f.html',1,'']]],
   ['zlaror_2ef',['zlaror.f',['../db/d50/zlaror_8f.html',1,'']]],
@@ -605,9 +597,7 @@ var searchData=
   ['zpot05_2ef',['zpot05.f',['../da/df3/zpot05_8f.html',1,'']]],
   ['zpot06_2ef',['zpot06.f',['../d5/db9/zpot06_8f.html',1,'']]],
   ['zpotf2_2ef',['zpotf2.f',['../d5/def/zpotf2_8f.html',1,'']]],
-  ['zpotrf_2ef',['zpotrf.f',['../da/d7a/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2zpotrf_8f.html',1,'']]],
-  ['zpotrf_2ef',['zpotrf.f',['../d5/dcc/_v_a_r_i_a_n_t_s_2cholesky_2_t_o_p_2zpotrf_8f.html',1,'']]],
-  ['zpotrf_2ef',['zpotrf.f',['../d1/db9/zpotrf_8f.html',1,'']]],
+  ['zpotrf_2ef',['zpotrf.f',['../da/d7a/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2zpotrf_8f.html',1,'(Global Namespace)'],['../d5/dcc/_v_a_r_i_a_n_t_s_2cholesky_2_t_o_p_2zpotrf_8f.html',1,'(Global Namespace)'],['../d1/db9/zpotrf_8f.html',1,'(Global Namespace)']]],
   ['zpotrf2_2ef',['zpotrf2.f',['../d4/d37/zpotrf2_8f.html',1,'']]],
   ['zpotri_2ef',['zpotri.f',['../d1/d5d/zpotri_8f.html',1,'']]],
   ['zpotrs_2ef',['zpotrs.f',['../df/daf/zpotrs_8f.html',1,'']]],
@@ -661,8 +651,7 @@ var searchData=
   ['zrqt03_2ef',['zrqt03.f',['../db/dc8/zrqt03_8f.html',1,'']]],
   ['zrzt01_2ef',['zrzt01.f',['../de/d45/zrzt01_8f.html',1,'']]],
   ['zrzt02_2ef',['zrzt02.f',['../d2/d5d/zrzt02_8f.html',1,'']]],
-  ['zsbmv_2ef',['zsbmv.f',['../dc/ddb/_e_i_g_2zsbmv_8f.html',1,'']]],
-  ['zsbmv_2ef',['zsbmv.f',['../d3/d64/_l_i_n_2zsbmv_8f.html',1,'']]],
+  ['zsbmv_2ef',['zsbmv.f',['../dc/ddb/_e_i_g_2zsbmv_8f.html',1,'(Global Namespace)'],['../d3/d64/_l_i_n_2zsbmv_8f.html',1,'(Global Namespace)']]],
   ['zscal_2ef',['zscal.f',['../d2/d74/zscal_8f.html',1,'']]],
   ['zsgt01_2ef',['zsgt01.f',['../de/dff/zsgt01_8f.html',1,'']]],
   ['zslect_2ef',['zslect.f',['../d8/d1d/zslect_8f.html',1,'']]],
